/*
 * Copyright 2024 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdint.h>
#include <string.h>

#include "applib/accel_service.h"


// ----------------------------------------------------------------
// Sample captured: 2015-09-05 19:59:07 local
AccelRawData *activity_sample_watch_on_table(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME watch_on_table
  //> TEST_EXPECTED 0
  //> TEST_EXPECTED_MIN 0
  //> TEST_EXPECTED_MAX 0
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    { 40, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 40, 8, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 16, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -992},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -992},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -992},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 56, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1008},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -992},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -992},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -992},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 40, 0, -976},
    { 48, 0, -1024},
    { 48, 8, -992},
    { 48, 8, -1008},
    { 48, 0, -976},
    { 48, 8, -1008},
    { 48, 0, -1016},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1016},
    { 48, 8, -992},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -992},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1008},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -992},
    { 48, 8, -992},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1008},
    { 40, 8, -1008},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -992},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    // elapsed: 1 minutes
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -992},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -992},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1024},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 8, -992},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 56, 0, -984},
    { 56, 0, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1008},
    { 48, 0, -1000},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 56, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 40, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -992},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 40, 0, -1008},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 56, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -992},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 56, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 56, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 56, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -992},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 56, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1016},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 40, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -992},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    // elapsed: 2 minutes
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -992},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -992},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -984},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 40, 8, -992},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -992},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -992},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -992},
    { 40, 8, -992},
    { 48, 0, -1008},
    { 56, 8, -992},
    { 40, 8, -976},
    { 48, 0, -1008},
    { 40, 0, -1016},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -984},
    { 48, 8, -968},
    { 48, -8, -992},
    { 56, 0, -1000},
    { 40, 8, -992},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -992},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 40, 8, -1008},
    { 40, 8, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 56, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 56, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -992},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 8, -992},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 56, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 8, -1008},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 56, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 56, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1008},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -992},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 40, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 56, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 56, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    // elapsed: 3 minutes
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -992},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 56, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 56, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 56, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 40, 0, -992},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -992},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -992},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -992},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 40, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 16, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 40, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 40, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 40, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -992},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 40, 8, -1000},
    { 48, 8, -1008},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 48, 0, -1008},
    { 40, 0, -1000},
    { 48, 8, -1008},
    { 48, 0, -1000},
    { 40, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 56, 0, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1008},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1000},
    { 48, 8, -1000},
    { 48, 8, -1000},
    { 48, 0, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
    { 48, 8, -1000},
    { 48, 8, -1008},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}



// ----------------------------------------------------------------
// Sample captured: 2015-09-18 08:59:10 local
AccelRawData *activity_sample_walk_70_hand_in_pocket(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME walk_70_hand_in_pocket
  //> TEST_EXPECTED 70
  //> TEST_EXPECTED_MIN 65
  //> TEST_EXPECTED_MAX 80
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { 392, -24, -928},
    { 384, -40, -936},
    { 416, -32, -936},
    { 408, -40, -944},
    { 408, -48, -920},
    { 392, -48, -904},
    { 408, -48, -912},
    { 384, -56, -912},
    { 384, -56, -928},
    { 408, -48, -944},
    { 376, -48, -928},
    { 360, -64, -920},
    { 368, -80, -896},
    { 400, -136, -872},
    { 344, -176, -928},
    { 368, -144, -976},
    { 368, -104, -936},
    { 360, -152, -872},
    { 328, -176, -792},
    { 352, -168, -848},
    { 888, -24, -920},
    { 480, -128, -728},
    { 512, -80, -592},
    { 624, -64, -512},
    { 592, 208, -456},
    { 680, 256, -464},
    { 856, 496, -536},
    { 920, 672, -560},
    { 872, 928, -624},
    { 680, 984, -544},
    { 712, 1360, -1440},
    { 240, 664, -864},
    { 520, 672, -600},
    { 736, 496, -504},
    { 960, 320, -472},
    { 984, 704, -512},
    { 952, 648, -352},
    { 600, 392, 80},
    { 456, 448, 232},
    { 552, 432, 40},
    { 376, 360, 248},
    { 640, 752, 192},
    { 768, 864, 224},
    { 712, 816, 320},
    { 696, 624, 352},
    { 864, 704, 352},
    { 896, 696, 336},
    { 736, 472, 432},
    { 856, 656, 280},
    { 744, 768, 424},
    { 688, 752, -16},
    { 632, 792, 248},
    { 720, 848, 152},
    { 728, 856, -8},
    { 640, 544, 184},
    { 824, 712, 224},
    { 880, 976, 216},
    { 1120, 808, 360},
    { 880, 480, 368},
    { 704, 64, 152},
    { 584, -96, 128},
    { 720, 208, 288},
    { 976, 576, 184},
    { 1248, 824, 328},
    { 1216, 696, 368},
    { 1032, 480, 256},
    { 696, 272, 304},
    { 600, 192, 128},
    { 544, 288, 8},
    { 672, 552, -24},
    { 808, 520, -72},
    { 816, 464, 8},
    { 936, 504, 64},
    { 1080, 720, 48},
    { 1136, 720, -32},
    { 800, 552, 40},
    { 856, 512, 8},
    { 1224, 896, 144},
    { 1296, 560, 336},
    { 528, -128, 384},
    { 656, 128, 304},
    { 648, 672, 424},
    { 720, 744, 488},
    { 864, 536, 416},
    { 872, 352, 344},
    { 808, 416, 416},
    { 752, 432, 424},
    { 752, 416, 376},
    { 808, 560, 336},
    { 768, 656, 304},
    { 744, 592, 256},
    { 712, 512, 248},
    { 744, 520, 288},
    { 768, 600, 392},
    { 808, 712, 384},
    { 784, 648, 384},
    { 832, 640, 464},
    { 960, 672, 656},
    { 1136, 768, 616},
    { 880, 408, 544},
    { 800, 200, 360},
    { 672, 48, 296},
    { 848, 40, 464},
    { 1128, 376, 552},
    { 1048, 584, 552},
    { 928, 560, 448},
    { 776, 392, 280},
    { 616, 248, 128},
    { 552, 240, -8},
    { 568, 312, -48},
    { 752, 424, -88},
    { 792, 624, -80},
    { 864, 800, -8},
    { 1056, 960, 8},
    { 1048, 576, 8},
    { 936, 360, 96},
    { 1600, 1288, 144},
    { 784, -144, 392},
    { 576, -112, 408},
    { 864, 272, 312},
    { 576, 696, 512},
    { 616, 720, 600},
    { 720, 584, 504},
    { 808, 480, 392},
    { 848, 400, 464},
    { 776, 400, 504},
    { 752, 384, 424},
    { 776, 432, 352},
    { 744, 552, 344},
    { 752, 608, 336},
    { 776, 568, 312},
    { 816, 488, 352},
    { 856, 520, 424},
    { 888, 656, 400},
    { 840, 696, 464},
    { 808, 760, 568},
    { 984, 744, 600},
    { 992, 544, 512},
    { 816, 336, 328},
    { 808, 24, 312},
    { 1000, -48, 480},
    { 1000, 328, 480},
    { 944, 552, 456},
    { 856, 560, 336},
    { 712, 480, 224},
    { 632, 384, 80},
    { 536, 232, 16},
    { 616, 384, 56},
    { 896, 552, 24},
    { 848, 488, -16},
    { 784, 480, 80},
    { 864, 616, 72},
    { 952, 840, 72},
    { 1024, 848, 40},
    { 960, 560, 80},
    { 1184, 728, 120},
    { 1320, 760, 200},
    { 568, -152, 448},
    { 488, -64, 384},
    { 728, 496, 392},
    { 896, 680, 448},
    { 936, 608, 472},
    { 840, 448, 400},
    { 792, 352, 400},
    { 744, 392, 384},
    { 776, 512, 304},
    { 848, 512, 176},
    { 776, 600, 232},
    { 752, 632, 280},
    { 760, 576, 256},
    { 760, 536, 312},
    { 792, 552, 352},
    { 808, 696, 304},
    { 832, 728, 352},
    { 976, 736, 512},
    { 1104, 672, 496},
    { 1016, 504, 504},
    { 920, 408, 360},
    { 808, 128, 256},
    { 904, -8, 320},
    { 1056, 184, 368},
    { 1072, 448, 368},
    { 976, 536, 304},
    { 768, 360, 216},
    { 640, 288, 88},
    { 560, 240, -16},
    { 624, 240, -40},
    { 784, 400, -112},
    { 896, 680, -104},
    { 944, 728, -80},
    { 992, 744, -96},
    { 1064, 680, -64},
    { 1224, 560, 56},
    { 1480, 888, 168},
    { 624, -192, 384},
    { 672, 32, 216},
    { 736, 424, 256},
    { 656, 768, 424},
    { 696, 624, 512},
    { 712, 512, 432},
    { 824, 592, 360},
    { 824, 504, 400},
    { 792, 352, 368},
    { 832, 360, 288},
    { 824, 528, 232},
    { 752, 640, 280},
    { 712, 608, 240},
    { 760, 560, 216},
    { 744, 520, 368},
    { 792, 616, 400},
    { 784, 736, 368},
    { 944, 800, 504},
    { 1184, 648, 520},
    { 1136, 664, 592},
    { 928, 368, 520},
    { 848, 208, 224},
    { 768, -80, 224},
    { 952, 8, 304},
    { 1064, 296, 352},
    { 1096, 552, 360},
    { 872, 472, 304},
    { 664, 328, 208},
    { 560, 256, 40},
    { 608, 256, -112},
    { 728, 352, -176},
    { 824, 608, -80},
    { 984, 752, -56},
    { 1072, 816, -24},
    { 992, 456, -24},
    { 920, 336, -64},
    { 1440, 912, 16},
    { 1152, 256, 440},
    { 536, -88, 448},
    { 832, 160, 280},
    { 592, 568, 416},
    { 656, 768, 528},
    { 696, 640, 472},
    { 792, 520, 360},
    { 816, 456, 400},
    { 800, 448, 416},
    { 776, 416, 376},
    { 800, 472, 304},
    { 768, 536, 296},
    { 744, 544, 328},
    { 800, 544, 304},
    { 808, 544, 360},
    { 824, 600, 464},
    { 896, 648, 328},
    { 824, 752, 480},
    { 848, 808, 624},
    { 1064, 736, 568},
    { 936, 536, 440},
    { 800, 280, 304},
    { 912, -96, 392},
    { 1088, 80, 496},
    { 1000, 440, 480},
    { 936, 560, 376},
    { 776, 464, 264},
    { 552, 352, 120},
    { 488, 184, -80},
    { 496, 184, -40},
    { 752, 440, -32},
    { 1000, 848, 8},
    { 1000, 728, 48},
    { 928, 528, 112},
    { 1040, 488, 0},
    { 944, 568, -80},
    { 1024, 608, -24},
    { 1480, 1184, 88},
    { 864, 16, 288},
    { 568, -200, 368},
    { 752, 264, 336},
    { 600, 672, 480},
    { 752, 752, 472},
    { 816, 624, 352},
    { 840, 464, 312},
    { 864, 368, 408},
    { 768, 456, 400},
    { 760, 496, 336},
    { 760, 520, 256},
    { 720, 568, 224},
    { 728, 592, 256},
    { 784, 560, 264},
    { 848, 568, 352},
    { 904, 568, 360},
    { 856, 632, 400},
    { 888, 752, 424},
    { 928, 760, 592},
    { 1080, 640, 552},
    { 904, 488, 544},
    { 816, 296, 336},
    { 792, 16, 328},
    { 968, -8, 488},
    { 1104, 368, 472},
    { 992, 624, 424},
    { 888, 600, 288},
    { 656, 360, 200},
    { 536, 224, 48},
    { 496, 176, -80},
    { 648, 360, -104},
    { 816, 640, -104},
    { 896, 776, -40},
    { 1024, 776, -64},
    { 1080, 608, -80},
    { 880, 392, -32},
    { 1240, 760, -48},
    { 1280, 560, 368},
    { 624, -128, 456},
    { 744, 160, 400},
    { 648, 656, 464},
    { 584, 840, 584},
    { 728, 648, 376},
    { 816, 368, 256},
    { 816, 400, 360},
    { 808, 488, 368},
    { 800, 480, 280},
    { 792, 496, 200},
    { 752, 632, 240},
    { 760, 688, 256},
    { 792, 528, 240},
    { 824, 472, 344},
    { 888, 512, 376},
    { 872, 632, 320},
    { 888, 752, 408},
    { 800, 888, 568},
    { 1048, 824, 384},
    { 1008, 448, 600},
    { 872, 360, 320},
    { 768, 16, 272},
    { 936, 32, 344},
    { 1032, 288, 392},
    { 968, 512, 392},
    { 896, 520, 304},
    { 752, 400, 224},
    { 656, 304, 112},
    { 600, 240, 24},
    { 720, 352, -48},
    { 824, 472, -16},
    { 856, 536, 16},
    { 880, 560, 8},
    { 1024, 752, -56},
    { 1128, 760, -40},
    { 856, 352, 80},
    { 952, 456, -120},
    { 1448, 1080, -112},
    { 1096, 256, 448},
    { 448, -256, 552},
    { 696, 160, 344},
    { 680, 624, 408},
    { 840, 848, 448},
    { 800, 640, 432},
    { 800, 392, 360},
    { 792, 352, 432},
    { 776, 408, 432},
    { 808, 504, 312},
    { 808, 544, 208},
    { 768, 560, 232},
    { 752, 552, 296},
    { 808, 528, 312},
    { 832, 496, 368},
    { 920, 544, 344},
    { 896, 632, 384},
    { 816, 768, 472},
    { 888, 856, 488},
    { 1080, 592, 496},
    { 904, 480, 448},
    { 848, 256, 256},
    { 856, -80, 336},
    { 1056, 136, 440},
    { 1008, 456, 432},
    { 952, 560, 336},
    { 840, 456, 248},
    { 696, 336, 152},
    { 632, 264, 32},
    { 600, 288, -16},
    { 736, 416, -64},
    { 832, 544, -64},
    { 832, 592, 16},
    { 888, 632, 16},
    { 1048, 688, 16},
    { 1056, 464, -16},
    { 792, 344, 56},
    { 1024, 640, 16},
    { 1496, 1312, 240},
    { 760, -48, 512},
    { 528, -192, 416},
    { 616, 208, 368},
    { 680, 712, 472},
    { 832, 784, 552},
    { 840, 552, 440},
    { 792, 344, 392},
    { 792, 432, 384},
    { 776, 480, 344},
    { 800, 480, 280},
    { 808, 560, 264},
    { 752, 656, 296},
    { 760, 592, 256},
    { 752, 480, 288},
    { 768, 456, 392},
    { 848, 536, 392},
    { 824, 656, 392},
    { 840, 752, 504},
    { 976, 808, 568},
    { 1056, 656, 496},
    { 1000, 416, 576},
    { 888, 312, 256},
    { 792, 24, 264},
    { 912, 0, 320},
    { 976, 304, 368},
    { 976, 568, 336},
    { 880, 560, 240},
    { 760, 384, 160},
    { 720, 280, 48},
    { 648, 256, 24},
    { 704, 296, -24},
    { 768, 408, -40},
    { 784, 552, 0},
    { 864, 616, 8},
    { 1040, 736, 16},
    { 1168, 680, 0},
    { 944, 448, 32},
    { 984, 408, -40},
    { 1504, 1000, 24},
    { 960, 112, 264},
    { 600, -72, 400},
    { 640, 120, 496},
    { 672, 480, 552},
    { 936, 848, 488},
    { 792, 648, 448},
    { 792, 344, 368},
    { 776, 344, 400},
    { 760, 448, 408},
    { 800, 552, 320},
    { 792, 504, 224},
    { 744, 528, 272},
    { 736, 576, 336},
    { 808, 568, 336},
    { 816, 536, 424},
    { 872, 568, 400},
    { 928, 632, 432},
    { 880, 744, 576},
    { 1048, 792, 544},
    { 968, 664, 504},
    { 896, 464, 384},
    { 768, 160, 304},
    { 880, -88, 448},
    { 960, 128, 496},
    { 968, 440, 448},
    { 928, 576, 344},
    { 760, 488, 256},
    { 680, 360, 136},
    { 624, 264, 32},
    { 648, 256, 0},
    { 744, 344, 8},
    { 832, 448, 16},
    { 904, 616, 24},
    { 1056, 816, 8},
    { 1096, 688, 88},
    { 888, 448, 104},
    { 768, 336, 128},
    { 1224, 776, -72},
    { 1416, 952, 240},
    { 656, -168, 504},
    { 608, -88, 424},
    { 640, 376, 408},
    { 760, 728, 528},
    { 840, 744, 536},
    { 776, 488, 432},
    { 784, 304, 424},
    { 792, 352, 440},
    { 800, 416, 400},
    { 824, 480, 304},
    { 768, 544, 256},
    { 736, 568, 296},
    { 752, 552, 336},
    { 808, 528, 328},
    { 848, 488, 440},
    { 904, 568, 400},
    { 920, 616, 472},
    { 872, 744, 608},
    { 1056, 800, 544},
    { 904, 592, 576},
    { 872, 432, 344},
    { 768, 152, 288},
    { 928, -40, 448},
    { 1064, 208, 520},
    { 992, 480, 480},
    { 912, 536, 352},
    { 728, 448, 224},
    { 592, 328, 104},
    { 536, 232, -32},
    { 608, 272, -16},
    { 776, 464, -48},
    { 864, 696, -16},
    { 896, 688, 24},
    { 1048, 696, 56},
    { 1112, 512, 32},
    { 848, 416, 48},
    { 1024, 688, 16},
    { 1544, 1272, 160},
    { 688, -208, 432},
    { 616, -176, 440},
    { 784, 272, 344},
    { 656, 728, 504},
    { 760, 744, 552},
    { 736, 544, 456},
    { 808, 408, 376},
    { 824, 384, 440},
    { 792, 408, 472},
    { 784, 432, 408},
    { 784, 480, 296},
    { 760, 560, 288},
    { 728, 544, 344},
    { 776, 528, 304},
    { 824, 488, 376},
    { 872, 496, 464},
    { 872, 528, 440},
    { 952, 608, 456},
    { 816, 808, 608},
    { 1080, 832, 544},
    { 936, 560, 536},
    { 768, 400, 304},
    { 752, 56, 304},
    { 984, -24, 504},
    { 1064, 392, 536},
    { 944, 520, 480},
    { 872, 520, 320},
    { 672, 424, 216},
    { 608, 336, 64},
    { 544, 256, -48},
    { 616, 296, 24},
    { 784, 456, -24},
    { 888, 568, -48},
    { 912, 704, 32},
    { 1048, 824, 80},
    { 1144, 680, 48},
    { 760, 384, 112},
    { 912, 512, -24},
    { 1384, 1104, 104},
    { 1112, 192, 400},
    { 544, -280, 448},
    { 696, 152, 376},
    { 680, 664, 464},
    { 808, 848, 536},
    { 768, 576, 496},
    { 784, 344, 400},
    { 792, 312, 440},
    { 784, 392, 440},
    { 808, 472, 360},
    { 800, 536, 288},
    { 736, 568, 280},
    { 728, 576, 312},
    { 768, 552, 328},
    { 824, 480, 416},
    { 888, 520, 416},
    { 896, 632, 480},
    { 856, 784, 640},
    { 1064, 880, 568},
    { 936, 624, 584},
    { 832, 408, 344},
    { 808, 80, 304},
    { 960, -64, 440},
    { 1032, 240, 488},
    { 952, 480, 456},
    { 880, 584, 312},
    { 744, 464, 216},
    { 648, 304, 128},
    { 576, 200, 24},
    { 640, 280, -16},
    { 784, 448, -40},
    { 856, 616, -32},
    { 936, 784, -24},
    { 1064, 840, 40},
    { 976, 520, 16},
    { 784, 376, 24},
    { 1176, 728, -24},
    { 1496, 1080, 248},
    { 664, -192, 416},
    { 712, -88, 432},
    { 688, 424, 424},
    { 656, 760, 600},
    { 704, 680, 592},
    { 752, 512, 416},
    { 808, 376, 400},
    { 784, 416, 448},
    { 768, 424, 440},
    { 808, 448, 320},
    { 800, 512, 256},
    { 736, 576, 328},
    { 760, 560, 344},
    { 824, 528, 312},
    { 792, 464, 432},
    { 832, 592, 464},
    { 808, 648, 440},
    { 808, 680, 440},
    { 848, 824, 592},
    { 1104, 784, 504},
    { 952, 472, 568},
    { 856, 336, 304},
    { 752, 64, 304},
    { 928, 16, 448},
    { 1040, 304, 488},
    { 944, 480, 464},
    { 896, 560, 280},
    { 712, 408, 184},
    { 672, 336, 16},
    { 576, 224, 16},
    { 672, 288, 32},
    { 776, 408, 16},
    { 872, 472, 32},
    { 928, 592, 56},
    { 1064, 776, 72},
    { 1200, 768, 40},
    { 840, 416, 80},
    { 752, 336, -40},
    { 1032, 800, -64},
    { 1472, 1048, 232},
    { 640, -208, 672},
    { 496, -200, 472},
    { 712, 320, 376},
    { 856, 768, 464},
    { 848, 776, 576},
    { 776, 416, 464},
    { 784, 288, 448},
    { 776, 360, 448},
    { 784, 432, 392},
    { 808, 536, 264},
    { 752, 568, 248},
    { 744, 552, 288},
    { 776, 536, 320},
    { 800, 472, 408},
    { 864, 504, 440},
    { 872, 584, 392},
    { 864, 648, 440},
    { 792, 784, 592},
    { 1072, 744, 560},
    { 968, 496, 592},
    { 864, 360, 384},
    { 840, 88, 304},
    { 1000, 8, 464},
    { 1040, 304, 520},
    { 968, 480, 464},
    { 928, 512, 304},
    { 696, 376, 216},
    { 624, 304, 72},
    { 544, 248, -32},
    { 592, 272, -40},
    { 736, 400, -72},
    { 832, 624, 0},
    { 1000, 768, 56},
    { 1216, 816, 40},
    { 984, 408, 48},
    { 808, 384, 56},
    { 1496, 1000, 72},
    { 1416, 672, 248},
    { 472, -392, 528},
    { 600, -24, 312},
    { 624, 512, 400},
    { 736, 912, 528},
    { 808, 720, 512},
    { 800, 440, 400},
    { 816, 360, 440},
    { 808, 384, 416},
    { 792, 376, 368},
    { 800, 424, 296},
    { 752, 536, 296},
    { 744, 568, 352},
    { 776, 496, 368},
    { 816, 440, 408},
    { 872, 464, 464},
    { 856, 632, 432},
    { 904, 760, 464},
    { 800, 824, 584},
    { 1024, 784, 512},
    { 904, 568, 488},
    { 848, 392, 360},
    { 808, 120, 320},
    { 984, -24, 488},
    { 1048, 288, 544},
    { 960, 472, 464},
    { 896, 512, 312},
    { 688, 408, 192},
    { 616, 328, 32},
    { 560, 280, 48},
    { 664, 288, 64},
    { 808, 440, 0},
    { 912, 624, 32},
    { 920, 648, 72},
    { 1032, 664, 80},
    { 1096, 576, 48},
    { 848, 424, 56},
    { 904, 520, -32},
    { 1368, 1080, 16},
    { 1080, 200, 328},
    { 592, -176, 480},
    { 760, 136, 400},
    { 624, 584, 504},
    { 752, 752, 576},
    { 792, 616, 488},
    { 800, 424, 400},
    { 800, 368, 424},
    { 768, 432, 416},
    { 784, 456, 344},
    { 800, 488, 272},
    { 752, 552, 288},
    { 736, 592, 328},
    { 784, 568, 344},
    { 800, 536, 392},
    { 832, 536, 456},
    { 856, 632, 432},
    { 872, 728, 552},
    { 1016, 848, 568},
    { 944, 760, 512},
    { 888, 456, 464},
    { 800, 288, 320},
    { 792, -16, 304},
    { 1040, 56, 408},
    { 1064, 416, 424},
    { 976, 536, 408},
    { 816, 480, 264},
    { 672, 384, 120},
    { 608, 328, -16},
    { 560, 224, 24},
    { 680, 280, 8},
    { 808, 392, 24},
    { 936, 568, 40},
    { 1000, 720, 48},
    { 1088, 768, 88},
    { 1080, 672, 16},
    { 744, 392, 80},
    { 928, 592, -72},
    { 1488, 1144, 104},
    { 984, 48, 448},
    { 544, -344, 504},
    { 704, 112, 400},
    { 736, 640, 488},
    { 888, 816, 552},
    { 776, 520, 520},
    { 784, 320, 432},
    { 776, 368, 440},
    { 768, 424, 424},
    { 792, 496, 304},
    { 800, 512, 232},
    { 744, 576, 320},
    { 744, 584, 368},
    { 784, 544, 360},
    { 840, 480, 440},
    { 848, 584, 448},
    { 880, 640, 464},
    { 872, 704, 576},
    { 1032, 768, 504},
    { 944, 568, 496},
    { 888, 416, 352},
    { 768, 192, 304},
    { 944, -32, 480},
    { 1072, 192, 560},
    { 992, 432, 488},
    { 920, 504, 336},
    { 760, 432, 192},
    { 632, 344, 64},
    { 576, 264, -16},
    { 584, 216, 32},
    { 712, 368, -16},
    { 832, 584, 8},
    { 960, 720, 8},
    { 1128, 840, 48},
    { 1088, 504, 56},
    { 856, 384, 48},
    { 928, 432, -8},
    { 1480, 1096, 152},
    { 1192, 368, 376},
    { 504, -240, 416},
    { 720, 88, 328},
    { 672, 688, 464},
    { 696, 784, 632},
    { 784, 560, 488},
    { 768, 432, 384},
    { 808, 424, 432},
    { 784, 480, 416},
    { 760, 464, 360},
    { 776, 504, 264},
    { 744, 552, 288},
    { 728, 600, 352},
    { 768, 528, 360},
    { 792, 448, 360},
    { 824, 456, 448},
    { 848, 576, 416},
    { 840, 648, 432},
    { 784, 784, 552},
    { 960, 816, 600},
    { 1040, 560, 616},
    { 944, 448, 448},
    { 872, 256, 288},
    { 880, 8, 424},
    { 1032, 144, 544},
    { 960, 400, 504},
    { 912, 504, 360},
    { 752, 440, 224},
    { 656, 344, 80},
    { 600, 264, -24},
    { 656, 328, 48},
    { 784, 448, 48},
    { 856, 480, 16},
    { 832, 544, 32},
    { 888, 664, 72},
    { 1000, 768, 96},
    { 1056, 664, 24},
    { 832, 400, 120},
    { 1040, 592, -32},
    { 1376, 1096, 168},
    { 824, -72, 424},
    { 520, -184, 456},
    { 648, 320, 464},
    { 752, 712, 576},
    { 872, 760, 576},
    { 792, 472, 448},
    { 792, 304, 416},
    { 768, 376, 384},
    { 784, 440, 336},
    { 816, 448, 264},
    { 752, 544, 272},
    { 704, 624, 320},
    { 800, 568, 392},
    { 808, 512, 416},
    { 880, 464, 424},
    { 832, 504, 416},
    { 840, 648, 480},
    { 832, 832, 624},
    { 1048, 696, 504},
    { 896, 448, 584},
    { 936, 344, 376},
    { 832, 136, 304},
    { 968, 24, 456},
    { 1064, 256, 512},
    { 1016, 488, 440},
    { 904, 528, 320},
    { 720, 352, 200},
    { 600, 264, 64},
    { 544, 232, -24},
    { 592, 248, 32},
    { 760, 440, 24},
    { 904, 608, 24},
    { 984, 704, 32},
    { 1088, 824, 40},
    { 1040, 632, -8},
    { 784, 384, 40},
    { 872, 512, -40},
    { 1464, 1232, -56},
    { 1040, 184, 440},
    { 576, -280, 464},
    { 768, 152, 384},
    { 704, 624, 496},
    { 784, 832, 600},
    { 736, 552, 520},
    { 776, 344, 416},
    { 760, 360, 440},
    { 760, 432, 432},
    { 792, 528, 360},
    { 800, 560, 256},
    { 728, 576, 280},
    { 728, 552, 360},
    { 784, 512, 368},
    { 816, 456, 416},
    { 872, 504, 464},
    { 832, 544, 432},
    { 920, 624, 464},
    { 800, 832, 624},
    { 976, 928, 560},
    { 904, 592, 544},
    { 880, 368, 392},
    { 824, 104, 304},
    { 992, -64, 512},
    { 1040, 312, 544},
    { 976, 512, 464},
    { 904, 544, 304},
    { 688, 440, 184},
    { 592, 344, 56},
    { 528, 256, 0},
    { 592, 224, -16},
    { 720, 400, -48},
    { 872, 680, -16},
    { 1048, 816, -40},
    { 1144, 728, 40},
    { 1000, 392, 88},
    { 792, 304, 8},
    { 904, 624, -56},
    { 1544, 1440, 48},
    { 944, -80, 368},
    { 528, -336, 528},
    { 856, 200, 312},
    { 656, 744, 488},
    { 736, 808, 560},
    { 680, 552, 464},
    { 768, 432, 368},
    { 800, 448, 400},
    { 792, 480, 392},
    { 800, 456, 304},
    { 800, 504, 232},
    { 736, 600, 280},
    { 752, 568, 328},
    { 776, 480, 320},
    { 800, 480, 408},
    { 808, 608, 496},
    { 800, 664, 392},
    { 912, 608, 432},
    { 880, 672, 648},
    { 1088, 736, 560},
    { 896, 520, 536},
    { 872, 312, 376},
    { 824, 88, 336},
    { 1024, 24, 488},
    { 1056, 288, 576},
    { 952, 464, 480},
    { 888, 528, 280},
    { 648, 400, 144},
    { 584, 336, -8},
    { 544, 224, 48},
    { 688, 352, 80},
    { 832, 528, 48},
    { 904, 584, 32},
    { 856, 600, 72},
    { 896, 616, 104},
    { 1032, 688, 88},
    { 1000, 536, 16},
    { 832, 352, 64},
    { 912, 616, -16},
    { 1480, 1256, 176},
    { 896, 56, 432},
    { 496, -344, 472},
    { 680, 208, 400},
    { 800, 656, 504},
    { 888, 712, 592},
    { 816, 488, 512},
    { 784, 344, 424},
    { 736, 352, 408},
    { 776, 440, 336},
    { 832, 480, 224},
    { 792, 504, 272},
    { 752, 552, 312},
    { 760, 592, 392},
    { 792, 552, 384},
    { 840, 456, 408},
    { 864, 520, 376},
    { 840, 760, 424},
    { 800, 840, 584},
    { 1008, 816, 528},
    { 976, 528, 624},
    { 928, 392, 424},
    { 888, 120, 288},
    { 1008, -32, 400},
    { 1040, 208, 480},
    { 952, 464, 448},
    { 872, 552, 304},
    { 704, 400, 176},
    { 632, 280, 16},
    { 552, 248, -64},
    { 656, 312, -16},
    { 816, 504, -24},
    { 888, 680, 0},
    { 944, 728, -8},
    { 1024, 720, 0},
    { 944, 536, -32},
    { 832, 472, 32},
    { 1096, 592, 0},
    { 1488, 1016, 200},
    { 776, -128, 384},
    { 680, -168, 480},
    { 680, 344, 464},
    { 680, 712, 608},
    { 784, 744, 568},
    { 744, 528, 440},
    { 784, 392, 416},
    { 768, 416, 440},
    { 784, 456, 376},
    { 816, 456, 272},
    { 744, 544, 304},
    { 720, 632, 328},
    { 752, 560, 328},
    { 800, 496, 336},
    { 840, 472, 456},
    { 872, 568, 456},
    { 816, 592, 384},
    { 872, 640, 416},
    { 728, 816, 616},
    { 1064, 704, 520},
    { 1032, 400, 592},
    { 928, 368, 400},
    { 840, 72, 328},
    { 960, 32, 456},
    { 992, 304, 496},
    { 952, 496, 432},
    { 864, 536, 272},
    { 680, 392, 160},
    { 640, 256, 24},
    { 544, 168, 64},
    { 728, 336, 48},
    { 840, 504, 24},
    { 896, 600, 48},
    { 920, 624, 112},
    { 1032, 640, 104},
    { 1056, 608, -8},
    { 816, 448, 32},
    { 944, 520, -48},
    { 1488, 1240, 192},
    { 1056, 216, 432},
    { 448, -384, 552},
    { 728, 80, 400},
    { 672, 624, 488},
    { 832, 848, 560},
    { 768, 544, 504},
    { 784, 392, 384},
    { 776, 376, 416},
    { 784, 416, 392},
    { 808, 448, 328},
    { 800, 504, 280},
    { 744, 584, 320},
    { 752, 544, 360},
    { 752, 520, 376},
    { 800, 472, 408},
    { 880, 504, 416},
    { 824, 568, 400},
    { 856, 608, 480},
    { 824, 792, 632},
    { 1040, 840, 520},
    { 1000, 552, 552},
    { 896, 392, 408},
    { 832, 160, 256},
    { 896, -40, 416},
    { 1000, 184, 480},
    { 968, 448, 432},
    { 904, 552, 296},
    { 736, 464, 168},
    { 680, 376, 72},
    { 616, 256, 56},
    { 672, 320, 40},
    { 736, 432, 32},
    { 816, 488, 48},
    { 880, 552, 40},
    { 968, 672, 24},
    { 1104, 704, 96},
    { 1008, 576, 80},
    { 896, 464, 80},
    { 1120, 664, 32},
    { 1352, 824, 200},
    { 640, -112, 464},
    { 680, -88, 416},
    { 640, 384, 424},
    { 768, 680, 560},
    { 864, 640, 576},
    { 776, 440, 480},
    { 776, 336, 448},
    { 760, 384, 416},
    { 792, 456, 352},
    { 824, 520, 288},
    { 784, 520, 288},
    { 768, 592, 328},
    { 768, 584, 368},
    { 792, 544, 360},
    { 808, 440, 432},
    { 856, 528, 432},
    { 904, 640, 488},
    { 944, 776, 664},
    { 1120, 792, 552},
    { 968, 512, 560},
    { 848, 288, 328},
    { 808, -80, 344},
    { 952, 0, 400},
    { 968, 304, 392},
    { 952, 512, 320},
    { 832, 512, 192},
    { 720, 392, 48},
    { 632, 240, 64},
    { 672, 224, 80},
    { 744, 336, 56},
    { 824, 448, 64},
    { 896, 544, 48},
    { 952, 616, 72},
    { 1024, 632, 104},
    { 1064, 696, 0},
    { 856, 528, -24},
    { 920, 456, -104},
    { 1336, 656, 8},
    { 1320, 648, 296},
    { 632, -144, 536},
    { 640, 32, 448},
    { 640, 368, 448},
    { 800, 696, 536},
    { 912, 720, 480},
    { 800, 504, 424},
    { 824, 336, 392},
    { 752, 400, 384},
    { 736, 464, 328},
    { 776, 528, 240},
    { 728, 536, 288},
    { 752, 576, 336},
    { 800, 560, 368},
    { 816, 520, 416},
    { 848, 536, 440},
    { 864, 536, 424},
    { 824, 688, 512},
    { 880, 792, 560},
    { 1056, 552, 592},
    { 968, 456, 536},
    { 896, 344, 368},
    { 848, 56, 352},
    { 1008, 16, 464},
    { 1040, 312, 448},
    { 1008, 520, 384},
    { 856, 488, 248},
    { 664, 336, 128},
    { 576, 280, 8},
    { 488, 216, -8},
    { 624, 304, -16},
    { 824, 520, -64},
    { 960, 800, -24},
    { 1072, 832, -16},
    { 1112, 560, 56},
    { 912, 368, 32},
    { 1096, 688, -16},
    { 1528, 1280, 160},
    { 616, -248, 392},
    { 728, -24, 352},
    { 752, 424, 344},
    { 640, 752, 552},
    { 720, 616, 568},
    { 720, 504, 448},
    { 792, 488, 416},
    { 784, 496, 408},
    { 776, 456, 352},
    { 792, 448, 264},
    { 768, 528, 264},
    { 712, 632, 336},
    { 744, 592, 344},
    { 776, 552, 320},
    { 800, 520, 400},
    { 808, 544, 464},
    { 808, 648, 448},
    { 832, 776, 616},
    { 1064, 824, 576},
    { 1080, 536, 616},
    { 968, 376, 520},
    { 880, 280, 264},
    { 792, 24, 352},
    { 944, -8, 464},
    { 952, 280, 440},
    { 984, 464, 384},
    { 880, 560, 240},
    { 720, 464, 80},
    { 656, 288, 8},
    { 600, 168, 32},
    { 728, 320, 16},
    { 832, 520, 8},
    { 880, 664, 32},
    { 864, 608, 24},
    { 928, 608, 24},
    { 1032, 592, 8},
    { 864, 544, 24},
    { 968, 584, -40},
    { 1696, 1184, 176},
    { 1208, 376, 352},
    { 456, -424, 384},
    { 560, -64, 240},
    { 688, 640, 448},
    { 736, 928, 584},
    { 864, 576, 480},
    { 824, 408, 368},
    { 816, 432, 408},
    { 784, 464, 368},
    { 776, 448, 264},
    { 776, 464, 232},
    { 736, 544, 296},
    { 752, 576, 328},
    { 784, 496, 336},
    { 792, 480, 400},
    { 784, 584, 472},
    { 768, 800, 488},
    { 1040, 752, 608},
    { 1080, 640, 624},
    { 1032, 496, 600},
    { 952, 376, 424},
    { 832, 192, 296},
    { 864, -120, 392},
    { 960, 8, 440},
    { 1032, 296, 424},
    { 1016, 528, 336},
    { 832, 488, 144},
    { 680, 376, 16},
    { 616, 224, 64},
    { 624, 208, 56},
    { 760, 312, 8},
    { 856, 464, 0},
    { 912, 624, 32},
    { 976, 712, 16},
    { 1088, 712, 40},
    { 912, 488, -32},
    { 792, 376, -48},
    { 1264, 736, 48},
    { 1528, 968, 344},
    { 592, -296, 520},
    { 704, -16, 360},
    { 624, 408, 472},
    { 744, 832, 576},
    { 816, 680, 520},
    { 760, 376, 408},
    { 808, 320, 432},
    { 800, 440, 416},
    { 768, 512, 360},
    { 768, 520, 280},
    { 736, 552, 288},
    { 728, 536, 368},
    { 784, 520, 376},
    { 808, 472, 408},
    { 872, 520, 432},
    { 824, 560, 424},
    { 872, 696, 480},
    { 856, 760, 672},
    { 1048, 864, 520},
    { 840, 520, 616},
    { 872, 312, 376},
    { 784, 96, 296},
    { 920, 16, 504},
    { 984, 296, 544},
    { 928, 472, 448},
    { 880, 568, 256},
    { 752, 496, 88},
    { 648, 360, 88},
    { 616, 264, 88},
    { 696, 328, 80},
    { 768, 440, 40},
    { 840, 472, 16},
    { 824, 512, 48},
    { 904, 608, 64},
    { 1040, 736, 72},
    { 1072, 576, 56},
    { 840, 416, 104},
    { 1032, 656, 0},
    { 1456, 1120, 208},
    { 936, 152, 456},
    { 488, -320, 488},
    { 624, 120, 408},
    { 720, 632, 504},
    { 824, 784, 568},
    { 784, 552, 480},
    { 784, 368, 400},
    { 768, 400, 400},
    { 808, 464, 344},
    { 800, 432, 312},
    { 808, 496, 280},
    { 768, 568, 320},
    { 768, 544, 384},
    { 776, 480, 368},
    { 792, 472, 424},
    { 840, 528, 432},
    { 872, 624, 448},
    { 872, 752, 576},
    { 992, 800, 616},
    { 1000, 616, 552},
    { 904, 480, 432},
    { 816, 248, 288},
    { 888, -40, 408},
    { 1056, 80, 528},
    { 976, 376, 496},
    { 944, 488, 336},
    { 768, 448, 216},
    { 656, 408, 72},
    { 632, 312, 24},
    { 648, 272, 48},
    { 744, 384, 16},
    { 792, 504, 0},
    { 784, 648, 32},
    { 896, 712, -24},
    { 1064, 696, 32},
    { 1064, 432, 0},
    { 936, 368, 48},
    { 1408, 920, -8},
    { 1336, 616, 336},
    { 464, -256, 480},
    { 744, 32, 320},
    { 664, 560, 400},
    { 720, 784, 584},
    { 792, 568, 544},
    { 776, 448, 424},
    { 808, 408, 456},
    { 800, 456, 424},
    { 752, 448, 376},
    { 776, 448, 280},
    { 768, 520, 296},
    { 760, 576, 352},
    { 768, 520, 376},
    { 800, 520, 352},
    { 808, 496, 464},
    { 848, 576, 432},
    { 808, 600, 432},
    { 800, 712, 496},
    { 864, 808, 608},
    { 1128, 600, 544},
    { 960, 408, 552},
    { 840, 296, 344},
    { 768, 48, 328},
    { 944, 48, 440},
    { 1000, 320, 456},
    { 1000, 536, 368},
    { 856, 520, 248},
    { 720, 360, 128},
    { 640, 264, 0},
    { 592, 208, 16},
    { 688, 360, 40},
    { 816, 488, 16},
    { 864, 592, 40},
    { 944, 704, 72},
    { 1072, 784, 88},
    { 1112, 584, 24},
    { 784, 360, 96},
    { 976, 600, -32},
    { 1432, 1232, 160},
    { 1000, 168, 400},
    { 472, -440, 520},
    { 600, 152, 400},
    { 752, 728, 456},
    { 832, 832, 552},
    { 816, 496, 512},
    { 792, 352, 456},
    { 736, 368, 464},
    { 768, 408, 384},
    { 800, 432, 296},
    { 800, 472, 272},
    { 784, 520, 320},
    { 776, 488, 368},
    { 816, 504, 360},
    { 816, 480, 464},
    { 872, 568, 440},
    { 904, 640, 464},
    { 792, 784, 616},
    { 1064, 816, 480},
    { 968, 512, 624},
    { 984, 392, 416},
    { 808, 200, 240},
    { 864, -64, 384},
    { 1000, 96, 472},
    { 1008, 424, 448},
    { 984, 544, 352},
    { 792, 440, 240},
    { 656, 336, 64},
    { 536, 232, -24},
    { 592, 208, -40},
    { 752, 488, -32},
    { 856, 720, 56},
    { 912, 680, 32},
    { 952, 656, -8},
    { 1064, 616, -16},
    { 896, 488, -72},
    { 864, 456, -16},
    { 1368, 872, 24},
    { 1272, 536, 424},
    { 520, -272, 480},
    { 848, 80, 352},
    { 672, 576, 424},
    { 680, 816, 568},
    { 752, 616, 512},
    { 760, 480, 400},
    { 816, 424, 440},
    { 808, 448, 416},
    { 784, 472, 368},
    { 768, 480, 312},
    { 744, 528, 320},
    { 736, 512, 384},
    { 800, 536, 384},
    { 800, 496, 384},
    { 792, 456, 432},
    { 800, 520, 432},
    { 808, 528, 400},
    { 760, 552, 392},
    { 848, 704, 488},
    { 872, 752, 536},
    { 1096, 744, 576},
    { 1096, 520, 600},
    { 1152, 368, 512},
    { 904, 608, 336},
    { 1096, 280, 288},
    { 904, 384, 408},
    { 888, 624, 280},
    { 736, 536, 208},
    { 640, 664, 72},
    { 600, 832, -200},
    { 648, 576, -400},
    { 616, 520, -320},
    { 560, 336, -440},
    { 488, 328, -632},
    { 480, 200, -720},
    { 464, 144, -808},
    { 432, 16, -792},
    { 352, 32, -832},
    { 328, -8, -880},
    { 320, -128, -792},
    { 328, -160, -784},
    { 312, -128, -840},
    { 280, -152, -888},
    { 256, -224, -816},
    { 320, -136, -912},
    { 288, -120, -976},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}


// ----------------------------------------------------------------
// Sample captured: 2015-09-20 10:40:49 local
AccelRawData *activity_sample_driving_1(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME driving_1
  //> TEST_EXPECTED 0
  //> TEST_EXPECTED_MIN 0
  //> TEST_EXPECTED_MAX 15
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { -488, -400, -704},
    { -480, -344, -592},
    { -528, -376, -712},
    { -536, -336, -688},
    { -568, -384, -736},
    { -536, -392, -728},
    { -656, -368, -816},
    { -616, -344, -776},
    { -616, -400, -784},
    { -616, -416, -824},
    { -560, -376, -680},
    { -544, -408, -760},
    { -592, -328, -648},
    { -528, -424, -768},
    { -536, -384, -688},
    { -512, -456, -696},
    { -488, -432, -648},
    { -520, -432, -680},
    { -496, -440, -688},
    { -488, -368, -760},
    { -488, -432, -720},
    { -592, -416, -760},
    { -616, -448, -808},
    { -616, -408, -688},
    { -608, -424, -728},
    { -632, -456, -792},
    { -552, -384, -648},
    { -648, -312, -720},
    { -592, -440, -752},
    { -472, -776, -704},
    { -520, -320, -768},
    { -600, -368, -688},
    { -496, -352, -680},
    { -552, -368, -608},
    { -488, -296, -656},
    { -552, -416, -696},
    { -536, -296, -656},
    { -552, -360, -584},
    { -464, -296, -600},
    { -464, -384, -704},
    { -584, -176, -752},
    { -568, -248, -744},
    { -544, -328, -584},
    { -504, -520, -760},
    { -464, -432, -784},
    { -520, -568, -936},
    { -696, -416, -864},
    { -656, -256, -880},
    { -608, -368, -784},
    { -592, -360, -688},
    { -512, -400, -768},
    { -600, -272, -712},
    { -568, -352, -880},
    { -504, -272, -736},
    { -512, -296, -720},
    { -552, -232, -680},
    { -520, -272, -784},
    { -568, -112, -752},
    { -552, -232, -760},
    { -576, -184, -816},
    { -528, -336, -744},
    { -592, -320, -792},
    { -512, -264, -728},
    { -584, -328, -736},
    { -496, -144, -720},
    { -528, -272, -712},
    { -504, -112, -704},
    { -416, -312, -680},
    { -400, -184, -760},
    { -512, -304, -768},
    { -456, -208, -824},
    { -472, -368, -840},
    { -616, -64, -944},
    { -648, -216, -872},
    { -560, -264, -912},
    { -464, -296, -736},
    { -528, -272, -776},
    { -472, -200, -856},
    { -504, -280, -872},
    { -584, -88, -888},
    { -568, -240, -904},
    { -560, -128, -864},
    { -512, -344, -808},
    { -496, -336, -776},
    { -544, -272, -792},
    { -528, -344, -720},
    { -528, -248, -784},
    { -600, -232, -848},
    { -536, -160, -904},
    { -616, -272, -792},
    { -448, -224, -704},
    { -416, -328, -688},
    { -520, -288, -728},
    { -440, -328, -768},
    { -544, -232, -824},
    { -600, -136, -800},
    { -544, -304, -800},
    { -600, -192, -896},
    { -496, -288, -784},
    { -544, -296, -672},
    { -448, -264, -856},
    { -560, -256, -816},
    { -568, -296, -744},
    { -560, -208, -832},
    { -528, -200, -832},
    { -608, -312, -808},
    { -496, -208, -728},
    { -520, -432, -848},
    { -544, -288, -800},
    { -520, -312, -792},
    { -560, -104, -728},
    { -576, -248, -784},
    { -512, -264, -824},
    { -496, -200, -760},
    { -544, -320, -792},
    { -496, -216, -720},
    { -456, -352, -720},
    { -520, -200, -688},
    { -456, -320, -720},
    { -512, -176, -744},
    { -512, -200, -776},
    { -480, -216, -744},
    { -504, -216, -784},
    { -480, -224, -776},
    { -456, -144, -800},
    { -536, -232, -776},
    { -568, -120, -744},
    { -544, -224, -792},
    { -560, -184, -824},
    { -512, -192, -848},
    { -600, -256, -800},
    { -512, -216, -800},
    { -600, -192, -792},
    { -528, -184, -800},
    { -600, -208, -888},
    { -512, -96, -744},
    { -592, -240, -784},
    { -520, -152, -800},
    { -512, -200, -808},
    { -456, -128, -744},
    { -560, -200, -800},
    { -480, -192, -768},
    { -528, -240, -816},
    { -576, -192, -856},
    { -528, -168, -736},
    { -528, -192, -880},
    { -552, -136, -728},
    { -568, -232, -728},
    { -464, -96, -816},
    { -576, -320, -848},
    { -520, -192, -800},
    { -560, -224, -904},
    { -528, -200, -768},
    { -456, -200, -832},
    { -544, -192, -832},
    { -464, -120, -704},
    { -576, -312, -880},
    { -424, -176, -864},
    { -632, -280, -840},
    { -512, -168, -824},
    { -544, -288, -848},
    { -608, -224, -816},
    { -520, -208, -808},
    { -544, -216, -768},
    { -512, -200, -832},
    { -536, -304, -768},
    { -472, -176, -752},
    { -528, -360, -832},
    { -472, -136, -800},
    { -480, -256, -712},
    { -504, -200, -768},
    { -480, -160, -752},
    { -456, -168, -720},
    { -544, -216, -872},
    { -608, -240, -872},
    { -464, -200, -736},
    { -584, -264, -880},
    { -648, -136, -896},
    { -544, -360, -776},
    { -584, -112, -824},
    { -624, -288, -864},
    { -536, -160, -736},
    { -528, -216, -736},
    { -560, -232, -784},
    { -400, -152, -752},
    { -512, -160, -792},
    { -408, -232, -688},
    { -544, -232, -912},
    { -512, -96, -832},
    { -640, -304, -768},
    { -552, -128, -944},
    { -608, -184, -808},
    { -520, -232, -832},
    { -616, -144, -808},
    { -552, -240, -704},
    { -496, -192, -736},
    { -584, -184, -784},
    { -448, -160, -648},
    { -464, -264, -832},
    { -480, -112, -768},
    { -440, -312, -704},
    { -496, -224, -768},
    { -488, -288, -744},
    { -480, -264, -736},
    { -488, -144, -848},
    { -632, -296, -848},
    { -520, -120, -832},
    { -632, -216, -912},
    { -544, -184, -816},
    { -624, -240, -856},
    { -480, -136, -808},
    { -608, -360, -816},
    { -472, -160, -728},
    { -464, -400, -728},
    { -496, -224, -752},
    { -520, -200, -800},
    { -504, -232, -768},
    { -480, -184, -744},
    { -640, -184, -904},
    { -512, -120, -704},
    { -560, -280, -864},
    { -544, -136, -840},
    { -640, -312, -880},
    { -520, -248, -832},
    { -624, -376, -824},
    { -472, -240, -816},
    { -424, -216, -720},
    { -544, -224, -840},
    { -488, -208, -736},
    { -544, -304, -864},
    { -584, -144, -864},
    { -536, -272, -816},
    { -552, -160, -776},
    { -576, -376, -808},
    { -552, -64, -808},
    { -544, -280, -856},
    { -584, -224, -808},
    { -536, -272, -824},
    { -632, -128, -848},
    { -496, -192, -672},
    { -600, -168, -888},
    { -488, -96, -800},
    { -520, -272, -808},
    { -528, -152, -720},
    { -496, -344, -768},
    { -448, -176, -736},
    { -448, -264, -760},
    { -560, -168, -800},
    { -416, -272, -840},
    { -632, -80, -880},
    { -424, -248, -848},
    { -648, -136, -856},
    { -504, -160, -808},
    { -632, -288, -824},
    { -504, -120, -776},
    { -528, -248, -856},
    { -496, -144, -736},
    { -496, -176, -920},
    { -520, -168, -808},
    { -440, -184, -808},
    { -568, -272, -880},
    { -488, -144, -936},
    { -656, -296, -944},
    { -600, -104, -944},
    { -640, -304, -808},
    { -576, -112, -776},
    { -560, -288, -816},
    { -528, -152, -688},
    { -480, -328, -760},
    { -552, -168, -760},
    { -504, -184, -736},
    { -544, -216, -696},
    { -464, -136, -800},
    { -536, -304, -784},
    { -568, -248, -784},
    { -496, -328, -816},
    { -552, -136, -744},
    { -512, -416, -792},
    { -600, -152, -792},
    { -544, -208, -872},
    { -768, -336, -752},
    { -568, -184, -768},
    { -616, -312, -856},
    { -536, -192, -792},
    { -600, -304, -728},
    { -424, -184, -696},
    { -504, -304, -824},
    { -488, -112, -616},
    { -416, -256, -696},
    { -496, -176, -736},
    { -440, -248, -680},
    { -528, -104, -776},
    { -440, -232, -760},
    { -608, -160, -864},
    { -536, -96, -816},
    { -688, -256, -936},
    { -648, -72, -912},
    { -704, -224, -976},
    { -808, -184, -912},
    { -624, -296, -800},
    { -696, -224, -912},
    { -496, -296, -688},
    { -448, -288, -736},
    { -344, -240, -560},
    { -400, -312, -672},
    { -328, -168, -632},
    { -416, -272, -760},
    { -456, -200, -768},
    { -488, -176, -792},
    { -560, -192, -832},
    { -504, -248, -736},
    { -544, -248, -840},
    { -536, -200, -752},
    { -616, -336, -840},
    { -576, -136, -896},
    { -624, -216, -864},
    { -632, -168, -840},
    { -528, -264, -880},
    { -696, -144, -928},
    { -512, -312, -856},
    { -640, -296, -880},
    { -584, -224, -808},
    { -632, -232, -760},
    { -568, -184, -776},
    { -560, -208, -792},
    { -584, -128, -720},
    { -504, -232, -792},
    { -600, -144, -752},
    { -472, -208, -776},
    { -672, -184, -840},
    { -560, -72, -800},
    { -664, -264, -800},
    { -688, -96, -760},
    { -584, -264, -728},
    { -616, -120, -696},
    { -472, -288, -744},
    { -560, -120, -736},
    { -448, -192, -640},
    { -488, -200, -728},
    { -440, -152, -720},
    { -504, -200, -744},
    { -488, -120, -752},
    { -560, -240, -848},
    { -656, -80, -824},
    { -584, -248, -888},
    { -776, -120, -928},
    { -648, -216, -824},
    { -712, -240, -912},
    { -744, -128, -864},
    { -664, -248, -864},
    { -648, -240, -776},
    { -536, -216, -792},
    { -560, -232, -760},
    { -456, -144, -728},
    { -464, -184, -776},
    { -496, -80, -680},
    { -488, -256, -832},
    { -544, -120, -728},
    { -496, -200, -800},
    { -648, -64, -808},
    { -512, -176, -776},
    { -672, -80, -856},
    { -536, -104, -712},
    { -696, -144, -960},
    { -632, 0, -752},
    { -672, -160, -792},
    { -616, -56, -792},
    { -512, -152, -752},
    { -560, -144, -728},
    { -400, -112, -712},
    { -504, -208, -768},
    { -432, -96, -704},
    { -472, -200, -728},
    { -480, -72, -760},
    { -480, -200, -672},
    { -488, -64, -800},
    { -472, -200, -744},
    { -560, -56, -824},
    { -552, -120, -744},
    { -608, -120, -888},
    { -648, 24, -792},
    { -528, -216, -784},
    { -632, -56, -792},
    { -512, -200, -744},
    { -624, -16, -768},
    { -488, -112, -720},
    { -568, -160, -896},
    { -504, -48, -776},
    { -656, -152, -920},
    { -624, 128, -920},
    { -608, -184, -816},
    { -472, -128, -768},
    { -552, -360, -856},
    { -504, -232, -912},
    { -504, -184, -800},
    { -560, -176, -848},
    { -584, 24, -776},
    { -488, -264, -696},
    { -552, -48, -720},
    { -384, -240, -728},
    { -568, -40, -736},
    { -408, -136, -704},
    { -560, -56, -760},
    { -536, -8, -704},
    { -528, -160, -800},
    { -600, -24, -776},
    { -568, -152, -848},
    { -656, -88, -864},
    { -544, -136, -840},
    { -648, -216, -848},
    { -560, -32, -704},
    { -576, -200, -792},
    { -576, 0, -728},
    { -480, -144, -704},
    { -624, -16, -760},
    { -464, -128, -792},
    { -616, -56, -760},
    { -504, -40, -760},
    { -648, -240, -784},
    { -520, 32, -728},
    { -616, -192, -760},
    { -592, -32, -792},
    { -496, -176, -792},
    { -640, -80, -816},
    { -512, -104, -808},
    { -640, -144, -856},
    { -584, 96, -760},
    { -600, -176, -856},
    { -640, 80, -808},
    { -504, -120, -800},
    { -656, -24, -832},
    { -512, -144, -800},
    { -576, -104, -856},
    { -544, -24, -720},
    { -576, -176, -816},
    { -544, 0, -712},
    { -472, -208, -720},
    { -560, -72, -816},
    { -440, -144, -784},
    { -520, -120, -840},
    { -576, -96, -744},
    { -552, -152, -824},
    { -600, 24, -760},
    { -576, -200, -816},
    { -616, 104, -832},
    { -488, -128, -792},
    { -624, -40, -832},
    { -488, -104, -792},
    { -528, -136, -784},
    { -528, -40, -736},
    { -592, -208, -744},
    { -592, 88, -752},
    { -464, -184, -760},
    { -704, 72, -800},
    { -432, -136, -792},
    { -688, -120, -952},
    { -496, -32, -840},
    { -568, -240, -856},
    { -592, 24, -824},
    { -520, -224, -768},
    { -648, 64, -776},
    { -424, -144, -784},
    { -616, -56, -832},
    { -360, -128, -720},
    { -608, -128, -904},
    { -488, 16, -752},
    { -552, -224, -800},
    { -560, 48, -840},
    { -480, -240, -808},
    { -712, 24, -872},
    { -480, -176, -776},
    { -560, -120, -864},
    { -552, -16, -752},
    { -512, -160, -824},
    { -608, 72, -840},
    { -504, -184, -792},
    { -600, 64, -952},
    { -592, -152, -888},
    { -552, -96, -856},
    { -528, -104, -864},
    { -592, -192, -880},
    { -496, -48, -720},
    { -552, -248, -848},
    { -584, 16, -800},
    { -464, -232, -832},
    { -624, -48, -912},
    { -520, -160, -864},
    { -568, -104, -872},
    { -520, -24, -752},
    { -576, -208, -824},
    { -584, 80, -768},
    { -504, -176, -792},
    { -664, 56, -824},
    { -536, -120, -792},
    { -592, -72, -872},
    { -544, -88, -832},
    { -576, -200, -816},
    { -544, -16, -784},
    { -544, -264, -760},
    { -568, 40, -816},
    { -432, -216, -808},
    { -536, -56, -856},
    { -464, -136, -816},
    { -520, -128, -920},
    { -536, -8, -856},
    { -624, -168, -920},
    { -624, 80, -800},
    { -600, -224, -808},
    { -664, 32, -848},
    { -504, -184, -792},
    { -584, -120, -832},
    { -488, -128, -784},
    { -536, -208, -840},
    { -456, 0, -792},
    { -464, -288, -824},
    { -496, 16, -800},
    { -480, -200, -832},
    { -608, 40, -872},
    { -480, -160, -840},
    { -584, -96, -928},
    { -504, -72, -808},
    { -624, -184, -880},
    { -520, -24, -856},
    { -592, -256, -808},
    { -608, -8, -848},
    { -552, -240, -816},
    { -568, -24, -808},
    { -496, -224, -784},
    { -584, -120, -800},
    { -552, -200, -848},
    { -608, -248, -808},
    { -568, -112, -808},
    { -560, -328, -736},
    { -584, -104, -704},
    { -512, -344, -744},
    { -608, -88, -736},
    { -472, -256, -744},
    { -592, -208, -808},
    { -560, -136, -704},
    { -608, -296, -904},
    { -640, -16, -776},
    { -616, -240, -760},
    { -648, -16, -792},
    { -608, -272, -728},
    { -608, -88, -824},
    { -568, -216, -688},
    { -608, -160, -872},
    { -552, -208, -792},
    { -560, -240, -760},
    { -600, -168, -768},
    { -488, -288, -736},
    { -616, -112, -752},
    { -488, -272, -680},
    { -568, -80, -768},
    { -496, -152, -656},
    { -560, -224, -832},
    { -560, -56, -776},
    { -584, -224, -808},
    { -656, -32, -840},
    { -600, -224, -808},
    { -720, -24, -840},
    { -640, -216, -816},
    { -696, -144, -888},
    { -592, -168, -800},
    { -592, -312, -872},
    { -576, -104, -768},
    { -504, -336, -776},
    { -592, -24, -736},
    { -512, -312, -832},
    { -608, -24, -688},
    { -488, -240, -784},
    { -600, -144, -784},
    { -512, -128, -712},
    { -632, -184, -848},
    { -584, -48, -736},
    { -544, -272, -744},
    { -608, -56, -744},
    { -552, -240, -712},
    { -624, -64, -816},
    { -512, -224, -824},
    { -608, -152, -776},
    { -536, -64, -760},
    { -600, -264, -880},
    { -504, -56, -744},
    { -584, -280, -800},
    { -536, -16, -800},
    { -552, -272, -872},
    { -664, -48, -832},
    { -592, -224, -912},
    { -712, -144, -920},
    { -616, -120, -792},
    { -616, -264, -896},
    { -600, 40, -848},
    { -576, -256, -808},
    { -584, -48, -808},
    { -560, -288, -752},
    { -560, 48, -760},
    { -536, -192, -760},
    { -608, -16, -752},
    { -504, -152, -752},
    { -600, -232, -848},
    { -576, -72, -792},
    { -600, -320, -840},
    { -560, 32, -752},
    { -576, -288, -776},
    { -624, -16, -784},
    { -576, -232, -832},
    { -648, -104, -760},
    { -528, -192, -752},
    { -552, -168, -736},
    { -472, -64, -680},
    { -520, -264, -816},
    { -496, -24, -760},
    { -552, -224, -768},
    { -576, -8, -776},
    { -520, -160, -824},
    { -648, -88, -808},
    { -496, -248, -768},
    { -576, -176, -816},
    { -504, -136, -736},
    { -584, -248, -864},
    { -528, -48, -720},
    { -672, -312, -736},
    { -504, -32, -792},
    { -560, -296, -696},
    { -576, 16, -672},
    { -448, -240, -776},
    { -656, -24, -776},
    { -528, -104, -704},
    { -616, -120, -816},
    { -544, -96, -712},
    { -552, -304, -832},
    { -552, -72, -744},
    { -520, -296, -784},
    { -584, -64, -744},
    { -496, -280, -848},
    { -664, -96, -776},
    { -464, -296, -768},
    { -656, -128, -840},
    { -456, -232, -744},
    { -576, -200, -784},
    { -480, -160, -680},
    { -544, -248, -728},
    { -640, 32, -824},
    { -600, -232, -776},
    { -616, -56, -744},
    { -576, -320, -784},
    { -720, -48, -792},
    { -520, -256, -720},
    { -616, -136, -744},
    { -520, -176, -704},
    { -624, -200, -832},
    { -552, -96, -680},
    { -600, -256, -784},
    { -584, -96, -680},
    { -512, -272, -720},
    { -616, -80, -648},
    { -512, -248, -648},
    { -600, -24, -736},
    { -520, -200, -736},
    { -616, -96, -832},
    { -496, -184, -664},
    { -544, -256, -800},
    { -568, -80, -808},
    { -584, -256, -856},
    { -696, -104, -848},
    { -712, -296, -824},
    { -720, -72, -760},
    { -616, -256, -688},
    { -656, -224, -744},
    { -512, -208, -632},
    { -560, -192, -752},
    { -496, -136, -592},
    { -512, -208, -728},
    { -552, -48, -704},
    { -544, -200, -776},
    { -624, -32, -696},
    { -592, -224, -760},
    { -688, -64, -816},
    { -640, -168, -696},
    { -648, -160, -856},
    { -664, -88, -664},
    { -600, -272, -720},
    { -600, -104, -696},
    { -568, -200, -616},
    { -552, -136, -656},
    { -520, -144, -608},
    { -536, -136, -688},
    { -488, -120, -648},
    { -544, -200, -792},
    { -560, -96, -720},
    { -576, -240, -792},
    { -624, -64, -776},
    { -576, -256, -704},
    { -712, -128, -792},
    { -568, -200, -688},
    { -672, -144, -736},
    { -560, -184, -688},
    { -536, -232, -744},
    { -496, -88, -688},
    { -584, -232, -808},
    { -592, 32, -728},
    { -592, -232, -784},
    { -736, -64, -776},
    { -624, -184, -784},
    { -712, -152, -784},
    { -576, -248, -736},
    { -648, -216, -824},
    { -576, -136, -696},
    { -552, -256, -728},
    { -600, -8, -736},
    { -560, -264, -736},
    { -656, -32, -752},
    { -584, -184, -704},
    { -640, -128, -768},
    { -520, -192, -680},
    { -568, -256, -784},
    { -528, -128, -720},
    { -544, -280, -752},
    { -616, -16, -760},
    { -576, -272, -664},
    { -576, -104, -728},
    { -520, -200, -672},
    { -592, -136, -760},
    { -464, -136, -704},
    { -576, -232, -824},
    { -560, -32, -712},
    { -512, -264, -752},
    { -712, 32, -776},
    { -544, -240, -808},
    { -728, -16, -800},
    { -608, -232, -840},
    { -752, -168, -872},
    { -552, -128, -672},
    { -648, -280, -824},
    { -592, -64, -648},
    { -512, -304, -816},
    { -584, -48, -776},
    { -480, -312, -712},
    { -624, -136, -832},
    { -496, -256, -688},
    { -568, -240, -768},
    { -488, -112, -664},
    { -552, -232, -728},
    { -560, -16, -664},
    { -568, -296, -752},
    { -672, -16, -824},
    { -560, -248, -664},
    { -720, -112, -864},
    { -504, -192, -688},
    { -568, -104, -824},
    { -584, -64, -680},
    { -600, -192, -736},
    { -576, -16, -808},
    { -592, -192, -728},
    { -600, -112, -832},
    { -576, -272, -752},
    { -536, -192, -784},
    { -560, -128, -664},
    { -608, -200, -744},
    { -672, 48, -800},
    { -528, -184, -712},
    { -584, -144, -752},
    { -552, -224, -696},
    { -584, -176, -808},
    { -544, -152, -712},
    { -624, -176, -760},
    { -552, -80, -664},
    { -520, -192, -720},
    { -608, -88, -728},
    { -512, -136, -680},
    { -616, -192, -824},
    { -568, -56, -696},
    { -632, -224, -832},
    { -664, -128, -800},
    { -632, -192, -784},
    { -672, 16, -728},
    { -688, -256, -720},
    { -608, -136, -752},
    { -528, -144, -688},
    { -592, -200, -760},
    { -520, -128, -680},
    { -472, -192, -792},
    { -592, -24, -720},
    { -504, -232, -704},
    { -560, -144, -784},
    { -544, -208, -760},
    { -608, -232, -752},
    { -504, -144, -704},
    { -552, -200, -712},
    { -576, -16, -680},
    { -536, -136, -704},
    { -592, -80, -760},
    { -568, -112, -736},
    { -560, -216, -784},
    { -504, -80, -744},
    { -624, -216, -784},
    { -592, -24, -736},
    { -536, -184, -720},
    { -624, -80, -904},
    { -616, -184, -784},
    { -560, -248, -888},
    { -592, -136, -848},
    { -608, -232, -832},
    { -648, -64, -784},
    { -568, -288, -752},
    { -640, -40, -832},
    { -488, -176, -656},
    { -592, -200, -832},
    { -480, -152, -728},
    { -552, -232, -752},
    { -512, -64, -696},
    { -480, -240, -656},
    { -576, 0, -776},
    { -512, -208, -704},
    { -552, -200, -800},
    { -528, -72, -736},
    { -592, -240, -776},
    { -576, -72, -768},
    { -560, -192, -728},
    { -576, -120, -824},
    { -512, -160, -704},
    { -544, -248, -800},
    { -480, -168, -800},
    { -536, -280, -760},
    { -544, -168, -752},
    { -536, -216, -744},
    { -544, -80, -800},
    { -560, -184, -720},
    { -496, -160, -840},
    { -528, -104, -672},
    { -520, -232, -808},
    { -552, -112, -768},
    { -520, -304, -792},
    { -648, -160, -824},
    { -536, -216, -696},
    { -640, -136, -744},
    { -664, 8, -768},
    { -584, -160, -784},
    { -592, -96, -712},
    { -568, -352, -800},
    { -584, -56, -736},
    { -440, -320, -720},
    { -624, -200, -832},
    { -472, -168, -784},
    { -600, -264, -792},
    { -576, -104, -704},
    { -544, -280, -744},
    { -576, -64, -744},
    { -496, -176, -656},
    { -584, -168, -768},
    { -512, -104, -696},
    { -568, -224, -832},
    { -624, -72, -760},
    { -560, -232, -816},
    { -592, -120, -784},
    { -480, -224, -624},
    { -600, -184, -816},
    { -480, -136, -696},
    { -560, -296, -744},
    { -616, -32, -768},
    { -536, -224, -704},
    { -608, -80, -880},
    { -560, -176, -640},
    { -544, -192, -840},
    { -528, -136, -720},
    { -552, -208, -792},
    { -664, -40, -768},
    { -464, -232, -672},
    { -680, -24, -904},
    { -448, -184, -680},
    { -584, -144, -832},
    { -512, -112, -728},
    { -568, -160, -752},
    { -552, 8, -760},
    { -576, -208, -760},
    { -560, -56, -840},
    { -512, -224, -648},
    { -488, -216, -848},
    { -528, -216, -720},
    { -456, -176, -680},
    { -512, -136, -808},
    { -480, -224, -712},
    { -560, -88, -848},
    { -528, -40, -760},
    { -696, -160, -912},
    { -584, -24, -800},
    { -568, -184, -848},
    { -640, -64, -712},
    { -496, -144, -736},
    { -488, -232, -800},
    { -544, -40, -696},
    { -552, -256, -824},
    { -616, -24, -768},
    { -448, -280, -784},
    { -592, -56, -776},
    { -560, -184, -752},
    { -464, -216, -816},
    { -616, -16, -752},
    { -560, -248, -800},
    { -616, -48, -856},
    { -520, -224, -784},
    { -584, -88, -744},
    { -520, -168, -720},
    { -480, -216, -696},
    { -496, -128, -744},
    { -552, -152, -728},
    { -592, 8, -800},
    { -472, -184, -696},
    { -576, -64, -800},
    { -480, -136, -736},
    { -520, -184, -752},
    { -592, -16, -736},
    { -512, -232, -736},
    { -632, -176, -912},
    { -528, -64, -672},
    { -592, -256, -776},
    { -544, -56, -792},
    { -568, -288, -800},
    { -640, -24, -832},
    { -504, -264, -792},
    { -592, -128, -824},
    { -472, -88, -632},
    { -528, -256, -792},
    { -560, -32, -696},
    { -504, -256, -784},
    { -648, -72, -864},
    { -480, -144, -672},
    { -584, -136, -728},
    { -568, -8, -656},
    { -520, -296, -760},
    { -576, -8, -736},
    { -584, -264, -784},
    { -592, -80, -832},
    { -560, -192, -744},
    { -632, -160, -872},
    { -568, -96, -696},
    { -536, -272, -816},
    { -616, -80, -784},
    { -504, -248, -704},
    { -592, -128, -880},
    { -528, -120, -720},
    { -584, -248, -808},
    { -552, -72, -696},
    { -504, -240, -760},
    { -568, -112, -776},
    { -456, -168, -720},
    { -504, -208, -768},
    { -456, -88, -656},
    { -584, -208, -792},
    { -584, -104, -784},
    { -520, -128, -760},
    { -544, -160, -736},
    { -480, -136, -768},
    { -496, -192, -736},
    { -584, -40, -752},
    { -544, -248, -792},
    { -664, -56, -904},
    { -600, -176, -824},
    { -616, -152, -856},
    { -640, -96, -872},
    { -680, -176, -912},
    { -760, -120, -920},
    { -632, -176, -792},
    { -696, -192, -800},
    { -496, -88, -656},
    { -568, -200, -712},
    { -488, -48, -560},
    { -400, -184, -728},
    { -512, -112, -728},
    { -432, -64, -672},
    { -584, -232, -776},
    { -568, -8, -776},
    { -496, -248, -760},
    { -552, -80, -776},
    { -456, -272, -688},
    { -552, -80, -832},
    { -632, -88, -808},
    { -584, -160, -784},
    { -576, -112, -680},
    { -512, -232, -776},
    { -592, -88, -824},
    { -504, -104, -728},
    { -496, -160, -728},
    { -528, -56, -728},
    { -488, -240, -760},
    { -544, -72, -832},
    { -496, -216, -760},
    { -584, -184, -880},
    { -552, -96, -784},
    { -632, -192, -936},
    { -696, -88, -848},
    { -560, -288, -816},
    { -632, -200, -912},
    { -536, -184, -784},
    { -576, -272, -776},
    { -632, -120, -824},
    { -512, -160, -848},
    { -712, -200, -1024},
    { -600, -120, -816},
    { -632, -264, -936},
    { -608, -48, -728},
    { -592, -152, -752},
    { -520, -128, -824},
    { -512, -152, -704},
    { -504, -224, -768},
    { -464, -56, -680},
    { -480, -200, -776},
    { -544, -48, -728},
    { -440, -216, -688},
    { -496, -160, -752},
    { -400, -120, -696},
    { -520, -248, -816},
    { -528, 8, -696},
    { -472, -216, -768},
    { -688, -56, -912},
    { -544, -80, -776},
    { -576, -232, -856},
    { -592, 8, -768},
    { -496, -224, -800},
    { -640, -104, -880},
    { -544, -200, -808},
    { -576, -272, -848},
    { -584, -24, -736},
    { -488, -256, -744},
    { -576, -40, -760},
    { -464, -208, -728},
    { -560, -168, -800},
    { -520, 0, -760},
    { -536, -184, -768},
    { -640, -40, -824},
    { -496, -160, -824},
    { -640, -120, -888},
    { -704, -56, -872},
    { -520, -176, -856},
    { -752, -104, -784},
    { -456, -168, -768},
    { -600, -96, -712},
    { -472, -136, -688},
    { -424, -208, -704},
    { -448, -32, -688},
    { -448, -160, -856},
    { -528, -56, -744},
    { -432, 56, -808},
    { -664, -312, -1056},
    { -608, -72, -744},
    { -560, -288, -840},
    { -704, -24, -840},
    { -560, -192, -792},
    { -616, -192, -872},
    { -584, -48, -736},
    { -552, -240, -744},
    { -552, 8, -680},
    { -448, -216, -728},
    { -552, -112, -768},
    { -448, -80, -744},
    { -528, -224, -824},
    { -576, 16, -824},
    { -504, -192, -872},
    { -616, 24, -872},
    { -536, -232, -784},
    { -568, -232, -912},
    { -528, -136, -744},
    { -608, -208, -808},
    { -656, 0, -912},
    { -544, -184, -864},
    { -616, -120, -920},
    { -528, -136, -704},
    { -520, -232, -784},
    { -576, -56, -816},
    { -504, -144, -816},
    { -616, -128, -904},
    { -544, -64, -760},
    { -544, -232, -792},
    { -504, -72, -704},
    { -504, -248, -744},
    { -496, -64, -752},
    { -456, -112, -712},
    { -496, -176, -760},
    { -496, -24, -728},
    { -496, -272, -816},
    { -608, -8, -936},
    { -528, -264, -800},
    { -632, -192, -920},
    { -624, -128, -688},
    { -536, -176, -832},
    { -648, -72, -760},
    { -496, -168, -736},
    { -488, -144, -808},
    { -432, -112, -624},
    { -408, -216, -744},
    { -336, -16, -656},
    { -384, -200, -744},
    { -408, -24, -784},
    { -408, -56, -680},
    { -528, -72, -904},
    { -600, -16, -864},
    { -480, -112, -840},
    { -592, -80, -928},
    { -552, -88, -872},
    { -704, -112, -1000},
    { -648, -40, -928},
    { -680, -224, -888},
    { -640, -192, -968},
    { -488, -216, -752},
    { -560, -256, -848},
    { -448, -136, -672},
    { -568, -144, -784},
    { -424, -120, -736},
    { -440, -152, -680},
    { -472, -192, -736},
    { -464, -80, -704},
    { -504, -264, -856},
    { -672, -24, -856},
    { -576, -184, -752},
    { -728, -72, -872},
    { -592, -120, -768},
    { -584, -208, -816},
    { -672, -64, -736},
    { -504, -168, -712},
    { -616, -96, -840},
    { -448, -128, -744},
    { -632, -160, -864},
    { -496, -144, -616},
    { -448, -328, -568},
    { -424, -48, -792},
    { -480, -424, -624},
    { -120, 32, -488},
    { -776, -624, -1600},
    { -296, 112, -496},
    { -968, -120, -1528},
    { -632, -464, -264},
    { -1232, -24, -1272},
    { -512, -80, -648},
    { -928, -224, -856},
    { -448, -272, -552},
    { -440, -152, -744},
    { -392, -136, -480},
    { -400, -256, -824},
    { -472, -48, -696},
    { -424, -248, -608},
    { -552, -112, -864},
    { -544, -80, -744},
    { -600, -240, -848},
    { -664, -168, -880},
    { -520, -176, -784},
    { -632, -264, -816},
    { -600, -88, -800},
    { -488, -256, -664},
    { -848, -152, -1112},
    { -472, -144, -584},
    { -792, -128, -1040},
    { -520, -224, -704},
    { -672, -176, -888},
    { -664, -152, -552},
    { -784, -104, -864},
    { -520, -288, -624},
    { -608, -128, -744},
    { -400, -168, -600},
    { -400, -152, -616},
    { -408, -128, -576},
    { -416, -152, -696},
    { -520, -104, -720},
    { -536, -152, -816},
    { -608, -152, -784},
    { -608, -144, -840},
    { -640, -144, -960},
    { -704, -176, -856},
    { -624, -176, -920},
    { -720, -168, -840},
    { -584, -120, -904},
    { -720, -160, -848},
    { -528, -208, -728},
    { -496, -128, -608},
    { -480, -208, -688},
    { -424, -168, -736},
    { -528, -112, -712},
    { -512, -120, -672},
    { -536, -40, -760},
    { -552, -208, -712},
    { -576, -104, -776},
    { -480, -232, -696},
    { -504, -176, -800},
    { -504, -136, -664},
    { -568, -88, -816},
    { -512, -192, -776},
    { -536, -200, -672},
    { -504, -176, -728},
    { -544, -136, -768},
    { -536, -96, -832},
    { -576, -64, -744},
    { -608, -224, -896},
    { -728, 64, -824},
    { -568, -72, -808},
    { -656, -128, -864},
    { -576, -88, -728},
    { -552, -208, -808},
    { -544, -112, -672},
    { -536, -144, -736},
    { -512, -256, -704},
    { -408, -104, -648},
    { -504, -280, -736},
    { -472, -8, -688},
    { -456, -192, -776},
    { -504, -152, -888},
    { -448, -136, -784},
    { -584, -224, -904},
    { -640, -48, -864},
    { -720, -216, -952},
    { -840, -96, -976},
    { -592, -136, -832},
    { -696, -264, -872},
    { -608, -120, -832},
    { -600, -296, -864},
    { -664, -208, -848},
    { -520, -80, -776},
    { -536, -296, -720},
    { -472, 16, -688},
    { -632, -296, -840},
    { -560, 0, -768},
    { -552, -144, -720},
    { -656, -224, -816},
    { -512, -64, -736},
    { -632, -272, -768},
    { -672, -96, -792},
    { -552, -272, -816},
    { -536, -240, -856},
    { -576, -168, -736},
    { -608, -240, -760},
    { -640, -200, -816},
    { -456, -72, -824},
    { -624, -256, -784},
    { -504, -40, -744},
    { -568, -184, -840},
    { -712, -208, -808},
    { -560, -224, -808},
    { -672, -240, -992},
    { -648, -128, -864},
    { -720, -184, -824},
    { -792, -208, -784},
    { -512, -272, -760},
    { -648, -128, -840},
    { -480, -48, -688},
    { -560, -264, -760},
    { -528, -96, -664},
    { -440, -208, -744},
    { -600, -192, -840},
    { -504, -184, -776},
    { -544, -280, -800},
    { -712, -56, -776},
    { -552, -280, -856},
    { -760, -192, -888},
    { -528, -96, -752},
    { -776, -152, -840},
    { -648, 48, -728},
    { -712, -48, -832},
    { -648, -216, -840},
    { -512, -104, -536},
    { -464, -376, -720},
    { -440, -32, -600},
    { -504, -336, -776},
    { -568, -192, -816},
    { -504, -200, -736},
    { -696, -264, -880},
    { -632, -136, -864},
    { -648, -208, -848},
    { -664, -168, -872},
    { -584, -152, -800},
    { -656, -272, -800},
    { -696, -48, -784},
    { -592, -264, -744},
    { -632, -200, -760},
    { -448, -224, -640},
    { -536, -344, -800},
    { -480, -192, -744},
    { -624, -248, -872},
    { -616, -96, -752},
    { -488, -256, -840},
    { -624, -200, -896},
    { -544, -48, -736},
    { -728, -232, -888},
    { -752, 0, -848},
    { -680, -168, -832},
    { -856, -304, -920},
    { -528, -56, -648},
    { -584, -328, -768},
    { -600, -112, -728},
    { -448, -240, -744},
    { -496, -248, -776},
    { -512, -104, -696},
    { -576, -288, -728},
    { -592, -72, -752},
    { -520, -232, -728},
    { -536, -176, -752},
    { -432, -144, -744},
    { -544, -192, -736},
    { -648, -112, -800},
    { -656, -216, -864},
    { -720, -192, -880},
    { -624, -176, -848},
    { -696, -296, -952},
    { -720, -152, -912},
    { -752, -296, -856},
    { -688, -192, -792},
    { -472, -248, -792},
    { -600, -224, -856},
    { -544, -208, -664},
    { -576, -200, -816},
    { -696, -120, -816},
    { -616, -152, -872},
    { -608, -280, -792},
    { -544, -48, -800},
    { -488, -256, -736},
    { -616, -96, -672},
    { -528, -224, -672},
    { -592, -120, -680},
    { -440, -264, -648},
    { -536, -272, -768},
    { -448, -144, -744},
    { -592, -320, -744},
    { -648, -120, -848},
    { -680, -192, -888},
    { -720, -288, -936},
    { -664, -112, -728},
    { -616, -296, -800},
    { -720, -128, -720},
    { -536, -264, -768},
    { -664, -160, -808},
    { -432, -168, -600},
    { -592, -304, -784},
    { -512, -40, -696},
    { -600, -288, -872},
    { -696, -80, -736},
    { -488, -272, -720},
    { -696, -248, -976},
    { -528, -136, -728},
    { -656, -304, -784},
    { -680, -136, -832},
    { -624, -328, -744},
    { -720, -168, -760},
    { -504, -280, -624},
    { -480, -224, -688},
    { -480, -40, -672},
    { -512, -264, -744},
    { -536, -40, -776},
    { -560, -264, -904},
    { -688, -152, -968},
    { -592, -184, -832},
    { -712, -248, -864},
    { -680, -104, -808},
    { -696, -296, -992},
    { -712, -120, -880},
    { -624, -240, -744},
    { -672, -280, -832},
    { -576, -88, -744},
    { -632, -264, -808},
    { -592, -184, -680},
    { -512, -344, -760},
    { -576, -232, -832},
    { -480, -152, -712},
    { -616, -256, -864},
    { -584, -88, -824},
    { -648, -216, -1000},
    { -824, -128, -920},
    { -696, -320, -1040},
    { -856, -208, -960},
    { -696, -240, -760},
    { -656, -200, -792},
    { -584, -160, -632},
    { -568, -248, -832},
    { -496, -56, -560},
    { -448, -264, -736},
    { -544, -80, -688},
    { -408, -224, -616},
    { -448, -112, -696},
    { -464, -120, -592},
    { -440, -200, -688},
    { -456, 8, -696},
    { -456, -248, -840},
    { -584, -24, -784},
    { -512, -184, -744},
    { -680, -72, -848},
    { -688, -40, -832},
    { -616, -160, -832},
    { -824, -40, -936},
    { -528, -288, -824},
    { -680, -56, -800},
    { -488, -288, -696},
    { -520, -232, -784},
    { -456, -120, -648},
    { -496, -264, -720},
    { -536, -16, -768},
    { -528, -312, -824},
    { -560, -64, -720},
    { -576, -264, -744},
    { -528, -120, -744},
    { -520, -64, -640},
    { -600, -312, -792},
    { -496, 32, -728},
    { -664, -288, -832},
    { -624, -16, -760},
    { -528, -232, -696},
    { -640, -128, -880},
    { -632, -80, -656},
    { -528, -248, -792},
    { -616, -40, -664},
    { -520, -312, -752},
    { -656, -72, -768},
    { -464, -320, -688},
    { -632, -168, -800},
    { -488, -248, -624},
    { -520, -256, -744},
    { -504, -32, -624},
    { -488, -288, -736},
    { -584, -24, -776},
    { -480, -336, -784},
    { -592, -56, -776},
    { -648, -232, -744},
    { -560, -184, -784},
    { -656, 40, -704},
    { -520, -352, -784},
    { -632, -8, -768},
    { -464, -272, -736},
    { -648, -144, -824},
    { -648, -208, -816},
    { -584, -224, -824},
    { -608, -72, -624},
    { -640, -288, -856},
    { -504, -40, -592},
    { -512, -296, -800},
    { -648, -56, -816},
    { -472, -376, -768},
    { -696, -120, -912},
    { -656, -192, -704},
    { -584, -208, -856},
    { -624, -72, -720},
    { -576, -288, -768},
    { -704, -8, -752},
    { -488, -296, -656},
    { -632, -104, -760},
    { -568, -96, -592},
    { -504, -272, -720},
    { -576, 88, -696},
    { -488, -320, -680},
    { -616, 0, -752},
    { -512, -256, -720},
    { -672, -136, -856},
    { -568, -96, -648},
    { -584, -296, -832},
    { -672, 88, -696},
    { -584, -304, -800},
    { -704, -16, -736},
    { -568, -264, -744},
    { -656, -160, -800},
    { -608, -80, -640},
    { -520, -352, -768},
    { -576, 32, -664},
    { -488, -320, -712},
    { -632, -72, -776},
    { -576, -240, -784},
    { -608, -200, -808},
    { -592, -144, -720},
    { -568, -256, -800},
    { -640, -32, -744},
    { -608, -280, -776},
    { -696, 8, -864},
    { -576, -240, -704},
    { -616, -96, -768},
    { -560, -296, -592},
    { -416, -216, -728},
    { -536, -96, -648},
    { -472, -288, -736},
    { -608, -16, -808},
    { -504, -216, -656},
    { -584, -192, -832},
    { -520, -160, -672},
    { -536, -296, -736},
    { -592, -32, -704},
    { -536, -304, -776},
    { -712, 64, -816},
    { -544, -248, -752},
    { -696, -112, -912},
    { -624, -168, -752},
    { -624, -304, -848},
    { -632, -8, -712},
    { -520, -312, -664},
    { -552, -48, -744},
    { -496, -272, -648},
    { -496, -216, -776},
    { -520, -128, -656},
    { -528, -232, -776},
    { -624, 48, -696},
    { -512, -320, -768},
    { -656, -56, -904},
    { -592, -312, -736},
    { -616, -248, -840},
    { -640, -64, -664},
    { -560, -312, -688},
    { -632, -16, -680},
    { -432, -336, -648},
    // elapsed: 1 minutes
    { -488, -56, -736},
    { -512, -240, -696},
    { -520, -184, -832},
    { -568, -160, -776},
    { -520, -336, -832},
    { -736, 0, -720},
    { -632, -264, -736},
    { -736, -64, -872},
    { -616, -136, -712},
    { -600, -360, -832},
    { -640, -64, -776},
    { -520, -376, -776},
    { -744, 8, -824},
    { -520, -296, -768},
    { -648, -152, -864},
    { -560, -184, -712},
    { -496, -288, -776},
    { -592, -56, -736},
    { -440, -280, -800},
    { -616, 16, -776},
    { -480, -272, -752},
    { -560, -176, -856},
    { -488, -144, -688},
    { -496, -288, -824},
    { -608, -16, -688},
    { -440, -264, -768},
    { -624, 48, -800},
    { -488, -176, -760},
    { -560, -72, -848},
    { -536, -64, -768},
    { -552, -232, -848},
    { -608, 56, -704},
    { -480, -280, -792},
    { -616, -16, -832},
    { -512, -336, -664},
    { -672, 32, -920},
    { -528, -216, -680},
    { -632, -216, -896},
    { -584, -32, -704},
    { -512, -288, -760},
    { -696, -72, -784},
    { -512, -232, -648},
    { -520, -232, -768},
    { -536, -120, -648},
    { -488, -216, -736},
    { -568, -16, -680},
    { -528, -288, -784},
    { -632, -8, -792},
    { -568, -168, -728},
    { -624, -240, -840},
    { -632, -48, -728},
    { -608, -224, -800},
    { -664, -56, -656},
    { -496, -208, -712},
    { -560, -16, -752},
    { -520, -176, -720},
    { -544, -88, -840},
    { -464, -56, -744},
    { -536, -208, -832},
    { -568, -8, -752},
    { -480, -288, -784},
    { -624, 32, -680},
    { -504, -208, -728},
    { -584, -64, -824},
    { -536, -104, -696},
    { -592, -136, -808},
    { -632, -72, -784},
    { -464, -184, -736},
    { -624, 16, -768},
    { -472, -256, -752},
    { -528, -24, -800},
    { -552, -136, -672},
    { -504, -144, -672},
    { -488, -40, -712},
    { -464, -224, -752},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}




// ----------------------------------------------------------------
// Sample captured: 2015-09-21 09:01:26 local
AccelRawData *activity_sample_driving_2(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME driving_2
  //> TEST_EXPECTED 0
  //> TEST_EXPECTED_MIN 0
  //> TEST_EXPECTED_MAX 0
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { -512, -344, -800},
    { -520, -368, -824},
    { -520, -336, -880},
    { -496, -400, -832},
    { -616, -360, -760},
    { -592, -384, -736},
    { -496, -424, -744},
    { -560, -400, -680},
    { -536, -384, -752},
    { -520, -312, -712},
    { -456, -376, -768},
    { -512, -312, -808},
    { -504, -272, -728},
    { -536, -288, -816},
    { -512, -312, -808},
    { -568, -312, -792},
    { -544, -328, -728},
    { -576, -368, -760},
    { -512, -344, -736},
    { -544, -432, -728},
    { -520, -432, -744},
    { -528, -400, -680},
    { -504, -360, -728},
    { -464, -328, -656},
    { -456, -352, -696},
    { -448, -336, -728},
    { -440, -384, -744},
    { -592, -352, -728},
    { -520, -368, -704},
    { -592, -328, -664},
    { -576, -432, -736},
    { -560, -368, -720},
    { -472, -688, -720},
    { -528, -536, -760},
    { -520, -304, -752},
    { -528, -360, -824},
    { -560, -432, -752},
    { -512, -352, -744},
    { -488, -368, -736},
    { -616, -416, -736},
    { -512, -408, -776},
    { -536, -424, -736},
    { -528, -448, -768},
    { -576, -288, -808},
    { -568, -320, -736},
    { -520, -376, -768},
    { -520, -320, -752},
    { -584, -424, -704},
    { -536, -344, -792},
    { -568, -304, -720},
    { -608, -448, -776},
    { -504, -344, -696},
    { -560, -368, -792},
    { -432, -384, -712},
    { -520, -416, -728},
    { -488, -400, -728},
    { -512, -392, -696},
    { -552, -320, -816},
    { -488, -288, -712},
    { -560, -312, -800},
    { -544, -320, -784},
    { -560, -344, -824},
    { -528, -352, -744},
    { -528, -240, -752},
    { -456, -368, -776},
    { -424, -328, -744},
    { -480, -424, -712},
    { -384, -464, -776},
    { -432, -384, -792},
    { -480, -336, -760},
    { -456, -264, -832},
    { -488, -312, -792},
    { -472, -272, -880},
    { -528, -264, -896},
    { -536, -256, -736},
    { -552, -288, -800},
    { -488, -304, -768},
    { -600, -280, -784},
    { -568, -280, -800},
    { -528, -328, -744},
    { -536, -360, -816},
    { -488, -248, -752},
    { -496, -312, -744},
    { -512, -320, -744},
    { -480, -336, -816},
    { -480, -296, -760},
    { -552, -384, -816},
    { -504, -264, -784},
    { -512, -296, -768},
    { -488, -328, -832},
    { -544, -352, -792},
    { -576, -296, -816},
    { -536, -296, -768},
    { -472, -304, -832},
    { -496, -312, -744},
    { -528, -264, -808},
    { -472, -296, -728},
    { -384, -280, -736},
    { -400, -312, -704},
    { -472, -280, -776},
    { -424, -248, -752},
    { -416, -296, -736},
    { -416, -232, -816},
    { -456, -304, -856},
    { -456, -224, -856},
    { -528, -296, -896},
    { -504, -200, -840},
    { -632, -224, -872},
    { -640, -240, -864},
    { -512, -344, -728},
    { -536, -208, -848},
    { -496, -264, -720},
    { -544, -336, -880},
    { -440, -216, -848},
    { -512, -264, -792},
    { -424, -240, -976},
    { -424, -240, -872},
    { -632, -384, -904},
    { -520, -304, -832},
    { -544, -312, -760},
    { -600, -384, -792},
    { -640, -288, -744},
    { -552, -312, -688},
    { -512, -184, -744},
    { -488, -264, -648},
    { -504, -96, -760},
    { -424, -168, -696},
    { -424, -288, -720},
    { -336, -224, -816},
    { -480, -208, -800},
    { -472, -224, -848},
    { -536, -240, -840},
    { -488, -288, -832},
    { -552, -272, -816},
    { -592, -280, -848},
    { -560, -232, -784},
    { -584, -288, -816},
    { -504, -240, -808},
    { -496, -360, -752},
    { -480, -144, -848},
    { -480, -192, -824},
    { -384, -192, -848},
    { -376, -296, -768},
    { -392, -184, -816},
    { -464, -280, -760},
    { -424, -216, -816},
    { -408, -248, -848},
    { -488, -264, -864},
    { -480, -264, -848},
    { -472, -208, -912},
    { -472, -224, -952},
    { -560, -240, -840},
    { -496, -232, -864},
    { -352, -272, -784},
    { -480, -272, -800},
    { -568, -264, -936},
    { -472, -112, -728},
    { -528, -232, -792},
    { -392, -240, -872},
    { -384, -232, -728},
    { -440, -200, -808},
    { -440, -224, -744},
    { -496, -152, -832},
    { -552, -280, -920},
    { -616, -256, -800},
    { -472, -184, -904},
    { -504, -248, -768},
    { -536, -288, -888},
    { -552, -240, -832},
    { -520, -264, -816},
    { -584, -256, -896},
    { -440, -272, -768},
    { -424, -240, -720},
    { -344, -336, -680},
    { -368, -280, -752},
    { -464, -184, -856},
    { -504, -272, -872},
    { -456, -192, -904},
    { -440, -248, -888},
    { -472, -208, -936},
    { -576, -232, -872},
    { -616, -248, -768},
    { -600, -296, -800},
    { -680, -232, -760},
    { -592, -240, -720},
    { -544, -248, -728},
    { -456, -216, -736},
    { -592, -152, -824},
    { -456, -184, -808},
    { -576, -160, -808},
    { -480, -296, -816},
    { -520, -208, -840},
    { -536, -344, -768},
    { -648, -280, -792},
    { -496, -336, -712},
    { -512, -376, -688},
    { -448, -352, -632},
    { -440, -256, -656},
    { -504, -216, -656},
    { -472, -224, -752},
    { -288, -208, -704},
    { -536, -112, -856},
    { -432, -224, -816},
    { -488, -176, -864},
    { -544, -176, -952},
    { -656, -280, -824},
    { -608, -296, -824},
    { -576, -360, -816},
    { -592, -344, -760},
    { -568, -344, -776},
    { -496, -240, -688},
    { -416, -288, -704},
    { -464, -280, -776},
    { -464, -152, -808},
    { -432, -248, -760},
    { -480, -224, -824},
    { -504, -216, -864},
    { -520, -216, -808},
    { -568, -224, -792},
    { -560, -240, -808},
    { -560, -216, -800},
    { -528, -224, -816},
    { -472, -304, -840},
    { -504, -168, -808},
    { -488, -256, -776},
    { -456, -200, -816},
    { -480, -216, -776},
    { -408, -208, -872},
    { -408, -200, -816},
    { -504, -168, -768},
    { -464, -144, -856},
    { -528, -208, -728},
    { -488, -240, -784},
    { -616, -136, -840},
    { -416, -208, -784},
    { -584, -144, -848},
    { -432, -120, -800},
    { -520, -208, -800},
    { -600, -208, -912},
    { -464, -192, -824},
    { -464, -248, -808},
    { -496, -176, -760},
    { -528, -208, -776},
    { -520, -224, -792},
    { -472, -168, -848},
    { -496, -176, -792},
    { -512, -248, -800},
    { -528, -144, -832},
    { -504, -200, -800},
    { -496, -256, -856},
    { -520, -112, -752},
    { -472, -208, -736},
    { -520, -176, -776},
    { -432, -296, -776},
    { -512, -176, -864},
    { -472, -176, -792},
    { -568, -152, -856},
    { -408, -176, -824},
    { -488, -208, -832},
    { -552, -248, -808},
    { -408, -184, -840},
    { -512, -288, -784},
    { -528, -224, -808},
    { -520, -176, -816},
    { -504, -296, -776},
    { -592, -176, -824},
    { -624, -248, -848},
    { -352, -136, -808},
    { -552, -320, -768},
    { -464, -160, -888},
    { -632, -128, -808},
    { -624, -280, -664},
    { -376, -184, -936},
    { -496, -336, -776},
    { -408, -224, -728},
    { -544, -176, -784},
    { -472, -224, -792},
    { -592, -256, -856},
    { -504, -184, -816},
    { -520, -256, -736},
    { -496, -216, -824},
    { -552, -152, -720},
    { -576, -320, -824},
    { -560, -184, -800},
    { -584, -144, -808},
    { -568, -200, -848},
    { -512, -208, -816},
    { -536, -416, -864},
    { -520, -48, -792},
    { -656, -192, -728},
    { -600, -288, -800},
    { -464, -304, -744},
    { -568, -240, -768},
    { -512, -120, -744},
    { -552, -152, -592},
    { -424, -184, -640},
    { -512, -200, -832},
    { -416, -112, -800},
    { -584, -112, -832},
    { -360, -80, -832},
    { -464, -48, -968},
    { -568, -240, -904},
    { -504, -384, -952},
    { -704, -312, -952},
    { -728, -216, -944},
    { -600, -240, -880},
    { -488, -360, -736},
    { -464, -312, -728},
    { -624, -232, -664},
    { -576, -160, -680},
    { -456, -192, -744},
    { -424, -96, -704},
    { -504, -88, -680},
    { -456, -160, -736},
    { -456, -144, -792},
    { -568, -264, -752},
    { -576, -184, -776},
    { -656, -224, -824},
    { -648, -200, -752},
    { -736, -224, -792},
    { -568, -256, -720},
    { -552, -264, -648},
    { -624, -192, -816},
    { -544, -136, -712},
    { -520, -200, -776},
    { -568, -224, -712},
    { -424, -160, -728},
    { -448, -216, -792},
    { -576, -240, -760},
    { -504, -264, -768},
    { -584, -152, -768},
    { -632, -264, -832},
    { -632, -208, -872},
    { -544, -280, -792},
    { -640, -240, -688},
    { -520, -160, -768},
    { -528, -248, -768},
    { -488, -360, -776},
    { -432, -256, -752},
    { -424, -272, -760},
    { -560, -216, -856},
    { -440, -240, -840},
    { -448, -272, -744},
    { -464, -304, -856},
    { -552, -264, -824},
    { -576, -248, -872},
    { -544, -240, -736},
    { -544, -264, -800},
    { -520, -184, -768},
    { -512, -184, -808},
    { -592, -224, -808},
    { -576, -176, -856},
    { -536, -176, -816},
    { -456, -216, -840},
    { -512, -240, -800},
    { -656, -160, -792},
    { -504, -224, -760},
    { -648, -152, -648},
    { -496, -240, -840},
    { -456, -120, -768},
    { -536, -272, -736},
    { -544, -96, -736},
    { -456, -112, -784},
    { -384, -232, -736},
    { -488, -152, -832},
    { -440, -224, -824},
    { -640, -136, -832},
    { -568, -120, -824},
    { -480, -136, -760},
    { -520, -256, -832},
    { -576, -224, -800},
    { -608, -104, -816},
    { -560, -208, -808},
    { -464, -152, -792},
    { -520, -264, -768},
    { -512, -176, -784},
    { -504, -192, -736},
    { -640, -216, -856},
    { -424, -168, -800},
    { -584, -248, -704},
    { -488, -232, -800},
    { -560, -152, -792},
    { -568, -168, -760},
    { -584, -208, -800},
    { -544, -112, -816},
    { -544, -168, -808},
    { -552, -192, -824},
    { -496, -168, -776},
    { -600, -192, -808},
    { -568, -152, -784},
    { -728, -152, -808},
    { -520, -200, -720},
    { -536, -216, -744},
    { -560, -128, -712},
    { -624, -160, -792},
    { -480, -160, -752},
    { -448, -200, -816},
    { -560, -224, -808},
    { -480, -168, -744},
    { -496, -224, -808},
    { -456, -280, -760},
    { -584, -296, -920},
    { -584, -200, -760},
    { -496, -224, -856},
    { -512, -216, -792},
    { -616, -168, -808},
    { -520, -264, -824},
    { -688, -56, -800},
    { -688, -248, -688},
    { -424, 24, -784},
    { -432, -328, -584},
    { -528, -88, -888},
    { -568, -216, -792},
    { -392, 8, -608},
    { -384, -192, -776},
    { -336, -240, -736},
    { -528, -120, -840},
    { -416, -136, -760},
    { -504, -328, -816},
    { -688, -192, -936},
    { -664, -144, -912},
    { -568, -168, -808},
    { -560, -416, -776},
    { -608, -304, -920},
    { -560, -80, -672},
    { -592, -288, -664},
    { -432, -312, -688},
    { -464, -272, -744},
    { -384, -176, -696},
    { -424, -272, -744},
    { -416, -216, -768},
    { -456, -160, -856},
    { -448, -296, -768},
    { -560, -176, -936},
    { -592, -208, -920},
    { -720, -312, -880},
    { -584, -224, -864},
    { -504, -200, -712},
    { -728, -256, -736},
    { -512, -256, -712},
    { -528, -224, -712},
    { -416, -248, -720},
    { -464, -136, -816},
    { -480, -200, -904},
    { -520, -168, -776},
    { -424, -208, -856},
    { -512, -216, -864},
    { -512, -304, -768},
    { -600, -296, -784},
    { -600, -272, -736},
    { -536, -280, -736},
    { -600, -264, -792},
    { -504, -176, -768},
    { -568, -120, -728},
    { -456, -264, -776},
    { -496, -200, -776},
    { -600, -128, -776},
    { -544, -240, -744},
    { -608, -160, -808},
    { -536, -208, -792},
    { -648, -120, -800},
    { -544, -176, -736},
    { -536, -232, -808},
    { -568, -192, -776},
    { -616, -152, -784},
    { -552, -200, -720},
    { -616, -240, -744},
    { -496, -264, -720},
    { -448, -240, -688},
    { -496, -256, -680},
    { -544, -160, -736},
    { -536, -248, -816},
    { -520, -104, -752},
    { -608, -168, -776},
    { -480, -208, -776},
    { -600, -136, -808},
    { -592, -256, -776},
    { -600, -216, -824},
    { -544, -192, -800},
    { -640, -192, -784},
    { -592, -208, -824},
    { -552, -192, -736},
    { -720, -216, -800},
    { -512, -136, -776},
    { -528, -232, -760},
    { -504, -280, -624},
    { -496, -160, -704},
    { -456, -264, -728},
    { -520, -208, -744},
    { -440, -224, -776},
    { -448, -144, -800},
    { -536, -248, -896},
    { -560, -176, -832},
    { -616, -200, -872},
    { -592, -216, -896},
    { -776, -232, -728},
    { -656, -176, -800},
    { -584, -304, -688},
    { -648, -216, -800},
    { -584, -288, -784},
    { -560, -112, -768},
    { -448, -256, -704},
    { -560, -184, -808},
    { -488, -216, -816},
    { -472, -288, -792},
    { -504, -384, -704},
    { -416, -216, -720},
    { -560, -280, -816},
    { -472, -368, -672},
    { -568, -288, -832},
    { -432, -136, -776},
    { -624, -160, -832},
    { -512, -248, -864},
    { -512, -104, -856},
    { -584, -192, -888},
    { -648, -216, -800},
    { -672, -136, -800},
    { -560, -152, -648},
    { -592, -176, -632},
    { -504, -144, -608},
    { -472, -120, -752},
    { -328, -184, -696},
    { -384, -96, -648},
    { -272, -168, -824},
    { -408, -272, -864},
    { -480, -200, -912},
    { -400, -368, -880},
    { -520, -328, -856},
    { -632, -256, -1024},
    { -648, -296, -888},
    { -576, -296, -808},
    { -648, -312, -728},
    { -632, -216, -800},
    { -408, -264, -800},
    { -416, -264, -744},
    { -408, -184, -688},
    { -448, -280, -744},
    { -400, -200, -792},
    { -456, -232, -816},
    { -520, -264, -856},
    { -456, -248, -848},
    { -504, -288, -832},
    { -552, -216, -888},
    { -576, -240, -712},
    { -584, -208, -832},
    { -440, -232, -816},
    { -536, -248, -848},
    { -504, -232, -808},
    { -512, -184, -824},
    { -472, -184, -792},
    { -536, -264, -776},
    { -544, -248, -792},
    { -448, -168, -784},
    { -560, -224, -720},
    { -432, -264, -800},
    { -504, -240, -832},
    { -552, -192, -832},
    { -560, -176, -808},
    { -448, -256, -840},
    { -544, -288, -808},
    { -544, -168, -824},
    { -512, -272, -736},
    { -568, -232, -832},
    { -536, -200, -832},
    { -520, -160, -712},
    { -536, -256, -752},
    { -432, -184, -832},
    { -520, -200, -808},
    { -480, -192, -824},
    { -560, -208, -800},
    { -496, -216, -848},
    { -568, -192, -800},
    { -520, -264, -776},
    { -440, -288, -792},
    { -512, -168, -768},
    { -560, -216, -824},
    { -544, -152, -832},
    { -480, -248, -720},
    { -576, -96, -904},
    { -440, -168, -752},
    { -552, -192, -784},
    { -496, -128, -808},
    { -568, -176, -792},
    { -528, -192, -856},
    { -408, -152, -744},
    { -552, -176, -752},
    { -448, -240, -800},
    { -488, -136, -808},
    { -432, -280, -800},
    { -552, -152, -856},
    { -432, -184, -776},
    { -448, -280, -784},
    { -544, -232, -904},
    { -480, -200, -816},
    { -616, -232, -808},
    { -456, -216, -864},
    { -608, -264, -776},
    { -504, -152, -800},
    { -576, -216, -832},
    { -560, -200, -784},
    { -568, -184, -808},
    { -480, -192, -800},
    { -384, -184, -720},
    { -560, -224, -800},
    { -480, -216, -760},
    { -496, -264, -768},
    { -432, -176, -848},
    { -520, -200, -744},
    { -504, -224, -864},
    { -464, -176, -792},
    { -624, -184, -800},
    { -560, -224, -880},
    { -576, -120, -864},
    { -600, -176, -784},
    { -560, -176, -808},
    { -544, -160, -880},
    { -568, -128, -784},
    { -576, -104, -784},
    { -520, -200, -744},
    { -496, -232, -752},
    { -416, -264, -736},
    { -504, -168, -688},
    { -392, -224, -752},
    { -464, -248, -792},
    { -480, -176, -792},
    { -464, -192, -784},
    { -472, -144, -832},
    { -488, -184, -800},
    { -536, -184, -848},
    { -520, -192, -824},
    { -544, -248, -864},
    { -504, -232, -808},
    { -600, -184, -776},
    { -560, -176, -848},
    { -472, -216, -760},
    { -552, -216, -832},
    { -472, -128, -784},
    { -536, -160, -776},
    { -488, -184, -792},
    { -512, -160, -808},
    { -464, -208, -816},
    { -512, -184, -816},
    { -520, -136, -816},
    { -528, -224, -872},
    { -528, -136, -848},
    { -536, -232, -816},
    { -520, -120, -824},
    { -544, -256, -728},
    { -640, -192, -776},
    { -464, -144, -760},
    { -496, -160, -688},
    { -448, -216, -832},
    { -456, -160, -840},
    { -568, -168, -784},
    { -520, -136, -824},
    { -408, -112, -784},
    { -488, -344, -808},
    { -520, -192, -848},
    { -584, -168, -768},
    { -608, -224, -904},
    { -520, -88, -792},
    { -504, -232, -736},
    { -552, -264, -872},
    { -512, -208, -792},
    { -600, -208, -840},
    { -504, -168, -760},
    { -512, -152, -776},
    { -424, -336, -816},
    { -600, -136, -856},
    { -448, -200, -784},
    { -576, -160, -840},
    { -416, -136, -824},
    { -440, -144, -824},
    { -456, -160, -784},
    { -512, -144, -832},
    { -552, -136, -800},
    { -456, -216, -840},
    { -448, -232, -832},
    { -504, -152, -784},
    { -640, -120, -800},
    { -464, -104, -904},
    { -424, -184, -808},
    { -472, -184, -840},
    { -504, -152, -808},
    { -584, -120, -848},
    { -560, -184, -864},
    { -568, -184, -832},
    { -480, -168, -768},
    { -520, -168, -776},
    { -416, -224, -712},
    { -528, -200, -752},
    { -472, -248, -792},
    { -576, -192, -840},
    { -464, -176, -848},
    { -584, -168, -800},
    { -544, -144, -880},
    { -456, -176, -824},
    { -544, -184, -832},
    { -616, -176, -776},
    { -512, -136, -792},
    { -528, -184, -792},
    { -616, -192, -776},
    { -480, -152, -808},
    { -464, -216, -824},
    { -480, -216, -744},
    { -528, -128, -800},
    { -456, -168, -792},
    { -488, -184, -744},
    { -472, -144, -752},
    { -424, -160, -760},
    { -456, -144, -816},
    { -560, -144, -832},
    { -432, -128, -864},
    { -552, -112, -768},
    { -504, -104, -992},
    { -472, -224, -752},
    { -544, -24, -784},
    { -432, -296, -1016},
    { -704, 48, -696},
    { -600, -128, -832},
    { -408, -216, -744},
    { -592, -160, -808},
    { -600, -88, -832},
    { -400, -192, -736},
    { -584, -256, -832},
    { -392, -152, -768},
    { -600, -200, -800},
    { -544, -160, -800},
    { -448, -40, -824},
    { -520, -168, -808},
    { -504, -160, -896},
    { -480, -72, -800},
    { -560, -160, -752},
    { -528, -136, -816},
    { -472, -152, -800},
    { -456, -208, -816},
    { -560, -128, -768},
    { -424, -200, -856},
    { -472, -128, -744},
    { -496, -200, -824},
    { -464, -184, -872},
    { -408, -136, -800},
    { -544, -208, -856},
    { -584, -184, -872},
    { -520, -88, -848},
    { -480, -112, -784},
    { -528, -176, -832},
    { -528, -144, -776},
    { -600, -136, -744},
    { -560, -152, -864},
    { -448, -112, -792},
    { -496, -176, -872},
    { -456, -80, -848},
    { -456, -208, -832},
    { -504, -144, -864},
    { -536, -128, -856},
    { -552, -168, -800},
    { -408, -208, -816},
    { -496, -216, -792},
    { -608, -208, -864},
    { -544, -88, -808},
    { -480, -88, -832},
    { -440, -176, -768},
    { -424, -136, -776},
    { -520, -136, -792},
    { -552, -104, -864},
    { -536, -88, -840},
    { -552, -144, -872},
    { -464, -184, -784},
    { -400, -168, -720},
    { -464, -232, -832},
    { -416, -280, -792},
    { -440, -256, -768},
    { -480, -272, -832},
    { -520, -120, -904},
    { -496, -272, -856},
    { -480, -160, -832},
    { -472, -192, -872},
    { -496, -200, -712},
    { -528, -168, -784},
    { -472, -168, -672},
    { -560, -200, -808},
    { -472, -184, -840},
    { -456, -184, -824},
    { -568, -168, -872},
    { -536, -152, -792},
    { -520, -104, -936},
    { -472, -200, -784},
    { -464, -192, -872},
    { -536, -168, -800},
    { -536, -144, -840},
    { -520, -152, -752},
    { -584, -208, -824},
    { -360, -232, -784},
    { -480, -248, -816},
    { -448, -160, -800},
    { -496, -144, -816},
    { -504, -152, -816},
    { -416, -200, -840},
    { -376, -200, -880},
    { -496, -168, -848},
    { -544, -128, -832},
    { -536, -192, -864},
    { -480, -128, -920},
    { -464, -224, -832},
    { -552, -208, -904},
    { -512, -128, -824},
    { -400, -208, -792},
    { -456, -136, -880},
    { -440, -280, -856},
    { -456, -136, -824},
    { -424, -104, -856},
    { -440, -200, -824},
    { -376, -144, -896},
    { -424, -208, -856},
    { -504, -200, -920},
    { -424, -72, -888},
    { -448, -224, -896},
    { -424, -168, -864},
    { -448, -120, -816},
    { -472, -144, -840},
    { -424, -208, -856},
    { -400, -168, -856},
    { -480, -136, -880},
    { -464, -80, -912},
    { -424, -120, -840},
    { -464, -80, -856},
    { -424, -128, -824},
    { -392, -176, -864},
    { -360, -192, -864},
    { -448, -104, -872},
    { -464, -192, -880},
    { -504, -112, -912},
    { -432, -176, -904},
    { -456, -216, -904},
    { -448, -144, -856},
    { -432, -208, -864},
    { -456, -144, -848},
    { -480, -208, -896},
    { -400, -144, -864},
    { -464, -152, -808},
    { -424, -144, -840},
    { -384, -88, -800},
    { -464, -208, -792},
    { -464, -104, -848},
    { -328, -32, -768},
    { -432, -184, -840},
    { -368, -104, -840},
    { -352, -160, -936},
    { -456, -48, -848},
    { -408, -88, -904},
    { -448, -56, -856},
    { -544, -136, -960},
    { -376, -152, -872},
    { -456, -192, -824},
    { -456, -200, -856},
    { -480, -184, -896},
    { -488, -152, -864},
    { -528, -168, -840},
    { -464, -112, -832},
    { -416, -200, -792},
    { -448, -168, -744},
    { -408, -112, -784},
    { -424, -216, -824},
    { -424, -184, -904},
    { -464, -176, -904},
    { -416, -152, -880},
    { -520, -40, -896},
    { -456, -56, -848},
    { -488, -120, -872},
    { -544, -48, -896},
    { -424, -152, -856},
    { -536, -136, -912},
    { -536, -88, -832},
    { -448, -120, -824},
    { -472, -192, -856},
    { -504, -120, -896},
    { -456, -104, -840},
    { -504, -152, -800},
    { -496, -160, -864},
    { -448, -104, -848},
    { -376, -152, -872},
    { -472, -144, -768},
    { -424, -192, -832},
    { -432, -136, -816},
    { -456, -192, -760},
    { -472, -192, -824},
    { -488, -232, -824},
    { -464, -160, -904},
    { -568, -224, -872},
    { -448, -144, -840},
    { -416, -160, -808},
    { -496, -104, -840},
    { -376, -208, -864},
    { -376, -168, -912},
    { -464, -208, -872},
    { -552, -216, -872},
    { -560, -136, -872},
    { -408, -224, -864},
    { -520, -152, -880},
    { -424, -160, -784},
    { -512, -160, -840},
    { -408, -152, -792},
    { -544, -176, -824},
    { -472, -168, -800},
    { -392, -168, -848},
    { -496, -136, -808},
    { -480, -200, -856},
    { -504, -152, -840},
    { -448, -136, -872},
    { -456, -112, -848},
    { -448, -48, -848},
    { -432, -136, -880},
    { -432, -160, -840},
    { -456, -240, -928},
    { -464, -40, -920},
    { -392, -192, -848},
    { -416, -224, -872},
    { -456, -136, -912},
    { -496, -152, -840},
    { -408, -168, -808},
    { -440, -136, -848},
    { -448, -224, -824},
    { -416, -152, -864},
    { -440, -208, -824},
    { -464, -176, -904},
    { -456, -144, -856},
    { -480, -152, -856},
    { -432, -160, -856},
    { -448, -152, -800},
    { -424, -152, -856},
    { -376, -144, -808},
    { -448, -136, -856},
    { -456, -184, -888},
    { -480, -96, -904},
    { -384, -112, -848},
    { -472, -144, -872},
    { -512, -208, -904},
    { -408, -176, -896},
    { -424, -64, -848},
    { -400, -216, -848},
    { -360, -160, -856},
    { -408, -160, -920},
    { -480, -168, -872},
    { -456, -184, -872},
    { -440, -128, -864},
    { -440, -184, -864},
    { -384, -184, -880},
    { -448, -88, -864},
    { -424, -128, -872},
    { -400, -152, -856},
    { -392, -216, -880},
    { -456, -152, -856},
    { -432, -144, -872},
    { -376, -160, -912},
    { -424, -160, -928},
    { -392, -168, -912},
    { -376, -104, -888},
    { -432, -176, -880},
    { -440, -80, -888},
    { -392, -136, -864},
    { -424, -120, -888},
    { -360, -176, -864},
    { -360, -96, -904},
    { -424, -160, -888},
    { -384, -160, -928},
    { -376, -176, -928},
    { -440, -120, -904},
    { -360, -168, -912},
    { -448, -120, -872},
    { -408, -128, -864},
    { -360, -112, -840},
    { -472, -72, -920},
    { -424, -120, -896},
    { -320, -80, -896},
    { -376, -104, -928},
    { -360, -32, -904},
    { -384, -120, -896},
    { -344, -112, -936},
    { -416, -56, -888},
    { -376, -104, -952},
    { -336, -88, -928},
    { -336, -48, -928},
    { -288, -88, -936},
    { -312, -64, -912},
    { -344, -64, -944},
    { -344, -32, -944},
    { -320, -80, -968},
    { -304, -80, -944},
    { -296, -64, -952},
    { -320, -8, -928},
    { -288, -16, -960},
    { -304, -56, -984},
    { -288, -56, -960},
    { -320, -48, -960},
    { -312, -72, -960},
    { -312, -64, -952},
    { -320, -96, -976},
    { -336, -80, -976},
    { -304, -80, -976},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}




// ----------------------------------------------------------------
// Sample captured: 2015-09-21 09:02:27 local
AccelRawData *activity_sample_driving_3(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME driving_3
  //> TEST_EXPECTED 0
  //> TEST_EXPECTED_MIN 0
  //> TEST_EXPECTED_MAX 10
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { -712, -288, -616},
    { -688, -336, -624},
    { -720, -288, -600},
    { -704, -312, -568},
    { -736, -304, -584},
    { -704, -304, -640},
    { -720, -320, -648},
    { -736, -320, -552},
    { -704, -336, -576},
    { -744, -288, -600},
    { -712, -280, -600},
    { -728, -272, -600},
    { -816, -264, -592},
    { -760, -304, -616},
    { -736, -304, -608},
    { -680, -320, -600},
    { -760, -288, -632},
    { -696, -312, -608},
    { -744, -304, -656},
    { -736, -312, -592},
    { -760, -328, -600},
    { -784, -336, -568},
    { -648, -432, -512},
    { -680, -304, -528},
    { -680, -288, -640},
    { -704, -328, -560},
    { -664, -408, -616},
    { -696, -208, -584},
    { -760, -416, -616},
    { -808, -344, -688},
    { -752, -288, -656},
    { -688, -288, -640},
    { -704, -280, -648},
    { -696, -184, -592},
    { -640, -272, -608},
    { -720, -248, -560},
    { -584, -184, -608},
    { -664, -288, -664},
    { -736, -264, -656},
    { -664, -256, -664},
    { -688, -312, -656},
    { -712, -240, -648},
    { -672, -288, -616},
    { -696, -248, -640},
    { -640, -320, -640},
    { -664, -200, -664},
    { -712, -296, -648},
    { -664, -208, -664},
    { -664, -224, -656},
    { -712, -272, -680},
    { -672, -288, -664},
    { -720, -240, -648},
    { -688, -240, -648},
    { -752, -48, -664},
    { -728, -144, -632},
    { -640, -208, -600},
    { -656, -256, -664},
    { -616, -336, -664},
    { -536, -440, -704},
    { -512, -424, -696},
    { -552, -384, -736},
    { -768, -240, -744},
    { -704, -248, -712},
    { -696, -160, -712},
    { -688, -232, -696},
    { -600, -232, -656},
    { -624, -208, -680},
    { -600, -256, -704},
    { -616, -232, -760},
    { -648, -184, -760},
    { -592, -184, -808},
    { -584, -128, -784},
    { -600, -176, -760},
    { -584, -128, -760},
    { -576, -128, -768},
    { -616, -136, -720},
    { -576, -152, -720},
    { -576, -120, -800},
    { -616, -176, -704},
    { -600, -176, -776},
    { -624, -120, -768},
    { -584, -152, -704},
    { -592, -136, -752},
    { -592, -152, -760},
    { -584, -176, -776},
    { -608, -152, -784},
    { -576, -96, -808},
    { -544, -136, -744},
    { -560, -160, -728},
    { -584, -64, -736},
    { -536, -152, -728},
    { -512, -240, -792},
    { -608, -304, -560},
    { -520, -48, -872},
    { -560, -304, -664},
    { -624, -176, -888},
    { -600, -152, -800},
    { -616, -280, -712},
    { -640, -232, -752},
    { -672, -320, -664},
    { -560, -96, -848},
    { -776, -264, -616},
    { -632, -256, -664},
    { -560, -288, -640},
    { -720, -272, -696},
    { -720, -288, -848},
    { -744, -320, -688},
    { -848, -360, -632},
    { -640, -232, -544},
    { -608, -272, -608},
    { -608, -248, -576},
    { -632, -224, -656},
    { -704, -232, -760},
    { -696, -240, -664},
    { -664, -200, -760},
    { -680, -280, -712},
    { -632, -288, -672},
    { -664, -176, -736},
    { -664, -136, -648},
    { -664, -288, -616},
    { -696, -224, -664},
    { -704, -256, -688},
    { -784, -272, -648},
    { -720, -192, -616},
    { -648, -224, -624},
    { -744, -248, -728},
    { -608, -296, -640},
    { -656, -256, -736},
    { -696, -176, -544},
    { -608, -216, -680},
    { -720, -304, -688},
    { -688, -176, -664},
    { -632, -224, -696},
    { -704, -224, -664},
    { -648, -240, -616},
    { -640, -368, -680},
    { -672, -344, -680},
    { -752, -264, -632},
    { -768, -336, -688},
    { -696, -320, -672},
    { -704, -352, -664},
    { -648, -272, -720},
    { -696, -240, -664},
    { -720, -304, -672},
    { -728, -296, -640},
    { -640, -232, -512},
    { -720, -376, -656},
    { -800, -352, -584},
    { -728, -232, -672},
    { -648, -168, -576},
    { -800, -216, -688},
    { -640, -272, -664},
    { -608, -232, -736},
    { -720, -152, -656},
    { -712, -304, -624},
    { -752, -288, -624},
    { -640, -360, -592},
    { -680, -368, -600},
    { -616, -288, -648},
    { -744, -336, -632},
    { -744, -272, -664},
    { -664, -312, -672},
    { -712, -272, -592},
    { -600, -336, -656},
    { -624, -320, -696},
    { -648, -328, -696},
    { -648, -440, -688},
    { -680, -320, -672},
    { -584, -248, -776},
    { -608, -400, -688},
    { -592, -280, -736},
    { -648, -184, -744},
    { -616, -192, -752},
    { -576, -184, -808},
    { -608, -112, -768},
    { -488, -200, -680},
    { -472, -120, -792},
    { -528, -120, -880},
    { -544, -96, -800},
    { -456, -144, -736},
    { -512, -104, -808},
    { -384, -168, -752},
    { -464, -128, -784},
    { -464, -152, -792},
    { -528, -40, -880},
    { -504, -104, -864},
    { -416, -96, -872},
    { -464, -88, -912},
    { -536, -88, -872},
    { -488, -88, -824},
    { -472, -128, -904},
    { -480, -144, -832},
    { -584, -104, -768},
    { -488, -144, -776},
    { -472, -136, -768},
    { -512, -104, -792},
    { -448, -168, -808},
    { -416, -112, -728},
    { -480, -136, -776},
    { -480, -96, -824},
    { -592, -104, -904},
    { -560, -72, -848},
    { -632, -112, -912},
    { -616, -208, -744},
    { -696, -192, -768},
    { -688, -192, -792},
    { -672, -176, -664},
    { -680, -264, -696},
    { -680, -168, -696},
    { -672, -192, -712},
    { -648, -176, -632},
    { -488, -160, -672},
    { -544, -168, -712},
    { -592, -160, -696},
    { -536, -192, -712},
    { -592, -168, -712},
    { -432, -280, -640},
    { -712, -56, -912},
    { -768, -360, -528},
    { -672, -64, -936},
    { -520, -304, -688},
    { -632, -176, -856},
    { -648, -248, -712},
    { -432, -128, -776},
    { -760, -128, -824},
    { -568, -216, -816},
    { -544, -200, -776},
    { -472, -272, -832},
    { -488, -144, -728},
    { -648, -80, -720},
    { -512, -32, -808},
    { -456, -184, -728},
    { -440, -128, -776},
    { -416, -208, -800},
    { -504, -152, -808},
    { -416, -280, -816},
    { -496, -112, -864},
    { -552, -152, -816},
    { -648, -184, -776},
    { -560, -176, -704},
    { -616, -232, -768},
    { -640, -232, -752},
    { -616, -216, -752},
    { -600, -224, -736},
    { -608, -208, -728},
    { -584, -240, -808},
    { -576, -256, -712},
    { -608, -208, -720},
    { -600, -240, -680},
    { -616, -280, -752},
    { -512, -296, -728},
    { -592, -328, -696},
    { -544, -288, -720},
    { -608, -200, -768},
    { -592, -248, -800},
    { -552, -248, -712},
    { -600, -264, -760},
    { -568, -240, -688},
    { -584, -280, -800},
    { -552, -248, -768},
    { -576, -208, -776},
    { -552, -336, -728},
    { -608, -144, -728},
    { -528, -240, -728},
    { -552, -264, -776},
    { -432, -216, -712},
    { -560, -296, -752},
    { -584, -96, -848},
    { -480, -136, -808},
    { -488, -152, -880},
    { -448, -208, -816},
    { -520, -168, -872},
    { -544, -200, -856},
    { -584, -192, -824},
    { -536, -184, -856},
    { -528, -288, -712},
    { -600, -208, -832},
    { -488, -208, -800},
    { -536, -192, -792},
    { -480, -176, -784},
    { -512, -176, -728},
    { -512, -160, -752},
    { -480, -176, -760},
    { -432, -216, -888},
    { -560, -128, -824},
    { -528, -128, -888},
    { -552, -144, -792},
    { -496, -104, -800},
    { -552, -240, -808},
    { -552, -184, -840},
    { -560, -192, -808},
    { -528, -120, -784},
    { -512, -144, -776},
    { -480, -168, -792},
    { -480, -120, -832},
    { -512, -80, -808},
    { -472, -144, -792},
    { -480, -120, -776},
    { -512, -56, -792},
    { -488, -136, -832},
    { -552, 32, -880},
    { -480, -160, -840},
    { -504, -112, -840},
    { -472, -152, -856},
    { -520, -176, -856},
    { -616, -168, -848},
    { -544, -184, -728},
    { -496, -144, -784},
    { -560, -192, -800},
    { -472, -120, -824},
    { -512, -64, -872},
    { -480, -64, -792},
    { -576, -72, -824},
    { -488, -24, -816},
    { -528, -184, -792},
    { -584, -152, -840},
    { -544, -176, -776},
    { -608, -128, -736},
    { -544, -184, -808},
    { -616, -200, -808},
    { -592, -128, -832},
    { -608, -80, -784},
    { -544, -152, -704},
    { -608, -112, -696},
    { -672, -40, -768},
    { -592, -32, -760},
    { -728, 0, -840},
    { -568, -136, -760},
    { -552, -56, -792},
    { -528, -224, -720},
    { -568, -112, -736},
    { -480, -360, -560},
    { -536, -160, -768},
    { -528, -288, -656},
    { -600, -96, -904},
    { -448, -224, -728},
    { -496, -56, -888},
    { -512, -272, -752},
    { -512, -200, -840},
    { -640, -208, -744},
    { -704, -144, -912},
    { -704, -320, -832},
    { -560, -200, -760},
    { -712, -192, -832},
    { -616, -136, -784},
    { -576, -144, -744},
    { -536, -136, -728},
    { -432, -208, -704},
    { -544, -104, -712},
    { -464, -96, -736},
    { -488, -40, -752},
    { -440, -88, -832},
    { -552, -88, -752},
    { -480, -24, -808},
    { -504, -112, -760},
    { -448, -64, -808},
    { -616, -160, -792},
    { -528, -16, -768},
    { -576, -24, -912},
    { -648, 48, -872},
    { -544, -72, -824},
    { -608, -96, -776},
    { -528, -80, -808},
    { -624, -136, -856},
    { -600, -184, -752},
    { -568, -112, -800},
    { -536, -32, -840},
    { -576, -104, -816},
    { -568, -16, -808},
    { -448, -104, -808},
    { -600, -152, -760},
    { -432, -192, -688},
    { -600, -120, -736},
    { -568, -32, -792},
    { -560, -144, -680},
    { -520, -16, -888},
    { -408, -80, -856},
    { -536, -40, -848},
    { -496, -120, -824},
    { -448, 8, -840},
    { -544, -216, -832},
    { -584, -64, -896},
    { -504, -112, -840},
    { -552, -104, -880},
    { -528, -136, -776},
    { -488, -128, -736},
    { -552, -48, -768},
    { -480, -168, -784},
    { -504, -136, -744},
    { -528, -152, -736},
    { -568, 24, -808},
    { -512, -128, -752},
    { -536, -120, -776},
    { -464, -240, -800},
    { -528, -176, -856},
    { -472, -304, -840},
    { -608, -144, -776},
    { -680, -56, -848},
    { -616, -120, -840},
    { -624, -136, -776},
    { -616, -192, -784},
    { -632, -64, -760},
    { -520, -128, -768},
    { -672, -32, -848},
    { -536, -72, -752},
    { -528, -96, -752},
    { -520, -152, -680},
    { -520, -160, -736},
    { -528, -144, -688},
    { -520, -168, -760},
    { -552, -160, -752},
    { -456, -144, -736},
    { -576, -152, -784},
    { -488, -120, -776},
    { -592, -128, -792},
    { -536, -80, -720},
    { -584, -144, -864},
    { -544, -104, -792},
    { -624, -112, -752},
    { -600, -112, -800},
    { -544, -64, -760},
    { -648, -56, -816},
    { -528, -152, -744},
    { -576, -24, -776},
    { -568, -160, -728},
    { -616, -32, -808},
    { -536, -72, -736},
    { -496, -128, -752},
    { -568, -24, -808},
    { -488, -88, -776},
    { -544, -88, -784},
    { -440, -72, -792},
    { -592, -96, -800},
    { -520, -16, -840},
    { -560, -120, -864},
    { -504, -88, -792},
    { -576, -88, -800},
    { -512, -56, -784},
    { -624, -48, -856},
    { -536, -8, -728},
    { -504, -112, -848},
    { -608, 0, -760},
    { -472, -112, -760},
    { -528, -96, -784},
    { -520, 40, -768},
    { -488, -104, -728},
    { -504, -48, -776},
    { -416, -184, -720},
    { -472, -80, -832},
    { -520, -160, -784},
    { -472, -144, -808},
    { -488, -16, -848},
    { -536, -232, -896},
    { -600, -120, -856},
    { -600, -128, -752},
    { -528, -128, -712},
    { -520, -176, -752},
    { -504, -224, -768},
    { -608, -112, -864},
    { -592, -64, -840},
    { -568, 0, -848},
    { -480, -112, -920},
    { -472, -216, -760},
    { -592, -144, -760},
    { -568, -120, -704},
    { -592, -136, -832},
    { -528, -192, -816},
    { -560, -176, -800},
    { -552, -144, -800},
    { -512, -32, -760},
    { -504, -168, -800},
    { -480, -200, -776},
    { -560, -168, -832},
    { -584, -160, -720},
    { -584, -72, -808},
    { -480, -168, -736},
    { -544, -160, -760},
    { -512, -136, -800},
    { -528, -120, -840},
    { -528, -264, -784},
    { -544, -64, -728},
    { -472, -248, -808},
    { -512, -184, -728},
    { -560, -256, -792},
    { -624, -136, -808},
    { -624, -112, -792},
    { -592, -240, -888},
    { -568, -120, -824},
    { -656, -96, -832},
    { -552, -240, -776},
    { -624, -32, -664},
    { -568, -192, -792},
    { -640, -96, -776},
    { -560, -200, -840},
    { -624, -40, -880},
    { -440, -192, -848},
    { -568, -80, -832},
    { -440, -128, -720},
    { -560, -248, -712},
    { -512, -104, -736},
    { -472, -136, -656},
    { -648, -112, -720},
    { -416, -24, -744},
    { -528, -56, -712},
    { -352, -72, -776},
    { -504, 112, -856},
    { -560, -40, -872},
    { -472, 88, -864},
    { -544, -128, -904},
    { -496, -40, -896},
    { -592, -144, -944},
    { -632, -88, -840},
    { -480, -144, -856},
    { -648, -56, -856},
    { -488, -136, -816},
    { -544, -72, -800},
    { -424, -152, -728},
    { -448, -48, -848},
    { -504, -136, -832},
    { -520, -32, -784},
    { -568, -32, -808},
    { -472, -64, -832},
    { -416, -80, -760},
    { -504, -128, -808},
    { -472, -104, -760},
    { -536, -56, -840},
    { -568, -24, -888},
    { -536, -40, -816},
    { -480, -56, -936},
    { -464, -88, -816},
    { -520, -48, -824},
    { -520, -72, -752},
    { -496, -56, -848},
    { -536, -64, -776},
    { -488, -120, -720},
    { -424, 0, -824},
    { -624, -120, -816},
    { -448, 72, -824},
    { -488, -24, -816},
    { -448, -128, -760},
    { -416, -8, -872},
    { -616, -120, -880},
    { -512, -32, -864},
    { -440, -216, -904},
    { -568, -200, -928},
    { -392, -184, -752},
    { -536, -224, -936},
    { -432, -192, -864},
    { -536, -168, -752},
    { -464, -96, -832},
    { -480, -104, -688},
    { -504, -96, -832},
    { -560, 120, -864},
    { -576, 16, -792},
    { -480, 24, -992},
    { -608, 32, -824},
    { -456, -40, -896},
    { -496, -56, -776},
    { -528, -152, -800},
    { -456, -184, -920},
    { -520, -200, -720},
    { -488, -136, -752},
    { -472, -104, -784},
    { -488, -152, -768},
    { -408, 8, -816},
    { -416, -160, -824},
    { -504, 16, -904},
    { -560, 0, -896},
    { -520, -72, -800},
    { -568, -16, -880},
    { -560, -176, -784},
    { -584, -160, -704},
    { -512, -208, -872},
    { -600, -160, -688},
    { -552, -40, -1080},
    { -648, -120, -832},
    { -408, -24, -736},
    { -344, -120, -928},
    { -440, -128, -632},
    { -424, -40, -1008},
    { -456, -176, -864},
    { -424, -272, -992},
    { -440, -152, -920},
    { -440, -168, -840},
    { -520, -120, -872},
    { -544, -104, -800},
    { -568, -48, -840},
    { -480, -96, -824},
    { -568, -112, -856},
    { -512, -24, -864},
    { -520, -88, -784},
    { -456, -24, -816},
    { -464, -88, -800},
    { -416, -56, -784},
    { -432, -112, -808},
    { -424, -112, -840},
    { -344, -256, -976},
    { -304, -800, -1024},
    { -224, -248, -1104},
    { 8, 64, -792},
    { -184, -200, -680},
    { -352, 160, -784},
    { -440, 296, -784},
    { -400, 64, -640},
    { -520, 176, -600},
    { -552, 184, -280},
    { -432, 1032, -496},
    { -784, 1128, -392},
    { -824, 864, -296},
    { -816, 840, -304},
    { -432, 944, -504},
    { -528, 808, -176},
    { -288, 1000, -544},
    { -552, 1320, -352},
    { -696, 1016, -544},
    { -776, 360, -352},
    { -712, 736, -456},
    { -632, 608, -456},
    { -560, 400, -480},
    { -472, 120, -496},
    { -432, 0, -440},
    { -360, -56, -464},
    { -184, -72, -432},
    { 8, 1920, -1536},
    { -344, -432, -712},
    { -96, -1232, -1120},
    { -648, 176, -656},
    { -768, 216, -744},
    { -440, -24, -752},
    { -416, 80, -720},
    { -568, 216, -824},
    { -592, 72, -904},
    { -400, 8, -816},
    { -456, 24, -960},
    { -520, -64, -856},
    { -536, 120, -816},
    { -472, 64, -824},
    { -464, 48, -848},
    { -504, 184, -880},
    { -480, 40, -920},
    { -472, 24, -840},
    { -456, -56, -824},
    { -496, 0, -816},
    { -384, -136, -840},
    { -400, -152, -824},
    { -400, -160, -824},
    { -376, -240, -872},
    { -456, -112, -864},
    { -504, -16, -816},
    { -464, -32, -864},
    { -464, -48, -816},
    { -416, -112, -832},
    { -544, -88, -864},
    { -504, -184, -768},
    { -528, -88, -832},
    { -536, -112, -872},
    { -488, -104, -824},
    { -552, -120, -872},
    { -536, -160, -824},
    { -616, -80, -848},
    { -464, -120, -744},
    { -512, -88, -816},
    { -496, -72, -760},
    { -504, -24, -768},
    { -520, -112, -800},
    { -496, 104, -904},
    { -544, -104, -864},
    { -488, 72, -896},
    { -520, -16, -800},
    { -448, -80, -800},
    { -464, -72, -792},
    { -480, -56, -744},
    { -600, 16, -872},
    { -544, -72, -712},
    { -512, -56, -816},
    { -568, -56, -816},
    { -552, 8, -808},
    { -544, -40, -776},
    { -544, 8, -792},
    { -528, -48, -816},
    { -600, -24, -824},
    { -576, -64, -768},
    { -592, -32, -768},
    { -592, -16, -776},
    { -520, -112, -720},
    { -616, 56, -768},
    { -600, -8, -752},
    { -504, -40, -768},
    { -512, -40, -768},
    { -544, 40, -816},
    { -544, -16, -824},
    { -472, -16, -792},
    { -448, -16, -832},
    { -544, 40, -896},
    { -520, 72, -848},
    { -480, 24, -824},
    { -504, -8, -800},
    { -504, 24, -872},
    { -536, -16, -840},
    { -584, 56, -816},
    { -584, 40, -768},
    { -480, -32, -800},
    { -496, 8, -744},
    { -520, -8, -776},
    { -528, 40, -792},
    { -552, 128, -864},
    { -456, -64, -808},
    { -448, 144, -824},
    { -448, -120, -872},
    { -440, 56, -912},
    { -464, 80, -872},
    { -488, 32, -856},
    { -480, 88, -960},
    { -464, 8, -872},
    { -448, -40, -704},
    { -384, 0, -856},
    { -488, -56, -816},
    { -440, 16, -872},
    { -464, 24, -920},
    { -440, -32, -776},
    { -352, -24, -824},
    { -440, 0, -920},
    { -336, -152, -888},
    { -320, -176, -768},
    { -392, 0, -880},
    { -304, -160, -960},
    { -344, -216, -992},
    { -376, 88, -904},
    { -432, -16, -1032},
    { -336, -104, -936},
    { -328, -48, -888},
    { -328, -88, -920},
    { -400, -64, -952},
    { -352, 8, -960},
    { -328, -8, -952},
    { -288, 24, -896},
    { -312, 16, -960},
    { -280, 72, -912},
    { -248, -16, -952},
    { -272, -72, -992},
    { -248, -120, -984},
    { -280, -192, -1008},
    { -264, -216, -992},
    { -224, -168, -944},
    { -280, -216, -944},
    { -208, -120, -904},
    { -264, -120, -944},
    { -184, -144, -888},
    { -192, -192, -904},
    { -176, -136, -1024},
    { -216, -120, -880},
    { -96, -256, -952},
    { -112, -296, -960},
    { -152, -344, -1016},
    { -144, -288, -992},
    { -184, -288, -1064},
    { -240, -232, -976},
    { -232, -176, -952},
    { -192, -168, -952},
    { -216, -240, -952},
    { -128, -208, -936},
    { -192, -248, -904},
    { -176, -248, -920},
    { -160, -312, -896},
    { -192, -328, -912},
    { -120, -392, -936},
    { -88, -440, -952},
    { -104, -312, -952},
    { -120, -392, -1008},
    { -112, -400, -944},
    { -32, -408, -976},
    { -80, -392, -928},
    { -56, -376, -928},
    { 16, -440, -928},
    { -64, -448, -968},
    { -112, -360, -960},
    { -112, -384, -976},
    { -80, -344, -1008},
    { -96, -392, -912},
    { -104, -368, -952},
    { -96, -392, -928},
    { -8, -384, -960},
    { -8, -392, -960},
    { -72, -408, -976},
    { -88, -392, -952},
    { -16, -472, -880},
    { -80, -360, -928},
    { -72, -400, -896},
    { -96, -336, -912},
    { -56, -408, -888},
    { -72, -448, -912},
    { -32, -472, -912},
    { -104, -376, -896},
    { 0, -520, -920},
    { -64, -336, -928},
    { -40, -448, -904},
    { 16, -432, -952},
    { -32, -400, -912},
    { -16, -416, -904},
    { -8, -272, -856},
    { 16, -536, -944},
    { 0, -448, -1024},
    { 0, -488, -936},
    { -16, -408, -896},
    { -96, -376, -928},
    { -200, -368, -880},
    { -72, -448, -816},
    { -96, -464, -864},
    { -136, -496, -864},
    { -168, -472, -872},
    { -152, -496, -832},
    { -136, -480, -880},
    { -144, -496, -880},
    { -144, -528, -872},
    { -120, -488, -888},
    { -112, -536, -896},
    { -120, -464, -888},
    { -160, -488, -864},
    { -120, -544, -888},
    { -112, -544, -912},
    { -80, -592, -872},
    { -136, -528, -936},
    { -168, -496, -808},
    { -144, -544, -816},
    { -144, -640, -848},
    { -176, -632, -848},
    { -224, -608, -760},
    { -272, -688, -752},
    { -232, -720, -704},
    { -264, -712, -752},
    { -264, -712, -720},
    { -256, -736, -728},
    { -272, -736, -712},
    { -272, -712, -736},
    { -304, -720, -696},
    { -272, -720, -696},
    { -248, -712, -704},
    { -272, -720, -688},
    { -280, -744, -680},
    { -280, -712, -704},
    { -256, -648, -752},
    { -256, -688, -728},
    { -256, -664, -704},
    { -296, -720, -728},
    { -240, -728, -736},
    { -296, -744, -688},
    { -296, -784, -688},
    { -280, -800, -744},
    { -280, -736, -728},
    { -352, -736, -736},
    { -360, -704, -728},
    { -384, -632, -704},
    { -384, -608, -720},
    { -392, -568, -720},
    { -392, -544, -704},
    { -440, -568, -736},
    { -472, -456, -728},
    { -432, -496, -712},
    { -464, -584, -720},
    { -552, -488, -728},
    { -544, -456, -696},
    { -560, -584, -720},
    { -584, -384, -688},
    { -544, -512, -744},
    { -640, -440, -712},
    { -536, -456, -744},
    { -584, -440, -704},
    { -560, -408, -688},
    { -584, -368, -688},
    { -568, -400, -688},
    { -608, -320, -656},
    { -592, -400, -704},
    { -608, -312, -672},
    { -608, -392, -720},
    { -648, -384, -672},
    { -624, -320, -712},
    { -672, -312, -656},
    { -632, -424, -704},
    { -632, -288, -712},
    { -688, -232, -648},
    { -600, -352, -656},
    { -648, -320, -688},
    { -656, -344, -672},
    { -624, -376, -696},
    { -664, -336, -664},
    { -632, -352, -680},
    { -632, -352, -664},
    { -616, -320, -656},
    { -656, -336, -696},
    { -640, -336, -672},
    { -648, -416, -736},
    { -672, -272, -704},
    { -640, -304, -664},
    { -720, -280, -664},
    { -656, -360, -632},
    { -600, -272, -616},
    { -616, -344, -640},
    { -632, -320, -672},
    { -704, -360, -656},
    { -664, -368, -688},
    { -656, -304, -664},
    { -688, -344, -696},
    { -672, -336, -744},
    { -664, -480, -456},
    { -616, -640, -728},
    { -600, 80, -608},
    { -792, -464, -696},
    { -584, -368, -616},
    { -712, -232, -712},
    { -664, -336, -640},
    { -632, -256, -672},
    { -848, -448, -752},
    { -648, -328, -600},
    { -616, -304, -640},
    { -712, -240, -656},
    { -664, -240, -656},
    { -712, -232, -688},
    { -704, -160, -648},
    { -640, -216, -664},
    { -720, -192, -624},
    { -704, -80, -672},
    { -736, -112, -648},
    { -696, -184, -632},
    { -688, -176, -680},
    { -640, -264, -648},
    { -672, -96, -624},
    { -760, -184, -712},
    { -776, -168, -680},
    { -656, -216, -688},
    { -656, -200, -680},
    { -624, -136, -640},
    { -792, -8, -680},
    { -728, -152, -616},
    { -720, -128, -696},
    { -728, -136, -680},
    { -664, -144, -688},
    { -720, -88, -656},
    { -728, -64, -672},
    { -648, -200, -632},
    { -760, -120, -664},
    { -672, -176, -664},
    { -680, -120, -632},
    { -680, -152, -688},
    { -664, -184, -688},
    { -624, -96, -712},
    { -688, -112, -688},
    { -720, -112, -680},
    { -592, -216, -648},
    { -704, -152, -712},
    { -648, -120, -632},
    { -728, -152, -664},
    { -704, -104, -696},
    { -712, -104, -688},
    { -672, -56, -624},
    { -792, -88, -688},
    { -552, -224, -704},
    { -544, -168, -720},
    { -616, -144, -720},
    { -664, -136, -744},
    { -584, -128, -736},
    { -568, -112, -768},
    { -568, -144, -728},
    { -576, -168, -736},
    { -592, -168, -784},
    { -536, -176, -768},
    { -608, -72, -720},
    { -520, -208, -808},
    { -488, -192, -760},
    { -528, -168, -768},
    { -488, -176, -800},
    { -464, -152, -792},
    { -448, -176, -880},
    { -488, -136, -888},
    { -480, -112, -912},
    { -512, -192, -880},
    { -544, -192, -928},
    { -552, -160, -864},
    { -576, -200, -864},
    { -632, -192, -776},
    { -648, -192, -824},
    { -584, -232, -736},
    { -592, -232, -744},
    { -608, -256, -720},
    { -576, -216, -776},
    { -592, -232, -696},
    { -576, -216, -720},
    { -536, -216, -728},
    { -576, -232, -704},
    { -600, -240, -760},
    { -592, -224, -736},
    { -592, -224, -728},
    { -616, -272, -752},
    { -600, -256, -736},
    { -632, -224, -712},
    { -640, -248, -728},
    { -624, -160, -704},
    { -664, -176, -752},
    { -544, -248, -792},
    { -496, -184, -736},
    { -504, -296, -728},
    { -544, -304, -768},
    { -544, -264, -760},
    { -472, -296, -792},
    { -584, -208, -816},
    { -568, -224, -832},
    { -584, -192, -824},
    { -520, -224, -856},
    { -544, -184, -824},
    { -544, -248, -824},
    { -616, -176, -816},
    { -624, -208, -760},
    { -592, -128, -808},
    { -560, -160, -768},
    { -560, -168, -744},
    { -504, -176, -792},
    { -496, -176, -784},
    { -456, -280, -728},
    { -584, -136, -808},
    { -480, -200, -736},
    { -544, -168, -752},
    { -440, -216, -736},
    { -544, -176, -680},
    { -512, -152, -832},
    { -504, -120, -640},
    { -488, -224, -752},
    { -424, -216, -768},
    { -472, -208, -712},
    { -488, -184, -736},
    { -496, -152, -800},
    { -424, -224, -824},
    { -528, -208, -808},
    { -480, -224, -848},
    { -568, -96, -848},
    { -544, -200, -848},
    { -536, -184, -856},
    { -608, -168, -800},
    { -608, -192, -776},
    { -648, -152, -808},
    { -568, -192, -808},
    { -576, -160, -736},
    { -576, -144, -776},
    { -480, -248, -784},
    { -432, -256, -848},
    { -536, -184, -728},
    { -568, -208, -712},
    { -512, -208, -744},
    { -480, -224, -632},
    { -504, -312, -760},
    { -536, -200, -720},
    { -496, -152, -728},
    { -528, -160, -752},
    { -416, -88, -920},
    { -528, -64, -872},
    { -488, -152, -896},
    { -520, -136, -840},
    { -544, -168, -896},
    { -632, -80, -880},
    { -576, -176, -944},
    { -560, -152, -840},
    { -608, -152, -776},
    { -648, -200, -832},
    { -592, -112, -800},
    { -608, -104, -704},
    { -512, -200, -704},
    { -440, -136, -712},
    { -520, -152, -752},
    { -488, -136, -704},
    { -456, -152, -792},
    { -456, -120, -832},
    { -440, -120, -864},
    { -440, -192, -872},
    { -424, -200, -864},
    { -528, -168, -864},
    { -616, -48, -816},
    { -552, -128, -792},
    { -560, -168, -800},
    { -536, -88, -816},
    { -568, -24, -880},
    { -512, -104, -808},
    { -512, 32, -856},
    { -456, -80, -816},
    { -520, 80, -872},
    { -432, -64, -800},
    { -496, -32, -792},
    { -496, -8, -832},
    { -488, -56, -800},
    { -464, -56, -776},
    { -464, -120, -784},
    { -488, -112, -840},
    { -432, -40, -912},
    { -456, -72, -792},
    { -440, -88, -832},
    { -488, 16, -840},
    { -480, -48, -920},
    { -512, -40, -896},
    { -440, -56, -840},
    { -472, -104, -848},
    { -480, -120, -912},
    { -520, -16, -768},
    { -512, -120, -840},
    { -432, -104, -864},
    { -448, -120, -824},
    { -472, -40, -848},
    { -488, -48, -904},
    { -448, -16, -840},
    { -424, -112, -824},
    { -448, -80, -888},
    { -456, -48, -920},
    { -496, -16, -896},
    { -432, -112, -816},
    { -488, -96, -848},
    { -512, -40, -840},
    { -456, -152, -824},
    { -520, -40, -800},
    { -440, -152, -936},
    { -416, -16, -920},
    { -520, -272, -816},
    { -160, -272, -952},
    { -200, -200, -528},
    { -312, 32, -696},
    { -456, 200, -784},
    { -624, 248, -800},
    { -568, 8, -816},
    { -568, 336, -704},
    { -536, 208, -704},
    { -504, 136, -728},
    { -416, -24, -616},
    { -376, 840, -896},
    { -672, 648, -600},
    { -576, 640, -728},
    { -752, 784, -904},
    { -616, 256, -488},
    { -800, 1096, -760},
    { -624, 824, -688},
    { -576, 712, -464},
    { -888, 752, -408},
    { -792, 672, -512},
    { -648, 504, -568},
    { -576, -8, -424},
    { -344, -120, -520},
    { -88, -368, -544},
    { 56, -408, -440},
    { 120, -408, -456},
    { 512, -664, -880},
    { -384, -896, -888},
    { -1120, -144, -976},
    { -600, -80, -848},
    { -472, -328, -720},
    { -448, -336, -824},
    { -416, -352, -824},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}



// ----------------------------------------------------------------
// Sample captured: 2015-09-24 07:03:30 local
AccelRawData *activity_sample_50_steps_in_sandals(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME walk_50_in_sandals
  //> TEST_EXPECTED 50
  //> TEST_EXPECTED_MIN 45
  //> TEST_EXPECTED_MAX 60
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { 56, -64, -1016},
    { 72, -96, -1024},
    { 64, -96, -1008},
    { 72, -96, -1008},
    { 72, -88, -1016},
    { 72, -88, -1024},
    { 72, -96, -1024},
    { 64, -112, -1016},
    { 56, -128, -1024},
    { 64, -128, -1016},
    { 80, -144, -1000},
    { 64, -160, -968},
    { 72, -176, -984},
    { 64, -144, -1024},
    { 56, -168, -1040},
    { -88, -248, -976},
    { -56, -232, -976},
    { -32, -192, -976},
    { -40, -200, -952},
    { -24, -184, -944},
    { -8, -184, -984},
    { -16, -160, -888},
    { 48, -120, -1016},
    { -32, -120, -992},
    { -56, -112, -1000},
    { -56, -88, -1008},
    { -80, -96, -1008},
    { -40, -104, -1008},
    { -56, -120, -944},
    { -72, -176, -880},
    { -80, -136, -848},
    { -24, -120, -752},
    { -8, -64, -544},
    { 168, 8, -504},
    { 656, 280, -656},
    { 864, 184, -360},
    { 1144, 224, -24},
    { 1616, 408, 344},
    { 1832, 576, 544},
    { 1696, 720, 184},
    { 1248, 712, 56},
    { 992, 496, 256},
    { 896, 320, 160},
    { 784, 192, 56},
    { 688, 112, 16},
    { 696, 168, -8},
    { 760, 280, -72},
    { 888, 416, -56},
    { 1048, 472, -64},
    { 1032, 408, 0},
    { 1464, 576, -80},
    { 1408, 584, 136},
    { 1232, 352, 168},
    { 1056, 184, 184},
    { 944, 168, 160},
    { 848, 192, 136},
    { 816, 160, 168},
    { 880, 136, 168},
    { 992, 112, 232},
    { 1128, 72, 328},
    { 1120, 24, 368},
    { 1008, 128, 224},
    { 1192, 72, 272},
    { 808, 72, 160},
    { 752, 248, -152},
    { 760, 152, -72},
    { 864, 136, 8},
    { 896, 168, 64},
    { 944, 256, 32},
    { 976, 432, -80},
    { 992, 568, 24},
    { 1000, 464, -128},
    { 1176, 608, -104},
    { 1016, 560, -80},
    { 1360, 648, 40},
    { 1504, 592, 168},
    { 1280, 400, 160},
    { 1064, 248, 144},
    { 992, 192, 200},
    { 936, 208, 168},
    { 920, 176, 160},
    { 880, 88, 240},
    { 904, 72, 208},
    { 976, 40, 272},
    { 992, 32, 296},
    { 904, 80, 240},
    { 960, 112, 120},
    { 1136, 24, 280},
    { 784, 72, 136},
    { 848, 288, -168},
    { 984, 312, -128},
    { 1016, 280, 8},
    { 920, 272, -40},
    { 864, 240, -112},
    { 888, 304, -152},
    { 848, 376, -208},
    { 952, 448, -200},
    { 1160, 504, -176},
    { 1000, 472, -64},
    { 1752, 640, -72},
    { 1296, 464, 128},
    { 1192, 264, 184},
    { 1072, 176, 200},
    { 928, 200, 144},
    { 840, 176, 152},
    { 776, 144, 152},
    { 840, 112, 160},
    { 936, 96, 200},
    { 1000, 32, 248},
    { 1040, 48, 248},
    { 1072, 88, 168},
    { 1072, 64, 208},
    { 800, 120, -8},
    { 784, 224, -160},
    { 928, 232, -128},
    { 1032, 216, -8},
    { 960, 208, 32},
    { 904, 280, -72},
    { 872, 344, -144},
    { 840, 392, -136},
    { 808, 424, -200},
    { 1072, 456, -144},
    { 944, 424, -80},
    { 1376, 480, 112},
    { 1432, 544, 96},
    { 1408, 432, 168},
    { 1288, 328, 248},
    { 1040, 176, 280},
    { 872, 152, 168},
    { 848, 128, 184},
    { 856, 120, 200},
    { 912, 104, 200},
    { 880, 40, 272},
    { 904, 24, 304},
    { 960, 80, 296},
    { 880, 128, 144},
    { 1072, 120, 200},
    { 968, 104, 176},
    { 888, 296, -112},
    { 1000, 408, -232},
    { 1064, 256, 24},
    { 1016, 264, 32},
    { 976, 224, -88},
    { 864, 192, -112},
    { 848, 296, -168},
    { 832, 304, -96},
    { 936, 288, -40},
    { 1120, 296, 24},
    { 1008, 256, 144},
    { 1544, 352, 152},
    { 1424, 424, 232},
    { 1192, 320, 264},
    { 1008, 224, 232},
    { 984, 192, 256},
    { 896, 192, 264},
    { 808, 112, 264},
    { 832, 80, 272},
    { 896, 96, 288},
    { 928, 64, 352},
    { 976, 80, 328},
    { 952, 96, 232},
    { 1248, 8, 336},
    { 872, -40, 224},
    { 832, 256, -248},
    { 856, 272, -224},
    { 944, 144, -64},
    { 936, 96, 16},
    { 872, 152, -64},
    { 832, 240, -216},
    { 872, 296, -168},
    { 912, 304, -160},
    { 952, 368, -200},
    { 1112, 376, -128},
    { 1064, 336, -24},
    { 1560, 400, 16},
    { 1352, 448, 64},
    { 1304, 320, 160},
    { 1024, 240, 136},
    { 1016, 224, 120},
    { 920, 208, 120},
    { 792, 144, 160},
    { 832, 112, 136},
    { 856, 40, 208},
    { 992, 40, 232},
    { 1072, 40, 272},
    { 992, 64, 192},
    { 1216, 40, 208},
    { 1016, 24, 216},
    { 848, 176, -128},
    { 840, 256, -240},
    { 928, 144, -96},
    { 920, 104, 24},
    { 856, 120, 16},
    { 840, 240, -48},
    { 856, 304, 0},
    { 920, 352, -24},
    { 1000, 344, -16},
    { 1096, 360, -16},
    { 1032, 368, 0},
    { 1648, 576, -48},
    { 1224, 504, 72},
    { 1208, 336, 0},
    { 1040, 240, 40},
    { 1064, 224, 56},
    { 992, 184, 48},
    { 856, 120, 104},
    { 872, 96, 96},
    { 832, 48, 152},
    { 880, 72, 136},
    { 888, 40, 192},
    { 968, 56, 176},
    { 1040, 88, 120},
    { 1216, 48, 248},
    { 1040, 112, 24},
    { 992, 280, -216},
    { 1008, 264, -176},
    { 968, 168, 40},
    { 848, 144, 88},
    { 800, 208, 40},
    { 784, 288, 32},
    { 760, 312, 32},
    { 784, 296, 0},
    { 1008, 328, 24},
    { 1048, 368, -8},
    { 1144, 400, 48},
    { 1504, 600, -8},
    { 1256, 368, 80},
    { 1048, 304, -64},
    { 1016, 248, 8},
    { 1072, 224, 8},
    { 896, 128, 8},
    { 864, 112, 24},
    { 800, 56, 56},
    { 824, 64, 32},
    { 792, 32, 88},
    { 944, 24, 104},
    { 984, 48, 120},
    { 1120, 80, 144},
    { 1216, 96, 200},
    { 1104, 208, 88},
    { 1040, 312, -80},
    { 992, 256, 8},
    { 984, 168, 144},
    { 848, 144, 144},
    { 768, 176, 136},
    { 720, 224, 128},
    { 712, 312, 48},
    { 728, 376, 24},
    { 968, 416, 0},
    { 976, 440, -24},
    { 1152, 432, 56},
    { 1576, 656, -48},
    { 1272, 496, 24},
    { 1112, 232, -8},
    { 1080, 248, 16},
    { 1048, 264, -48},
    { 864, 184, -40},
    { 768, 112, 8},
    { 824, 88, 0},
    { 824, 64, 56},
    { 864, 32, 80},
    { 960, 8, 120},
    { 984, 56, 128},
    { 1112, 88, 128},
    { 1384, 80, 280},
    { 1072, 184, 160},
    { 1000, 336, -88},
    { 992, 280, 0},
    { 864, 208, 112},
    { 752, 144, 64},
    { 704, 152, 32},
    { 696, 208, 56},
    { 680, 256, 0},
    { 776, 312, -24},
    { 1096, 344, 32},
    { 1016, 392, -16},
    { 1256, 448, 16},
    { 1456, 560, -16},
    { 1320, 352, 136},
    { 1088, 280, -24},
    { 1000, 240, 8},
    { 1040, 264, 16},
    { 904, 176, 24},
    { 840, 104, 48},
    { 824, 48, 72},
    { 808, 32, 96},
    { 808, 40, 120},
    { 896, 32, 144},
    { 936, 72, 136},
    { 1184, 88, 168},
    { 1328, 80, 296},
    { 1144, 256, 96},
    { 984, 360, -136},
    { 936, 248, 48},
    { 864, 192, 136},
    { 768, 120, 88},
    { 768, 184, 80},
    { 816, 232, 80},
    { 800, 304, 24},
    { 752, 344, -56},
    { 992, 352, -72},
    { 1056, 344, -32},
    { 1488, 400, 72},
    { 1424, 520, 24},
    { 1168, 288, 64},
    { 960, 288, -40},
    { 1008, 256, 40},
    { 976, 240, 48},
    { 872, 136, 56},
    { 808, 64, 112},
    { 816, 72, 88},
    { 768, 72, 128},
    { 824, 88, 136},
    { 936, 64, 176},
    { 952, 88, 144},
    { 1304, 80, 216},
    { 1184, 104, 224},
    { 1040, 296, -56},
    { 992, 360, -176},
    { 1016, 216, 64},
    { 872, 128, 152},
    { 776, 144, 72},
    { 736, 232, 48},
    { 728, 304, 8},
    { 744, 320, -16},
    { 824, 328, -40},
    { 984, 328, -24},
    { 968, 336, -40},
    { 1408, 416, 56},
    { 1320, 600, -72},
    { 1256, 304, 152},
    { 1080, 208, 80},
    { 1048, 216, 88},
    { 952, 256, 64},
    { 792, 168, 80},
    { 768, 136, 64},
    { 792, 88, 96},
    { 768, 56, 112},
    { 848, 32, 128},
    { 944, 32, 160},
    { 960, 88, 128},
    { 1360, 72, 264},
    { 1152, 152, 224},
    { 968, 360, -128},
    { 904, 360, -160},
    { 992, 200, 96},
    { 888, 112, 136},
    { 760, 104, 48},
    { 744, 216, 24},
    { 752, 304, -24},
    { 760, 344, -64},
    { 848, 328, -88},
    { 1080, 312, -56},
    { 984, 344, -40},
    { 1584, 488, 0},
    { 1344, 520, 128},
    { 1216, 320, 88},
    { 1064, 240, 80},
    { 1040, 232, 128},
    { 880, 216, 96},
    { 776, 144, 56},
    { 744, 96, 104},
    { 816, 80, 96},
    { 864, 40, 152},
    { 952, 16, 184},
    { 968, 56, 160},
    { 1040, 88, 152},
    { 1296, 88, 272},
    { 1024, 184, 128},
    { 968, 352, -160},
    { 968, 312, -64},
    { 968, 200, 96},
    { 832, 120, 80},
    { 784, 160, 40},
    { 776, 232, 40},
    { 792, 312, -24},
    { 784, 328, -32},
    { 960, 320, -24},
    { 984, 336, -32},
    { 968, 360, 16},
    { 1672, 592, -40},
    { 1288, 456, 168},
    { 1184, 184, 136},
    { 1120, 184, 104},
    { 1040, 248, 88},
    { 936, 248, 72},
    { 816, 136, 64},
    { 776, 88, 88},
    { 712, 56, 88},
    { 792, 24, 104},
    { 872, -8, 168},
    { 912, 40, 176},
    { 1040, 88, 112},
    { 1344, 104, 240},
    { 1224, 248, 96},
    { 1112, 384, -112},
    { 1008, 360, -80},
    { 872, 264, 64},
    { 728, 176, 96},
    { 720, 192, 40},
    { 800, 256, 56},
    { 800, 264, 40},
    { 768, 296, -16},
    { 936, 312, -24},
    { 1104, 344, 16},
    { 1464, 520, 0},
    { 1384, 400, 184},
    { 1128, 288, -8},
    { 976, 240, 24},
    { 1024, 296, 24},
    { 896, 240, 32},
    { 800, 128, 80},
    { 776, 80, 96},
    { 744, 64, 128},
    { 856, 96, 128},
    { 984, 64, 208},
    { 1048, 72, 248},
    { 1352, 96, 280},
    { 1168, 104, 312},
    { 904, 248, -40},
    { 816, 312, -200},
    { 864, 224, -64},
    { 816, 88, 88},
    { 760, 40, 72},
    { 792, 176, -24},
    { 824, 264, -40},
    { 840, 288, -8},
    { 856, 312, -72},
    { 976, 328, -88},
    { 1064, 360, -80},
    { 1136, 352, 48},
    { 1600, 624, -88},
    { 1224, 440, 136},
    { 1152, 232, 88},
    { 1072, 208, 120},
    { 960, 248, 80},
    { 808, 192, 80},
    { 760, 144, 72},
    { 760, 104, 96},
    { 760, 80, 112},
    { 880, 48, 144},
    { 1008, 40, 192},
    { 1096, 72, 208},
    { 1360, 64, 312},
    { 984, 192, 56},
    { 904, 344, -248},
    { 904, 288, -152},
    { 920, 136, 32},
    { 816, 40, 64},
    { 784, 152, -16},
    { 776, 256, -56},
    { 768, 320, -80},
    { 784, 328, -104},
    { 904, 336, -80},
    { 1024, 384, -96},
    { 1520, 512, 40},
    { 1328, 616, 80},
    { 1328, 288, 136},
    { 1016, 208, 72},
    { 976, 248, 112},
    { 912, 256, 104},
    { 760, 152, 104},
    { 776, 120, 104},
    { 744, 72, 160},
    { 776, 88, 128},
    { 872, 64, 184},
    { 960, 48, 240},
    { 1008, 96, 232},
    { 1336, 104, 280},
    { 1080, 160, 176},
    { 952, 320, -128},
    { 872, 336, -120},
    { 960, 176, 88},
    { 888, 128, 96},
    { 768, 192, -16},
    { 760, 256, -64},
    { 760, 264, -32},
    { 744, 264, -24},
    { 744, 264, -40},
    { 984, 296, 0},
    { 984, 360, 24},
    { 1072, 360, 88},
    { 1696, 560, 64},
    { 1408, 392, 240},
    { 1120, 240, 168},
    { 1064, 184, 184},
    { 936, 200, 160},
    { 792, 200, 128},
    { 736, 144, 128},
    { 752, 88, 176},
    { 824, 72, 200},
    { 944, 48, 288},
    { 1024, 56, 352},
    { 928, 128, 232},
    { 1256, 144, 264},
    { 1096, 104, 328},
    { 832, 256, -40},
    { 800, 312, -200},
    { 896, 176, -16},
    { 888, 128, 48},
    { 824, 96, -16},
    { 808, 192, -88},
    { 832, 288, -136},
    { 808, 320, -120},
    { 824, 304, -128},
    { 960, 312, -96},
    { 1072, 328, -32},
    { 1304, 360, 96},
    { 1440, 528, 8},
    { 1336, 320, 184},
    { 1096, 248, 152},
    { 1032, 208, 152},
    { 936, 264, 112},
    { 816, 168, 144},
    { 752, 120, 160},
    { 800, 120, 136},
    { 792, 64, 208},
    { 944, 64, 216},
    { 1016, 48, 280},
    { 912, 120, 176},
    { 1232, 104, 176},
    { 1088, 80, 232},
    { 856, 232, -136},
    { 832, 304, -256},
    { 920, 200, -120},
    { 888, 168, 0},
    { 856, 144, -16},
    { 824, 256, -128},
    { 832, 336, -112},
    { 824, 400, -128},
    { 888, 384, -80},
    { 1072, 384, -32},
    { 904, 376, -24},
    { 1360, 472, 40},
    { 1448, 536, 128},
    { 1312, 304, 216},
    { 1096, 264, 136},
    { 1040, 200, 208},
    { 880, 200, 176},
    { 792, 200, 112},
    { 832, 104, 184},
    { 800, 56, 224},
    { 840, 80, 200},
    { 880, 56, 264},
    { 992, 64, 296},
    { 968, 128, 240},
    { 1328, 120, 304},
    { 936, 136, 168},
    { 880, 344, -192},
    { 864, 344, -144},
    { 968, 232, 8},
    { 864, 152, 16},
    { 816, 160, -80},
    { 792, 248, -136},
    { 800, 272, -96},
    { 840, 288, -96},
    { 848, 320, -144},
    { 976, 360, -88},
    { 952, 352, -16},
    { 1344, 376, 120},
    { 1384, 456, 96},
    { 1240, 392, 184},
    { 1000, 312, 128},
    { 992, 240, 152},
    { 832, 216, 120},
    { 744, 168, 120},
    { 792, 104, 176},
    { 856, 80, 216},
    { 920, 80, 296},
    { 960, 72, 360},
    { 1008, 104, 304},
    { 1088, 152, 192},
    { 1232, 40, 344},
    { 808, 136, 16},
    { 824, 288, -264},
    { 864, 200, -168},
    { 928, 112, -48},
    { 864, 64, -32},
    { 824, 160, -144},
    { 824, 232, -200},
    { 856, 224, -128},
    { 904, 256, -136},
    { 912, 312, -144},
    { 1056, 360, -120},
    { 1024, 344, -40},
    { 1320, 352, 64},
    { 1360, 528, -56},
    { 1288, 416, 152},
    { 1064, 248, 144},
    { 1024, 176, 184},
    { 880, 200, 136},
    { 784, 176, 144},
    { 720, 136, 136},
    { 800, 136, 120},
    { 864, 80, 200},
    { 944, 56, 216},
    { 992, 24, 248},
    { 1056, 80, 200},
    { 1288, 96, 288},
    { 912, 176, 40},
    { 904, 328, -224},
    { 960, 240, -88},
    { 920, 152, 56},
    { 816, 120, 32},
    { 776, 232, -112},
    { 784, 352, -112},
    { 800, 424, -112},
    { 800, 456, -136},
    { 1008, 440, -48},
    { 1032, 424, -24},
    { 944, 440, 40},
    { 1656, 592, 128},
    { 1368, 520, 224},
    { 1192, 336, 224},
    { 1080, 232, 256},
    { 888, 208, 208},
    { 792, 192, 152},
    { 784, 136, 168},
    { 808, 96, 176},
    { 816, 56, 192},
    { 848, 32, 224},
    { 904, 40, 232},
    { 888, 96, 192},
    { 1128, 112, 224},
    { 1168, 64, 352},
    { 904, 232, 0},
    { 968, 376, -216},
    { 1064, 344, -72},
    { 896, 256, 8},
    { 824, 144, -24},
    { 808, 184, -104},
    { 824, 272, -88},
    { 856, 336, -112},
    { 848, 304, -96},
    { 904, 304, -80},
    { 1032, 312, -48},
    { 1032, 304, 88},
    { 1616, 456, 8},
    { 1376, 432, 168},
    { 1184, 296, 200},
    { 1080, 208, 200},
    { 1000, 216, 184},
    { 832, 184, 192},
    { 760, 136, 168},
    { 848, 112, 176},
    { 800, 56, 264},
    { 880, 48, 248},
    { 968, 40, 280},
    { 896, 88, 248},
    { 1120, 120, 200},
    { 1232, 64, 320},
    { 976, 192, 40},
    { 904, 352, -256},
    { 864, 304, -184},
    { 840, 176, -32},
    { 856, 80, -16},
    { 888, 120, -64},
    { 912, 248, -56},
    { 936, 352, -80},
    { 880, 392, -96},
    { 800, 328, -56},
    { 840, 272, -40},
    { 840, 240, 0},
    { 872, 232, 96},
    { 1920, 440, 136},
    { 1600, 432, 456},
    { 1232, 312, 192},
    { 1216, 176, 136},
    { 1176, 240, 200},
    { 1000, 336, 216},
    { 936, 248, 240},
    { 872, 272, 336},
    { 936, 576, 336},
    { 904, 768, 184},
    { 864, 816, 56},
    { 768, 912, -200},
    { 632, 544, -352},
    { 456, 200, -504},
    { 328, 8, -560},
    { 168, -192, -712},
    { 192, -160, -824},
    { 176, -192, -840},
    { 152, -136, -832},
    { 128, -200, -816},
    { 128, -216, -840},
    { 120, -208, -928},
    { 152, -240, -960},
    { 136, -216, -968},
    { 104, -192, -1008},
    { 64, -160, -984},
    { 64, -208, -968},
    { 80, -192, -1000},
    { 24, -152, -1032},
    { -40, -192, -984},
    { -48, -152, -992},
    { -48, -136, -1000},
    { 16, -176, -1056},
    { -64, -136, -992},
    { -96, -112, -984},
    { -112, -80, -1024},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}




// ----------------------------------------------------------------
// Sample captured: 2015-09-24 06:49:33 local
AccelRawData *activity_sample_50_steps_barefoot_1(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME walk_50_barefoot_1
  //> TEST_EXPECTED 50
  //> TEST_EXPECTED_MIN 45
  //> TEST_EXPECTED_MAX 60
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { 0, 56, -1016},
    { -8, 56, -1008},
    { -8, 48, -1000},
    { -8, 56, -1000},
    { -16, 56, -1000},
    { -16, 56, -1008},
    { -8, 64, -1016},
    { -16, 64, -1016},
    { -16, 64, -1008},
    { -16, 56, -1016},
    { -16, 72, -1008},
    { -24, 72, -1008},
    { -24, 72, -1008},
    { -16, 64, -1016},
    { -24, 48, -1008},
    { -16, 56, -1016},
    { -16, 64, -1000},
    { -16, 56, -1008},
    { -16, 64, -1008},
    { -16, 64, -1000},
    { -8, 64, -1000},
    { -16, 48, -1000},
    { -16, 48, -1008},
    { -8, 64, -1016},
    { -24, 88, -1016},
    { -8, 104, -1024},
    { 200, 32, -936},
    { -88, 0, -1008},
    { -56, 32, -1008},
    { -56, 64, -1024},
    { -72, 32, -1016},
    { -40, 40, -976},
    { -56, 40, -976},
    { -16, 56, -992},
    { -16, 32, -1008},
    { -8, 64, -1056},
    { 24, 24, -960},
    { 48, 136, -952},
    { 0, 120, -896},
    { -80, 72, -880},
    { -64, 152, -912},
    { -72, 200, -704},
    { -56, 280, -648},
    { 96, 384, -536},
    { 256, 544, -504},
    { 480, 768, -512},
    { 536, 808, -392},
    { 560, 768, -184},
    { 648, 816, -40},
    { 712, 840, 40},
    { 776, 728, 104},
    { 952, 528, 160},
    { 1184, 440, 200},
    { 1120, 344, 240},
    { 1176, 304, 232},
    { 1096, 352, 192},
    { 920, 400, 104},
    { 928, 336, 112},
    { 920, 256, 80},
    { 864, 168, 40},
    { 768, 16, 0},
    { 752, 80, -16},
    { 792, 168, -24},
    { 880, 208, -24},
    { 864, 208, -8},
    { 1016, 216, 8},
    { 1080, 224, 40},
    { 1184, 248, 96},
    { 1144, 312, 80},
    { 1080, 352, 96},
    { 848, 360, 56},
    { 856, 328, 56},
    { 928, 288, 112},
    { 848, 200, 160},
    { 800, 184, 104},
    { 832, 152, 136},
    { 848, 152, 144},
    { 960, 128, 184},
    { 1016, 96, 240},
    { 1056, 120, 192},
    { 1008, 96, 144},
    { 1168, 16, 232},
    { 1088, 88, 136},
    { 872, 184, -96},
    { 776, 192, -160},
    { 728, 120, -64},
    { 816, 96, -16},
    { 784, 88, -32},
    { 816, 208, -24},
    { 888, 232, -8},
    { 936, 272, -16},
    { 984, 296, -8},
    { 1136, 344, -8},
    { 1088, 376, 24},
    { 1288, 432, -24},
    { 1056, 400, 8},
    { 896, 368, -16},
    { 920, 320, 8},
    { 952, 288, 56},
    { 896, 216, 112},
    { 848, 168, 136},
    { 920, 192, 96},
    { 992, 128, 184},
    { 952, 96, 200},
    { 1024, 104, 176},
    { 976, 80, 168},
    { 960, 80, 80},
    { 1136, 32, 216},
    { 880, 104, 64},
    { 856, 272, -136},
    { 880, 208, -32},
    { 880, 184, 48},
    { 824, 144, 56},
    { 776, 200, 8},
    { 760, 248, -24},
    { 784, 280, 0},
    { 912, 320, -8},
    { 1136, 368, 8},
    { 1048, 432, -16},
    { 1272, 456, -8},
    { 1160, 504, -16},
    { 1080, 392, 56},
    { 944, 336, 16},
    { 912, 312, 40},
    { 872, 264, 104},
    { 840, 208, 104},
    { 880, 184, 112},
    { 936, 144, 160},
    { 936, 120, 168},
    { 976, 88, 224},
    { 1048, 96, 248},
    { 880, 120, 144},
    { 1048, 120, 96},
    { 1104, 88, 208},
    { 792, 160, 32},
    { 824, 264, -112},
    { 848, 216, -32},
    { 888, 200, 64},
    { 832, 160, 24},
    { 800, 184, -16},
    { 856, 248, 8},
    { 912, 304, -40},
    { 952, 352, -48},
    { 1080, 384, -72},
    { 1040, 392, -72},
    { 1080, 328, 24},
    { 1240, 408, 0},
    { 1072, 376, 72},
    { 1008, 384, 0},
    { 1024, 336, 72},
    { 976, 248, 136},
    { 872, 200, 104},
    { 848, 128, 152},
    { 896, 136, 152},
    { 936, 120, 176},
    { 936, 80, 224},
    { 1000, 88, 184},
    { 1056, 104, 128},
    { 1064, 72, 184},
    { 952, 136, 8},
    { 784, 240, -184},
    { 832, 216, -144},
    { 856, 184, -56},
    { 856, 152, -16},
    { 800, 184, -8},
    { 816, 240, -48},
    { 880, 240, 0},
    { 952, 280, 0},
    { 1072, 336, -8},
    { 1104, 416, -40},
    { 1360, 464, 8},
    { 1128, 496, -16},
    { 1008, 352, 24},
    { 864, 344, -16},
    { 912, 352, -16},
    { 968, 304, 56},
    { 896, 200, 88},
    { 856, 176, 96},
    { 912, 152, 120},
    { 880, 120, 160},
    { 920, 96, 168},
    { 960, 96, 192},
    { 976, 128, 152},
    { 1208, 96, 168},
    { 1040, 48, 224},
    { 784, 184, -56},
    { 816, 288, -184},
    { 920, 224, -64},
    { 888, 160, 56},
    { 824, 128, 16},
    { 784, 216, -56},
    { 800, 288, -40},
    { 832, 328, -40},
    { 888, 336, -32},
    { 1048, 392, -32},
    { 1080, 448, 0},
    { 992, 408, 72},
    { 1224, 472, 48},
    { 1152, 448, 88},
    { 864, 360, 64},
    { 928, 336, 64},
    { 1016, 304, 136},
    { 928, 216, 208},
    { 872, 208, 136},
    { 872, 168, 176},
    { 864, 136, 176},
    { 936, 112, 176},
    { 960, 64, 232},
    { 1056, 88, 224},
    { 1008, 120, 168},
    { 1096, 120, 200},
    { 912, 152, 72},
    { 760, 240, -80},
    { 768, 224, -80},
    { 872, 208, 0},
    { 896, 176, 40},
    { 840, 208, -8},
    { 800, 248, -16},
    { 800, 264, -16},
    { 872, 280, -40},
    { 928, 296, -16},
    { 1088, 384, -24},
    { 1096, 424, -32},
    { 1296, 432, 8},
    { 1136, 424, 8},
    { 1032, 360, 24},
    { 840, 312, 0},
    { 944, 296, 40},
    { 968, 248, 120},
    { 896, 168, 168},
    { 864, 168, 152},
    { 928, 168, 152},
    { 856, 120, 216},
    { 864, 112, 192},
    { 936, 120, 184},
    { 984, 104, 192},
    { 936, 80, 152},
    { 1208, 64, 224},
    { 944, 112, 96},
    { 776, 296, -136},
    { 872, 264, -88},
    { 936, 216, 24},
    { 936, 168, 56},
    { 856, 216, 16},
    { 808, 272, -32},
    { 800, 296, 0},
    { 840, 312, -16},
    { 912, 320, 8},
    { 1128, 384, 16},
    { 992, 432, 0},
    { 1240, 456, 16},
    { 1096, 416, 56},
    { 976, 368, 48},
    { 968, 320, 72},
    { 976, 296, 104},
    { 944, 216, 184},
    { 864, 192, 168},
    { 920, 184, 160},
    { 872, 136, 208},
    { 864, 136, 184},
    { 936, 120, 216},
    { 992, 88, 248},
    { 960, 104, 216},
    { 1224, 88, 256},
    { 920, 112, 112},
    { 856, 232, -72},
    { 752, 256, -112},
    { 856, 208, -40},
    { 888, 160, 24},
    { 896, 184, -16},
    { 848, 232, -24},
    { 832, 272, -32},
    { 824, 240, -40},
    { 856, 264, -40},
    { 984, 296, -8},
    { 1144, 360, 0},
    { 1048, 376, 16},
    { 1256, 392, 24},
    { 1128, 384, 56},
    { 1000, 352, 32},
    { 912, 320, 24},
    { 944, 296, 72},
    { 936, 248, 136},
    { 864, 192, 168},
    { 856, 192, 152},
    { 864, 168, 184},
    { 888, 152, 216},
    { 984, 136, 256},
    { 1056, 104, 296},
    { 992, 112, 264},
    { 1216, 120, 272},
    { 920, 144, 128},
    { 856, 216, -64},
    { 704, 224, -176},
    { 800, 168, -112},
    { 864, 120, -72},
    { 856, 120, -80},
    { 832, 184, -96},
    { 848, 216, -96},
    { 872, 224, -88},
    { 888, 256, -72},
    { 1008, 320, -56},
    { 1144, 384, -40},
    { 1056, 392, 8},
    { 1224, 472, -56},
    { 1104, 432, 8},
    { 968, 352, 24},
    { 928, 288, 48},
    { 960, 296, 80},
    { 896, 248, 136},
    { 848, 224, 144},
    { 856, 192, 168},
    { 888, 176, 184},
    { 928, 144, 200},
    { 984, 104, 248},
    { 1072, 128, 240},
    { 1040, 120, 248},
    { 1192, 88, 264},
    { 856, 128, 48},
    { 840, 184, -104},
    { 720, 184, -112},
    { 840, 168, -80},
    { 904, 120, -64},
    { 872, 136, -72},
    { 856, 192, -72},
    { 832, 224, -80},
    { 840, 256, -104},
    { 888, 272, -72},
    { 1024, 344, -88},
    { 1128, 376, -72},
    { 1008, 360, -48},
    { 1232, 392, -40},
    { 1088, 408, -24},
    { 968, 344, 16},
    { 864, 288, 8},
    { 944, 296, 16},
    { 1048, 264, 88},
    { 952, 184, 136},
    { 920, 168, 112},
    { 880, 152, 128},
    { 920, 144, 112},
    { 888, 96, 144},
    { 920, 80, 136},
    { 984, 88, 96},
    { 928, 80, 56},
    { 1104, 64, 144},
    { 984, 88, 96},
    { 888, 240, -56},
    { 896, 272, -80},
    { 888, 240, 24},
    { 960, 208, 72},
    { 880, 216, 96},
    { 824, 272, 88},
    { 792, 288, 56},
    { 848, 288, 56},
    { 912, 264, 24},
    { 1008, 288, 8},
    { 1032, 328, -24},
    { 1056, 320, -32},
    { 1176, 352, -56},
    { 1056, 328, -16},
    { 920, 288, -48},
    { 896, 304, -80},
    { 1024, 288, -48},
    { 1128, 200, 48},
    { 1016, 144, 80},
    { 928, 136, 80},
    { 896, 136, 104},
    { 872, 136, 112},
    { 856, 120, 104},
    { 856, 96, 96},
    { 888, 56, 128},
    { 840, 72, 104},
    { 1120, 80, 168},
    { 1056, 104, 200},
    { 976, 256, 104},
    { 904, 312, 8},
    { 1016, 328, 64},
    { 1056, 272, 112},
    { 904, 200, 104},
    { 840, 232, 72},
    { 816, 224, 56},
    { 800, 216, 32},
    { 784, 208, 8},
    { 888, 272, -48},
    { 976, 288, -56},
    { 1144, 256, 0},
    { 1272, 296, -24},
    { 952, 288, 24},
    { 840, 304, -112},
    { 912, 296, -112},
    { 1056, 256, -48},
    { 1128, 144, 80},
    { 1016, 120, 104},
    { 944, 160, 88},
    { 920, 200, 64},
    { 960, 168, 96},
    { 864, 104, 88},
    { 880, 88, 40},
    { 880, 32, 88},
    { 840, 56, 48},
    { 992, 80, 56},
    { 1112, 112, 144},
    { 1136, 224, 96},
    { 880, 312, -48},
    { 920, 256, 72},
    { 1048, 208, 192},
    { 944, 200, 168},
    { 808, 208, 136},
    { 744, 224, 96},
    { 736, 216, 48},
    { 728, 184, 32},
    { 792, 200, 8},
    { 984, 248, -24},
    { 1112, 288, 16},
    { 1304, 376, -16},
    { 1104, 368, -16},
    { 960, 336, -104},
    { 856, 328, -128},
    { 984, 320, -80},
    { 1080, 208, 32},
    { 960, 160, 88},
    { 872, 192, 48},
    { 856, 184, 64},
    { 864, 160, 80},
    { 856, 128, 72},
    { 872, 112, 72},
    { 1016, 112, 88},
    { 1040, 104, 104},
    { 1144, 112, 120},
    { 976, 136, 88},
    { 920, 224, -8},
    { 768, 264, -80},
    { 848, 248, -56},
    { 904, 144, 72},
    { 920, 184, 72},
    { 840, 224, 56},
    { 784, 248, 32},
    { 768, 224, 8},
    { 816, 192, -8},
    { 888, 200, 0},
    { 1024, 264, -8},
    { 1104, 344, -48},
    { 1176, 392, -56},
    { 1136, 456, -112},
    { 1112, 360, -8},
    { 960, 288, -16},
    { 952, 264, 8},
    { 960, 272, 56},
    { 904, 232, 112},
    { 864, 208, 112},
    { 880, 176, 144},
    { 872, 136, 184},
    { 864, 136, 168},
    { 920, 112, 192},
    { 976, 96, 208},
    { 1016, 104, 192},
    { 992, 112, 136},
    { 1128, 88, 192},
    { 928, 152, 64},
    { 752, 264, -112},
    { 768, 256, -112},
    { 896, 208, -16},
    { 952, 152, 32},
    { 904, 184, 32},
    { 840, 256, 8},
    { 824, 288, -16},
    { 872, 272, -24},
    { 872, 232, -8},
    { 952, 264, -16},
    { 1096, 320, -16},
    { 992, 320, 32},
    { 1184, 360, 0},
    { 1136, 368, 24},
    { 992, 328, 64},
    { 952, 296, 64},
    { 976, 280, 104},
    { 960, 248, 144},
    { 912, 200, 144},
    { 864, 144, 176},
    { 864, 152, 144},
    { 912, 112, 184},
    { 960, 72, 240},
    { 1000, 80, 248},
    { 968, 112, 192},
    { 1168, 96, 216},
    { 968, 88, 224},
    { 840, 224, -8},
    { 744, 256, -136},
    { 840, 264, -88},
    { 888, 176, 0},
    { 968, 168, 8},
    { 888, 224, -16},
    { 856, 264, -32},
    { 832, 272, -64},
    { 824, 248, -40},
    { 912, 248, -24},
    { 1104, 304, -8},
    { 1064, 360, 16},
    { 1264, 392, 16},
    { 1120, 400, 40},
    { 976, 336, 40},
    { 864, 272, 32},
    { 928, 280, 40},
    { 968, 232, 128},
    { 888, 200, 144},
    { 864, 176, 152},
    { 848, 168, 160},
    { 896, 168, 152},
    { 904, 104, 208},
    { 976, 104, 200},
    { 1024, 120, 184},
    { 1200, 96, 208},
    { 976, 80, 176},
    { 904, 184, 8},
    { 728, 256, -152},
    { 760, 248, -128},
    { 856, 152, -32},
    { 920, 136, -16},
    { 880, 192, -56},
    { 832, 224, -56},
    { 808, 224, -80},
    { 816, 216, -48},
    { 912, 232, -32},
    { 1056, 280, -24},
    { 1048, 336, -32},
    { 1288, 368, -16},
    { 1104, 456, -48},
    { 1016, 344, 64},
    { 952, 288, 24},
    { 992, 296, 56},
    { 976, 280, 96},
    { 888, 200, 144},
    { 816, 184, 136},
    { 840, 192, 128},
    { 848, 136, 168},
    { 904, 112, 176},
    { 952, 96, 192},
    { 1040, 104, 192},
    { 960, 112, 136},
    { 1136, 96, 176},
    { 992, 120, 88},
    { 840, 232, -88},
    { 792, 272, -152},
    { 880, 224, -56},
    { 920, 152, 32},
    { 888, 160, 32},
    { 840, 216, 0},
    { 808, 248, -16},
    { 800, 248, -32},
    { 816, 224, -16},
    { 952, 240, 0},
    { 1112, 328, 16},
    { 1056, 368, 48},
    { 1256, 440, 0},
    { 1120, 416, 72},
    { 960, 344, 32},
    { 968, 304, 40},
    { 976, 280, 88},
    { 920, 224, 128},
    { 880, 176, 136},
    { 856, 176, 128},
    { 880, 144, 168},
    { 880, 120, 176},
    { 968, 96, 216},
    { 1032, 88, 224},
    { 960, 112, 176},
    { 1192, 96, 224},
    { 968, 88, 176},
    { 792, 200, -32},
    { 744, 256, -144},
    { 864, 240, -72},
    { 920, 152, 24},
    { 920, 136, 16},
    { 856, 200, -8},
    { 840, 256, -24},
    { 848, 256, -32},
    { 880, 224, -16},
    { 952, 264, -48},
    { 1104, 344, -32},
    { 1040, 368, 16},
    { 1256, 392, 16},
    { 1112, 400, 24},
    { 960, 320, 64},
    { 944, 280, 64},
    { 968, 304, 64},
    { 968, 264, 112},
    { 920, 200, 144},
    { 856, 160, 144},
    { 920, 160, 120},
    { 888, 96, 192},
    { 976, 96, 176},
    { 1016, 88, 200},
    { 992, 104, 184},
    { 1192, 72, 256},
    { 960, 120, 120},
    { 784, 224, -80},
    { 760, 256, -152},
    { 824, 184, -56},
    { 872, 104, 16},
    { 856, 128, 16},
    { 864, 200, 8},
    { 856, 256, -24},
    { 880, 256, -24},
    { 904, 240, -16},
    { 1000, 280, -48},
    { 1112, 344, -56},
    { 1056, 336, 24},
    { 1232, 392, -48},
    { 1032, 352, 24},
    { 976, 312, 32},
    { 984, 280, 48},
    { 984, 296, 64},
    { 936, 240, 120},
    { 888, 216, 120},
    { 848, 168, 136},
    { 864, 160, 120},
    { 888, 112, 168},
    { 912, 96, 184},
    { 968, 96, 184},
    { 992, 120, 168},
    { 1232, 96, 216},
    { 968, 88, 168},
    { 864, 208, -32},
    { 808, 240, -136},
    { 872, 224, -88},
    { 840, 128, 0},
    { 840, 112, -24},
    { 808, 184, -48},
    { 808, 224, -32},
    { 840, 232, -32},
    { 904, 248, -24},
    { 1000, 288, -48},
    { 1136, 360, -48},
    { 1072, 400, 32},
    { 1288, 480, -8},
    { 1112, 384, 56},
    { 936, 320, 32},
    { 936, 320, 16},
    { 1000, 336, 40},
    { 936, 224, 144},
    { 880, 200, 120},
    { 888, 160, 144},
    { 904, 144, 168},
    { 912, 128, 184},
    { 960, 96, 200},
    { 1032, 88, 216},
    { 968, 104, 184},
    { 1176, 64, 232},
    { 936, 80, 160},
    { 760, 224, -80},
    { 736, 256, -144},
    { 888, 200, -32},
    { 960, 136, 24},
    { 928, 144, 24},
    { 864, 224, -16},
    { 840, 280, -40},
    { 864, 248, -16},
    { 888, 224, -8},
    { 976, 264, 0},
    { 1136, 352, 16},
    { 1208, 392, 80},
    { 1216, 464, 0},
    { 1000, 344, 40},
    { 888, 320, -8},
    { 896, 288, 16},
    { 984, 280, 40},
    { 976, 224, 120},
    { 936, 192, 152},
    { 880, 160, 168},
    { 856, 168, 160},
    { 880, 152, 168},
    { 920, 96, 208},
    { 984, 96, 200},
    { 1008, 96, 208},
    { 1200, 80, 240},
    { 984, 80, 208},
    { 848, 192, -8},
    { 712, 264, -160},
    { 848, 256, -96},
    { 896, 152, 0},
    { 944, 120, 8},
    { 872, 192, -24},
    { 848, 256, -24},
    { 840, 288, -56},
    { 832, 256, -32},
    { 880, 256, -16},
    { 1088, 312, -16},
    { 1104, 368, 8},
    { 1288, 384, 48},
    { 1104, 416, 8},
    { 1024, 336, 48},
    { 912, 288, 24},
    { 952, 272, 48},
    { 968, 248, 104},
    { 920, 208, 168},
    { 872, 192, 152},
    { 896, 168, 168},
    { 848, 128, 200},
    { 848, 120, 184},
    { 920, 112, 200},
    { 944, 88, 224},
    { 888, 96, 192},
    { 1232, 112, 216},
    { 1048, 112, 168},
    { 904, 272, -88},
    { 800, 312, -176},
    { 896, 240, -48},
    { 944, 136, 64},
    { 960, 136, 48},
    { 888, 232, 8},
    { 840, 272, 8},
    { 808, 288, -24},
    { 800, 240, -16},
    { 816, 224, -16},
    { 968, 280, -24},
    { 1024, 320, -16},
    { 936, 280, 16},
    { 1192, 288, 40},
    { 1056, 288, 64},
    { 1048, 320, 120},
    { 1008, 336, 120},
    { 920, 312, 144},
    { 952, 360, 192},
    { 984, 432, 240},
    { 1016, 512, 264},
    { 1008, 624, 264},
    { 952, 656, 248},
    { 904, 752, 128},
    { 832, 824, 16},
    { 776, 768, -96},
    { 688, 720, -264},
    { 584, 464, -352},
    { 432, 160, -488},
    { 368, 56, -640},
    { 248, -80, -664},
    { 232, -192, -808},
    { 208, -272, -840},
    { 192, -288, -864},
    { 160, -288, -880},
    { 136, -272, -920},
    { 168, -336, -888},
    { 192, -336, -872},
    { 192, -384, -808},
    { 240, -288, -888},
    { 192, -344, -904},
    { 176, -352, -896},
    { 176, -400, -888},
    { 192, -368, -904},
    { 176, -400, -928},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}




// ----------------------------------------------------------------
// Sample captured: 2015-09-24 06:50:23 local
AccelRawData *activity_sample_50_steps_barefoot_2(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME walk_50_barefoot_2
  //> TEST_EXPECTED 50
  //> TEST_EXPECTED_MIN 45
  //> TEST_EXPECTED_MAX 60
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { 96, 608, -584},
    { 40, 696, -632},
    { 8, 688, -688},
    { -40, 552, -712},
    { -96, 688, -704},
    { -104, 712, -712},
    { -32, 720, -728},
    { -16, 744, -784},
    { 64, 664, -840},
    { 64, 576, -848},
    { 72, 456, -848},
    { 56, 424, -864},
    { 56, 280, -976},
    { 120, 200, -968},
    { 136, 208, -1000},
    { 184, 168, -1032},
    { 96, 96, -888},
    { 144, 24, -896},
    { 248, 112, -952},
    { 216, -32, -920},
    { 288, -112, -936},
    { 928, -96, -832},
    { 208, -120, -952},
    { 144, -120, -944},
    { 368, -168, -968},
    { 248, -120, -984},
    { 296, -120, -992},
    { 200, -96, -984},
    { 296, -128, -992},
    { 248, -216, -984},
    { 304, -208, -992},
    { 232, -200, -968},
    { 208, -208, -944},
    { 264, -192, -928},
    { 224, -256, -992},
    { 80, -272, -960},
    { 144, -216, -968},
    { 152, -184, -992},
    { -8, -192, -920},
    { 696, 8, -1032},
    { 416, -104, -976},
    { 200, 8, -1008},
    { 144, -24, -976},
    { 152, -24, -960},
    { 224, 64, -968},
    { 232, -48, -968},
    { 216, 8, -984},
    { 232, 96, -1016},
    { 200, 80, -1016},
    { 184, 64, -1000},
    { 200, 96, -960},
    { 192, 88, -976},
    { 160, 104, -960},
    { 160, 160, -968},
    { 176, 192, -920},
    { 160, 184, -800},
    { 128, 200, -624},
    { 152, 296, -592},
    { 280, 392, -568},
    { 352, 528, -576},
    { 456, 728, -584},
    { 448, 888, -472},
    { 448, 952, -432},
    { 464, 888, -352},
    { 480, 752, -256},
    { 520, 648, -184},
    { 608, 632, -152},
    { 768, 584, -104},
    { 848, 464, -56},
    { 1016, 368, 48},
    { 1120, 352, 192},
    { 1056, 360, 184},
    { 1032, 376, 72},
    { 1008, 400, 104},
    { 1064, 432, 136},
    { 992, 328, 72},
    { 872, 144, 24},
    { 816, 32, 16},
    { 840, 80, 0},
    { 864, 128, -16},
    { 888, 160, 24},
    { 832, 176, 40},
    { 944, 168, 72},
    { 1024, 200, 88},
    { 1168, 264, 144},
    { 1176, 320, 168},
    { 1040, 328, 168},
    { 736, 304, 40},
    { 752, 320, 32},
    { 904, 328, 88},
    { 944, 296, 136},
    { 872, 248, 80},
    { 888, 200, 88},
    { 864, 112, 120},
    { 936, 96, 136},
    { 984, -40, 224},
    { 1024, -56, 208},
    { 1600, -24, 344},
    { 1136, 88, 136},
    { 976, 240, -224},
    { 816, 144, -184},
    { 712, -48, -8},
    { 808, -128, 64},
    { 840, -32, 48},
    { 864, 192, 32},
    { 856, 320, -48},
    { 840, 368, -88},
    { 872, 328, -96},
    { 1080, 288, -48},
    { 1056, 288, -80},
    { 1072, 288, -40},
    { 1208, 400, -112},
    { 1144, 392, -16},
    { 936, 296, -8},
    { 952, 272, -16},
    { 1040, 280, 32},
    { 936, 248, 96},
    { 848, 192, 80},
    { 824, 128, 112},
    { 888, 128, 112},
    { 968, 112, 176},
    { 1048, 72, 184},
    { 1048, -48, 160},
    { 1144, 24, 176},
    { 1072, 24, 248},
    { 952, 208, 8},
    { 824, 320, -176},
    { 848, 264, -104},
    { 832, 152, 40},
    { 832, 56, 56},
    { 784, 96, 16},
    { 808, 200, 16},
    { 864, 280, 0},
    { 912, 344, -24},
    { 1024, 368, -40},
    { 1112, 400, -104},
    { 1176, 344, 0},
    { 1224, 360, -32},
    { 1160, 344, 8},
    { 928, 312, 8},
    { 936, 312, 0},
    { 968, 280, 80},
    { 880, 224, 128},
    { 864, 192, 128},
    { 920, 160, 176},
    { 912, 144, 200},
    { 944, 128, 208},
    { 976, 112, 224},
    { 1016, 112, 200},
    { 1000, 88, 144},
    { 1168, 48, 200},
    { 944, 112, 56},
    { 816, 280, -192},
    { 808, 224, -160},
    { 832, 120, 0},
    { 896, 88, 64},
    { 856, 120, 48},
    { 848, 224, 32},
    { 864, 336, -16},
    { 856, 416, 8},
    { 984, 416, 16},
    { 1112, 400, 8},
    { 984, 376, 24},
    { 1232, 408, 8},
    { 1160, 424, 8},
    { 960, 368, 16},
    { 936, 328, 8},
    { 984, 336, 32},
    { 968, 288, 120},
    { 872, 232, 96},
    { 920, 192, 128},
    { 936, 152, 184},
    { 968, 128, 184},
    { 1024, 80, 240},
    { 1008, 96, 232},
    { 920, 136, 120},
    { 1168, 96, 192},
    { 920, 48, 136},
    { 792, 168, -48},
    { 840, 208, -136},
    { 896, 224, -120},
    { 896, 168, -8},
    { 840, 136, -16},
    { 800, 176, -80},
    { 824, 232, -56},
    { 864, 264, -64},
    { 936, 304, -40},
    { 1096, 376, -64},
    { 1112, 424, -40},
    { 1352, 464, -24},
    { 1128, 416, 8},
    { 1032, 312, 16},
    { 848, 288, 0},
    { 920, 304, 16},
    { 984, 288, 64},
    { 928, 208, 120},
    { 864, 176, 128},
    { 928, 184, 104},
    { 920, 120, 192},
    { 904, 112, 184},
    { 1016, 96, 208},
    { 984, 88, 208},
    { 864, 128, 72},
    { 1096, 96, 136},
    { 960, 72, 136},
    { 816, 216, -96},
    { 856, 264, -152},
    { 880, 232, -56},
    { 944, 192, 48},
    { 888, 168, 24},
    { 840, 224, -8},
    { 848, 256, -16},
    { 880, 280, -40},
    { 912, 304, -48},
    { 1008, 336, -56},
    { 1096, 376, -40},
    { 952, 344, -8},
    { 1168, 368, -32},
    { 1216, 376, 32},
    { 976, 304, 64},
    { 920, 296, 32},
    { 1016, 312, 48},
    { 992, 288, 112},
    { 888, 240, 104},
    { 848, 184, 136},
    { 888, 144, 160},
    { 904, 112, 184},
    { 1032, 88, 208},
    { 1072, 104, 216},
    { 968, 120, 152},
    { 1200, 112, 128},
    { 1000, 48, 152},
    { 824, 176, -72},
    { 704, 240, -216},
    { 792, 176, -120},
    { 848, 120, -8},
    { 872, 104, 16},
    { 824, 168, 8},
    { 856, 256, -32},
    { 872, 288, 0},
    { 912, 344, -24},
    { 1040, 360, -16},
    { 1128, 392, -40},
    { 1216, 432, 8},
    { 1208, 488, -40},
    { 1096, 400, 0},
    { 872, 336, -40},
    { 944, 312, 8},
    { 976, 272, 72},
    { 936, 216, 104},
    { 888, 176, 136},
    { 888, 208, 104},
    { 904, 160, 160},
    { 904, 104, 184},
    { 968, 104, 208},
    { 1032, 96, 224},
    { 952, 112, 152},
    { 1168, 88, 184},
    { 1024, 64, 160},
    { 832, 208, -80},
    { 752, 256, -200},
    { 856, 208, -112},
    { 920, 120, 16},
    { 928, 104, 24},
    { 856, 184, -16},
    { 824, 264, -56},
    { 816, 272, -56},
    { 856, 272, -40},
    { 984, 264, -16},
    { 1112, 320, -8},
    { 1104, 368, 32},
    { 1216, 432, -16},
    { 1112, 384, 40},
    { 920, 312, 32},
    { 952, 280, 48},
    { 992, 280, 88},
    { 896, 232, 136},
    { 880, 232, 96},
    { 896, 168, 168},
    { 896, 160, 160},
    { 880, 136, 168},
    { 976, 112, 200},
    { 1032, 80, 224},
    { 1008, 96, 192},
    { 1176, 96, 168},
    { 1016, 80, 152},
    { 848, 200, -72},
    { 688, 232, -160},
    { 832, 208, -88},
    { 912, 136, 32},
    { 944, 136, 24},
    { 856, 200, -16},
    { 808, 264, -40},
    { 840, 280, -24},
    { 896, 256, -16},
    { 936, 240, -8},
    { 1048, 296, -8},
    { 1072, 344, -8},
    { 1288, 360, 56},
    { 1144, 368, 32},
    { 1088, 336, 56},
    { 864, 304, 0},
    { 880, 296, 16},
    { 944, 256, 72},
    { 936, 224, 104},
    { 944, 176, 160},
    { 880, 136, 192},
    { 872, 160, 160},
    { 864, 136, 216},
    { 944, 128, 232},
    { 1032, 104, 272},
    { 968, 88, 232},
    { 1160, 64, 224},
    { 992, 80, 128},
    { 832, 184, -80},
    { 728, 224, -168},
    { 896, 184, -64},
    { 992, 144, -8},
    { 936, 160, -56},
    { 856, 200, -80},
    { 848, 248, -72},
    { 880, 280, -96},
    { 912, 288, -120},
    { 944, 296, -128},
    { 1064, 320, -112},
    { 1096, 320, -64},
    { 944, 280, -16},
    { 1168, 296, 0},
    { 1176, 344, 32},
    { 984, 288, 80},
    { 840, 264, 40},
    { 952, 264, 56},
    { 1064, 256, 128},
    { 936, 184, 168},
    { 832, 144, 144},
    { 848, 144, 168},
    { 864, 136, 192},
    { 880, 128, 208},
    { 936, 112, 208},
    { 984, 112, 184},
    { 1016, 112, 128},
    { 1104, 80, 136},
    { 944, 128, -40},
    { 888, 216, -176},
    { 768, 184, -176},
    { 864, 152, -72},
    { 952, 120, -48},
    { 968, 176, -56},
    { 872, 200, -48},
    { 816, 232, -80},
    { 824, 248, -96},
    { 840, 232, -48},
    { 928, 216, -32},
    { 1064, 264, -24},
    { 1056, 288, -24},
    { 1288, 320, -8},
    { 1128, 328, -56},
    { 1000, 296, -32},
    { 856, 272, -64},
    { 960, 248, -8},
    { 1056, 224, 40},
    { 1000, 168, 112},
    { 928, 160, 112},
    { 888, 152, 136},
    { 856, 144, 136},
    { 864, 136, 136},
    { 888, 96, 168},
    { 912, 80, 144},
    { 888, 80, 88},
    { 1000, 96, 64},
    { 1088, 88, 136},
    { 1040, 168, 40},
    { 904, 264, -72},
    { 880, 288, -104},
    { 976, 256, 0},
    { 1032, 200, 40},
    { 920, 184, 64},
    { 832, 224, 40},
    { 808, 224, 32},
    { 800, 208, 24},
    { 824, 200, 16},
    { 896, 216, -8},
    { 1000, 248, -40},
    { 1008, 248, 0},
    { 1176, 264, -8},
    { 1104, 304, -64},
    { 968, 304, -40},
    { 896, 296, -88},
    { 896, 256, -48},
    { 1032, 224, -24},
    { 1032, 168, 48},
    { 920, 176, 56},
    { 904, 152, 88},
    { 864, 144, 104},
    { 872, 136, 96},
    { 864, 112, 112},
    { 904, 104, 120},
    { 896, 96, 88},
    { 1184, 96, 136},
    { 1040, 96, 168},
    { 992, 208, 72},
    { 888, 248, 0},
    { 904, 272, -16},
    { 976, 216, 56},
    { 952, 176, 80},
    { 864, 208, 104},
    { 824, 216, 72},
    { 824, 232, 56},
    { 800, 224, 48},
    { 816, 240, -16},
    { 904, 280, -80},
    { 944, 256, -56},
    { 1080, 224, -8},
    { 1240, 264, 0},
    { 976, 304, 8},
    { 904, 304, -80},
    { 992, 256, -32},
    { 1120, 216, 16},
    { 1040, 144, 104},
    { 920, 160, 80},
    { 848, 168, 80},
    { 848, 176, 88},
    { 872, 160, 80},
    { 832, 104, 72},
    { 872, 88, 80},
    { 944, 80, 80},
    { 992, 120, 56},
    { 1184, 136, 104},
    { 1176, 152, 176},
    { 1200, 272, 112},
    { 896, 328, 8},
    { 696, 312, -16},
    { 872, 192, 128},
    { 896, 144, 128},
    { 808, 208, 120},
    { 712, 224, 64},
    { 688, 224, 40},
    { 768, 208, 8},
    { 784, 160, 8},
    { 864, 192, -64},
    { 1032, 232, -80},
    { 1312, 248, -8},
    { 1256, 304, -56},
    { 1056, 328, -112},
    { 904, 312, -144},
    { 992, 304, -72},
    { 1088, 216, 16},
    { 968, 168, 96},
    { 848, 192, 88},
    { 840, 216, 64},
    { 848, 200, 112},
    { 848, 152, 128},
    { 848, 120, 128},
    { 880, 104, 120},
    { 984, 104, 136},
    { 1040, 104, 120},
    { 1128, 104, 144},
    { 1160, 120, 176},
    { 1008, 224, 16},
    { 824, 304, -128},
    { 824, 272, -96},
    { 848, 168, 24},
    { 896, 136, 64},
    { 840, 200, 56},
    { 784, 248, 40},
    { 760, 256, 8},
    { 760, 224, 0},
    { 784, 208, -8},
    { 912, 224, 8},
    { 1104, 288, 8},
    { 1080, 336, 32},
    { 1272, 400, -56},
    { 1168, 360, -8},
    { 984, 296, 0},
    { 888, 264, -16},
    { 960, 256, 32},
    { 936, 216, 112},
    { 896, 216, 112},
    { 904, 192, 152},
    { 896, 168, 184},
    { 880, 152, 192},
    { 888, 112, 200},
    { 928, 112, 208},
    { 976, 112, 200},
    { 888, 88, 112},
    { 1152, 72, 144},
    { 1080, 80, 176},
    { 848, 240, -96},
    { 824, 288, -192},
    { 896, 216, -72},
    { 928, 144, 48},
    { 896, 112, 8},
    { 832, 184, -8},
    { 808, 248, -24},
    { 824, 288, -40},
    { 864, 248, -16},
    { 960, 248, -8},
    { 1120, 304, -8},
    { 1064, 344, 16},
    { 1264, 368, 32},
    { 1176, 368, 24},
    { 952, 336, 8},
    { 864, 296, 16},
    { 952, 288, 32},
    { 976, 240, 96},
    { 912, 176, 152},
    { 936, 192, 104},
    { 944, 136, 208},
    { 928, 128, 200},
    { 952, 136, 176},
    { 944, 96, 208},
    { 952, 64, 168},
    { 1128, 32, 168},
    { 1024, -16, 200},
    { 944, 120, -24},
    { 800, 240, -208},
    { 888, 184, -112},
    { 904, 96, 32},
    { 888, 72, 16},
    { 864, 160, -8},
    { 848, 232, -16},
    { 840, 280, -48},
    { 856, 288, -64},
    { 968, 312, -48},
    { 1136, 360, -56},
    { 1112, 408, -8},
    { 1344, 480, -72},
    { 1144, 376, 0},
    { 936, 296, -8},
    { 920, 264, 16},
    { 976, 296, 24},
    { 968, 232, 136},
    { 928, 208, 152},
    { 944, 168, 176},
    { 928, 144, 200},
    { 896, 128, 192},
    { 928, 104, 232},
    { 952, 96, 200},
    { 928, 88, 160},
    { 1088, 80, 160},
    { 1056, 40, 208},
    { 880, 152, 0},
    { 808, 256, -168},
    { 904, 240, -128},
    { 912, 168, -16},
    { 952, 120, 24},
    { 888, 160, 0},
    { 864, 248, -24},
    { 872, 296, -40},
    { 904, 312, -24},
    { 944, 304, -32},
    { 1048, 344, -32},
    { 1072, 376, -16},
    { 1304, 392, 40},
    { 1152, 368, 24},
    { 1016, 328, 40},
    { 936, 288, 40},
    { 1024, 272, 80},
    { 992, 248, 128},
    { 928, 224, 128},
    { 920, 168, 176},
    { 888, 152, 176},
    { 936, 136, 184},
    { 880, 88, 208},
    { 936, 80, 200},
    { 928, 88, 200},
    { 896, 88, 152},
    { 1104, 80, 168},
    { 968, 80, 152},
    { 920, 208, -32},
    { 896, 256, -112},
    { 960, 264, -72},
    { 976, 200, 16},
    { 952, 176, 32},
    { 856, 232, -8},
    { 832, 280, -8},
    { 824, 304, -40},
    { 848, 296, -32},
    { 944, 280, -24},
    { 1120, 328, 0},
    { 1104, 352, 32},
    { 1304, 424, -16},
    { 1112, 352, 32},
    { 976, 296, 16},
    { 944, 264, 32},
    { 976, 272, 64},
    { 968, 224, 144},
    { 864, 200, 144},
    { 896, 176, 160},
    { 872, 136, 184},
    { 864, 136, 168},
    { 880, 112, 208},
    { 920, 88, 232},
    { 952, 96, 192},
    { 1016, 104, 208},
    { 1080, 88, 240},
    { 960, 168, 56},
    { 816, 264, -120},
    { 848, 256, -152},
    { 872, 192, -72},
    { 936, 128, -24},
    { 904, 168, -40},
    { 840, 224, -64},
    { 832, 248, -64},
    { 856, 248, -72},
    { 904, 232, -40},
    { 992, 264, -48},
    { 1088, 312, -48},
    { 1248, 320, 24},
    { 1208, 400, -24},
    { 1104, 344, 64},
    { 888, 288, 40},
    { 968, 264, 72},
    { 984, 280, 104},
    { 880, 232, 136},
    { 880, 216, 104},
    { 896, 160, 192},
    { 888, 136, 168},
    { 864, 112, 160},
    { 904, 96, 192},
    { 952, 96, 176},
    { 960, 112, 152},
    { 1104, 80, 184},
    { 1048, 88, 216},
    { 936, 192, 48},
    { 816, 280, -128},
    { 856, 256, -112},
    { 904, 160, 8},
    { 952, 96, 0},
    { 880, 136, -24},
    { 840, 256, -24},
    { 832, 272, -40},
    { 848, 312, -48},
    { 872, 264, -40},
    { 992, 280, -40},
    { 1120, 328, -16},
    { 1008, 312, 40},
    { 1224, 360, 24},
    { 1128, 352, 48},
    { 944, 320, 64},
    { 992, 288, 56},
    { 1048, 280, 112},
    { 984, 248, 120},
    { 872, 184, 160},
    { 864, 184, 96},
    { 936, 128, 176},
    { 896, 80, 200},
    { 976, 88, 184},
    { 1008, 80, 192},
    { 968, 104, 144},
    { 1120, 80, 200},
    { 920, 88, 80},
    { 808, 208, -112},
    { 808, 224, -144},
    { 928, 160, -32},
    { 992, 96, 64},
    { 928, 160, 48},
    { 872, 248, 0},
    { 848, 320, -32},
    { 872, 304, -16},
    { 896, 256, -8},
    { 968, 264, -24},
    { 1104, 368, -56},
    { 1064, 400, 24},
    { 1248, 464, -40},
    { 1112, 384, -8},
    { 944, 304, 0},
    { 960, 272, 40},
    { 1008, 288, 56},
    { 952, 240, 128},
    { 904, 216, 120},
    { 928, 160, 184},
    { 920, 144, 200},
    { 920, 120, 200},
    { 920, 96, 232},
    { 936, 88, 224},
    { 944, 112, 184},
    { 1152, 88, 208},
    { 984, 64, 208},
    { 904, 176, -16},
    { 760, 240, -168},
    { 840, 216, -112},
    { 912, 136, 8},
    { 976, 120, 16},
    { 912, 208, -16},
    { 856, 272, -32},
    { 840, 288, -56},
    { 848, 272, -56},
    { 928, 240, -32},
    { 1024, 288, -40},
    { 1112, 384, -32},
    { 1216, 384, 24},
    { 1192, 408, -8},
    { 1072, 336, 40},
    { 904, 280, -8},
    { 928, 264, 24},
    { 1008, 272, 56},
    { 968, 208, 144},
    { 928, 192, 152},
    { 872, 160, 168},
    { 880, 168, 160},
    { 864, 128, 208},
    { 896, 104, 208},
    { 944, 96, 208},
    { 984, 104, 192},
    { 912, 96, 136},
    { 1112, 88, 176},
    { 928, 112, 80},
    { 760, 256, -112},
    { 848, 264, -120},
    { 968, 240, -32},
    { 1024, 216, 24},
    { 936, 200, 8},
    { 864, 264, -16},
    { 848, 304, -16},
    { 896, 328, -24},
    { 912, 288, -24},
    { 952, 304, -32},
    { 1080, 352, -24},
    { 1176, 328, 40},
    { 1192, 352, 8},
    { 1104, 320, 48},
    { 952, 272, 48},
    { 912, 248, 64},
    { 960, 232, 112},
    { 984, 224, 152},
    { 912, 184, 200},
    { 888, 168, 176},
    { 864, 152, 208},
    { 856, 144, 192},
    { 880, 104, 248},
    { 952, 96, 248},
    { 968, 104, 224},
    { 1160, 104, 232},
    { 968, 88, 200},
    { 920, 208, -48},
    { 824, 256, -168},
    { 856, 264, -152},
    { 904, 176, -72},
    { 992, 128, -40},
    { 920, 200, -56},
    { 848, 264, -32},
    { 856, 288, -48},
    { 872, 288, -32},
    { 864, 248, -24},
    { 872, 248, -40},
    { 912, 280, -48},
    { 928, 272, -16},
    { 880, 232, 16},
    { 1224, 264, 72},
    { 1216, 312, 40},
    { 1184, 272, 136},
    { 1128, 224, 128},
    { 1120, 200, 128},
    { 1072, 224, 152},
    { 976, 168, 176},
    { 984, 120, 176},
    { 968, 72, 208},
    { 960, 88, 208},
    { 944, 184, 216},
    { 904, 320, 184},
    { 880, 456, 152},
    { 808, 536, 88},
    { 720, 608, 0},
    { 624, 656, -80},
    { 576, 632, -120},
    { 560, 680, -176},
    { 528, 696, -248},
    { 528, 752, -272},
    { 512, 768, -312},
    { 480, 808, -344},
    { 448, 776, -352},
    { 416, 808, -416},
    { 360, 800, -496},
    { 360, 712, -536},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}



// ----------------------------------------------------------------
// Sample captured: 2015-09-22 11:54:51 local
AccelRawData *activity_sample_100_steps_heather_1(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME walk_100_heather_1
  //> TEST_EXPECTED 100
  //> TEST_EXPECTED_MIN 85
  //> TEST_EXPECTED_MAX 105
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { 128, -272, -920},
    { 80, -344, -1024},
    { 64, -384, -944},
    { 72, -392, -848},
    { 112, -344, -736},
    { 112, -336, -984},
    { 160, -368, -1056},
    { 136, -304, -1096},
    { 88, -232, -1136},
    { -24, -288, -968},
    { -80, -208, -992},
    { -48, -216, -944},
    { -112, -176, -944},
    { -136, -336, -1024},
    { -376, -272, -960},
    { 200, -256, -928},
    { 112, -320, -952},
    { -24, -280, -968},
    { 8, -304, -952},
    { 0, -336, -936},
    { 8, -352, -944},
    { -16, -312, -928},
    { 0, -352, -968},
    { -8, -328, -944},
    { -8, -328, -944},
    { -64, -368, -936},
    { -48, -352, -944},
    { -32, -376, -936},
    { -16, -368, -936},
    { 0, -344, -960},
    { -8, -360, -960},
    { -24, -360, -936},
    { -8, -384, -952},
    { -8, -368, -952},
    { 24, -376, -936},
    { 0, -400, -920},
    { 24, -400, -912},
    { 16, -400, -928},
    { 0, -424, -944},
    { 8, -440, -928},
    { -8, -376, -912},
    { -40, -376, -912},
    { -72, -352, -920},
    { -112, -424, -920},
    { -168, -344, -896},
    { -192, -352, -896},
    { -216, -352, -872},
    { -176, -360, -872},
    { -192, -384, -864},
    { -184, -376, -840},
    { -136, -424, -848},
    { -88, -536, -936},
    { -208, -472, -1040},
    { -456, -328, -1152},
    { -480, -264, -880},
    { -440, -64, -584},
    { -320, 56, -480},
    { -24, 104, -360},
    { 520, 224, -128},
    { 1080, 312, 8},
    { -1936, 600, -208},
    { -1984, 688, -312},
    { 1832, 688, -144},
    { 2008, 672, -160},
    { 1920, 624, -136},
    { 1984, 280, -120},
    { 1816, 512, -232},
    { 1680, 496, -56},
    { 1584, 680, 8},
    { 1304, 760, 32},
    { 1312, 848, 160},
    { 1328, 1184, 280},
    { 872, 1432, -16},
    { 832, 1088, 144},
    { 856, 928, 0},
    { 1112, 928, 64},
    { 1648, 784, 24},
    { -1880, 656, 0},
    { -1776, 544, -32},
    { -1848, 512, -8},
    { -1952, 480, 0},
    { 1952, 560, -8},
    { 1664, 488, -160},
    { 1328, 320, -352},
    { 1024, -160, -72},
    { 472, -592, -120},
    { 728, -344, -392},
    { 976, -232, -104},
    { 1200, 184, -136},
    { 1496, 272, -168},
    { 1880, 360, -136},
    { -1976, 544, -200},
    { 1944, 616, -136},
    { 1744, 744, -168},
    { 1432, 856, -288},
    { 1664, 424, -96},
    { 1824, 912, 24},
    { 1664, 1552, 128},
    { 960, 1296, 112},
    { 1072, 1208, 32},
    { 832, 1032, 16},
    { 1016, 808, 0},
    { 1496, 856, 80},
    { 1960, 712, 40},
    { 1872, 552, -8},
    { 1832, 496, -8},
    { 1888, 400, 24},
    { 1872, 488, -64},
    { 1656, 448, -136},
    { 1544, 320, -232},
    { 1248, -8, -304},
    { 656, -536, -168},
    { 824, -408, -280},
    { 1000, -240, -240},
    { 1320, 160, -264},
    { 1496, 256, -264},
    { 1696, 328, -328},
    { 1720, 320, -224},
    { 1760, 496, -72},
    { 1784, 688, -64},
    { 1616, 848, 0},
    { 1544, 960, -288},
    { 1712, 1568, -88},
    { 1112, 1672, -256},
    { 808, 1304, -256},
    { 1256, 1224, -32},
    { 1120, 1000, -104},
    { 1520, 824, 0},
    { -1912, 752, 80},
    { -2008, 648, -24},
    { 1872, 600, -88},
    { 1800, 504, 24},
    { 1808, 512, -200},
    { 1624, 408, -320},
    { 1296, -16, -264},
    { 944, -392, -336},
    { 552, -520, -648},
    { 728, -464, -472},
    { 1176, -296, -160},
    { 1440, 192, -256},
    { 1872, 288, -248},
    { 1992, 400, -352},
    { 1992, 464, -192},
    { -2008, 560, -104},
    { -1968, 904, -112},
    { 1736, 1376, -528},
    { 1704, 1040, -488},
    { 1592, 1448, -440},
    { 976, 1248, -416},
    { 1248, 1240, -360},
    { 944, 896, -304},
    { 1440, 600, -128},
    { 1768, 552, 8},
    { 1736, 592, -120},
    { 1688, 624, -216},
    { 1712, 544, -80},
    { 1752, 464, -40},
    { 1688, 504, -112},
    { 1600, 352, -168},
    { 1496, -72, -160},
    { 992, -536, -80},
    { 824, -416, -256},
    { 1088, -248, -192},
    { 1256, 168, -192},
    { 1512, 232, -200},
    { 1872, 320, -264},
    { 1816, 368, -248},
    { 1712, 488, -144},
    { 1616, 720, -208},
    { 1448, 872, -128},
    { 1400, 1016, -624},
    { 1632, 1120, -392},
    { 1360, 1192, -320},
    { 944, 1096, -344},
    { 1120, 1064, -280},
    { 1040, 784, -264},
    { 1544, 632, -104},
    { -2032, 648, 48},
    { 1968, 584, -72},
    { 1792, 512, -160},
    { 1688, 456, -56},
    { 1672, 464, -72},
    { 1520, 416, -224},
    { 1376, 200, -208},
    { 1160, -304, -96},
    { 656, -544, -344},
    { 1048, -368, -224},
    { 1200, -40, -264},
    { 1536, 280, -264},
    { 1768, 304, -256},
    { 1992, 376, -296},
    { 1720, 400, -112},
    { 1528, 512, -104},
    { 1392, 672, -120},
    { 1648, 576, -200},
    { 1712, 632, 128},
    { 1664, 1104, 112},
    { 1112, 1848, 320},
    { 760, 968, 96},
    { 1112, 984, 136},
    { 864, 944, -24},
    { 1240, 848, 80},
    { 1744, 816, 136},
    { 1920, 688, 112},
    { 1824, 560, -16},
    { 1824, 384, -8},
    { 1792, 368, -80},
    { 1672, 440, -112},
    { 1504, 344, -216},
    { 1336, 112, -296},
    { 928, -488, -104},
    { 608, -576, -312},
    { 1240, -176, -120},
    { 1544, 432, -200},
    { 1664, 432, -184},
    { -2040, 416, -328},
    { -2024, 448, -232},
    { -1856, 472, 96},
    { 1888, 1008, -328},
    { 1216, 1016, -344},
    { 1560, 456, -328},
    { 1384, 1032, -64},
    { 1328, 1248, 128},
    { 744, 1040, 168},
    { 1184, 1304, 176},
    { 1080, 960, 32},
    { 1464, 784, -8},
    { -1872, 800, 80},
    { -1840, 816, 120},
    { -1936, 664, 56},
    { -1880, 256, 112},
    { 1936, 296, -16},
    { 1776, 488, -192},
    { 1648, 336, -192},
    { 1408, -392, 112},
    { 728, -664, 32},
    { 1000, -368, -112},
    { 1088, -160, -192},
    { 1464, 248, -224},
    { 1728, 200, -144},
    { -1912, 264, -304},
    { -2040, 408, -200},
    { 1928, 648, -112},
    { 1576, 936, -88},
    { 1480, 704, -352},
    { 1736, 968, -520},
    { 1616, 1896, -752},
    { 1088, 1208, -520},
    { 1096, 1000, -480},
    { 1048, 856, -408},
    { 1168, 616, -288},
    { 1816, 504, -48},
    { 2040, 608, 8},
    { 1920, 560, -80},
    { 1848, 504, -104},
    { 1696, 448, -40},
    { 1632, 600, -232},
    { 1504, 408, -296},
    { 1352, 168, -336},
    { 1168, -512, -360},
    { 584, -776, -456},
    { 936, -456, -328},
    { 1272, 16, -392},
    { 1536, 216, -240},
    { 1960, 328, -184},
    { -1880, 440, -232},
    { -2016, 560, -160},
    { 1792, 744, -64},
    { 1352, 880, -224},
    { 1504, 432, -184},
    { 1648, 664, 0},
    { 1680, 1656, 112},
    { 984, 1448, 104},
    { 856, 1304, 88},
    { 1056, 1104, 88},
    { 1016, 888, -80},
    { 1416, 856, -16},
    { -1976, 768, 40},
    { -1936, 480, 80},
    { 1920, 624, -72},
    { 1920, 448, 16},
    { 1992, 560, 16},
    { 1736, 352, -32},
    { 1608, 48, -72},
    { 1048, -568, 248},
    { 664, -448, -96},
    { 944, -392, -48},
    { 1168, -56, -208},
    { 1440, 256, -192},
    { 1632, 216, -104},
    { 1880, 344, -280},
    { 1648, 336, -168},
    { 1680, 408, 88},
    { 1760, 696, 0},
    { 1904, 712, -176},
    { 1768, 1168, -240},
    { 1600, 1976, -160},
    { 960, 1448, 8},
    { 1240, 1576, -8},
    { 1000, 1096, -184},
    { 1360, 800, -224},
    { 1832, 784, 0},
    { -2016, 768, 32},
    { 1920, 680, -24},
    { 1928, 488, 0},
    { 1896, 256, 64},
    { 1736, 384, -48},
    { 1528, 360, -248},
    { 1344, -88, -128},
    { 704, -568, -56},
    { 632, -480, -256},
    { 1168, -264, -216},
    { 1392, 136, -440},
    { 1664, 88, -336},
    { -2048, 104, -184},
    { -1976, 256, -128},
    { -2048, 672, -88},
    { 1904, 1032, -168},
    { 1392, 1200, -216},
    { 1896, 304, -72},
    { 1848, 936, 152},
    { 1160, 1752, 80},
    { 744, 1360, 176},
    { 960, 1104, 0},
    { 784, 760, -64},
    { 1352, 744, 24},
    { 2008, 904, 72},
    { -1944, 816, 16},
    { -2000, 568, -64},
    { 1920, 336, 0},
    { 1800, 408, -72},
    { 1696, 480, -120},
    { 1528, 280, -320},
    { 1424, -128, -312},
    { 840, -688, -216},
    { 896, -568, -160},
    { 1208, -208, -320},
    { 1568, 192, -280},
    { 1688, 248, -168},
    { 2000, 336, -208},
    { 2024, 424, -176},
    { 2024, 696, -128},
    { 1488, 1056, 144},
    { 1352, 728, -320},
    { 1632, 648, -104},
    { 1592, 1544, -40},
    { 976, 1328, 80},
    { 912, 1376, 120},
    { 1008, 992, -8},
    { 1080, 752, -104},
    { 1488, 752, 48},
    { 2040, 784, 128},
    { 1968, 672, 40},
    { 1856, 504, -24},
    { 1792, 336, 48},
    { 1736, 440, -112},
    { 1576, 352, -248},
    { 1360, 56, -288},
    { 984, -456, -184},
    { 592, -528, -472},
    { 984, -488, -240},
    { 1408, 8, -304},
    { 1712, 192, -256},
    { 2040, 280, -200},
    { -2000, 392, -248},
    { 1856, 520, -152},
    { 1672, 696, -64},
    { 1416, 784, 48},
    { 1680, 536, -64},
    { 1632, 864, 88},
    { 1520, 1584, 168},
    { 928, 1248, 104},
    { 1264, 1160, 120},
    { 872, 912, -120},
    { 1216, 752, -112},
    { 1736, 776, 64},
    { 2024, 656, 56},
    { 1840, 528, -56},
    { 1816, 440, -8},
    { 1800, 408, -8},
    { 1752, 432, -104},
    { 1576, 288, -184},
    { 1424, -40, -144},
    { 984, -456, -72},
    { 752, -432, -272},
    { 1096, -360, -136},
    { 1536, 184, -232},
    { 1664, 184, -112},
    { 2032, 272, -136},
    { 1928, 392, -192},
    { 1680, 568, -128},
    { 1568, 712, -104},
    { 1336, 792, -216},
    { 1632, 504, -64},
    { 1616, 952, -72},
    { 1384, 1536, -152},
    { 896, 968, -160},
    { 1104, 1168, -72},
    { 928, 968, -152},
    { 1160, 736, -112},
    { 1728, 800, 8},
    { -1952, 664, 56},
    { 2008, 552, -32},
    { 1896, 328, 8},
    { 1752, 248, 16},
    { 1648, 264, -160},
    { 1376, 120, -112},
    { 1184, -24, -168},
    { 952, -216, -312},
    { 744, -424, -320},
    { 1064, -440, -88},
    { 1536, 32, -328},
    { 1560, 96, -208},
    { 1848, 224, -248},
    { 1968, 368, -232},
    { 1824, 520, -208},
    { 1624, 784, -128},
    { 1448, 736, -104},
    { 1624, 552, -160},
    { 1648, 920, -288},
    { 1752, 1384, -552},
    { 840, 1272, -568},
    { 1312, 1264, -464},
    { 1144, 968, -488},
    { 1312, 576, -352},
    { 1920, 608, -200},
    { 2024, 608, -224},
    { -2024, 536, -320},
    { -2032, 304, -40},
    { 1944, 416, -32},
    { 1736, 288, -56},
    { 1424, -40, -72},
    { 1080, -456, 8},
    { 912, -552, 0},
    { 808, -608, -112},
    { 1096, -464, 0},
    { 1536, -16, -424},
    { 1704, -48, -168},
    { -1816, 72, -192},
    { -1792, 432, -264},
    { -1968, 728, -112},
    { 1800, 1064, 16},
    { 1560, 864, -232},
    { 1456, 808, -40},
    { 1592, 1136, 144},
    { 1240, 1112, 288},
    { 800, 1176, 184},
    { 960, 1240, 176},
    { 872, 944, -16},
    { 1144, 800, -16},
    { 1824, 904, 32},
    { -1992, 584, 72},
    { 1880, 544, -32},
    { 1992, 384, 16},
    { 1992, 264, 16},
    { 1792, 448, -112},
    { 1624, 360, -208},
    { 1368, -288, 0},
    { 704, -600, -64},
    { 1016, -352, -160},
    { 1248, -160, -168},
    { 1448, 152, -232},
    { 1648, 192, -144},
    { 1808, 312, -176},
    { 1696, 384, -160},
    { 1776, 552, -120},
    { 1608, 776, 24},
    { 1448, 920, -120},
    { 1632, 872, -336},
    { 1600, 1304, -128},
    { 992, 1216, -32},
    { 1320, 1288, 0},
    { 800, 1056, -216},
    { 1160, 752, -136},
    { 1736, 728, 32},
    { 2008, 704, 80},
    { 1880, 616, -16},
    { 1856, 392, 0},
    { 1712, 288, 48},
    { 1744, 408, -104},
    { 1552, 384, -56},
    { 1384, 32, -168},
    { 928, -448, -88},
    { 536, -504, -352},
    { 1008, -392, -160},
    { 1536, 176, -304},
    { 1544, 192, -192},
    { 1880, 248, -192},
    { 1896, 376, -216},
    { 1720, 496, -136},
    { 1632, 688, -96},
    { 1392, 800, 8},
    { 1512, 632, -288},
    { 1592, 1008, -280},
    { 1424, 1448, -176},
    { 1016, 1240, -80},
    { 1168, 1248, -192},
    { 840, 944, -224},
    { 1144, 768, -136},
    { 1728, 688, 0},
    { 2040, 664, 64},
    { 1952, 592, -48},
    { 1784, 432, -64},
    { 1728, 344, 40},
    { 1752, 496, -112},
    { 1568, 392, -208},
    { 1448, -224, -72},
    { 872, -704, -32},
    { 696, -456, -432},
    { 1024, -424, -64},
    { 1376, 152, -280},
    { 1712, 200, -256},
    { 2032, 264, -208},
    { -2040, 384, -224},
    { 1824, 520, -152},
    { 1784, 688, -88},
    { 1536, 768, -32},
    { 1592, 560, -88},
    { 1872, 984, 104},
    { 1288, 1800, 280},
    { 792, 1248, 24},
    { 1128, 1160, -48},
    { 1016, 888, -232},
    { 1456, 776, -72},
    { -2016, 824, 56},
    { -2032, 712, -32},
    { 1856, 528, -64},
    { 1864, 376, -8},
    { 1784, 320, 80},
    { 1680, 400, -40},
    { 1528, 304, -168},
    { 1216, -296, 144},
    { 688, -496, -24},
    { 936, -384, -224},
    { 1160, -216, -64},
    { 1712, 224, -240},
    { 1696, 152, -32},
    { -1976, 320, -136},
    { -2024, 512, -112},
    { 1752, 728, -144},
    { 1400, 1008, -208},
    { 1448, 576, -280},
    { 1496, 384, 16},
    { 1688, 912, -64},
    { 1352, 1496, -248},
    { 976, 1264, -176},
    { 1040, 1080, -240},
    { 1032, 760, -304},
    { 1472, 592, -136},
    { -2032, 696, -24},
    { -2016, 688, -104},
    { -2024, 520, -168},
    { 1904, 256, 72},
    { 1760, 368, -56},
    { 1656, 368, -64},
    { 1456, 120, -64},
    { 1136, -344, 24},
    { 776, -392, -136},
    { 880, -448, -88},
    { 1088, -112, -96},
    { 1624, 184, -176},
    { 1736, 176, -144},
    { -1896, 288, -256},
    { -2048, 464, -256},
    { 1768, 584, -224},
    { 1576, 760, -304},
    { 1328, 696, -288},
    { 1520, 712, -312},
    { 1624, 1224, -208},
    { 1096, 1376, -224},
    { 928, 1272, -168},
    { 1072, 1072, -240},
    { 1208, 752, -192},
    { 1744, 712, -48},
    { -1856, 696, 8},
    { 2040, 648, -72},
    { 2024, 424, 0},
    { 1856, 296, 104},
    { 1824, 408, -80},
    { 1640, 368, -120},
    { 1488, 112, -168},
    { 1064, -496, 16},
    { 512, -544, -240},
    { 952, -480, -104},
    { 1168, -72, -192},
    { 1656, 208, -160},
    { 1968, 240, -136},
    { -1832, 336, -272},
    { -1960, 440, -144},
    { 1944, 680, -120},
    { 1608, 1048, -104},
    { 1648, 752, -472},
    { 1672, 904, -40},
    { 1456, 1504, -144},
    { 928, 1160, -96},
    { 1168, 1360, -152},
    { 816, 1096, -176},
    { 1304, 768, -128},
    { 1984, 832, 32},
    { -1936, 680, 16},
    { 1976, 616, -64},
    { 1928, 448, 24},
    { 1896, 344, 96},
    { 1824, 424, -40},
    { 1608, 376, -120},
    { 1512, 48, -144},
    { 872, -688, 120},
    { 488, -352, -320},
    { 864, 16, 16},
    { 1208, 1032, -288},
    { 696, -1408, -488},
    { 32, 1744, -376},
    { -256, 1264, -720},
    { -312, 920, -800},
    { -376, 752, -576},
    { -360, 704, -576},
    { -288, 896, -400},
    { -152, 808, -296},
    { -120, 808, -56},
    { 392, 1432, -608},
    { 264, 1528, -32},
    { -224, 1952, 440},
    { -488, 968, 88},
    { -360, 688, 248},
    { -48, 880, -120},
    { 80, 368, -400},
    { 160, 448, -208},
    { -40, 704, -384},
    { -64, 608, -376},
    { -104, 1000, -560},
    { -96, 1296, -528},
    { -32, 1560, -424},
    { -144, 1536, -376},
    { 8, 1384, -136},
    { 80, 1488, -144},
    { 136, 1080, -176},
    { 176, 880, -184},
    { 120, 744, -208},
    { -24, 800, -192},
    { -176, 880, -120},
    { -304, 880, -192},
    { -352, 896, -184},
    { -496, 968, -96},
    { -656, 1008, 16},
    { -544, 1064, -80},
    { -648, 1160, -112},
    { -360, 1264, -344},
    { -344, 1048, -272},
    { -352, 888, -152},
    { -272, 872, -208},
    { -304, 712, -256},
    { -376, 520, -280},
    { -480, 584, -296},
    { -472, 568, -312},
    { -112, 592, -600},
    { -272, 728, -488},
    { -136, 808, -560},
    { -200, 784, -632},
    { 24, 1408, -704},
    { 120, 1536, -680},
    { 456, 1208, -608},
    { 672, 552, -480},
    { 544, 200, -160},
    { 504, 272, -8},
    { 536, 400, -56},
    { 664, 488, -96},
    { 824, 824, -192},
    { 1032, 992, -280},
    { 1328, 1272, -504},
    { -2024, 1160, -208},
    { -1928, 1864, -480},
    { 1648, -1696, -128},
    { 792, 2008, -200},
    { 1168, 1128, -48},
    { 1624, 736, -48},
    { 1296, 664, -216},
    { 1344, 528, -72},
    { 1440, 448, -32},
    { 1384, 400, -48},
    { 1440, 376, -56},
    { 1552, 320, -64},
    { 1520, 48, -32},
    { 824, -464, -16},
    { 1096, -104, -168},
    { 1232, 32, -72},
    { 1600, 296, -200},
    { 1840, 344, -192},
    { 1744, 400, -200},
    { 1480, 440, -232},
    { 1448, 480, -176},
    { 1400, 608, -72},
    { 1312, 608, -88},
    { 1264, 712, -88},
    { 1464, 1312, -144},
    { 1112, 1272, 16},
    { 816, 832, -56},
    { 1200, 1056, -24},
    { 1072, 832, -136},
    { 1352, 792, -40},
    { -2040, 888, 88},
    { 2000, 672, 96},
    { 1952, 552, 48},
    { 1864, 328, 80},
    { 1784, 320, 48},
    { 1624, 464, -128},
    { 1456, 304, -176},
    { 1120, -296, 8},
    { 792, -376, -192},
    { 656, -248, -456},
    { 1032, -176, -160},
    { 1392, 168, -208},
    { 1680, 248, -208},
    { 2032, 336, -264},
    { 1904, 424, -288},
    { 1632, 488, -152},
    { 1656, 624, -176},
    { 1600, 704, -168},
    { 1552, 720, -184},
    { 1472, 1208, -304},
    { 1376, 1352, -200},
    { 824, 992, -128},
    { 1216, 1152, -176},
    { 872, 912, -192},
    { 1432, 624, -168},
    { 2008, 736, -16},
    { 1984, 744, -32},
    { 1856, 576, -88},
    { 1824, 368, 24},
    { 1784, 344, 8},
    { 1664, 440, -176},
    { 1464, 248, -216},
    { 1344, -240, -72},
    { 784, -488, -168},
    { 704, -256, -328},
    { 1112, -112, -176},
    { 1472, 256, -216},
    { 1544, 272, -184},
    { 1936, 304, -232},
    { 1720, 352, -184},
    { 1488, 448, -152},
    { 1592, 592, -48},
    { 1464, 688, -40},
    { 1432, 600, -128},
    { 1576, 768, -104},
    { 1720, 1512, -232},
    { 936, 1096, -216},
    { 1208, 1016, -264},
    { 800, 824, -360},
    { 1104, 608, -224},
    { 1560, 792, -48},
    { 1824, 656, -32},
    { 1736, 552, -128},
    { 1704, 384, -88},
    { 1672, 312, 0},
    { 1656, 416, -80},
    { 1528, 408, -160},
    { 1528, 224, -168},
    { 1040, -304, 32},
    { 584, -232, -232},
    { 992, -168, -296},
    { 1144, 160, -224},
    { 1496, 280, -312},
    { 1704, 272, -296},
    { 1648, 288, -256},
    { 1240, 264, -128},
    { 1232, 360, -160},
    { 1352, 576, -120},
    { 1472, 544, -176},
    { 1344, 632, -112},
    { 1736, 960, -224},
    { 1224, 1744, -168},
    { 1160, 984, -176},
    { 1040, 1056, -216},
    { 976, 768, -256},
    { 1376, 680, -104},
    { 1712, 632, -8},
    { 1568, 560, -88},
    { 1520, 456, -160},
    { 1632, 392, -56},
    { 1656, 424, -48},
    { 1688, 408, -192},
    { 1472, 208, -216},
    { 1200, -232, -88},
    { 736, -464, -208},
    { 856, -192, -416},
    { 1304, -88, -232},
    { 1536, 208, -240},
    { 1744, 272, -192},
    { 1832, 320, -232},
    { 1568, 416, -216},
    { 1408, 472, -176},
    { 1352, 600, -16},
    { 1232, 704, -24},
    { 1296, 552, -80},
    { 1384, 960, -96},
    { 1488, 1256, -16},
    { 840, 1016, -72},
    { 1272, 976, -40},
    { 928, 920, -184},
    { 1208, 744, -136},
    { 1720, 768, -8},
    { 2024, 696, 64},
    { 1784, 536, -40},
    { 1712, 360, 0},
    { 1664, 312, 0},
    { 1616, 400, -72},
    { 1464, 336, -176},
    { 1272, 72, -96},
    { 896, -304, -88},
    { 576, -296, -328},
    { 952, -200, -200},
    { 1240, 56, -120},
    { 1608, 280, -256},
    { 1928, 296, -192},
    { 1952, 368, -216},
    { 1632, 488, -168},
    { 1520, 544, -200},
    { 1456, 664, -88},
    { 1440, 624, -152},
    { 1424, 936, -408},
    { 1648, 1224, -256},
    { 1104, 1088, -144},
    { 920, 1080, -136},
    { 984, 936, -136},
    { 1120, 760, -192},
    { 1624, 768, 0},
    { 2040, 736, 64},
    { 1848, 616, -48},
    { 1832, 448, -32},
    { 1824, 344, 48},
    { 1784, 400, -88},
    { 1592, 320, -232},
    { 1408, 32, -80},
    { 1064, -320, -80},
    { 648, -376, -264},
    { 872, -304, -208},
    { 1288, 48, -216},
    { 1576, 256, -208},
    { 1832, 280, -232},
    { 1856, 368, -296},
    { 1536, 376, -152},
    { 1488, 504, -112},
    { 1560, 528, -160},
    { 1528, 600, -80},
    { 1424, 736, -80},
    { 1784, 1536, -232},
    { 1192, 1136, -8},
    { 880, 912, -176},
    { 1168, 936, -128},
    { 888, 768, -208},
    { 1280, 776, -96},
    { 1912, 744, 0},
    { 1776, 584, -48},
    { 1704, 432, -80},
    { 1736, 352, -8},
    { 1744, 400, -88},
    { 1592, 384, -208},
    { 1456, 184, -200},
    { 1200, -256, -88},
    { 704, -408, -264},
    { 984, -232, -256},
    { 1096, -104, -128},
    { 1616, 272, -296},
    { 1712, 264, -200},
    { 1856, 296, -280},
    { 1472, 368, -248},
    { 1368, 416, -168},
    { 1480, 536, 24},
    { 1536, 648, -56},
    { 1432, 792, -128},
    { 1616, 1296, -280},
    { 1176, 1072, -136},
    { 872, 1016, -128},
    { 1056, 1072, -168},
    { 1080, 736, -232},
    { 1488, 672, -128},
    { 1888, 712, -8},
    { 1808, 664, -56},
    { 1760, 512, -48},
    { 1728, 328, 48},
    { 1680, 352, 24},
    { 1648, 424, -176},
    { 1456, 128, -176},
    { 1240, -304, -8},
    { 744, -408, -136},
    { 696, -312, -296},
    { 936, -168, -160},
    { 1440, 112, -96},
    { 1896, 280, -200},
    { -1824, 304, -216},
    { 1808, 424, -240},
    { 1488, 456, -144},
    { 1552, 576, -104},
    { 1488, 720, -16},
    { 1480, 792, -272},
    { 1368, 1136, -192},
    { 1368, 1216, -168},
    { 864, 880, -128},
    { 1288, 1048, -168},
    { 920, 976, -216},
    { 1312, 704, -136},
    { 1856, 736, 0},
    { 1928, 608, -24},
    { 1800, 520, -16},
    { 1824, 448, 40},
    { 1784, 352, 80},
    { 1656, 352, -80},
    { 1424, 280, -192},
    { 1352, 64, -176},
    { 984, -392, -16},
    { 576, -360, -240},
    { 952, -312, -248},
    { 1128, 0, -112},
    { 1720, 248, -160},
    { 2008, 304, -192},
    { -2024, 408, -240},
    { 1648, 464, -184},
    { 1392, 480, -200},
    { 1408, 608, -240},
    { 1368, 600, -144},
    { 1320, 920, -400},
    { 1512, 1176, -304},
    { 1192, 1064, -248},
    { 912, 888, -224},
    { 1112, 968, -200},
    { 1040, 808, -224},
    { 1568, 656, -112},
    { 1936, 672, 16},
    { 1800, 640, -64},
    { 1680, 504, -96},
    { 1640, 360, 24},
    { 1592, 360, 8},
    { 1544, 328, -144},
    { 1344, 88, -160},
    { 1160, -240, -64},
    { 872, -328, -176},
    { 848, -288, -272},
    { 1200, -120, -112},
    { 1632, 216, -232},
    { 1776, 232, -248},
    { 1992, 280, -256},
    { 1688, 400, -200},
    { 1528, 536, -104},
    { 1432, 576, -216},
    { 1416, 544, -168},
    { 1400, 752, -232},
    { 1344, 1016, -320},
    { 1376, 1072, -192},
    { 872, 856, -112},
    { 1320, 1048, -96},
    { 856, 872, -208},
    { 1232, 672, -144},
    { 1728, 712, 16},
    { 1800, 624, -16},
    { 1688, 528, -48},
    { 1696, 424, 8},
    { 1752, 352, 32},
    { 1720, 368, -144},
    { 1584, 256, -272},
    { 1432, -168, -112},
    { 912, -456, -80},
    { 744, -280, -352},
    { 1120, -208, -96},
    { 1416, 176, -224},
    { 1664, 248, -224},
    { 1912, 296, -224},
    { 1568, 320, -256},
    { 1344, 360, -200},
    { 1360, 488, -136},
    { 1440, 584, -120},
    { 1432, 656, -208},
    { 1528, 992, -224},
    { 1384, 1416, -392},
    { 880, 928, -280},
    { 1232, 1048, -232},
    { 832, 824, -272},
    { 1176, 616, -264},
    { 1672, 696, -72},
    { 1912, 664, -80},
    { 1752, 536, -136},
    { 1696, 408, -72},
    { 1752, 336, 0},
    { 1696, 424, -200},
    { 1480, 304, -240},
    { 1368, -88, -96},
    { 1088, -512, -128},
    { 784, -464, -256},
    { 1160, -232, -72},
    { 1464, 216, -328},
    { 1560, 360, -344},
    { 1984, 248, -136},
    { -2016, 328, -56},
    { 1784, 600, -168},
    { 1392, 800, -56},
    { 1136, 784, -240},
    { 1456, 304, -160},
    { 1352, 656, -144},
    { 1592, 1224, -16},
    { 880, 1264, -96},
    { 1104, 1016, -192},
    { 920, 880, -280},
    { 1048, 648, -280},
    { 1560, 656, -80},
    { 1872, 648, 16},
    { 1728, 568, -112},
    { 1712, 464, -88},
    { 1672, 344, 64},
    { 1608, 368, -24},
    { 1584, 392, -216},
    { 1360, 32, -160},
    { 1024, -408, -8},
    { 824, -376, -224},
    { 1080, -288, -208},
    { 1296, -16, -144},
    { 1576, 224, -200},
    { 1832, 272, -192},
    { 1856, 328, -208},
    { 1536, 384, -136},
    { 1424, 472, -152},
    { 1456, 640, -88},
    { 1376, 696, -80},
    { 1256, 832, -256},
    { 1504, 800, -8},
    { 1136, 1192, -200},
    { 776, 992, -216},
    { 1304, 984, -224},
    { 888, 816, -264},
    { 1424, 624, -160},
    { 1944, 696, -40},
    { 1848, 608, -32},
    { 1752, 464, -40},
    { 1728, 328, 32},
    { 1672, 352, 0},
    { 1576, 376, -152},
    { 1376, 216, -208},
    { 1192, -232, 8},
    { 832, -400, -112},
    { 760, -304, -288},
    { 1240, -208, 0},
    { 1744, 248, -176},
    { 1816, 272, -232},
    { -2032, 304, -232},
    { 1744, 344, -136},
    { 1536, 416, -168},
    { 1472, 624, -224},
    { 1448, 744, 0},
    { 1304, 888, -328},
    { 1328, 896, -160},
    { 1448, 1040, -40},
    { 800, 952, -56},
    { 1280, 1032, -16},
    { 952, 904, -168},
    { 1336, 712, -88},
    { 1832, 768, 32},
    { 1992, 656, 32},
    { 1808, 584, 0},
    { 1840, 440, 48},
    { 1784, 304, 32},
    { 1760, 368, -144},
    { 1576, 144, -216},
    { 1104, -384, 24},
    { 912, -384, -112},
    { 688, -384, -224},
    { 1080, -208, -48},
    { 1648, 160, -184},
    { 1784, 200, -144},
    { -1992, 304, -176},
    { 1856, 392, -176},
    { 1544, 344, -40},
    { 1384, 632, -80},
    { 1440, 736, -144},
    { 1456, 688, -160},
    { 1384, 920, -344},
    { 1456, 1296, -328},
    { 928, 904, -272},
    { 1128, 1000, -240},
    { 936, 896, -304},
    { 1240, 752, -264},
    { 1664, 688, -72},
    { 1920, 624, -16},
    { 1824, 560, -80},
    { 1784, 448, -48},
    { 1672, 344, 64},
    { 1696, 368, -32},
    { 1528, 384, -168},
    { 1384, 152, -152},
    { 1128, -296, 40},
    { 744, -320, -208},
    { 1072, -216, -208},
    { 1160, 48, -128},
    { 1552, 240, -336},
    { 1760, 176, -240},
    { 1784, 224, -184},
    { 1544, 384, -208},
    { 1520, 488, -264},
    { 1600, 624, -184},
    { 1480, 800, -120},
    { 1240, 1112, -528},
    { 1640, 808, -216},
    { 1080, 992, -112},
    { 1504, 1112, -160},
    { 824, 912, -256},
    { 1216, 656, -192},
    { 1616, 672, -40},
    { 1768, 608, -16},
    { 1688, 512, -24},
    { 1632, 440, 8},
    { 1616, 312, 40},
    { 1600, 328, -48},
    { 1576, 384, -136},
    { 1448, -136, -176},
    { 936, -424, 8},
    { 640, -280, -304},
    { 976, -328, -64},
    { 1240, -104, -152},
    { 1608, 224, -232},
    { 1896, 80, -112},
    { -2016, 288, -224},
    { 1704, 416, -208},
    { 1608, 520, -24},
    { 1432, 672, -64},
    { 1384, 696, -40},
    { 1304, 944, -256},
    { 1528, 1112, -176},
    { 1160, 1088, -120},
    { 1008, 1112, -48},
    { 1024, 992, -64},
    { 1080, 840, -168},
    { 1536, 688, -32},
    { 1960, 656, 24},
    { 1888, 584, 24},
    { 1776, 520, -16},
    { 1856, 360, 56},
    { 1752, 360, -32},
    { 1608, 296, -176},
    { 1360, -16, -128},
    { 1000, -344, -72},
    { 664, -400, -224},
    { 704, -320, -288},
    { 1136, -112, -96},
    { 1560, 184, -216},
    { 1856, 192, -208},
    { -1904, 296, -264},
    { 1768, 496, -104},
    { 1376, 488, -144},
    { 1352, 632, -200},
    { 1416, 688, -160},
    { 1416, 952, -416},
    { 1400, 1112, -392},
    { 1312, 1024, -360},
    { 856, 1032, -288},
    { 1312, 1072, -200},
    { 968, 784, -304},
    { 1376, 624, -184},
    { 1840, 664, -32},
    { 1792, 648, -48},
    { 1672, 560, -120},
    { 1616, 424, -48},
    { 1720, 408, -48},
    { 1736, 488, -152},
    { 1440, 40, -48},
    { 1080, -336, -88},
    { 904, -264, -352},
    { 640, -312, -232},
    { 1096, -72, -112},
    { 1456, 312, -320},
    { 1640, 360, -320},
    { 2008, 392, -256},
    { 1752, 384, -96},
    { 1368, 408, -128},
    { 1432, 512, -184},
    { 1504, 560, -128},
    { 1368, 592, -128},
    { 1352, 976, -336},
    { 1320, 1512, -344},
    { 880, 816, -216},
    { 1344, 1032, -200},
    { 928, 704, -304},
    { 1160, 672, -216},
    { 1528, 736, -72},
    { 1720, 648, -88},
    { 1544, 528, -88},
    { 1608, 408, 8},
    { 1784, 368, 40},
    { 1712, 400, -160},
    { 1536, 216, -256},
    { 1304, -192, -56},
    { 920, -272, -216},
    { 672, -264, -352},
    { 1176, -240, -40},
    { 1400, 128, -216},
    { 1584, 224, -216},
    { 1928, 256, -184},
    { 1736, 360, -248},
    { 1464, 384, -184},
    { 1552, 480, -104},
    { 1616, 584, 0},
    { 1488, 752, 104},
    { 1288, 1280, -432},
    { 1216, 1192, -72},
    { 896, 912, 0},
    { 1216, 1016, 40},
    { 856, 840, -168},
    { 1096, 704, -160},
    { 1640, 760, -16},
    { 1840, 704, 32},
    { 1776, 608, -40},
    { 1688, 520, 16},
    { 1800, 376, 8},
    { 1744, 392, -232},
    { 1544, 216, -216},
    { 1328, -136, -184},
    { 888, -312, -136},
    { 664, -224, -264},
    { 1016, -96, -224},
    { 1080, 32, -64},
    { 1224, 224, -48},
    { 1480, 304, -88},
    { 1776, 472, -184},
    { 1512, 544, -176},
    { 1384, 440, -56},
    { 1544, 488, -96},
    { 1688, 552, -192},
    { 1560, 672, -48},
    { 1352, 1288, -464},
    { 1384, 1168, -272},
    { 896, 992, -168},
    { 1344, 1072, -288},
    { 936, 704, -344},
    { 1232, 624, -208},
    { 1824, 728, -8},
    { 1792, 608, -56},
    { 1584, 520, -104},
    { 1672, 360, 0},
    { 1672, 336, 48},
    { 1616, 440, -128},
    { 1440, 264, -184},
    { 1160, -288, -8},
    { 920, -328, -192},
    { 648, -336, -328},
    { 1160, -208, -80},
    { 1320, 216, -272},
    { 1640, 256, -232},
    { 2040, 248, -272},
    { 1632, 344, -216},
    { 1336, 368, -104},
    { 1440, 464, -144},
    { 1560, 544, -240},
    { 1472, 720, -192},
    { 1176, 1528, -640},
    { 1424, 864, -408},
    { 872, 888, -304},
    { 1072, 896, -208},
    { 1000, 832, -304},
    { 1248, 696, -328},
    { 1712, 704, -128},
    { 2024, 688, -80},
    { 1864, 520, -56},
    { 1768, 384, -16},
    { 1680, 344, 8},
    { 1680, 368, -120},
    { 1440, 200, -144},
    { 1224, -192, 40},
    { 1032, -320, -168},
    { 784, -320, -344},
    { 928, -320, -72},
    { 1272, 48, -96},
    { 1664, 280, -240},
    { 2016, 320, -232},
    { -1960, 368, -224},
    { 1784, 456, -80},
    { 1576, 608, -192},
    { 1432, 616, -56},
    { 1408, 560, -88},
    { 1288, 632, -168},
    { 1408, 896, -176},
    { 1208, 1192, 24},
    { 688, 848, -128},
    { 1256, 984, -96},
    { 880, 808, -264},
    { 1208, 648, -232},
    { 1904, 776, -56},
    { 1888, 680, -96},
    { 2008, 504, -72},
    { 2032, 304, 40},
    { 1864, 328, 24},
    { 1592, 400, -64},
    { 1384, 304, -136},
    { 1144, 240, -104},
    { 1000, 304, -192},
    { 792, 312, -272},
    { 736, 408, -368},
    { 520, 408, -504},
    { 376, 464, -856},
    { 512, 1480, -992},
    { 176, 1320, -840},
    { -368, 816, -720},
    { -536, 800, -672},
    { -520, 792, -648},
    { -464, 720, -616},
    { -448, 616, -624},
    { -472, 648, -672},
    { -488, 712, -712},
    { -360, 528, -784},
    { -320, 472, -960},
    { -152, 648, -1200},
    { -40, 488, -1040},
    { 168, 192, -1088},
    { 184, 280, -1208},
    { 200, -56, -952},
    { 88, -32, -1144},
    { 184, 80, -1040},
    { 168, -64, -840},
    { -56, -24, -984},
    { 128, -720, -752},
    { 848, -352, -704},
    { 64, -632, -952},
    { 216, -16, -1160},
    { 104, -168, -1088},
    { 56, -344, -984},
    { -240, -32, -936},
    { 712, 208, -1216},
    { 632, -536, -976},
    { -48, -136, -840},
    { -128, -200, -888},
    { -64, -200, -864},
    { -232, -328, -968},
    { 96, 56, -920},
    { -304, -144, -872},
    { -336, -352, -864},
    { -344, -296, -920},
    { -280, -376, -984},
    { -80, 120, -744},
    { 520, -520, -888},
    { -424, -208, -864},
    { -272, -312, -1032},
    { -280, -288, -984},
    { -248, -288, -912},
    { -184, -208, -944},
    { -296, -176, -952},
    { -312, -152, -984},
    { 56, -544, -880},
    { -120, -360, -848},
    { -176, -352, -896},
    { -48, -352, -944},
    { -328, -272, -1016},
    { 32, -736, -912},
    { -152, -384, -944},
    { -224, -368, -904},
    { -128, -400, -928},
    { -152, -376, -896},
    { -128, -368, -888},
    { -152, -376, -888},
    { -168, -456, -872},
    { -112, -504, -888},
    { -120, -432, -920},
    { -160, -408, -912},
    { -168, -384, -872},
    { -176, -360, -872},
    { -176, -328, -920},
    { -168, -320, -936},
    { -192, -304, -944},
    { -216, -344, -904},
    { -224, -392, -912},
    { -232, -352, -888},
    { -232, -344, -880},
    { -240, -328, -872},
    { -64, -488, -872},
    { -168, -360, -928},
    { -184, -360, -952},
    { -88, -360, -992},
    { -144, -488, -976},
    { -128, -464, -872},
    { -160, -440, -848},
    { -152, -432, -864},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}



// ----------------------------------------------------------------
// Sample captured: 2015-09-22 12:00:16 local
AccelRawData *activity_sample_100_steps_heather_2(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME walk_100_heather_2
  //> TEST_EXPECTED 100
  //> TEST_EXPECTED_MIN 95
  //> TEST_EXPECTED_MAX 110
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { -72, -128, -960},
    { -104, -144, -976},
    { -168, -160, -1016},
    { 128, -80, -1016},
    { -56, -168, -1064},
    { -40, -240, -904},
    { -56, -88, -1152},
    { -64, -184, -992},
    { 24, -160, -1000},
    { -216, -144, -1040},
    { -72, -192, -1024},
    { -88, -80, -1048},
    { 0, -168, -1016},
    { -72, -224, -976},
    { -16, -232, -952},
    { -128, -264, -960},
    { -120, -80, -1008},
    { -152, -64, -984},
    { -104, -88, -1088},
    { -96, -72, -1080},
    { -128, -104, -1032},
    { -216, -160, -1016},
    { -144, -56, -992},
    { 8, -152, -1024},
    { 40, -192, -960},
    { -16, -144, -1032},
    { 48, -176, -1032},
    { 8, -152, -1048},
    { -24, -176, -1024},
    { -48, -168, -1024},
    { -32, -152, -1024},
    { -48, -160, -1040},
    { -32, -160, -1048},
    { -32, -112, -1032},
    { -96, -120, -1048},
    { -96, -144, -1040},
    { -88, -112, -1032},
    { -72, -136, -1016},
    { -56, -168, -1024},
    { -80, -168, -1024},
    { -120, -120, -984},
    { -176, -112, -976},
    { -184, -120, -960},
    { -232, -104, -920},
    { -240, -96, -904},
    { -232, -88, -904},
    { -256, -40, -920},
    { -264, -104, -944},
    { -296, -96, -1008},
    { -240, -160, -1096},
    { -184, -136, -1152},
    { -200, -136, -1072},
    { -224, -200, -992},
    { -184, -160, -904},
    { -192, -184, -888},
    { -208, -176, -960},
    { -240, -144, -968},
    { -288, -104, -984},
    { -296, -72, -1040},
    { -296, -80, -1128},
    { -176, 48, -1240},
    { 16, -48, -1152},
    { 160, -64, -904},
    { 296, -56, -784},
    { 480, -192, -688},
    { 576, -144, -664},
    { 688, 376, -320},
    { 792, 296, -280},
    { 960, 448, -112},
    { 1136, 584, -88},
    { 1432, 528, 48},
    { 1928, 552, 184},
    { -1168, 696, 304},
    { -1640, 1208, 208},
    { -1960, 1072, -16},
    { 1912, 920, -128},
    { 1568, 688, -88},
    { 1264, 848, -88},
    { 640, 1152, -288},
    { 496, 1416, -368},
    { 720, 1048, -192},
    { 1056, 776, -24},
    { 1416, 576, -48},
    { 1456, 480, -56},
    { 1752, 560, -64},
    { -2040, 608, -48},
    { 2032, 552, -24},
    { 1896, 512, 24},
    { 1664, 416, -8},
    { 1552, 392, 8},
    { 1528, 464, -280},
    { 864, -544, -40},
    { 576, -1048, 32},
    { 1024, -440, -312},
    { 1240, -136, -224},
    { 1280, -80, -184},
    { 1456, 8, -184},
    { 1512, 192, -232},
    { 1480, 360, -384},
    { 1448, 368, -440},
    { 1384, 176, -432},
    { 1536, 232, -408},
    { 1440, 232, -448},
    { 1744, 488, -568},
    { 1608, 936, -728},
    { 904, 832, -712},
    { 1056, 848, -568},
    { 792, 1096, -576},
    { 848, 640, -432},
    { 1248, 672, -312},
    { 1784, 720, -168},
    { 1872, 576, -88},
    { 1896, 392, -64},
    { 1960, 368, -32},
    { 2008, 440, -64},
    { 1768, 432, -120},
    { 1408, 272, -232},
    { 1232, 136, -392},
    { 704, -392, -264},
    { 424, -520, -632},
    { 920, -472, -408},
    { 1120, -104, -248},
    { 1272, 200, -288},
    { 1488, 200, -160},
    { 1832, 384, -128},
    { 1744, 536, -128},
    { 1760, 544, -136},
    { 1896, 656, -80},
    { 1928, 768, 48},
    { 1696, 784, -40},
    { 1440, 768, -80},
    { 1504, 1624, -96},
    { 840, 1528, -136},
    { 944, 1384, -56},
    { 904, 1192, -152},
    { 1104, 928, -144},
    { 1696, 824, -40},
    { -1976, 752, 64},
    { -1984, 608, 8},
    { -2016, 472, -48},
    { -1984, 352, -296},
    { 1928, 448, -176},
    { 1560, 424, -240},
    { 1192, 512, -536},
    { 1008, 88, -528},
    { 392, -528, -592},
    { 448, -368, -600},
    { 976, -104, -384},
    { 1600, 216, -456},
    { 1400, 224, -240},
    { 1848, 184, -120},
    { -2000, 440, -200},
    { -2000, 648, -208},
    { 1944, 920, -224},
    { 1568, 1136, -376},
    { 1840, 232, -104},
    { 1616, 592, 48},
    { 1720, 1112, 160},
    { 1064, 1376, 168},
    { 640, 1344, 16},
    { 896, 1216, 216},
    { 856, 856, 168},
    { 1160, 816, 80},
    { 1912, 824, 64},
    { 1952, 672, 48},
    { 1952, 664, 8},
    { -2016, 472, 64},
    { -2032, 400, 32},
    { 1864, 448, -80},
    { 1528, 352, -176},
    { 1384, 152, -240},
    { 736, -448, -32},
    { 504, -360, -480},
    { 920, -288, -328},
    { 1176, 0, -320},
    { 1448, 88, -232},
    { 1696, 224, -248},
    { 1936, 360, -312},
    { 1816, 440, -264},
    { 1808, 608, -272},
    { 1712, 704, -144},
    { 1600, 808, -152},
    { 1616, 616, -216},
    { 1552, 928, -96},
    { 1080, 1544, -240},
    { 760, 1144, -200},
    { 952, 1136, -144},
    { 920, 896, -152},
    { 1312, 720, -104},
    { 1920, 760, -32},
    { -1992, 728, -32},
    { 2000, 616, -24},
    { 2016, 328, 56},
    { 1904, 328, 32},
    { 1760, 488, -152},
    { 1496, 376, -288},
    { 1304, 32, -296},
    { 736, -616, -32},
    { 432, -416, -568},
    { 1008, -360, -256},
    { 1136, 48, -272},
    { 1480, 192, -192},
    { 1776, 224, -24},
    { -1936, 448, -56},
    { -2024, 640, -104},
    { 1896, 760, -112},
    { 1672, 944, 96},
    { 1736, 560, -232},
    { 1592, 392, 40},
    { 1760, 1288, 264},
    { 928, 1760, 136},
    { 800, 1312, 40},
    { 920, 1152, 128},
    { 808, 832, -32},
    { 1112, 736, -16},
    { 1784, 872, 72},
    { 2040, 784, 160},
    { 1976, 648, 128},
    { -1968, 328, 96},
    { 1944, 200, 96},
    { 1760, 408, -48},
    { 1448, 432, -144},
    { 1328, 224, -280},
    { 904, -632, -104},
    { 528, -496, -440},
    { 1080, -408, -296},
    { 1360, 88, -304},
    { 1544, 104, -256},
    { 1936, 224, -168},
    { 2032, 416, -216},
    { 1840, 592, -208},
    { 1640, 744, -296},
    { 1408, 824, -168},
    { 1528, 488, -280},
    { 1512, 440, -224},
    { 1536, 1328, -712},
    { 928, 1608, -664},
    { 1016, 1240, -584},
    { 1176, 824, -424},
    { 1232, 480, -280},
    { 1600, 464, -88},
    { 2000, 560, -72},
    { -2048, 528, -224},
    { 1920, 480, -160},
    { 1744, 344, 56},
    { 1592, 480, 56},
    { 1376, 504, 64},
    { 1208, 320, -120},
    { 1096, -320, -56},
    { 552, -664, -72},
    { 1064, -416, -328},
    { 1264, -240, -216},
    { 1824, 200, -384},
    { 1696, 200, -216},
    { -2016, 256, -128},
    { -1984, 464, -232},
    { 1904, 608, -184},
    { 1776, 768, -96},
    { 1664, 728, -56},
    { 1584, 504, -24},
    { 1440, 776, 128},
    { 1480, -1960, 32},
    { 624, 1480, 96},
    { 1112, 1400, -136},
    { 1024, 816, -344},
    { 1312, 544, -232},
    { 1944, 712, 40},
    { -1880, 704, 16},
    { -1880, 576, -176},
    { -1968, 440, -80},
    { 1936, 416, 48},
    { 1656, 472, -8},
    { 1360, 368, -56},
    { 1240, 184, -104},
    { 1016, -296, 184},
    { 496, -416, 24},
    { 968, -152, -296},
    { 1168, -16, -104},
    { 1584, 216, -200},
    { 1552, 184, -96},
    { 1896, 296, -56},
    { -2024, 448, -176},
    { -1960, 688, -200},
    { 1920, 872, -120},
    { 1712, 872, -96},
    { 1784, 480, -104},
    { 1632, 592, 144},
    { 1432, 1600, 80},
    { 704, 1520, 32},
    { 1112, 1024, -112},
    { 752, 968, -264},
    { 1176, 648, -176},
    { 1720, 696, 0},
    { 1968, 696, 8},
    { -2048, 568, -120},
    { -2040, 384, -16},
    { 1944, 408, 32},
    { 1920, 456, 8},
    { 1560, 400, -24},
    { 1328, 216, -120},
    { 952, -304, 16},
    { 632, -456, -136},
    { 1184, -360, -240},
    { 1368, -40, -320},
    { 1520, 152, -192},
    { 1696, 216, -160},
    { 2000, 368, -176},
    { 2032, 520, -208},
    { 1872, 720, -200},
    { 1552, 888, 8},
    { 1472, 568, -256},
    { 1480, 328, -64},
    { 1520, 928, -8},
    { 1088, 1640, -136},
    { 816, 1008, -112},
    { 1040, 1040, -192},
    { 936, 784, -224},
    { 1232, 640, -144},
    { 1768, 736, -16},
    { 1968, 672, 8},
    { 1904, 520, -72},
    { 1896, 344, 16},
    { 1824, 352, 8},
    { 1696, 440, -48},
    { 1456, 352, -208},
    { 1304, -56, -120},
    { 728, -552, 8},
    { 792, -304, -472},
    { 1200, -344, -232},
    { 1584, 72, -232},
    { 1632, 160, -120},
    { 1888, 280, -128},
    { 1944, 440, -248},
    { 1872, 568, -192},
    { 1768, 696, -96},
    { 1528, 832, 16},
    { 1504, 592, -168},
    { 1320, 456, 16},
    { 1512, 1088, -24},
    { 896, 1504, 16},
    { 920, 1184, -16},
    { 896, 1056, -200},
    { 1000, 720, -216},
    { 1504, 672, -88},
    { -1976, 728, 48},
    { 2040, 680, -32},
    { -2040, 528, -96},
    { 2032, 376, 8},
    { 1880, 392, 16},
    { 1640, 456, -176},
    { 1440, 264, -208},
    { 1144, -240, 24},
    { 624, -528, -40},
    { 808, -232, -392},
    { 1040, -144, -288},
    { 1256, 192, -248},
    { 1336, 168, -168},
    { 1744, 232, -88},
    { 1896, 376, -112},
    { 1888, 544, -152},
    { 1824, 704, -144},
    { 1816, 776, 64},
    { 1752, 648, -152},
    { 1472, 496, 16},
    { 1592, 1064, 104},
    { 920, 1640, 80},
    { 1040, 1200, 240},
    { 832, 1080, 88},
    { 856, 832, -64},
    { 1232, 808, 8},
    { 1848, 856, 112},
    { -2048, 728, 136},
    { -2016, 472, 32},
    { -2048, 296, 72},
    { 1888, 400, 24},
    { 1704, 424, -56},
    { 1376, 312, -168},
    { 1096, -16, -112},
    { 624, -472, -64},
    { 600, -56, -616},
    { 1080, -120, -400},
    { 1192, 0, -312},
    { 1288, 40, -248},
    { 1632, 80, -128},
    { 1840, 304, -184},
    { 1792, 448, -160},
    { 1792, 608, -168},
    { 1808, 720, -112},
    { 1776, 840, 0},
    { 1448, 736, -232},
    { 1240, 1072, -472},
    { 1144, 1312, -328},
    { 864, 1008, -256},
    { 1072, 1048, -280},
    { 936, 728, -336},
    { 1096, 672, -216},
    { 1672, 688, -56},
    { 1848, 616, -8},
    { 1816, 544, -112},
    { 1784, 440, -56},
    { 1808, 432, 24},
    { 1744, 464, -56},
    { 1448, 368, -208},
    { 1336, 128, -240},
    { 928, -384, -128},
    { 720, -336, -672},
    { 976, -528, -304},
    { 1216, -168, -296},
    { 1520, 96, -400},
    { 1568, 160, -208},
    { 1840, 304, -192},
    { 1872, 432, -192},
    { 1904, 576, -104},
    { 1776, 760, -8},
    { 1712, 864, -64},
    { 1480, 584, -136},
    { 1136, 712, -88},
    { 1256, 1440, -200},
    { 720, 1216, -136},
    { 1120, 1136, -216},
    { 776, 856, -248},
    { 1152, 600, -176},
    { 1648, 672, -40},
    { 1912, 640, -24},
    { 1792, 552, -104},
    { 1856, 456, -32},
    { 1880, 408, 56},
    { 1792, 432, -40},
    { 1544, 360, -160},
    { 1456, 88, -312},
    { 1136, -624, -80},
    { 872, -560, -320},
    { 1096, -432, -232},
    { 1296, 16, -328},
    { 1344, 136, -232},
    { 1616, 224, -64},
    { 1872, 360, -80},
    { 1920, 552, -144},
    { 1776, 728, -184},
    { 1512, 808, 8},
    { 1376, 688, -312},
    { 1384, 352, -200},
    { 1352, 1040, -256},
    { 1112, 1456, -312},
    { 928, 1040, -288},
    { 1056, 1008, -304},
    { 904, 640, -336},
    { 1216, 600, -208},
    { 1688, 696, -16},
    { 1992, 664, 0},
    { 1888, 496, -72},
    { 1864, 360, 0},
    { 1800, 336, 72},
    { 1656, 448, -40},
    { 1424, 368, -184},
    { 1176, -104, -184},
    { 752, -504, -112},
    { 872, -376, -480},
    { 1160, -368, -264},
    { 1584, 168, -344},
    { 1536, 168, -288},
    { 1720, 200, -120},
    { 1920, 344, -88},
    { 1944, 544, -112},
    { 1784, 760, -120},
    { 1504, 984, 104},
    { 1368, 704, -248},
    { 1408, 384, -32},
    { 1376, 1096, -104},
    { 1048, 1432, -136},
    { 928, 1000, -128},
    { 952, 968, -264},
    { 896, 672, -272},
    { 1224, 624, -128},
    { 1704, 696, 8},
    { 1976, 656, -24},
    { 1832, 512, -80},
    { 1840, 384, 0},
    { 1832, 352, 32},
    { 1664, 448, -96},
    { 1432, 344, -280},
    { 1240, -40, -184},
    { 800, -520, -104},
    { 672, -264, -592},
    { 1192, -248, -280},
    { 1464, 136, -296},
    { 1456, 184, -192},
    { 1720, 264, -160},
    { 1904, 416, -168},
    { 1904, 560, -144},
    { 1704, 752, -112},
    { 1336, 936, -88},
    { 1456, 480, -232},
    { 1360, 360, 24},
    { 1472, 1048, 32},
    { 1080, 1512, 40},
    { 832, 1072, -120},
    { 1160, 1008, -144},
    { 936, 712, -312},
    { 1008, 592, -184},
    { 1592, 720, -16},
    { 1992, 688, 56},
    { 1880, 552, -40},
    { 1872, 360, -24},
    { 1792, 304, 40},
    { 1696, 392, -64},
    { 1448, 376, -256},
    { 1336, 184, -304},
    { 888, -432, -48},
    { 696, -448, -312},
    { 1120, -328, -328},
    { 1200, 8, -240},
    { 1384, 128, -224},
    { 1504, 184, -120},
    { 1840, 312, -136},
    { 1832, 512, -152},
    { 1704, 656, -152},
    { 1472, 768, -152},
    { 1392, 688, -248},
    { 1480, 400, -200},
    { 1288, 536, -208},
    { 1384, 1064, -112},
    { 952, 1280, -184},
    { 1056, 1024, -184},
    { 944, 928, -272},
    { 912, 616, -256},
    { 1376, 680, -128},
    { 1808, 736, 8},
    { 1848, 592, -8},
    { 1776, 392, -64},
    { 1784, 288, 8},
    { 1768, 336, -176},
    { 1672, 480, -376},
    { 1440, 80, -208},
    { 944, -432, 0},
    { 528, -424, -296},
    { 480, -216, -536},
    { 1008, -392, -200},
    { 1416, -248, -152},
    { 1720, -40, -128},
    { 1800, 272, -216},
    { 1864, 200, -136},
    { 1824, 352, -240},
    { 1792, 600, -280},
    { 1632, 688, -8},
    { 1448, 768, -224},
    { 1368, 640, -200},
    { 1224, 888, -176},
    { 1168, 1288, -232},
    { 872, 1112, -120},
    { 1136, 1016, -128},
    { 992, 824, -168},
    { 1096, 656, -168},
    { 1560, 744, -80},
    { -2024, 792, 72},
    { -1912, 560, 80},
    { 2032, 392, 16},
    { 1904, 272, 80},
    { 1736, 392, -24},
    { 1536, 400, -120},
    { 1296, 136, -304},
    { 752, -416, -16},
    { 456, -384, -208},
    { 744, -232, -680},
    { 984, -280, -176},
    { 1344, 72, -208},
    { 1416, 144, -224},
    { 1760, 256, -128},
    { -2016, 448, -176},
    { 1976, 624, -168},
    { 1816, 728, -152},
    { 1600, 848, -120},
    { 1568, 504, -152},
    { 1480, 416, -80},
    { 1224, 584, 24},
    { 1440, 1184, 80},
    { 688, 1408, -40},
    { 1152, 968, -48},
    { 936, 888, -160},
    { 968, 648, -176},
    { 1384, 744, -24},
    { 1832, 744, 56},
    { 1880, 600, 56},
    { 1896, 376, 24},
    { 1848, 272, 104},
    { 1736, 360, 40},
    { 1640, 392, 0},
    { 1248, 344, -8},
    { 968, 8, 96},
    { 736, -208, -104},
    { 656, -272, -304},
    { 976, -480, -24},
    { 1272, -176, -160},
    { 1872, 208, -304},
    { 1936, 240, -216},
    { -1856, 392, -344},
    { -2032, 512, -256},
    { 1712, 736, -200},
    { 1552, 600, 24},
    { 1624, 704, -160},
    { 1536, 1064, -160},
    { 1104, 1136, 24},
    { 976, 1120, 80},
    { 664, 904, 56},
    { 1256, 1072, 64},
    { 888, 864, -8},
    { 1552, 816, 16},
    { -1744, 904, 56},
    { -1472, 768, 144},
    { -1696, 520, 80},
    { -1952, 296, 88},
    { 1864, 384, -8},
    { 1688, 392, -144},
    { 1528, 248, -152},
    { 1032, -352, 56},
    { 544, -544, 8},
    { 392, -424, -288},
    { 720, -320, -88},
    { 1552, 136, -136},
    { 1904, 304, -184},
    { -1632, 344, -120},
    { -1616, 520, -152},
    { 1864, 592, -144},
    { 1704, 480, -184},
    { 1712, 560, -296},
    { 1800, 360, -216},
    { 1584, 784, -136},
    { 1384, 1600, 88},
    { 1272, 1152, -64},
    { 768, 848, -24},
    { 1056, 1096, -120},
    { 768, 912, -152},
    { 1216, 784, -80},
    { 1896, 824, 104},
    { -1792, 744, 104},
    { -1856, 568, 16},
    { -1888, 408, 40},
    { -2048, 344, 56},
    { 1792, 416, 0},
    { 1512, 408, -176},
    { 1384, 0, -112},
    { 848, -616, 152},
    { 656, -216, -304},
    { 848, -280, -328},
    { 1296, 88, -184},
    { 1784, 240, -216},
    { 1840, 240, -216},
    { -2040, 304, -208},
    { 1928, 464, -160},
    { 1616, 560, -176},
    { 1400, 576, -136},
    { 1448, 488, -184},
    { 1400, 456, -48},
    { 1264, 512, -88},
    { 1280, 696, -88},
    { 1360, 976, 88},
    { 888, 1208, -264},
    { 952, 776, -288},
    { 648, 864, -264},
    { 1088, 736, -144},
    { 1624, 688, 16},
    { 1992, 616, 40},
    { 1952, 432, -32},
    { 1832, 376, -48},
    { 1696, 288, 48},
    { 1512, 368, -32},
    { 1424, 368, -96},
    { 1248, 328, -184},
    { 1184, 16, -136},
    { 736, -424, 16},
    { 640, -96, -448},
    { 1184, 48, -440},
    { 1480, 160, -232},
    { 1456, 224, -152},
    { 1752, 256, -216},
    { 1776, 400, -224},
    { 1536, 496, -240},
    { 1432, 520, -232},
    { 1328, 552, -168},
    { 1376, 536, -192},
    { 1560, 488, -176},
    { 1256, 656, -128},
    { 1304, 1184, -176},
    { 816, 1288, -352},
    { 1048, 816, -272},
    { 784, 784, -296},
    { 1080, 600, -232},
    { 1456, 640, -56},
    { 1936, 616, 16},
    { 1912, 448, -112},
    { 1776, 440, -120},
    { 1712, 416, -40},
    { 1640, 512, -144},
    { 1528, 488, -208},
    { 1368, 216, -368},
    { 960, -560, 0},
    { 512, -416, -400},
    { 856, -168, -512},
    { 1056, -16, -320},
    { 1552, 176, -360},
    { 1512, 160, -216},
    { 1912, 272, -176},
    { 1872, 448, -200},
    { 1576, 552, -208},
    { 1392, 648, -176},
    { 1384, 560, -72},
    { 1360, 464, -112},
    { 1352, 472, -80},
    { 1344, 824, -104},
    { 1344, 1280, 56},
    { 776, 1168, -200},
    { 1096, 808, -128},
    { 728, 816, -248},
    { 952, 608, -168},
    { 1488, 672, 0},
    { 1824, 664, 32},
    { 1848, 552, -64},
    { 1832, 432, -80},
    { 1808, 336, -16},
    { 1720, 400, -160},
    { 1496, 344, -280},
    { 1216, -8, -288},
    { 744, -440, -40},
    { 752, -328, -416},
    { 1096, -248, -488},
    { 1464, -120, -120},
    { 1648, 240, -176},
    { 1768, 352, -152},
    { 1904, 408, -248},
    { 1768, 496, -160},
    { 1664, 568, -72},
    { 1512, 784, 264},
    { 1432, 712, -128},
    { 1424, 424, 8},
    { 1152, 624, 40},
    { 1408, 1144, 16},
    { 752, 1536, 32},
    { 1112, 952, -104},
    { 752, 944, -184},
    { 904, 752, -216},
    { 1392, 664, -72},
    { 1824, 656, 32},
    { 1792, 552, -72},
    { 1744, 528, -120},
    { 1856, 416, 0},
    { 1872, 400, -40},
    { 1656, 432, -288},
    { 1400, 256, -272},
    { 1128, -328, -56},
    { 584, -560, -264},
    { 896, -192, -504},
    { 1264, -32, -352},
    { 1520, 168, -312},
    { 1520, 160, -104},
    { 1832, 280, -160},
    { 1784, 432, -224},
    { 1632, 600, -200},
    { 1536, 672, -96},
    { 1456, 656, 48},
    { 1392, 528, -160},
    { 1240, 632, -160},
    { 1512, 1016, -304},
    { 904, 1344, -344},
    { 1200, 1072, -224},
    { 832, 1008, -288},
    { 1000, 624, -280},
    { 1456, 560, -128},
    { 1720, 640, -32},
    { 1728, 544, -104},
    { 1680, 536, -128},
    { 1776, 432, 16},
    { 1824, 408, 16},
    { 1616, 360, -248},
    { 1400, 224, -368},
    { 1056, -392, -88},
    { 552, -608, -376},
    { 872, -328, -584},
    { 1288, -232, -296},
    { 1808, 112, -224},
    { 1656, 224, -104},
    { 1896, 344, -112},
    { -2032, 552, -160},
    { 1952, 728, -112},
    { 1720, 808, 112},
    { 1352, 848, -144},
    { 1400, 368, -144},
    { 1248, 520, -88},
    { 1232, 1152, -88},
    { 1040, 1288, -48},
    { 800, 1040, -128},
    { 1008, 968, -224},
    { 928, 704, -272},
    { 1328, 616, -136},
    { 1792, 688, 32},
    { 2008, 648, 16},
    { 1920, 552, -64},
    { 1936, 408, 40},
    { 1856, 352, 48},
    { 1696, 408, -40},
    { 1432, 328, -136},
    { 1248, -24, -184},
    { 744, -440, -80},
    { 720, -328, -480},
    { 1080, -224, -352},
    { 1320, 160, -256},
    { 1496, 304, -296},
    { 1672, 232, -200},
    { 1976, 344, -232},
    { 1864, 512, -200},
    { 1616, 640, -264},
    { 1408, 656, -200},
    { 1352, 496, -280},
    { 1376, 552, -296},
    { 1040, 1000, -496},
    { 1128, 1112, -416},
    { 984, 888, -288},
    { 1168, 888, -296},
    { 1048, 712, -312},
    { 1272, 592, -240},
    { 1624, 592, -56},
    { 1912, 664, 0},
    { 1888, 552, -40},
    { 1768, 416, 32},
    { 1648, 344, 48},
    { 1560, 408, -32},
    { 1400, 392, -160},
    { 1248, 144, -328},
    { 768, -544, 32},
    { 552, -392, -256},
    { 912, -152, -776},
    { 1304, -152, -224},
    { 1592, 112, -216},
    { 1704, 176, -144},
    { 1928, 368, -160},
    { 1920, 560, -176},
    { 1704, 600, -112},
    { 1536, 688, -48},
    { 1440, 664, -184},
    { 1344, 416, -192},
    { 1208, 424, -136},
    { 1096, 976, -208},
    { 1064, 1512, -264},
    { 864, 856, -184},
    { 1192, 840, -224},
    { 936, 800, -296},
    { 1280, 648, -160},
    { 1632, 680, 8},
    { -2016, 664, 64},
    { 1968, 504, 32},
    { 1904, 400, 16},
    { 1800, 352, 120},
    { 1680, 464, 48},
    { 1440, 416, -24},
    { 1232, 280, -144},
    { 1112, 16, -168},
    { 608, -384, -104},
    { 840, -136, -584},
    { 1048, -192, -312},
    { 1352, 96, -272},
    { 1432, 176, -296},
    { 1608, 240, -224},
    { 1712, 352, -264},
    { 1640, 432, -240},
    { 1584, 536, -264},
    { 1528, 608, -208},
    { 1320, 680, -192},
    { 1344, 536, -264},
    { 1248, 704, -272},
    { 1392, 1064, -296},
    { 1008, 1008, -248},
    { 1048, 944, -264},
    { 928, 816, -240},
    { 944, 648, -216},
    { 1312, 608, -120},
    { 1712, 656, 32},
    { 1864, 520, 24},
    { 1720, 416, -64},
    { 1656, 368, -8},
    { 1616, 408, -16},
    { 1520, 440, -112},
    { 1272, 384, -336},
    { 1112, -16, -240},
    { 632, -504, -112},
    { 544, -216, -544},
    { 1200, -128, -416},
    { 1392, 104, -360},
    { 1360, 168, -256},
    { 1536, 216, -168},
    { 1688, 368, -216},
    { 1584, 464, -160},
    { 1552, 544, -72},
    { 1568, 600, -16},
    { 1584, 696, 0},
    { 1480, 584, -176},
    { 1288, 704, -104},
    { 1456, 1456, -272},
    { 920, 1048, -192},
    { 1080, 1208, -208},
    { 848, 896, -264},
    { 968, 624, -224},
    { 1400, 640, -88},
    { 1800, 672, 16},
    { 1816, 608, 0},
    { 1832, 496, -80},
    { 1792, 320, 120},
    { 1680, 400, 8},
    { 1504, 400, -56},
    { 1248, 336, -192},
    { 1088, -48, -136},
    { 712, -432, -152},
    { 792, -176, -664},
    { 1048, -256, -440},
    { 1120, 0, -368},
    { 1368, 128, -280},
    { 1632, 240, -288},
    { 1960, 440, -352},
    { 1776, 496, -208},
    { 1576, 528, -168},
    { 1400, 624, -200},
    { 1440, 512, -288},
    { 1408, 712, -232},
    { 1208, 1232, -280},
    { 1160, 1176, -248},
    { 1000, 1040, -200},
    { 1016, 920, -272},
    { 904, 696, -264},
    { 1272, 688, -144},
    { 1720, 752, 56},
    { 1888, 616, 64},
    { 1744, 448, -40},
    { 1736, 336, 104},
    { 1744, 360, 48},
    { 1720, 448, -32},
    { 1376, 384, -184},
    { 1224, 104, -264},
    { 944, -280, -128},
    { 904, -312, -368},
    { 1192, -280, -320},
    { 1296, 80, -432},
    { 1440, 96, -320},
    { 1600, 192, -328},
    { 1608, 256, -288},
    { 1608, 392, -264},
    { 1720, 560, -192},
    { 1624, 672, -88},
    { 1472, 792, -232},
    { 1384, 584, -232},
    { 1512, 976, -240},
    { 1168, 1080, -136},
    { 960, 992, -200},
    { 928, 1056, -208},
    { 856, 768, -200},
    { 1280, 584, -112},
    { 1680, 664, 24},
    { 1760, 592, -8},
    { 1696, 520, -64},
    { 1832, 392, 16},
    { 1864, 392, 40},
    { 1688, 408, -72},
    { 1400, 296, -248},
    { 1240, -80, -200},
    { 856, -424, -120},
    { 856, -256, -392},
    { 1120, -96, -376},
    { 1304, 160, -336},
    { 1248, 152, -312},
    { 1528, 168, -216},
    { 1712, 304, -224},
    { 1656, 488, -200},
    { 1520, 624, -232},
    { 1360, 640, -104},
    { 1248, 568, -256},
    { 1312, 416, -168},
    { 1256, 808, -248},
    { 1344, 1200, -232},
    { 920, 1000, -248},
    { 1160, 832, -256},
    { 888, 672, -320},
    { 1016, 576, -232},
    { 1368, 624, -80},
    { 1728, 640, 0},
    { 1744, 536, -48},
    { 1712, 424, -72},
    { 1664, 320, 8},
    { 1536, 360, -72},
    { 1352, 352, -256},
    { 1080, 184, -304},
    { 848, -152, -136},
    { 632, -264, -216},
    { 808, 16, -672},
    { 1176, -8, -384},
    { 1280, 72, -232},
    { 1352, 160, -240},
    { 1584, 264, -216},
    { 1688, 416, -240},
    { 1536, 464, -184},
    { 1424, 544, -160},
    { 1336, 552, -48},
    { 1336, 592, -152},
    { 1360, 544, -200},
    { 1304, 720, -112},
    { 1400, 1104, -128},
    { 1040, 1080, -136},
    { 1216, 1000, -200},
    { 744, 784, -320},
    { 808, 544, -216},
    { 1248, 712, -16},
    { 1880, 672, 48},
    { 1688, 496, -16},
    { 1672, 368, -72},
    { 1680, 288, 16},
    { 1632, 392, -72},
    { 1448, 400, -304},
    { 1144, 248, -312},
    { 1016, -120, -176},
    { 712, -320, -312},
    { 1096, -152, -384},
    { 1320, 104, -416},
    { 1336, 216, -360},
    { 1360, 168, -248},
    { 1552, 216, -112},
    { 1536, 392, -144},
    { 1456, 512, -184},
    { 1352, 576, -136},
    { 1312, 608, -104},
    { 1304, 568, -248},
    { 1272, 488, -176},
    { 1520, 736, -176},
    { 1232, 1016, -216},
    { 1192, 1144, -312},
    { 816, 928, -344},
    { 816, 616, -304},
    { 1200, 552, -112},
    { 1608, 616, 8},
    { 1720, 472, -40},
    { 1600, 376, -136},
    { 1568, 360, -48},
    { 1520, 384, -16},
    { 1432, 376, -56},
    { 1296, 344, -184},
    { 1072, 208, -264},
    { 920, -96, -200},
    { 608, -168, -296},
    { 1016, 16, -480},
    { 1272, 72, -328},
    { 1408, 184, -368},
    { 1408, 152, -216},
    { 1480, 256, -168},
    { 1368, 392, -176},
    { 1296, 472, -216},
    { 1272, 496, -160},
    { 1288, 488, -56},
    { 1328, 528, -72},
    { 1504, 568, -216},
    { 1424, 776, -184},
    { 1376, 1232, -376},
    { 1128, 872, -272},
    { 888, 776, -368},
    { 760, 632, -352},
    { 1080, 520, -192},
    { 1416, 568, -64},
    { 1712, 544, -40},
    { 1632, 440, -128},
    { 1592, 352, -56},
    { 1504, 304, -8},
    { 1352, 376, -80},
    { 1216, 320, -216},
    { 1040, 200, -208},
    { 952, -64, -64},
    { 824, -48, -224},
    { 1016, 104, -440},
    { 1200, 120, -240},
    { 1400, 232, -272},
    { 1320, 232, -232},
    { 1536, 288, -200},
    { 1472, 376, -224},
    { 1304, 440, -248},
    { 1184, 480, -216},
    { 1144, 488, -128},
    { 1176, 496, -136},
    { 1272, 504, -208},
    { 1232, 584, -152},
    { 1344, 800, -248},
    { 1136, 904, -168},
    { 1008, 896, -328},
    { 768, 608, -320},
    { 1064, 520, -192},
    { 1344, 608, -40},
    { 1664, 536, -48},
    { 1536, 344, -96},
    { 1440, 296, -88},
    { 1424, 328, -96},
    { 1352, 336, -152},
    { 1224, 328, -208},
    { 1120, 176, -200},
    { 1040, -40, -208},
    { 912, -112, -344},
    { 840, -160, -288},
    { 1232, -32, -120},
    { 1368, 248, -248},
    { 1328, 336, -240},
    { 1624, 304, -208},
    { 1800, 448, -312},
    { 1504, 480, -248},
    { 1296, 472, -176},
    { 1152, 496, -80},
    { 1040, 480, -184},
    { 1064, 432, -152},
    { 1000, 576, -240},
    { 1136, 808, -248},
    { 1056, 1032, -120},
    { 768, 904, -272},
    { 1248, 656, -208},
    { 1032, 640, -352},
    { 1208, 552, -208},
    { 1800, 712, -104},
    { -2016, 648, -72},
    { 1880, 440, -120},
    { 1792, 288, -128},
    { 1712, 312, -176},
    { 1520, 312, -296},
    { 1216, -8, -320},
    { 600, -432, -72},
    { 464, -280, -304},
    { 648, -56, -536},
    { 720, 0, -336},
    { 1344, 56, -64},
    { 1568, 216, -80},
    { 1760, 368, -80},
    { 1960, 512, -64},
    { 1816, 600, -120},
    { 1520, 512, -96},
    { 1464, 544, -8},
    { 1544, 520, 16},
    { 1368, 616, -48},
    { 1440, 1024, -184},
    { 912, 1760, -456},
    { 1184, 880, -168},
    { 792, 944, -160},
    { 1224, 744, -208},
    { 1096, 696, -368},
    { 1168, 624, -296},
    { 1656, 744, -112},
    { 2032, 672, -32},
    { 1912, 504, -88},
    { 1784, 392, -48},
    { 1704, 288, -72},
    { 1592, 336, -232},
    { 1368, 200, -376},
    { 1000, -296, -176},
    { 632, -496, -240},
    { 744, -472, -440},
    { 976, -416, -168},
    { 1600, 24, -152},
    { 1704, 240, -144},
    { 1952, 296, -56},
    { -1992, 432, -160},
    { 1936, 544, -120},
    { 1800, 592, -16},
    { 1664, 792, 224},
    { 1552, 696, -160},
    { 1360, 464, 8},
    { 1080, 856, -88},
    { 1152, 1288, -168},
    { 744, 1008, -24},
    { 1024, 992, -32},
    { 936, 856, -192},
    { 944, 608, -216},
    { 1408, 664, -56},
    { 1888, 664, 16},
    { 1936, 592, -56},
    { 1872, 520, -32},
    { 1960, 376, 8},
    { 1888, 352, -120},
    { 1648, 272, -216},
    { 1328, 112, -216},
    { 912, -152, -96},
    { 720, -288, -208},
    { 632, -272, -416},
    { 1120, -216, -208},
    { 1416, 104, -296},
    { 1528, 112, -104},
    { 1976, 288, -72},
    { 2024, 496, -208},
    { 1880, 544, -128},
    { 1720, 648, -16},
    { 1648, 768, 152},
    { 1672, 632, -120},
    { 1168, 480, -8},
    { 1040, 1000, -136},
    { 1056, 1368, 24},
    { 632, 704, -176},
    { 1040, 848, -144},
    { 1008, 720, -208},
    { 960, 592, -120},
    { 1416, 640, -16},
    { 1848, 632, 8},
    { 1824, 528, -56},
    { 1832, 424, -8},
    { 1880, 392, -16},
    { 1824, 408, -200},
    { 1576, 336, -336},
    { 1160, -56, -312},
    { 792, -624, -256},
    { 864, -544, -440},
    { 1072, -472, -216},
    { 1456, 16, -256},
    { 1424, 208, -192},
    { 1736, 272, -104},
    { 2000, 392, -184},
    { 1808, 488, -96},
    { 1688, 560, -8},
    { 1592, 752, 144},
    { 1680, 648, -144},
    { 1400, 648, 104},
    { 1072, 1248, 32},
    { 896, 1528, -136},
    { 880, 928, -128},
    { 1272, 808, -368},
    { 1032, 504, -296},
    { 1352, 544, -96},
    { 1696, 656, -80},
    { 1832, 704, -176},
    { 1848, 560, -112},
    { 1808, 336, 48},
    { 1688, 296, -16},
    { 1536, 336, -136},
    { 1312, 120, -224},
    { 760, -288, 24},
    { 760, -240, -112},
    { 856, -288, -224},
    { 1296, -104, -56},
    { 1432, 176, -152},
    { 1456, 232, -72},
    { 1856, 328, -104},
    { 1960, 448, -144},
    { 1832, 520, -112},
    { 1560, 656, -64},
    { 1360, 800, -184},
    { 1528, 392, -176},
    { 1224, 512, -24},
    { 1136, 1184, -232},
    { 1024, 1264, -168},
    { 1008, 888, -152},
    { 1040, 736, -264},
    { 936, 576, -272},
    { 1248, 632, -112},
    { 1712, 680, 16},
    { 1928, 608, -24},
    { 1768, 416, -64},
    { 1672, 328, 24},
    { 1608, 352, -16},
    { 1480, 384, -112},
    { 1312, 296, -216},
    { 1016, -72, -120},
    { 672, -296, -152},
    { 752, -208, -512},
    { 1184, -336, -128},
    { 1392, 104, -280},
    { 1568, 184, -232},
    { 1816, 280, -192},
    { 1952, 408, -272},
    { 1760, 488, -152},
    { 1616, 600, -136},
    { 1336, 760, -40},
    { 1504, 544, -216},
    { 1264, 656, -152},
    { 928, 1048, -184},
    { 1176, 1104, -160},
    { 840, 840, -88},
    { 1080, 904, -120},
    { 1224, 808, -200},
    { 1040, 672, -176},
    { 1408, 728, -40},
    { 2008, 704, 72},
    { 1888, 520, 48},
    { 1840, 376, 8},
    { 1800, 280, 32},
    { 1664, 384, -88},
    { 1488, 312, -232},
    { 952, -208, -104},
    { 640, -264, -144},
    { 816, -312, -416},
    { 952, -368, -248},
    { 1448, -328, -8},
    { 1496, 64, -160},
    { 1616, 208, -160},
    { 1896, 328, -224},
    { 1976, 504, -280},
    { 1968, 520, -168},
    { 1920, 720, -24},
    { 1680, 888, -136},
    { 1592, 544, -160},
    { 1144, 624, 16},
    { 1080, 776, 104},
    { 992, 816, 184},
    { 736, 1040, 144},
    { 992, 1184, -152},
    { 992, 616, -184},
    { 1048, 680, -96},
    { 1712, 832, 32},
    { -2000, 664, 32},
    { -2032, 336, 24},
    { 1896, 232, 56},
    { 1792, 312, -8},
    { 1744, 384, -56},
    { 1384, 368, -96},
    { 1144, 128, -32},
    { 928, -160, -40},
    { 624, -200, -240},
    { 920, -216, -144},
    { 1032, -56, -160},
    { 1216, 184, -168},
    { 1440, 280, -88},
    { 1712, 432, -320},
    { 1672, 544, -400},
    { 1640, 408, -120},
    { 1744, 528, -72},
    { 1664, 632, -104},
    { 1512, 696, -272},
    { 1168, 896, -280},
    { 1280, 1144, -168},
    { 960, 1032, -64},
    { 1216, 1048, -80},
    { 984, 856, -192},
    { 1032, 584, -192},
    { 1472, 688, -48},
    { 1864, 704, 16},
    { 1680, 576, 8},
    { 1704, 384, 24},
    { 1792, 288, 64},
    { 1776, 368, -16},
    { 1536, 312, -96},
    { 1200, 200, -104},
    { 1000, -64, -96},
    { 632, -216, -128},
    { 672, -56, -432},
    { 952, -120, -288},
    { 1264, 136, -376},
    { 1368, 120, -256},
    { 1768, 184, -264},
    { 1912, 368, -296},
    { 1792, 488, -248},
    { 1560, 528, -216},
    { 1392, 600, -72},
    { 1424, 480, -152},
    { 1376, 440, -72},
    { 1272, 640, 40},
    { 1264, 928, 224},
    { 832, 1184, 160},
    { 1080, 952, -32},
    { 752, 680, -128},
    { 720, 640, -136},
    { 1248, 760, 72},
    { 1776, 776, 136},
    { 1832, 544, 8},
    { 1784, 416, -8},
    { 1960, 344, 56},
    { 1952, 360, -96},
    { 1640, 336, -160},
    { 1232, 240, -176},
    { 1032, 160, -144},
    { 904, 152, -224},
    { 608, 88, -432},
    { 744, 552, -432},
    { 680, 1144, -984},
    { 200, 1232, -872},
    { 240, 928, -704},
    { 176, 672, -896},
    { -32, 544, -904},
    { -160, 440, -848},
    { -64, 328, -752},
    { -32, 344, -712},
    { -136, 440, -696},
    { -344, 488, -448},
    { -440, 592, -488},
    { -560, 712, -496},
    { -648, 872, -392},
    { -704, 1032, -56},
    { -568, 1168, 72},
    { -512, 1344, 168},
    { -424, 1184, 200},
    { -232, 800, -200},
    { -392, 720, -288},
    { -352, 760, -480},
    { -280, 848, -648},
    { -184, 280, -800},
    { -176, 456, -760},
    { -112, 408, -880},
    { -72, 264, -1040},
    { 128, 56, -1008},
    { 144, 8, -1064},
    { 104, -120, -1144},
    { 0, -152, -1088},
    { -48, -32, -1104},
    { -80, 96, -1120},
    { 40, -312, -960},
    { 0, -80, -1104},
    { 72, -80, -952},
    { 32, 0, -960},
    { -56, -72, -928},
    { -32, -88, -968},
    { -48, -72, -1048},
    { -40, -56, -1080},
    { -64, -8, -1072},
    { 48, -408, -928},
    { -216, -120, -1032},
    { 216, -376, -944},
    { -16, -184, -1040},
    { 8, -256, -1048},
    { -64, -168, -1016},
    { -56, -232, -920},
    { 448, 96, -1080},
    { 24, -368, -928},
    { -136, -424, -992},
    { 56, -184, -1048},
    { -72, -248, -1080},
    { -160, -112, -1008},
    { -96, -192, -1008},
    { -80, -184, -976},
    { -24, -208, -984},
    { -56, -216, -1008},
    { -48, -312, -1024},
    { -32, -232, -1000},
    { -48, -264, -1016},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}




// ----------------------------------------------------------------
// Sample captured: 2015-09-22 12:01:41 local
AccelRawData *activity_sample_100_steps_heather_3(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME walk_100_heather_3
  //> TEST_EXPECTED 100
  //> TEST_EXPECTED_MIN 90
  //> TEST_EXPECTED_MAX 115
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { 64, -200, -1032},
    { 40, -168, -1024},
    { 40, -192, -1032},
    { 0, -200, -1016},
    { 16, -176, -1000},
    { -32, -136, -1016},
    { -16, -168, -968},
    { -24, -216, -928},
    { 0, -232, -936},
    { -8, -232, -984},
    { 0, -184, -1048},
    { 16, -152, -1096},
    { 16, -96, -1096},
    { 16, -72, -1064},
    { 8, -104, -1000},
    { 16, -80, -1000},
    { 40, -112, -1032},
    { 72, -64, -984},
    { -32, -240, -1024},
    { 64, -80, -1016},
    { 168, -24, -992},
    { 144, -208, -1000},
    { 56, -80, -1048},
    { 8, -128, -1032},
    { -48, -216, -992},
    { -144, -152, -1000},
    { -248, -408, -1048},
    { 384, 40, -1280},
    { 320, -240, -1008},
    { 168, -200, -1000},
    { 72, -144, -992},
    { 96, -216, -1048},
    { 80, -152, -1064},
    { 120, -72, -1000},
    { -80, 0, -976},
    { -160, -40, -1008},
    { -120, -96, -864},
    { -120, -48, -864},
    { -48, -64, -888},
    { -104, -40, -896},
    { -208, 200, -976},
    { -200, 104, -976},
    { -200, 264, -1168},
    { -208, 112, -1296},
    { -240, 56, -1200},
    { -272, 96, -1104},
    { -288, 56, -1024},
    { -256, -8, -808},
    { -184, 48, -680},
    { -64, 80, -576},
    { 120, 88, -488},
    { 440, 128, -376},
    { 1040, 304, -80},
    { 1744, 456, -48},
    { 2024, 592, -264},
    { 1984, 728, -400},
    { 1680, 672, -280},
    { 1552, 424, -112},
    { 1560, 360, -344},
    { 1472, 416, -360},
    { 1336, 400, -288},
    { 1152, 544, -192},
    { 1072, 664, -232},
    { 1000, 704, -264},
    { 944, 696, -192},
    { 1088, 768, -240},
    { 1000, 784, -232},
    { 840, 648, -208},
    { 952, 624, -184},
    { 1216, 800, -256},
    { 1232, 608, -224},
    { 1648, 544, -112},
    { -1936, 440, -32},
    { 1944, 368, -72},
    { 1664, 368, -64},
    { 1424, 312, -48},
    { 1280, 288, -120},
    { 1128, 312, -112},
    { 1016, 280, -120},
    { 976, 232, -224},
    { 920, 176, -264},
    { 792, 112, -384},
    { 672, 64, -504},
    { 696, -16, -504},
    { 808, -16, -320},
    { 1032, 96, -368},
    { 1328, 264, -304},
    { 1800, 416, -440},
    { 1792, 512, -456},
    { 1440, 472, -288},
    { 1208, 416, -216},
    { 1152, 328, -144},
    { 1192, 392, -136},
    { 1120, 424, -128},
    { 984, 504, -104},
    { 1080, 648, -112},
    { 1072, 688, -128},
    { 904, 640, -152},
    { 1144, 696, -232},
    { 1016, 672, -320},
    { 760, 496, -344},
    { 1096, 512, -264},
    { 1368, 568, -272},
    { 1368, 504, -328},
    { 1360, 424, -320},
    { 1456, 360, -328},
    { 1536, 256, -320},
    { 1296, 216, -376},
    { 992, 192, -408},
    { 824, 168, -368},
    { 784, 152, -320},
    { 832, 152, -368},
    { 832, 136, -416},
    { 1136, 160, -288},
    { 1080, 224, -264},
    { 1120, 304, -376},
    { 1088, 264, -280},
    { 1376, 312, -120},
    { 1592, 392, -168},
    { 1432, 440, -128},
    { 1232, 488, -96},
    { 1080, 464, -56},
    { 1128, 464, -96},
    { 1120, 472, -88},
    { 1048, 544, -176},
    { 1064, 560, -184},
    { 1136, 632, -176},
    { 1256, 808, -216},
    { 840, 864, -392},
    { 568, 424, -432},
    { 784, 416, -296},
    { 1144, 560, -224},
    { 1608, 488, -216},
    { 1688, 256, -224},
    { 1456, 168, -248},
    { 1432, 224, -200},
    { 1352, 288, -208},
    { 1176, 296, -240},
    { 984, 224, -264},
    { 864, 192, -256},
    { 840, 144, -272},
    { 864, 120, -352},
    { 792, 72, -352},
    { 1048, 104, -296},
    { 1128, 208, -328},
    { 1272, 280, -456},
    { 1248, 336, -392},
    { 1464, 408, -256},
    { 1456, 416, -200},
    { 1272, 416, -256},
    { 1200, 368, -264},
    { 1152, 400, -208},
    { 1120, 368, -232},
    { 976, 368, -280},
    { 880, 384, -360},
    { 904, 512, -504},
    { 1104, 728, -760},
    { 1024, 1144, -656},
    { 1064, 648, -592},
    { 1080, 88, -384},
    { 1192, 264, -288},
    { 1464, 376, -128},
    { 1920, 432, -160},
    { 1968, 504, -56},
    { 2008, 552, -256},
    { 1824, 488, 168},
    { 1720, 672, 168},
    { 1624, 656, 320},
    { 1512, 520, 320},
    { 1376, 456, 272},
    { 1312, 416, 224},
    { 1280, 424, 200},
    { 1344, 448, 200},
    { 1400, 448, 144},
    { 1440, 456, 88},
    { 1496, 472, 0},
    { 1512, 432, -136},
    { 1520, 368, -472},
    { 1696, 312, -472},
    { 1704, 40, -656},
    { 1528, -304, -984},
    { 1288, -616, -1064},
    { 1064, -664, -952},
    { 1088, -392, -896},
    { 1128, -216, -896},
    { 1136, -56, -768},
    { 1088, -8, -544},
    { 1168, 80, -352},
    { 1224, 248, -256},
    { 1256, 464, -288},
    { 1232, 360, -296},
    { 1184, 344, -280},
    { 1120, 336, -280},
    { 1264, 472, -304},
    { 1200, 640, -272},
    { 920, 840, -280},
    { 1088, 1136, -336},
    { 912, 768, -272},
    { 864, 568, -304},
    { 1072, 624, -224},
    { 1472, 632, -104},
    { 1728, 552, -80},
    { 1696, 312, -80},
    { 1736, 256, -80},
    { 1672, 336, -64},
    { 1568, 384, -56},
    { 1408, 392, -104},
    { 1192, 288, -96},
    { 1040, 208, -104},
    { 928, 80, -208},
    { 704, -72, -328},
    { 768, -72, -488},
    { 848, -88, -360},
    { 880, 48, -392},
    { 1176, 144, -408},
    { 1536, 296, -544},
    { 1520, 336, -496},
    { 1336, 304, -368},
    { 1296, 384, -272},
    { 1360, 432, -232},
    { 1408, 456, -264},
    { 1232, 544, -296},
    { 1200, 672, -216},
    { 1344, 1080, -104},
    { 936, 1200, -400},
    { 1280, 696, -120},
    { 920, 880, -192},
    { 928, 592, -248},
    { 1184, 720, -152},
    { 1736, 752, -8},
    { 1896, 576, 16},
    { 1888, 352, -32},
    { 1784, 208, 0},
    { 1640, 296, 32},
    { 1552, 368, -120},
    { 1392, 360, -128},
    { 1224, 232, -200},
    { 848, -200, -104},
    { 552, -256, -392},
    { 840, -80, -456},
    { 944, -24, -272},
    { 1184, 152, -352},
    { 1464, 208, -456},
    { 1736, 248, -376},
    { 1648, 320, -256},
    { 1392, 392, -280},
    { 1320, 408, -240},
    { 1352, 504, -192},
    { 1400, 448, -184},
    { 1416, 568, -144},
    { 1448, 1048, -128},
    { 1104, 1432, -304},
    { 928, 568, -144},
    { 1088, 848, -152},
    { 984, 744, -208},
    { 1040, 680, -168},
    { 1456, 728, -96},
    { 1832, 680, -16},
    { 1856, 504, -24},
    { 1792, 248, -64},
    { 1672, 168, -64},
    { 1600, 312, -208},
    { 1568, 376, -384},
    { 1440, 72, -336},
    { 1032, -496, -16},
    { 824, -424, -360},
    { 944, -336, -328},
    { 1000, -200, -64},
    { 1360, 176, -240},
    { 1520, 216, -120},
    { 1872, 336, -152},
    { 1976, 512, -184},
    { 1880, 720, -128},
    { 1536, 984, 176},
    { 1640, 536, -352},
    { 1512, 560, -272},
    { 1552, 1352, -616},
    { 944, 1144, -320},
    { 880, 1080, -408},
    { 1160, 920, -296},
    { 1056, 808, -400},
    { 1328, 752, -272},
    { -2024, 648, -64},
    { -2048, 520, -88},
    { 1944, 424, -192},
    { 1992, 352, -96},
    { 1928, 376, -16},
    { 1728, 432, -136},
    { 1568, 384, -312},
    { 1240, -112, -104},
    { 664, -632, -112},
    { 840, -256, -480},
    { 1112, -264, -152},
    { 1528, 200, -368},
    { 1432, 120, -224},
    { 1776, 216, -152},
    { 1904, 320, -208},
    { 1864, 464, -192},
    { 1680, 744, -264},
    { 1592, 736, -240},
    { 1736, 512, -264},
    { 1632, 656, -144},
    { 1512, 1528, -368},
    { 1168, 984, -192},
    { 992, 1152, -304},
    { 696, 920, -360},
    { 1192, 584, -200},
    { 1608, 632, -64},
    { 1960, 608, -48},
    { 1952, 520, -128},
    { 1912, 528, -8},
    { 1760, 272, 56},
    { 1696, 368, -48},
    { 1496, 360, -16},
    { 1472, 280, -104},
    { 1240, -128, 48},
    { 632, -456, -72},
    { 1032, -128, -504},
    { 1000, -192, -296},
    { 1360, 136, -224},
    { 1480, 120, -232},
    { 1784, 248, -224},
    { 1784, 352, -224},
    { 1744, 496, -224},
    { 1544, 552, -192},
    { 1352, 752, -56},
    { 1536, 472, -272},
    { 1584, 464, -72},
    { 1648, 1040, -160},
    { 1040, 1320, -192},
    { 1136, 1104, -208},
    { 760, 1032, -328},
    { 864, 688, -280},
    { 1312, 608, -104},
    { 1792, 568, 0},
    { 1768, 456, -128},
    { 1744, 392, -216},
    { 1856, 304, -32},
    { 1832, 336, -56},
    { 1624, 384, -136},
    { 1352, 360, -184},
    { 1272, 112, -272},
    { 680, -488, 88},
    { 488, -216, -320},
    { 1056, -216, -232},
    { 1856, 168, -376},
    { 1680, 16, -208},
    { 1792, 112, -200},
    { 1496, 216, -264},
    { 1264, 368, -320},
    { 1360, 496, -352},
    { 1432, 488, -152},
    { 1432, 608, -112},
    { 1512, 600, -144},
    { 1648, 840, 0},
    { 1088, 1200, -192},
    { 1200, 792, -64},
    { 752, 1040, -136},
    { 864, 800, -184},
    { 1296, 704, -32},
    { 1824, 736, -24},
    { 1816, 528, -48},
    { 1728, 320, -48},
    { 1712, 160, 8},
    { 1680, 216, -120},
    { 1568, 384, -272},
    { 1456, 256, -288},
    { 1264, -120, -72},
    { 864, -384, -72},
    { 1056, -160, -240},
    { 1200, 40, -264},
    { 1224, 232, -192},
    { 1416, 248, -192},
    { 1696, 320, -208},
    { 1736, 384, -216},
    { 1576, 688, -224},
    { 1296, 656, -8},
    { 1120, 656, -344},
    { 1384, 256, -224},
    { 1320, 568, -152},
    { 1496, 1016, -208},
    { 1136, 960, -24},
    { 1304, 1024, -248},
    { 1032, 880, -352},
    { 784, 584, -344},
    { 1168, 568, -152},
    { 1776, 664, -8},
    { 1704, 392, -88},
    { 1680, 208, -128},
    { 1672, 208, -104},
    { 1640, 328, -120},
    { 1520, 424, -136},
    { 1376, 328, -176},
    { 1248, 232, -192},
    { 944, 120, -232},
    { 784, 0, -384},
    { 856, -96, -32},
    { 1312, 240, -360},
    { 1184, 184, -424},
    { 1352, 192, -296},
    { 1456, 168, -216},
    { 1440, 328, -248},
    { 1312, 456, -272},
    { 1168, 464, -248},
    { 1040, 488, -152},
    { 952, 432, -216},
    { 1136, 448, -256},
    { 1184, 512, -296},
    { 1032, 640, -288},
    { 1248, 1040, -344},
    { 1072, 784, -384},
    { 1208, 712, -240},
    { 848, 832, -352},
    { 776, 576, -272},
    { 1336, 688, -120},
    { 1992, 656, 48},
    { 1968, 440, 32},
    { 1832, 320, -128},
    { 1704, 272, 8},
    { 1592, 320, -56},
    { 1416, 384, -200},
    { 1200, 328, -280},
    { 1040, -32, -152},
    { 760, -400, -136},
    { 816, -136, -656},
    { 1080, -192, -312},
    { 1368, 64, -256},
    { 1544, 216, -424},
    { 1792, 264, -304},
    { 1896, 360, -320},
    { 1648, 480, -304},
    { 1544, 584, -216},
    { 1304, 760, -16},
    { 1512, 424, -216},
    { 1192, 400, -112},
    { 1216, 736, -8},
    { 1176, 1144, -80},
    { 784, 1000, -144},
    { 1144, 904, -96},
    { 960, 704, -232},
    { 848, 576, -224},
    { 1304, 736, -72},
    { 1848, 632, 8},
    { 1680, 496, -56},
    { 1608, 328, -72},
    { 1648, 224, 16},
    { 1584, 336, -64},
    { 1384, 416, -168},
    { 1136, 256, -288},
    { 1064, -8, -168},
    { 864, -264, -272},
    { 1104, -272, -248},
    { 1272, -72, -288},
    { 1312, 96, -352},
    { 1392, 176, -272},
    { 1656, 232, -248},
    { 1696, 336, -304},
    { 1640, 488, -248},
    { 1544, 536, -304},
    { 1336, 592, -24},
    { 1328, 544, -272},
    { 1248, 648, -104},
    { 1376, 1144, -120},
    { 952, 1008, -96},
    { 1160, 896, -144},
    { 1048, 800, -240},
    { 848, 616, -272},
    { 1200, 656, -120},
    { 1640, 648, 8},
    { 1696, 528, -16},
    { 1632, 304, -96},
    { 1608, 232, 0},
    { 1608, 312, -48},
    { 1464, 376, -152},
    { 1224, 344, -232},
    { 1152, 192, -208},
    { 904, -136, -144},
    { 808, -216, -416},
    { 1112, -136, -304},
    { 1136, 48, -344},
    { 1232, 136, -280},
    { 1472, 240, -296},
    { 1544, 320, -296},
    { 1488, 344, -280},
    { 1560, 456, -208},
    { 1608, 592, -128},
    { 1512, 632, -216},
    { 1320, 624, -256},
    { 1496, 1112, -408},
    { 1088, 992, -216},
    { 888, 808, -328},
    { 864, 1048, -256},
    { 840, 712, -256},
    { 1184, 584, -208},
    { 1784, 664, -72},
    { 1752, 536, -104},
    { 1624, 392, -152},
    { 1680, 288, -64},
    { 1720, 304, -72},
    { 1624, 448, -256},
    { 1440, 472, -304},
    { 1360, 64, -176},
    { 768, -776, 248},
    { 1056, -464, -160},
    { 1112, -200, -232},
    { 1288, 48, -264},
    { 1464, 80, -248},
    { 1672, -24, -272},
    { 1760, 88, -272},
    { 1864, 440, -328},
    { 1736, 720, -200},
    { 1392, 784, -320},
    { 1512, 344, -392},
    { 1512, 752, -352},
    { 1392, 1136, -440},
    { 928, 968, -352},
    { 1192, 1048, -400},
    { 896, 800, -440},
    { 1040, 584, -320},
    { 1608, 632, -128},
    { 1856, 584, -88},
    { 1752, 488, -240},
    { 1824, 352, -192},
    { 1848, 256, -48},
    { 1728, 352, -128},
    { 1448, 400, -216},
    { 1328, 184, -208},
    { 968, -224, 16},
    { 512, -280, -264},
    { 728, -128, -272},
    { 960, 88, -264},
    { 1056, 240, -360},
    { 1264, 192, -256},
    { 1640, 232, -208},
    { 1616, 376, -304},
    { 1456, 424, -304},
    { 1400, 592, -352},
    { 1424, 496, -224},
    { 1432, 496, -200},
    { 1528, 376, -216},
    { 1720, 784, -432},
    { 1072, 1520, -464},
    { 1336, 1056, -544},
    { 1008, 664, -488},
    { 808, 320, -296},
    { 1240, 408, -136},
    { 1576, 512, -112},
    { 1512, 408, -248},
    { 1544, 408, -280},
    { 1576, 216, -96},
    { 1512, 264, -88},
    { 1352, 344, -184},
    { 1192, 248, -160},
    { 1072, -24, -80},
    { 760, -272, -112},
    { 1056, -128, -256},
    { 1232, 112, -248},
    { 1280, 216, -304},
    { 1416, 232, -296},
    { 1608, 288, -272},
    { 1544, 312, -208},
    { 1488, 424, -216},
    { 1392, 544, -192},
    { 1240, 632, -152},
    { 1216, 616, -360},
    { 1312, 896, -400},
    { 1344, 1120, -368},
    { 1016, 888, -320},
    { 1376, 840, -312},
    { 1032, 672, -400},
    { 1144, 488, -272},
    { 1480, 552, -88},
    { 1720, 600, -40},
    { 1712, 448, -144},
    { 1664, 304, -96},
    { 1512, 240, -32},
    { 1408, 296, -88},
    { 1224, 304, -120},
    { 1104, 136, -192},
    { 872, -208, -64},
    { 664, -216, -184},
    { 840, 0, -456},
    { 1080, 72, -232},
    { 1232, 264, -224},
    { 1512, 272, -320},
    { 1752, 352, -328},
    { 1632, 448, -256},
    { 1488, 280, -216},
    { 1280, 504, -232},
    { 1280, 536, -256},
    { 1400, 408, -216},
    { 1256, 416, -280},
    { 1344, 616, -264},
    { 1208, 1120, -400},
    { 1000, 1128, -592},
    { 1224, 576, -440},
    { 864, 472, -392},
    { 1192, 424, -232},
    { 1752, 528, -128},
    { 1640, 400, -160},
    { 1536, 248, -216},
    { 1456, 120, -80},
    { 1448, 184, -104},
    { 1376, 216, -400},
    { 1336, 232, -352},
    { 1040, 56, 8},
    { 784, 112, -264},
    { 664, -32, -280},
    { 1024, 96, -352},
    { 1088, 360, -488},
    { 1128, 240, -248},
    { 1496, 232, -312},
    { 1512, 256, -272},
    { 1408, 336, -256},
    { 1296, 464, -240},
    { 1368, 456, -256},
    { 1440, 624, -312},
    { 1296, 784, -352},
    { 1368, 1168, -464},
    { 1096, 880, -272},
    { 1200, 864, -336},
    { 984, 856, -336},
    { 1040, 672, -288},
    { 1408, 584, -144},
    { 1720, 576, -40},
    { 1616, 480, -104},
    { 1560, 344, -136},
    { 1560, 264, -48},
    { 1512, 312, -72},
    { 1400, 344, -248},
    { 1232, 240, -328},
    { 1088, -136, -256},
    { 688, -416, -216},
    { 1016, -256, -344},
    { 1184, 24, -392},
    { 1248, 208, -408},
    { 1376, 192, -264},
    { 1736, 232, -208},
    { 1776, 384, -232},
    { 1680, 504, -256},
    { 1440, 680, -248},
    { 1264, 608, -288},
    { 1408, 328, -256},
    { 1328, 728, -208},
    { 1256, 1264, -384},
    { 1024, 1016, -320},
    { 1184, 944, -376},
    { 936, 768, -440},
    { 936, 520, -368},
    { 1400, 616, -200},
    { 2008, 680, -96},
    { 1944, 504, -80},
    { 1800, 328, -48},
    { 1752, 304, 40},
    { 1632, 304, 0},
    { 1384, 304, -112},
    { 1184, 128, -136},
    { 888, -176, -88},
    { 760, -216, -296},
    { 880, -328, -472},
    { 1040, -400, -136},
    { 1376, 32, -424},
    { 1384, 80, -336},
    { 1656, 192, -392},
    { 1776, 264, -336},
    { 1712, 400, -344},
    { 1576, 688, -144},
    { 1448, 656, -216},
    { 1480, 544, -192},
    { 1272, 504, -136},
    { 1296, 880, -208},
    { 1104, 1232, -256},
    { 1008, 840, -312},
    { 912, 1104, -264},
    { 856, 816, -264},
    { 1256, 688, -256},
    { 1664, 632, -120},
    { 1696, 488, -24},
    { 1632, 472, -64},
    { 1704, 432, -112},
    { 1848, 448, 16},
    { 1624, 96, 104},
    { 1344, 72, -176},
    { 1032, -176, -64},
    { 792, -288, -192},
    { 896, -288, -152},
    { 1136, -208, -144},
    { 1296, 40, -176},
    { 1448, 120, -304},
    { 1632, 136, -344},
    { 1520, 248, -248},
    { 1448, 328, -240},
    { 1520, 376, -248},
    { 1480, 568, -176},
    { 1448, 576, -192},
    { 1384, 792, -328},
    { 1384, 992, -368},
    { 1000, 840, -352},
    { 1272, 872, -392},
    { 984, 800, -416},
    { 872, 640, -352},
    { 1368, 584, -232},
    { 1720, 528, -136},
    { 1528, 384, -72},
    { 1544, 328, -96},
    { 1600, 280, -120},
    { 1560, 240, -152},
    { 1392, 192, -160},
    { 1160, 48, -208},
    { 936, -80, -112},
    { 720, -232, -144},
    { 920, -128, -184},
    { 1064, -72, -232},
    { 1248, 88, -232},
    { 1512, 56, -336},
    { 1712, 192, -320},
    { 1488, 304, -272},
    { 1328, 360, -312},
    { 1232, 464, -248},
    { 1280, 440, -104},
    { 1264, 472, -216},
    { 1168, 440, -248},
    { 1392, 736, -336},
    { 1016, 1320, -424},
    { 1240, 696, -304},
    { 1016, 976, -408},
    { 1000, 592, -344},
    { 1368, 640, -280},
    { 1720, 632, -192},
    { 1656, 568, -48},
    { 1504, 216, 24},
    { 1608, 296, 40},
    { 1520, 472, 112},
    { 1392, 160, -40},
    { 1192, 272, -80},
    { 1072, 0, -64},
    { 888, -56, -104},
    { 752, -136, -248},
    { 1048, -120, -184},
    { 1152, 32, -272},
    { 1296, 8, -208},
    { 1712, 128, -448},
    { 1768, 232, -432},
    { 1528, 264, -344},
    { 1328, 376, -248},
    { 1232, 504, -288},
    { 1224, 568, -272},
    { 1120, 712, -360},
    { 1072, 904, -480},
    { 1328, 872, -368},
    { 1000, 792, -288},
    { 1232, 832, -288},
    { 1144, 776, -264},
    { 1080, 704, -256},
    { 1616, 688, -168},
    { 1952, 600, -40},
    { 1800, 432, 24},
    { 1680, 280, 56},
    { 1584, 384, -112},
    { 1536, 176, -96},
    { 1320, 168, -160},
    { 1104, 88, -192},
    { 880, -160, -184},
    { 648, -320, -272},
    { 680, -280, -360},
    { 992, -104, -296},
    { 1304, 48, -360},
    { 1480, 112, -304},
    { 1848, 288, -400},
    { 1760, 376, -352},
    { 1488, 448, -304},
    { 1256, 432, -296},
    { 1192, 448, -360},
    { 1152, 448, -432},
    { 920, 560, -416},
    { 896, 896, -608},
    { 1080, 704, -528},
    { 968, 640, -400},
    { 1328, 784, -336},
    { 904, 672, -312},
    { 968, 512, -288},
    { 1336, 560, -216},
    { 1840, 552, -72},
    { 1712, 408, -72},
    { 1432, 280, -128},
    { 1304, 272, -240},
    { 1224, 240, -400},
    { 1040, 144, -440},
    { 776, -72, -456},
    { 440, -272, -336},
    { 400, -280, -392},
    { 536, -280, -368},
    { 688, -176, -440},
    { 888, -152, -104},
    { -2048, 176, 88},
    { -1936, 488, 16},
    { -1768, 488, -40},
    { -1840, 624, -240},
    { 1968, 544, -152},
    { 1704, 560, -280},
    { 1280, 392, -256},
    { 1176, 456, -264},
    { 1000, 872, -280},
    { 1008, 1224, -248},
    { 1168, 1072, -160},
    { 816, 936, -96},
    { 1120, 1064, -208},
    { 1000, 864, -264},
    { 1536, 600, -216},
    { -1872, 760, -96},
    { -1824, 752, 120},
    { -1960, 400, 56},
    { 2008, 248, -56},
    { 1872, 368, -72},
    { 1688, 280, -88},
    { 1384, 80, -96},
    { 1096, -136, -56},
    { 680, -408, -48},
    { 568, -304, -232},
    { 896, -216, -80},
    { 1304, 128, -240},
    { 1520, 72, -200},
    { 1888, 192, -352},
    { 1984, 256, -264},
    { 1840, 368, -232},
    { 1840, 472, -56},
    { 1504, 552, -208},
    { 1600, 600, -256},
    { 1456, 552, -224},
    { 1496, 800, -280},
    { 1256, 1320, -360},
    { 968, 968, -304},
    { 928, 1112, -248},
    { 792, 856, -320},
    { 1168, 720, -224},
    { 1680, 648, -160},
    { 1920, 536, -64},
    { 1800, 448, 16},
    { 1856, 336, 16},
    { 1904, 328, -48},
    { 1824, 248, -48},
    { 1552, 152, -104},
    { 1352, 24, -16},
    { 888, -304, -16},
    { 824, -320, -256},
    { 1064, -392, -96},
    { 1256, -32, -264},
    { 1328, 32, -176},
    { 1616, 120, -344},
    { 1736, 232, -336},
    { 1648, 384, -224},
    { 1640, 560, -328},
    { 1528, 616, -240},
    { 1464, 608, -224},
    { 1416, 712, -336},
    { 1472, 912, -496},
    { 1144, 1048, -440},
    { 1104, 976, -448},
    { 904, 912, -408},
    { 872, 672, -392},
    { 1312, 704, -272},
    { 1840, 816, -128},
    { -2032, 592, 8},
    { 1944, 352, 88},
    { 1776, 128, -72},
    { 1720, 320, -32},
    { 1560, 136, -112},
    { 1304, 120, -112},
    { 984, -208, -24},
    { 824, -312, 0},
    { 880, -376, -16},
    { 1096, -280, -160},
    { 1344, -104, -320},
    { 1280, 72, -160},
    { 1544, 80, -16},
    { 1672, 72, 0},
    { 1784, 336, -224},
    { 1776, 592, -304},
    { 1624, 672, -144},
    { 1392, 736, -176},
    { 1312, 456, -424},
    { 1640, 688, -320},
    { 1104, 1400, -624},
    { 1016, 944, -464},
    { 1056, 1024, -432},
    { 912, 632, -464},
    { 1232, 424, -312},
    { 1672, 496, -144},
    { 1816, 464, -152},
    { 1752, 432, -288},
    { 1840, 360, -192},
    { 1872, 288, -80},
    { 1736, 296, -152},
    { 1424, 312, -320},
    { 1192, 0, -360},
    { 832, -488, -32},
    { 600, -376, -336},
    { 960, -424, -312},
    { 1024, -168, -176},
    { 1408, 192, -280},
    { 1568, 168, -168},
    { 1928, 272, -192},
    { 2008, 408, -264},
    { 1928, 544, -176},
    { 1744, 720, 0},
    { 1568, 712, -288},
    { 1592, 528, -224},
    { 1336, 1272, -504},
    { 1152, 1408, -424},
    { 904, 1128, -432},
    { 1376, 1072, -336},
    { 1016, 760, -480},
    { 1080, 576, -384},
    { 1640, 656, -128},
    { 2032, 648, 0},
    { 1904, 472, -152},
    { 1880, 320, -56},
    { 1960, 328, -88},
    { 1864, 448, -80},
    { 1576, 344, -184},
    { 1304, 48, -208},
    { 808, -584, 72},
    { 536, -480, -384},
    { 912, -384, -288},
    { 1336, -168, -392},
    { 1472, 48, -504},
    { 1720, 40, -296},
    { 2040, 104, -272},
    { -2032, 288, -328},
    { 1952, 624, -368},
    { 1728, 768, -120},
    { 1728, 600, -328},
    { 1512, 480, -136},
    { 1304, 1104, -384},
    { 1168, 1336, -256},
    { 792, 992, -272},
    { 1080, 1000, -200},
    { 912, 664, -304},
    { 1128, 544, -232},
    { 1568, 616, -88},
    { 1912, 656, -64},
    { 1856, 568, -168},
    { 1856, 424, -24},
    { 1880, 344, -56},
    { 1784, 360, -136},
    { 1560, 344, -328},
    { 1328, 0, -304},
    { 888, -440, -48},
    { 688, -416, -360},
    { 968, -336, -272},
    { 1256, -72, -472},
    { 1224, 104, -472},
    { 1456, 80, -248},
    { 1784, 160, -208},
    { 1824, 368, -160},
    { 1808, 672, -184},
    { 1600, 712, -64},
    { 1720, 616, -104},
    { 1464, 568, -64},
    { 1384, 1032, -176},
    { 1080, 1472, -184},
    { 944, 1152, -96},
    { 1072, 1008, -208},
    { 920, 592, -320},
    { 1288, 632, -200},
    { 1792, 600, -56},
    { 1616, 576, -168},
    { 1632, 512, -208},
    { 1720, 376, -80},
    { 1768, 280, -64},
    { 1552, 360, -248},
    { 1464, 216, -296},
    { 1176, -184, -112},
    { 744, -400, -64},
    { 888, -184, -248},
    { 1248, -40, -272},
    { 1456, 216, -344},
    { 1584, 200, -208},
    { 1760, 224, -144},
    { 1704, 320, -200},
    { 1720, 488, -280},
    { 1616, 504, -144},
    { 1512, 640, -56},
    { 1456, 600, -144},
    { 1400, 520, -112},
    { 1488, 992, -280},
    { 1176, 1120, -160},
    { 1192, 1000, -200},
    { 696, 888, -384},
    { 680, 616, -320},
    { 1248, 568, -112},
    { 1872, 608, -24},
    { 1824, 456, -96},
    { 1824, 304, -192},
    { 1848, 232, 24},
    { 1584, 384, -120},
    { 1392, 240, -192},
    { 1224, 192, -240},
    { 1072, 64, -216},
    { 880, -152, -144},
    { 1032, -112, -232},
    { 1376, 88, -304},
    { 1320, 224, -320},
    { 1144, 152, -168},
    { 1352, 168, -96},
    { 1432, 368, -168},
    { 1416, 472, -176},
    { 1376, 600, -192},
    { 1328, 592, -128},
    { 1232, 672, -168},
    { 1472, 352, -256},
    { 1600, 560, -176},
    { 1368, 912, -168},
    { 928, 792, -200},
    { 1016, 776, -344},
    { 624, 712, -288},
    { 824, 552, -160},
    { 1328, 640, -64},
    { 2032, 568, -72},
    { 1784, 408, -136},
    { 1464, 328, -192},
    { 1376, 48, -24},
    { 1296, 240, -56},
    { 1288, 256, -136},
    { 1200, 176, -144},
    { 1224, 168, -176},
    { 928, -56, -88},
    { 1040, 56, -208},
    { 1048, 192, -248},
    { 1072, 288, -304},
    { 1088, 232, -232},
    { 1360, 176, -192},
    { 1472, 264, -192},
    { 1344, 408, -336},
    { 1168, 472, -400},
    { 1144, 440, -232},
    { 1144, 424, -184},
    { 1224, 528, -160},
    { 1496, 824, -184},
    { 1384, 1256, -224},
    { 1040, 920, -256},
    { 1240, 672, -232},
    { 872, 664, -296},
    { 992, 584, -168},
    { 1440, 600, -32},
    { 1648, 552, -8},
    { 1544, 368, -80},
    { 1440, 344, -56},
    { 1496, 296, -48},
    { 1512, 392, -64},
    { 1384, 344, -280},
    { 1224, 216, -296},
    { 1024, -72, -232},
    { 736, -288, -288},
    { 1024, -160, -336},
    { 1072, 8, -352},
    { 1096, 136, -280},
    { 1256, 208, -248},
    { 1536, 312, -264},
    { 1512, 400, -312},
    { 1432, 440, -280},
    { 1320, 592, -256},
    { 1256, 648, -248},
    { 1288, 640, -400},
    { 1104, 752, -296},
    { 1272, 992, -232},
    { 1064, 960, -152},
    { 1312, 944, -184},
    { 1000, 648, -264},
    { 888, 504, -216},
    { 1376, 608, -72},
    { 1776, 512, -40},
    { 1704, 360, -112},
    { 1536, 360, -152},
    { 1504, 312, -136},
    { 1368, 352, -144},
    { 1152, 304, -352},
    { 928, 160, -320},
    { 856, -72, -272},
    { 688, -248, -312},
    { 944, -72, -264},
    { 1216, 136, -376},
    { 1128, 200, -320},
    { 1416, 224, -256},
    { 1720, 296, -272},
    { 1608, 432, -280},
    { 1408, 416, -200},
    { 1312, 536, -152},
    { 1352, 560, -240},
    { 1368, 488, -160},
    { 1120, 656, -80},
    { 1184, 984, -112},
    { 848, 1008, -104},
    { 1200, 784, -120},
    { 904, 680, -184},
    { 1000, 560, -112},
    { 1440, 576, -80},
    { 1736, 576, -96},
    { 1680, 392, -112},
    { 1560, 296, -112},
    { 1512, 280, -152},
    { 1408, 272, -176},
    { 1200, 224, -280},
    { 968, 24, -176},
    { 872, -176, -224},
    { 848, -208, -304},
    { 1360, 24, -232},
    { 1200, 96, -312},
    { 1280, 184, -240},
    { 1544, 256, -248},
    { 1544, 328, -304},
    { 1448, 432, -368},
    { 1392, 472, -184},
    { 1384, 560, -80},
    { 1360, 568, -224},
    { 1136, 504, -80},
    { 1360, 832, -168},
    { 992, 1120, -32},
    { 1128, 1128, -112},
    { 1008, 736, -176},
    { 800, 488, -240},
    { 1240, 584, -144},
    { 1592, 616, -32},
    { 1584, 528, -112},
    { 1568, 384, -136},
    { 1632, 328, -80},
    { 1600, 344, -112},
    { 1376, 344, -280},
    { 1168, 184, -232},
    { 1112, -16, -208},
    { 728, -248, -264},
    { 1016, -80, -392},
    { 1296, 48, -488},
    { 1136, 56, -264},
    { 1312, 64, -208},
    { 1416, 208, -224},
    { 1344, 296, -248},
    { 1344, 376, -256},
    { 1440, 392, -184},
    { 1568, 480, -80},
    { 1544, 552, -96},
    { 1304, 728, 32},
    { 1456, 1408, -640},
    { 968, 992, -88},
    { 960, 1160, -288},
    { 848, 904, -328},
    { 744, 664, -280},
    { 1184, 576, -120},
    { 1768, 584, -24},
    { 1744, 512, -160},
    { 1808, 464, -256},
    { 1856, 384, -96},
    { 1744, 392, -88},
    { 1456, 272, -240},
    { 1152, 48, -296},
    { 1024, -368, -112},
    { 736, -512, -320},
    { 1080, -400, -240},
    { 1096, -224, -280},
    { 1216, -24, -304},
    { 1480, 88, -224},
    { 1664, 176, -328},
    { 1616, 240, -264},
    { 1816, 352, -120},
    { 1848, 640, -56},
    { 1904, 808, 48},
    { 1520, 920, -184},
    { 1424, 1168, -360},
    { 1120, 1152, -40},
    { 1056, 1184, -128},
    { 800, 1000, -320},
    { 792, 680, -280},
    { 1336, 616, -112},
    { 1768, 568, -56},
    { 1704, 512, -144},
    { 1728, 464, -184},
    { 1808, 376, -56},
    { 1760, 392, -56},
    { 1568, 336, -152},
    { 1400, 216, -264},
    { 1192, -184, -104},
    { 816, -360, -160},
    { 1056, -200, -328},
    { 1144, -176, -264},
    { 1352, 160, -312},
    { 1384, 152, -176},
    { 1664, 272, -216},
    { 1680, 344, -280},
    { 1672, 440, -288},
    { 1576, 664, -160},
    { 1424, 712, -16},
    { 1448, 528, -304},
    { 1512, 672, -152},
    { 1256, 1256, -288},
    { 968, 1128, -256},
    { 1024, 1072, -256},
    { 736, 800, -288},
    { 1152, 520, -176},
    { 1536, 616, -64},
    { 1744, 512, -96},
    { 1632, 440, -176},
    { 1720, 384, -104},
    { 1800, 384, -48},
    { 1728, 400, -136},
    { 1464, 336, -272},
    { 1320, 48, -296},
    { 824, -344, -144},
    { 744, -264, -552},
    { 1136, -224, -360},
    { 1312, -16, -352},
    { 1328, 56, -312},
    { 1464, 176, -216},
    { 1560, 280, -216},
    { 1576, 400, -216},
    { 1624, 544, -184},
    { 1608, 624, -96},
    { 1464, 776, -32},
    { 1400, 504, -296},
    { 1424, 816, -88},
    { 1200, 1600, -224},
    { 816, 1184, -128},
    { 1032, 1432, -248},
    { 1064, 872, -320},
    { 1384, 528, -240},
    { 2008, 584, -96},
    { -1952, 664, -96},
    { 2032, 616, -200},
    { 1960, 408, 8},
    { 1824, 360, -24},
    { 1704, 408, -96},
    { 1408, 208, -208},
    { 944, -304, 32},
    { 616, -432, -88},
    { 728, -280, -512},
    { 1080, -440, -120},
    { 1440, 32, -240},
    { 1592, 160, -184},
    { 1976, 256, -152},
    { -1864, 432, -320},
    { -2040, 560, -264},
    { 1904, 664, -176},
    { 1640, 808, -136},
    { 1824, 320, -136},
    { 1536, 768, 88},
    { 1488, 1656, -48},
    { 944, 1400, -88},
    { 976, 1376, -152},
    { 968, 992, -272},
    { 1064, 752, -288},
    { 1528, 696, -88},
    { -2000, 600, 24},
    { -2032, 560, -112},
    { 2032, 480, -160},
    { -2032, 400, 16},
    { 2016, 424, -16},
    { 1752, 408, -80},
    { 1496, 128, -232},
    { 976, -392, 8},
    { 696, -488, -216},
    { 832, -472, -496},
    { 1064, -416, -120},
    { 1584, 184, -360},
    { 1592, 120, -152},
    { -2040, 240, -200},
    { -1920, 408, -296},
    { 2040, 560, -224},
    { 1800, 776, -248},
    { 1744, 624, -248},
    { 1792, 344, -120},
    { 1592, 856, 152},
    { 1360, 1816, 40},
    { 800, 1384, 40},
    { 928, 1376, -240},
    { 936, 800, -368},
    { 1312, 696, -200},
    { 2000, 688, -16},
    { -1944, 616, -80},
    { 2008, 560, -232},
    { -2032, 376, -80},
    { 1968, 368, 8},
    { 1808, 448, -96},
    { 1520, 280, -232},
    { 1296, -248, -64},
    { 920, -768, 0},
    { 808, -504, -424},
    { 1200, -568, -120},
    { 1600, 56, -384},
    { 1664, 152, -184},
    { -1992, 256, -176},
    { -1600, 392, -264},
    { -1672, 608, -192},
    { 1848, 1184, 120},
    { 1776, 416, -408},
    { 1720, 176, -56},
    { 1536, 1040, 112},
    { 1088, 1744, 8},
    { 776, 1184, 136},
    { 664, 1176, -8},
    { 872, 816, -160},
    { 1264, 696, -104},
    { 1912, 848, -16},
    { -1920, 664, 24},
    { -2032, 560, -56},
    { -1992, 344, 0},
    { 2000, 320, 48},
    { 1968, 368, -80},
    { 1696, 288, -144},
    { 1456, 8, -176},
    { 888, -584, 8},
    { 832, -336, -360},
    { 1144, -496, -272},
    { 1512, 56, -352},
    { 1544, 56, -200},
    { 1816, 160, -176},
    { 1944, 312, -256},
    { 1912, 456, -136},
    { 1768, 664, -216},
    { 1480, 848, -64},
    { 1608, 416, -304},
    { 1624, 520, -8},
    { 1472, 1384, -176},
    { 880, 1168, -104},
    { 1088, 1192, -128},
    { 776, 960, -224},
    { 1024, 704, -176},
    { 1592, 720, -72},
    { -2048, 656, 0},
    { 2016, 560, -72},
    { 1976, 400, -80},
    { 1936, 328, -8},
    { 1856, 432, -96},
    { 1624, 376, -272},
    { 1424, 72, -272},
    { 952, -472, -112},
    { 656, -456, -408},
    { 936, -384, -592},
    { 984, -296, -136},
    { 1536, 272, -256},
    { 1688, 232, -200},
    { 1952, 336, -192},
    { 2008, 480, -232},
    { 1888, 552, -184},
    { 1680, 664, -144},
    { 1584, 584, -272},
    { 1560, 400, -168},
    { 1288, 928, -160},
    { 1128, 1432, -192},
    { 856, 1096, -96},
    { 1072, 1272, -208},
    { 816, 800, -272},
    { 1376, 648, -256},
    { 2008, 832, -88},
    { -1784, 712, -40},
    { -1776, 352, -96},
    { -1944, 184, 80},
    { 1832, 376, -24},
    { 1744, 736, -120},
    { 1600, 672, 24},
    { 1360, 576, 128},
    { 1032, 560, -72},
    { 648, 520, -240},
    { 336, 536, -440},
    { 192, 552, -352},
    { -16, 712, -408},
    { 56, 744, -472},
    { 208, 968, -464},
    { 152, 1112, -280},
    { -40, 1112, -128},
    { -240, 1024, 136},
    { -472, 936, 160},
    { -616, 944, 376},
    { -840, 752, 376},
    { -928, 920, 104},
    { -1048, 1056, 96},
    { -816, 1216, 128},
    { -744, 1152, 24},
    { -752, 1080, -80},
    { -592, 1080, -256},
    { -456, 1232, -448},
    { -352, 960, -464},
    { -152, 432, -496},
    { -224, 648, -632},
    { -128, 592, -832},
    { -40, 368, -896},
    { 32, 240, -888},
    { 88, 96, -1032},
    { 112, -104, -1024},
    { 152, -136, -1072},
    { 656, -792, -1048},
    { 8, -176, -1096},
    { 16, -120, -1064},
    { -344, 232, -1192},
    { 224, -536, -928},
    { -32, -272, -1032},
    { 24, -288, -880},
    { -48, -320, -960},
    { -80, -272, -912},
    { -24, -288, -928},
    { -32, -336, -952},
    { -64, -320, -936},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}




// ----------------------------------------------------------------
// Sample captured: 2015-09-22 12:02:46 local
AccelRawData *activity_sample_100_steps_heather_4(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME walk_100_heather_4
  //> TEST_EXPECTED 100
  //> TEST_EXPECTED_MIN 75
  //> TEST_EXPECTED_MAX 115
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { -104, -96, -1040},
    { -56, -144, -1008},
    { -80, -104, -1024},
    { -96, -120, -1000},
    { -112, -104, -1008},
    { -104, -104, -1008},
    { -96, -112, -1024},
    { -88, -112, -1032},
    { -80, -120, -1024},
    { -96, -104, -1032},
    { -104, -120, -1008},
    { -112, -112, -1016},
    { -112, -120, -1000},
    { -128, -88, -1000},
    { -104, -96, -1016},
    { -80, -64, -1032},
    { -104, -80, -1016},
    { -104, -152, -1032},
    { -112, -136, -1016},
    { -96, -144, -1000},
    { -152, -104, -1016},
    { -152, -88, -1016},
    { -112, -80, -992},
    { -56, -120, -1032},
    { -72, -120, -1032},
    { -104, -88, -1040},
    { -120, -64, -1048},
    { -152, -72, -1016},
    { -176, -72, -1016},
    { -160, -72, -1008},
    { -152, -80, -1024},
    { -144, -64, -1024},
    { -152, -64, -1000},
    { -144, -80, -992},
    { -144, -64, -1000},
    { -112, -80, -992},
    { -128, -72, -984},
    { -136, -80, -968},
    { -96, -88, -968},
    { 16, -160, -984},
    { -128, -32, -1008},
    { -424, -336, -952},
    { -120, -56, -1056},
    { -136, -96, -1064},
    { -104, -128, -1064},
    { -112, -200, -1000},
    { -112, -192, -928},
    { -128, -176, -912},
    { -128, -160, -896},
    { -136, -152, -912},
    { -128, -120, -968},
    { -120, -80, -1032},
    { -128, -56, -1072},
    { -152, 40, -1184},
    { -48, 272, -1392},
    { 72, 240, -1416},
    { -80, 104, -1136},
    { -200, 296, -1008},
    { -168, 304, -1008},
    { -32, 248, -1048},
    { -72, 128, -880},
    { -216, 176, -752},
    { -216, 192, -776},
    { -120, 88, -888},
    { -48, 80, -968},
    { -96, 8, -992},
    { -176, -32, -992},
    { -168, -16, -1088},
    { -152, -64, -1184},
    { -104, 24, -1248},
    { 40, 96, -1312},
    { 184, 320, -1336},
    { 328, 264, -1208},
    { 312, 168, -1008},
    { 248, 264, -920},
    { 208, 152, -824},
    { 80, 88, -728},
    { -64, 144, -608},
    { -224, 288, -736},
    { -352, 328, -992},
    { -352, 176, -1008},
    { -344, 264, -1072},
    { -344, 232, -944},
    { -256, 272, -1000},
    { -272, 760, -1128},
    { -344, 792, -1144},
    { -312, 800, -968},
    { -392, 880, -760},
    { -448, 960, -584},
    { -288, 760, -400},
    { -208, 528, -312},
    { -192, 264, -448},
    { -320, 152, -664},
    { -400, 72, -864},
    { -248, 80, -1000},
    { 24, 136, -904},
    { 496, 8, -944},
    { 1056, 104, -704},
    { 1872, 288, -216},
    { -1968, 576, 128},
    { 2008, 752, 240},
    { 1664, 888, -248},
    { 1344, 464, -96},
    { 1280, 456, 64},
    { 1104, 576, -8},
    { 1088, 336, 120},
    { 1128, 296, 112},
    { 1232, 480, 160},
    { 1168, 608, 48},
    { 1336, 712, -72},
    { 1512, 1024, -112},
    { 768, 1656, -464},
    { 1216, 800, -352},
    { 928, 880, -552},
    { 856, 776, -448},
    { 1208, 736, -128},
    { 1696, 840, 112},
    { -2000, 568, 296},
    { 1976, 544, 472},
    { 1672, 128, 744},
    { 960, -440, 240},
    { 1544, 216, -176},
    { 1104, 352, -272},
    { 928, 352, -176},
    { 1024, 64, -136},
    { 752, -344, -168},
    { 1008, -288, -208},
    { 1088, 136, -360},
    { 1064, 176, -432},
    { 1112, 112, -192},
    { 1304, 168, -88},
    { 1384, 320, -176},
    { 1496, 456, -240},
    { 1656, 592, 64},
    { 1512, 664, -48},
    { 1408, 752, -152},
    { 1088, 456, -256},
    { 1408, 928, -272},
    { 1200, 1080, -104},
    { 1072, 880, -152},
    { 1056, 760, -232},
    { 864, 712, -328},
    { 920, 552, -184},
    { 1352, 584, -32},
    { 1744, 504, 64},
    { 1688, 408, 0},
    { 1624, 312, -24},
    { 1552, 224, 32},
    { 1480, 288, -8},
    { 1320, 320, -72},
    { 1136, 248, -200},
    { 1048, 88, -248},
    { 792, -408, -136},
    { 728, -328, -504},
    { 1168, -224, -384},
    { 1328, 32, -440},
    { 1288, 96, -304},
    { 1528, 160, -224},
    { 1608, 280, -176},
    { 1512, 408, -184},
    { 1384, 480, -208},
    { 1336, 456, -56},
    { 1472, 496, -64},
    { 1408, 432, -152},
    { 1088, 656, -256},
    { 1432, 1464, -520},
    { 800, 1144, -528},
    { 1264, 832, -472},
    { 1024, 464, -536},
    { 1080, 360, -464},
    { 1408, 368, -168},
    { 1712, 384, -120},
    { 1616, 432, -248},
    { 1672, 384, -192},
    { 1656, 272, -8},
    { 1592, 328, -8},
    { 1424, 416, -120},
    { 1128, 200, -312},
    { 920, -224, -32},
    { 712, -272, -448},
    { 848, -168, -448},
    { 968, -120, -400},
    { 1128, -24, -528},
    { 1216, -48, -336},
    { 1568, 48, -160},
    { 1728, 304, -272},
    { 1568, 480, -352},
    { 1560, 496, -344},
    { 1496, 496, -216},
    { 1424, 376, -232},
    { 1304, 280, -360},
    { 1344, 752, -504},
    { 1240, 1048, -736},
    { 1056, 688, -576},
    { 1280, 776, -552},
    { 856, 448, -480},
    { 1008, 200, -280},
    { 1424, 472, -112},
    { 1760, 456, -144},
    { 1728, 440, -280},
    { 1688, 416, -192},
    { 1720, 520, -152},
    { 1648, 584, -256},
    { 1528, 816, -520},
    { 1424, 848, -752},
    { 1360, 896, -880},
    { 1048, 976, -1112},
    { 768, 752, -800},
    { 240, 536, -624},
    { 152, 280, -392},
    { -56, -24, -112},
    { -272, -120, -160},
    { -456, -192, -256},
    { -432, -448, -336},
    { -368, -544, -336},
    { -376, -552, -376},
    { -528, -416, -312},
    { -704, -376, -368},
    { -1048, -496, -360},
    { -1152, -512, -400},
    { -1192, -464, -456},
    { -1176, -496, -120},
    { -1072, -128, -112},
    { -816, 176, -56},
    { -832, -16, -72},
    { -904, 96, -16},
    { -784, 80, -104},
    { -752, 120, -200},
    { -736, 192, -256},
    { -744, 96, -256},
    { -856, -160, -200},
    { -1096, -136, -280},
    { -1312, -168, -280},
    { -1488, -72, -192},
    { -1440, -104, -272},
    { -1240, 200, -232},
    { -920, 536, -184},
    { -608, 264, -336},
    { -496, 128, -360},
    { -480, 136, -232},
    { -456, 32, -152},
    { -504, 48, -120},
    { -648, -96, -64},
    { -888, -344, -120},
    { -1184, -432, -96},
    { -1544, -416, -96},
    { -1440, -176, -128},
    { -1544, -256, -32},
    { -1336, 32, 192},
    { -1096, 288, 336},
    { -848, 152, 320},
    { -704, 16, 232},
    { -488, 72, 48},
    { -416, 64, -80},
    { -544, 80, -72},
    { -728, 136, 72},
    { -888, 56, 40},
    { -1080, -40, -152},
    { -1344, -56, -224},
    { -1328, -144, -264},
    { -1424, 56, -408},
    { -1400, 16, -288},
    { -1216, 472, -96},
    { -816, 648, -312},
    { -592, 368, -280},
    { -568, 216, -296},
    { -520, 160, -184},
    { -560, 96, -136},
    { -584, -8, -104},
    { -672, -56, -16},
    { -832, -112, 32},
    { -1032, -176, -56},
    { -1328, -200, -56},
    { -1496, -128, -24},
    { -1352, -144, -56},
    { -1400, 48, 16},
    { -1208, 448, 240},
    { -840, 400, 200},
    { -760, 248, 224},
    { -776, 240, 240},
    { -528, 184, 8},
    { -480, 112, -168},
    { -560, 128, -168},
    { -800, 192, -48},
    { -1000, 16, 0},
    { -1144, 40, -104},
    { -1408, 32, -64},
    { -1400, 56, -160},
    { -1472, 264, -184},
    { -1200, 200, -104},
    { -952, 528, -248},
    { -704, 528, -376},
    { -584, 376, -408},
    { -536, 328, -392},
    { -504, 160, -256},
    { -568, 120, -224},
    { -648, 88, -192},
    { -784, 48, -104},
    { -944, -24, -120},
    { -1112, -88, -104},
    { -1368, -96, -64},
    { -1328, -72, -120},
    { -1520, -16, -144},
    { -1376, 272, -80},
    { -1048, 560, -96},
    { -840, 392, 64},
    { -712, 240, 96},
    { -608, 264, 0},
    { -488, 200, -144},
    { -504, 152, -176},
    { -656, 128, -128},
    { -864, 152, -120},
    { -1040, 128, -256},
    { -1144, 104, -296},
    { -1216, 32, -376},
    { -1200, 104, -496},
    { -1240, 32, -440},
    { -864, -168, -296},
    { -208, -272, -264},
    { 608, -8, -400},
    { 992, 240, -248},
    { 1008, 328, -88},
    { 1296, 296, -16},
    { 1792, 360, 120},
    { -1336, 368, 360},
    { -256, 1016, 224},
    { -1192, 1464, -776},
    { 1576, 720, -456},
    { -1568, -16, -88},
    { 1760, 784, -440},
    { 1264, 1896, -1112},
    { 1080, 1120, -1144},
    { 744, 528, -712},
    { 1232, 264, -336},
    { 1600, 416, -64},
    { 1656, 408, 0},
    { 1648, 312, -256},
    { 1776, 400, -40},
    { 1792, 256, -24},
    { 1640, 392, 24},
    { 1336, 520, 0},
    { 1224, 416, -64},
    { 1152, 16, 8},
    { 648, -600, 32},
    { 632, -88, -208},
    { 1064, 48, -176},
    { 1128, 184, -352},
    { 1176, 120, -336},
    { 1392, 96, -120},
    { 1440, 96, -24},
    { 1448, 152, -32},
    { 1608, 264, -136},
    { 1792, 368, -200},
    { 1848, 520, -216},
    { 1416, 472, -384},
    { 1600, 1016, -728},
    { 1088, -1464, -920},
    { 904, 672, -496},
    { 1592, 264, -520},
    { 1192, 88, -456},
    { 1184, 208, -168},
    { 1592, 528, -40},
    { 1744, 728, -304},
    { 1944, 536, -248},
    { 1624, 88, 0},
    { 1480, 240, -40},
    { 1400, 360, -8},
    { 1232, 344, -176},
    { 1080, 152, -240},
    { 872, -456, 32},
    { 528, -480, -336},
    { 928, -256, -200},
    { 1392, 88, -360},
    { 1360, 168, -368},
    { 1728, 64, -64},
    { -1800, 248, -72},
    { 1984, 568, -216},
    { 1512, 608, -320},
    { 1296, 528, -152},
    { 1496, 216, -152},
    { 1536, 360, -152},
    { 1240, 824, -192},
    { 1336, 1520, -184},
    { 784, 888, -160},
    { 1080, 592, -80},
    { 944, 728, -224},
    { 944, 656, -192},
    { 1336, 672, -72},
    { 1840, 712, 32},
    { -2032, 544, 48},
    { 1912, 368, 24},
    { 1872, 240, 88},
    { 1760, 160, 32},
    { 1560, 192, -304},
    { 1400, 136, -600},
    { 1000, -496, -112},
    { 544, -488, -72},
    { 536, -128, -584},
    { 1032, -40, -320},
    { 1320, 160, -104},
    { 1472, 288, -128},
    { 1608, 312, 48},
    { 1928, 376, 152},
    { 1944, 512, 88},
    { 1848, 544, -48},
    { 1640, 776, 32},
    { 1608, 624, -232},
    { 1592, 696, -96},
    { 1336, 1312, -144},
    { 1112, 1456, -112},
    { 864, 1200, -40},
    { 1128, 1104, -80},
    { 1008, 808, -160},
    { 1280, 616, -152},
    { 1664, 680, 32},
    { -2040, 752, 144},
    { 1992, 640, 48},
    { 1984, 440, 48},
    { 2008, 264, 96},
    { 1848, 256, -32},
    { 1536, 288, -208},
    { 1256, 48, -256},
    { 728, -552, 48},
    { 336, -456, -432},
    { 848, -352, -472},
    { 1232, -152, -432},
    { 1560, 72, -336},
    { 1696, 88, -120},
    { -1832, 240, -112},
    { -1936, 496, -144},
    { 1824, 648, -144},
    { 1528, 776, 24},
    { 1624, 408, -256},
    { 1528, 312, -48},
    { 1248, 872, -96},
    { 1272, 1624, -208},
    { 848, 1040, -40},
    { 1152, 1128, -48},
    { 928, 840, -168},
    { 1152, 616, -144},
    { 1600, 656, -8},
    { 1992, 680, 72},
    { 2024, 632, 32},
    { 2000, 472, 32},
    { 2040, 304, 104},
    { 1880, 280, 24},
    { 1600, 328, -152},
    { 1304, 184, -224},
    { 1032, -304, -8},
    { 440, -536, -88},
    { 576, -280, -648},
    { 1016, -256, -328},
    { 1304, 32, -272},
    { 1584, 96, -160},
    { 1952, 160, -32},
    { -1944, 384, -128},
    { 1936, 528, -152},
    { 1648, 648, -104},
    { 1472, 664, -128},
    { 1688, 368, -136},
    { 1488, 584, -8},
    { 1320, 1272, -208},
    { 1024, 1576, -224},
    { 936, 960, -216},
    { 1168, 1016, -224},
    { 1088, 688, -336},
    { 1224, 592, -240},
    { 1760, 688, -32},
    { -2008, 664, 80},
    { -2040, 560, 16},
    { -2048, 384, 8},
    { 1968, 256, 144},
    { 1840, 336, 24},
    { 1544, 328, -104},
    { 1296, 144, -192},
    { 896, -480, 24},
    { 272, -496, -192},
    { 824, -224, -528},
    { 1144, -160, -264},
    { 1424, 128, -264},
    { 1480, 112, -152},
    { 1928, 152, -56},
    { -1984, 384, -96},
    { 1968, 544, -152},
    { 1744, 720, -280},
    { 1568, 608, -216},
    { 1712, 272, -192},
    { 1480, 464, -16},
    { 1392, 1056, -88},
    { 1064, 1576, -168},
    { 984, 1088, -64},
    { 960, 984, -200},
    { 888, 664, -248},
    { 1248, 536, -128},
    { 1720, 704, 32},
    { 1984, 672, 72},
    { 1992, 544, 8},
    { -2040, 344, 48},
    { 1992, 224, 88},
    { 1824, 288, -40},
    { 1488, 280, -280},
    { 1264, -16, -224},
    { 728, -608, 136},
    { 384, -280, -344},
    { 1120, -80, -448},
    { 1224, 48, -376},
    { 1224, 96, -248},
    { 1408, 72, -88},
    { 1824, 200, -24},
    { 1984, 440, -192},
    { 1904, 600, -248},
    { 1576, 688, -184},
    { 1640, 616, -232},
    { 1672, 272, -144},
    { 1360, 664, -152},
    { 1456, 1528, -432},
    { 800, 1072, -288},
    { 1136, 1032, -304},
    { 888, 656, -280},
    { 1080, 400, -192},
    { 1504, 464, -64},
    { 1904, 576, -40},
    { 1832, 544, -136},
    { 1888, 392, -104},
    { 1768, 232, 80},
    { 1616, 336, -32},
    { 1392, 360, -224},
    { 1232, 152, -280},
    { 960, -376, -8},
    { 688, -448, -312},
    { 920, -312, -360},
    { 1320, -144, -264},
    { 1336, 112, -328},
    { 1440, 120, -128},
    { 1776, 184, -96},
    { 1880, 328, -176},
    { 1744, 488, -128},
    { 1592, 656, -48},
    { 1616, 640, -200},
    { 1688, 368, -112},
    { 1224, 656, 32},
    { 1280, 1464, -272},
    { 824, 1192, -96},
    { 1232, 952, -112},
    { 872, 744, -280},
    { 1184, 576, -288},
    { 1576, 632, -88},
    { 1928, 696, -8},
    { 1816, 568, -40},
    { 1896, 344, 40},
    { 1944, 232, 128},
    { 1848, 256, 40},
    { 1640, 288, -72},
    { 1504, 240, -216},
    { 1088, -248, -56},
    { 384, -624, -56},
    { 856, -472, -312},
    { 1088, -304, -280},
    { 1392, 88, -336},
    { 1472, 136, -136},
    { 1688, 176, -72},
    { 1672, 216, -128},
    { 1744, 360, -128},
    { 1752, 528, -96},
    { 1768, 680, 0},
    { 1680, 576, -288},
    { 1480, 792, -232},
    { 1376, 1488, -504},
    { 952, 1112, -416},
    { 1096, 1112, -448},
    { 888, 856, -416},
    { 1056, 632, -312},
    { 1448, 672, -160},
    { -2040, 712, -8},
    { -2040, 544, 0},
    { 1928, 352, -24},
    { 1864, 200, 64},
    { 1816, 344, -8},
    { 1608, 328, -88},
    { 1328, 96, -192},
    { 928, -568, 64},
    { 424, -520, -240},
    { 952, -320, -472},
    { 1104, -176, -432},
    { 1376, 32, -288},
    { 1384, 0, -136},
    { 1848, 96, -80},
    { 1936, 320, -208},
    { 1792, 488, -224},
    { 1616, 632, -240},
    { 1576, 600, -192},
    { 1536, 464, -200},
    { 1384, 400, -88},
    { 1512, 904, -104},
    { 1080, 1392, -216},
    { 1000, 968, -168},
    { 936, 864, -216},
    { 832, 608, -224},
    { 1176, 592, -144},
    { 1600, 656, 0},
    { 1888, 600, 16},
    { 1760, 416, -8},
    { 1736, 272, 48},
    { 1696, 240, 40},
    { 1560, 328, -64},
    { 1320, 264, -224},
    { 1112, 96, -248},
    { 864, -168, -128},
    { 680, -192, -408},
    { 1016, -168, -448},
    { 960, -224, -152},
    { 1216, 64, -352},
    { 1304, 96, -208},
    { 1632, 136, -152},
    { 1792, 312, -256},
    { 1728, 368, -208},
    { 1624, 536, -136},
    { 1408, 696, -56},
    { 1576, 520, -208},
    { 1240, 456, -72},
    { 1264, 864, -304},
    { 984, 1288, -320},
    { 1304, 992, -264},
    { 856, 704, -288},
    { 1016, 464, -248},
    { 1384, 592, -120},
    { 1744, 704, -48},
    { 1800, 576, -72},
    { 1864, 312, 80},
    { 1600, 32, 88},
    { 1640, 248, -80},
    { 1456, 160, -112},
    { 1248, 256, -216},
    { 1168, 32, -208},
    { 832, -344, -264},
    { 760, -344, -128},
    { 1080, -16, -296},
    { 1136, 152, -376},
    { 1192, 160, -248},
    { 1568, 160, -128},
    { 1680, 232, -80},
    { 1728, 392, -64},
    { 1728, 520, -72},
    { 1704, 624, 200},
    { 1640, 656, -112},
    { 1304, 616, -64},
    { 1264, 896, -152},
    { 1232, 1240, 0},
    { 912, 1008, -48},
    { 1096, 712, -136},
    { 752, 560, -296},
    { 960, 528, -176},
    { 1440, 680, -32},
    { 1872, 672, -40},
    { 1928, 456, -48},
    { 1936, 216, 24},
    { 2024, 176, 24},
    { 1808, 320, -8},
    { 1528, 264, -88},
    { 1368, -24, -88},
    { 928, -344, -72},
    { 640, -200, -288},
    { 1024, -216, -216},
    { 1184, 40, -232},
    { 1288, 160, -176},
    { 1456, 456, -296},
    { 1776, 1248, -544},
    { 1408, 1216, -408},
    { 904, 976, 24},
    { 352, 1080, 64},
    { 8, 1368, -512},
    { 48, 760, -40},
    { 120, 1088, 168},
    { 272, 1216, 96},
    { 616, 1176, 8},
    { 680, 920, 32},
    { 1184, 1072, -360},
    { 856, 1088, 0},
    { 928, 856, 32},
    { 672, 800, 240},
    { 648, 928, -48},
    { 632, 736, -64},
    { 448, 696, -200},
    { 424, 632, -168},
    { 432, 568, -128},
    { 544, 632, -128},
    { 632, 680, -168},
    { 672, 640, -192},
    { 776, 856, -200},
    { 776, 1184, -320},
    { 704, 1168, -816},
    { 832, 1048, -208},
    { 640, 856, 8},
    { 824, 768, 0},
    { 808, 504, -208},
    { 832, 160, -184},
    { 936, 312, -264},
    { 904, 352, -248},
    { 944, 640, -152},
    { 848, 936, -48},
    { 968, 1472, -344},
    { 592, 1064, -176},
    { 632, -200, -672},
    { 680, 224, -1152},
    { 616, 616, -1152},
    { 360, 1024, -1024},
    { 216, 1240, -1040},
    { 504, 1032, -1144},
    { 736, 656, -1000},
    { 784, 584, -776},
    { 944, 712, -800},
    { 1056, 648, -920},
    { 1048, 544, -832},
    { 896, 464, -656},
    { 808, 464, -632},
    { 728, 416, -616},
    { 624, 296, -472},
    { 536, 176, -312},
    { 560, 96, -240},
    { 640, 56, -312},
    { 912, -88, -400},
    { 1184, -248, -96},
    { 1920, 56, -304},
    { -1800, 112, -368},
    { -1424, 104, -248},
    { -1376, 88, -488},
    { -1800, 232, -440},
    { 1888, 512, -200},
    { 1544, 624, -128},
    { 1272, 536, -264},
    { 992, 464, -136},
    { 680, 800, 16},
    { 792, 1120, 40},
    { 1008, 1064, -48},
    { 800, 784, -152},
    { 1384, 760, 0},
    { -1864, 800, 88},
    { -1888, 584, 80},
    { -1888, 496, 80},
    { -1752, 296, 208},
    { 2032, 216, 56},
    { 1720, 328, -104},
    { 1456, 392, -40},
    { 1344, 128, 56},
    { 1032, -152, 200},
    { 664, -80, -120},
    { 952, -64, -224},
    { 1128, 32, -64},
    { 1456, 144, -112},
    { 1560, 80, -80},
    { 1936, 184, -72},
    { 1880, 368, -112},
    { 1728, 568, -248},
    { 1376, 536, -272},
    { 1240, 528, -200},
    { 1304, 336, -120},
    { 1336, 336, -136},
    { 1456, 616, -152},
    { 1392, 1016, 72},
    { 928, 1016, -264},
    { 1104, 808, -192},
    { 744, 872, -232},
    { 920, 632, -128},
    { 1504, 648, -8},
    { 1968, 632, 120},
    { 1976, 376, 88},
    { 1832, 224, 16},
    { 1672, 104, 32},
    { 1528, 256, -64},
    { 1360, 376, -120},
    { 1280, 280, -192},
    { 1120, 56, -152},
    { 704, -264, -128},
    { 520, -128, -456},
    { 1152, -96, -264},
    { 1368, 104, -144},
    { 1592, 200, -200},
    { 1712, 208, -136},
    { 1792, 320, -144},
    { 1584, 408, -224},
    { 1432, 488, -336},
    { 1320, 464, -232},
    { 1392, 416, -104},
    { 1440, 496, -144},
    { 1384, 616, -56},
    { 1288, 1152, -176},
    { 864, 1088, -200},
    { 1152, 992, -168},
    { 896, 816, -208},
    { 1216, 544, -144},
    { 1656, 640, -16},
    { -2016, 624, 0},
    { 2000, 424, 0},
    { 1856, 264, 64},
    { 1768, 184, 40},
    { 1680, 304, -80},
    { 1472, 256, -144},
    { 1360, 112, -128},
    { 984, -344, 24},
    { 552, -352, -160},
    { 960, -184, -296},
    { 1200, -16, -232},
    { 1344, 152, -120},
    { 1536, 184, -24},
    { 2016, 304, -144},
    { 1920, 464, -176},
    { 1720, 512, -192},
    { 1456, 680, -304},
    { 1392, 448, -304},
    { 1552, 200, -160},
    { 1224, 568, -80},
    { 1432, 1272, -288},
    { 944, 1120, -216},
    { 1032, 976, -160},
    { 1240, 960, -240},
    { 1032, 536, -272},
    { 1304, 504, -168},
    { 1880, 664, -24},
    { 1872, 608, 24},
    { 1920, 400, 32},
    { 1800, 256, 120},
    { 1696, 240, 24},
    { 1536, 280, -40},
    { 1264, 240, -168},
    { 1024, -48, -120},
    { 760, -288, -104},
    { 584, -296, -360},
    { 968, -288, -208},
    { 1344, 32, -280},
    { 1400, 152, -256},
    { 1600, 176, -136},
    { 1920, 248, -104},
    { 1928, 424, -144},
    { 1944, 520, -104},
    { 1816, 656, -104},
    { 1576, 832, 8},
    { 1336, 520, -176},
    { 1128, 736, -208},
    { 1232, 1224, -96},
    { 808, 1008, 0},
    { 1120, 1176, -48},
    { 1200, 952, -168},
    { 1192, 656, -184},
    { 1648, 656, -88},
    { -1920, 704, 80},
    { -1840, 648, 120},
    { -1912, 320, 120},
    { 2016, 184, 176},
    { 1832, 312, 64},
    { 1648, 368, 48},
    { 1344, 288, -8},
    { 1216, 64, -64},
    { 648, -392, 72},
    { 256, -264, -256},
    { 736, -272, -344},
    { 960, -80, -232},
    { 1592, 184, -160},
    { 1656, 192, -168},
    { -1904, 280, -256},
    { -2000, 384, -104},
    { 1848, 536, -160},
    { 1952, 656, -520},
    { 1240, 264, -200},
    { 1600, 528, -88},
    { 1456, 624, 72},
    { 1360, 1152, 56},
    { 1056, 1344, 24},
    { 920, 856, 24},
    { 1000, 920, -32},
    { 1016, 816, -24},
    { 1040, 728, -40},
    { 1424, 768, 24},
    { 2024, 752, 160},
    { -1944, 552, 216},
    { -2024, 360, 160},
    { 2016, 176, 184},
    { 1784, 224, 128},
    { 1608, 336, -48},
    { 1280, 288, -120},
    { 1032, -112, -40},
    { 568, -376, -8},
    { 640, -384, -440},
    { 1064, -392, -168},
    { 1344, -24, -288},
    { 1536, 80, -344},
    { 1728, 80, -128},
    { 2032, 176, -128},
    { 1976, 424, -112},
    { 1856, 680, -280},
    { 1680, 704, -128},
    { 1712, 520, -176},
    { 1512, 480, -88},
    { 1400, 600, -40},
    { 1296, 1352, -152},
    { 704, 1032, -176},
    { 1120, 984, -96},
    { 760, 856, -168},
    { 1200, 560, -120},
    { 1656, 568, 0},
    { -1984, 632, 40},
    { -2000, 488, 56},
    { 2000, 344, 88},
    { 1880, 240, 168},
    { 1752, 360, 64},
    { 1488, 312, 56},
    { 1248, 80, 48},
    { 872, -288, 72},
    { 680, -320, -120},
    { 792, -264, -280},
    { 1160, -272, -96},
    { 1576, 176, -264},
    { 1552, 120, -184},
    { 1880, 128, -104},
    { 1856, 256, -96},
    { 1728, 400, -176},
    { 1560, 528, -288},
    { 1456, 544, 24},
    { 1560, 408, -72},
    { 1320, 656, 16},
    { 1440, 1288, -56},
    { 1072, 1144, 24},
    { 888, 824, -16},
    { 1104, 888, -72},
    { 992, 776, -136},
    { 1384, 656, -40},
    { 1896, 712, 56},
    { -2048, 616, 128},
    { 1984, 440, 8},
    { 1888, 224, 104},
    { 1728, 248, 80},
    { 1712, 320, -8},
    { 1440, 304, -88},
    { 1336, 104, -192},
    { 872, -376, -104},
    { 576, -416, -336},
    { 824, -320, -336},
    { 1080, -16, -296},
    { 1456, 200, -248},
    { 1432, 160, -80},
    { -2040, 280, -168},
    { 1832, 520, -96},
    { 1488, 528, -80},
    { 1384, 520, -208},
    { 1408, 352, -312},
    { 1544, 376, -208},
    { 1376, 688, -96},
    { 1240, 1688, -320},
    { 912, 1096, -184},
    { 1024, 848, -240},
    { 1312, 800, -352},
    { 1184, 800, -160},
    { 1472, 840, -112},
    { 1984, 808, 72},
    { -1848, 528, 296},
    { 1888, 320, 208},
    { 1680, 168, 240},
    { 1672, 352, 24},
    { 1520, 136, 64},
    { 1248, 256, 72},
    { 1160, 216, -104},
    { 872, -160, -96},
    { 416, -280, -232},
    { 656, -240, -304},
    { 800, -128, -184},
    { 1160, 88, -360},
    { 1504, 120, -320},
    { -1936, 216, -272},
    { -1960, 328, -320},
    { 1784, 472, -368},
    { 1424, 544, -344},
    { 1480, 280, -120},
    { 1416, 472, -64},
    { 1360, 968, -136},
    { 976, 1376, -152},
    { 984, 1112, 24},
    { 744, 800, 0},
    { 1216, 936, 72},
    { 1296, 952, 48},
    { 1472, 728, 64},
    { -2000, 816, 104},
    { -1624, 736, 200},
    { -1792, 608, 184},
    { -1880, 384, 248},
    { 2040, 176, 208},
    { 1736, 224, 8},
    { 1424, 216, -48},
    { 1224, 64, -176},
    { 840, -440, 48},
    { 296, -584, -88},
    { 304, -424, -472},
    { 760, -304, -168},
    { 1312, 32, -200},
    { 1888, 168, -160},
    { -1608, 232, 48},
    { -1320, 504, -88},
    { -1888, 656, -160},
    { 1752, 704, 24},
    { 1960, 480, -152},
    { -1992, 312, 8},
    { 1736, 592, 144},
    { 1536, 1120, 552},
    { 912, -1744, 128},
    { 728, 824, 128},
    { 816, 1184, 288},
    { 1024, 1152, 152},
    { 1320, 960, 32},
    { 1776, 984, 72},
    { -1616, 880, 184},
    { -1440, 800, 152},
    { -1416, 648, 448},
    { -1208, 656, 240},
    { -1376, 1112, 56},
    { -1664, 1096, 192},
    { 1696, 1000, 128},
    { 1208, 976, -136},
    { 752, 480, -176},
    { 304, 536, -344},
    { 232, 568, -952},
    { -192, 104, -992},
    { -512, 336, -880},
    { -384, 448, -376},
    { -456, 664, -360},
    { -664, 368, -504},
    { -704, 224, -400},
    { -664, 112, -264},
    { -624, 168, -352},
    { -784, 152, -312},
    { -936, 272, -384},
    { -1112, 504, -448},
    { -1136, 352, -456},
    { -1344, 312, -544},
    { -1480, 56, -184},
    { -1008, 288, -184},
    { -848, 144, -136},
    { -880, 112, -128},
    { -752, 96, -232},
    { -568, -256, -352},
    { -496, -208, -264},
    { -504, -264, -376},
    { -432, -600, -264},
    { -384, -640, -296},
    { -16, -480, -296},
    { 176, -200, -352},
    { 288, 168, -424},
    { 872, 808, -656},
    { 1320, 1248, -792},
    { -1696, 368, 144},
    { -464, 248, 240},
    { -256, 1104, -600},
    { -1984, 1408, -584},
    { 1504, 576, -256},
    { 1496, 344, -104},
    { 1352, 448, 40},
    { 1256, 1120, 96},
    { 1016, 1808, -408},
    { 752, 1512, -256},
    { 768, 808, 16},
    { 1224, 592, -312},
    { 1320, 984, -304},
    { 1664, 608, -224},
    { -1680, 656, -248},
    { -1512, 752, 32},
    { -1736, 496, 144},
    { -1912, 208, 56},
    { 1936, 160, 8},
    { 1680, 232, -80},
    { 1528, 208, -200},
    { 1152, -104, 0},
    { 656, -680, 272},
    { 256, -464, -112},
    { 400, -424, -304},
    { 1016, -296, -48},
    { 1688, 80, -208},
    { 1952, 152, -64},
    { -1648, 160, -40},
    { -1672, 328, -152},
    { -1776, 504, 40},
    { -1920, 728, 136},
    { 2000, 760, -120},
    { 1752, 648, 104},
    { 1616, 1264, -80},
    { 1040, 1824, -248},
    { 888, 1248, -64},
    { 632, 1056, -152},
    { 1328, 960, -96},
    { 1448, 784, -176},
    { 1800, 680, -96},
    { -1784, 672, -16},
    { -1592, 672, -24},
    { -1760, 552, 88},
    { -1856, 392, 160},
    { 1984, 296, 72},
    { 1648, 280, -88},
    { 1480, 32, -136},
    { 816, -600, 120},
    { 488, -440, 0},
    { 392, -400, -224},
    { 544, -272, -184},
    { 1128, -24, -120},
    { 1760, 248, -216},
    { 2008, 248, 8},
    { -1392, 328, 8},
    { -1536, 576, -152},
    { 1880, 648, 64},
    { 1736, 528, -248},
    { 1888, 312, -8},
    { 1744, 512, -8},
    { 1432, 944, -8},
    { 1096, -1984, -48},
    { 784, 1088, -80},
    { 592, 880, 112},
    { 1192, 984, 48},
    { 1312, 816, -8},
    { 1592, 760, 16},
    { -1936, 784, 88},
    { -1720, 720, 128},
    { -1824, 568, 128},
    { -1800, 432, 176},
    { -1976, 208, 112},
    { 1728, 320, 8},
    { 1528, 216, -208},
    { 1176, -208, -64},
    { 528, -728, 232},
    { 520, -376, -136},
    { 712, -256, -160},
    { 1224, -48, -208},
    { 1568, 280, -288},
    { 1880, 200, 64},
    { -1360, 232, -96},
    { -1728, 576, -304},
    { 1648, 624, -120},
    { 1480, 400, -224},
    { 2016, 112, -112},
    { 1712, 384, -96},
    { 1384, 960, -40},
    { 1240, 2008, -200},
    { 616, 1112, -160},
    { 872, 808, -40},
    { 1160, 968, -80},
    { 1112, 760, -104},
    { 1720, 656, 0},
    { -1896, 752, 88},
    { -1760, 656, 80},
    { -1808, 472, 72},
    { -1872, 344, 200},
    { 2024, 320, 144},
    { 1744, 360, -24},
    { 1360, 264, -216},
    { 1120, -176, 16},
    { 584, -624, 104},
    { 392, -504, -376},
    { 648, -488, -136},
    { 1208, -176, -136},
    { 1688, 192, -208},
    { 1968, -24, 40},
    { -1352, 136, -56},
    { -1440, 480, -136},
    { -1832, 680, -96},
    { 2000, 760, -80},
    { 1736, 624, -32},
    { 1592, 472, 40},
    { 1360, 736, 112},
    { 1368, 1440, -368},
    { 760, 1192, -232},
    { 736, 744, -336},
    { 1112, 1208, -288},
    { 1208, 824, -240},
    { 1624, 608, -120},
    { -2016, 648, -8},
    { -1864, 520, -24},
    { -1832, 424, -72},
    { -1840, 392, 48},
    { -1928, 344, 96},
    { 1984, 312, -56},
    { 1616, 216, -240},
    { 1336, -360, 56},
    { 568, -728, 248},
    { 416, -456, -304},
    { 712, -480, -72},
    { 1144, -80, -40},
    { 1672, 256, -112},
    { 1992, 200, 72},
    { -1528, 264, 16},
    { -1600, 448, -160},
    { -1952, 568, 0},
    { 1872, 936, -64},
    { 1840, 432, -80},
    { 1584, 640, 0},
    { 1256, 1880, -472},
    { 968, 1280, -280},
    { 704, 1072, -280},
    { 728, 752, -192},
    { 1656, 856, -160},
    { 1552, 720, -176},
    { -2024, 608, -96},
    { -1864, 736, -48},
    { -1664, 688, -32},
    { -1792, 464, 104},
    { -2000, 328, 176},
    { 1888, 320, 64},
    { 1640, 320, -24},
    { 1432, 96, -168},
    { 960, -544, 216},
    { 432, -632, 96},
    { 432, -480, -304},
    { 776, -464, 48},
    { 1320, 104, -216},
    { 1888, 152, -112},
    { -1656, 232, 96},
    { -1312, 384, -80},
    { -1608, 528, -56},
    { 1920, 1048, 184},
    { 1784, 528, -192},
    { 1872, 248, 48},
    { 1752, 1120, 40},
    { 968, -1768, -432},
    { 1056, 1152, -320},
    { 504, 1064, -352},
    { 1120, 720, -176},
    { 1288, 784, -128},
    { 1576, 744, -64},
    { -2000, 792, -56},
    { -1752, 752, -128},
    { -1504, 480, 0},
    { -1832, 464, 168},
    { -2024, 376, 160},
    { 2040, 312, -56},
    { 1616, 216, -64},
    { 1264, -328, 120},
    { 488, -600, 256},
    { 520, -464, -128},
    { 520, -336, -144},
    { 1032, -144, -136},
    { 1512, 272, -344},
    { 1712, 224, -112},
    { -1464, 200, -64},
    { -1688, 376, -208},
    { 1720, 480, -48},
    { 1616, 424, -200},
    { 1984, 184, -80},
    { 1912, 432, -144},
    { 1328, 776, -104},
    { 1488, 1352, 488},
    { 712, 1744, -248},
    { 648, 856, -216},
    { 1144, 880, -96},
    { 1056, 928, -120},
    { 1336, 872, -16},
    { -2024, 792, 112},
    { -1744, 640, 152},
    { -1784, 480, 48},
    { -1888, 376, 120},
    { -1952, 336, 152},
    { 1920, 360, 24},
    { 1616, 256, -352},
    { 1168, -184, -248},
    { 592, -816, 96},
    { 448, -680, -384},
    { 408, -256, -584},
    { 864, 0, -168},
    { 1392, 296, -224},
    { 1680, 280, -304},
    { -1680, 296, -104},
    { -1456, 400, 80},
    { -1904, 568, 88},
    { 1944, 688, 96},
    { -2016, 624, -88},
    { -1992, 488, 200},
    { 1624, 664, 304},
    { 1352, 784, 616},
    { 1192, 1144, 792},
    { 472, 1056, 384},
    { 880, 816, 544},
    { 920, 1000, 376},
    { 904, 960, 88},
    { 1360, 1056, 192},
    { -2040, 1088, 392},
    { -1568, 752, 440},
    { -1512, 496, 344},
    { -1392, 184, 248},
    { -1808, 104, 224},
    { 1912, 336, 0},
    { 1552, 344, -272},
    { 1352, -272, 216},
    { 680, -944, 328},
    { 528, -648, -64},
    { 1008, -408, -24},
    { 1288, 96, -288},
    { 1528, 240, -208},
    { 2040, -16, 344},
    { -1200, 312, 200},
    { -1488, 744, -240},
    { 1752, 944, -88},
    { 1648, 400, -360},
    { 1968, 64, -88},
    { 1784, 536, 248},
    { 1328, 1408, 288},
    { 808, 1872, -56},
    { 616, 1024, 40},
    { 992, 984, 136},
    { 1216, 784, -112},
    { 1104, 568, -48},
    { 1704, 792, 32},
    { -1816, 808, 152},
    { -1592, 616, 152},
    { -1672, 448, 160},
    { -1696, 280, 88},
    { -1960, 280, 40},
    { 1800, 216, 24},
    { 1152, -456, 296},
    { 552, -480, 136},
    { 832, -368, 8},
    { 544, -288, -48},
    { 1072, 8, 16},
    { 1368, 240, -144},
    { 1784, 248, 0},
    { -1488, 328, 96},
    { -1464, 696, -88},
    { 1856, 704, -128},
    { 1464, 672, -128},
    { 1496, 184, -256},
    { 1584, 168, -56},
    { 1424, 640, 72},
    { 1360, 1592, 240},
    { 768, 1768, -560},
    { 800, 768, -248},
    { 1392, 608, -312},
    { 1368, 480, -336},
    { 1344, 408, -208},
    { 1776, 696, -120},
    { -1984, 656, -152},
    { -1960, 376, -176},
    { 1968, 248, 56},
    { 1936, 272, 80},
    { 1840, 400, -24},
    { 1592, 320, -304},
    { 1360, -224, -32},
    { 768, -800, 320},
    { 488, -512, -176},
    { 784, -368, -104},
    { 1096, -144, -288},
    { 1488, 232, -360},
    { 1800, 104, 0},
    { -1472, 112, -32},
    { -1664, 360, -240},
    { 1920, 472, -96},
    { 1664, 632, -48},
    { 1744, 312, -248},
    { 1712, 456, -96},
    { 1448, 1120, -264},
    { 1160, 1816, -376},
    { 720, 1008, -296},
    { 864, 968, -336},
    { 1400, 832, -256},
    { 1400, 432, -208},
    { 1552, 544, -104},
    { -1968, 688, -48},
    { -1720, 672, -88},
    { -1656, 376, 72},
    { -1960, 192, 184},
    { 1976, 368, 24},
    { 1696, 416, -80},
    { 1512, 120, -144},
    { 920, -664, 176},
    { 520, -712, -8},
    { 384, -552, -296},
    { 856, -280, -48},
    { 1336, 136, -344},
    { 1672, 96, -80},
    { -1400, 232, -64},
    { -1376, 520, -360},
    { 1992, 472, -88},
    { 1792, 432, -16},
    { 1824, 320, -112},
    { 1936, 688, -120},
    { 1592, 472, 104},
    { 1248, 1176, 280},
    { 904, 1712, 80},
    { 696, 760, 64},
    { 680, 1000, 176},
    { 848, 928, 40},
    { 1168, 624, -80},
    { 2000, 896, 88},
    { -1400, 720, 232},
    { -1272, 440, 184},
    { -1504, 360, 112},
    { -1600, 464, 96},
    { -1784, 616, 488},
    { 1640, 112, 496},
    { 1024, 200, 256},
    { 624, 88, -8},
    { 176, -8, -416},
    { 64, 8, -608},
    { -56, 32, -760},
    { 8, 504, -1208},
    { 88, 616, -1360},
    { -96, 616, -1096},
    { 176, 576, -1096},
    { -128, 656, -968},
    { 0, 672, -1104},
    { -208, 600, -920},
    { -176, 472, -824},
    { -112, 360, -912},
    { -48, 232, -904},
    { 152, 192, -936},
    { 168, 64, -1056},
    { 168, -152, -1128},
    { 200, 96, -1152},
    { 144, -176, -680},
    { -200, -64, -952},
    { 704, -336, -1072},
    { 152, -328, -1080},
    { -16, 88, -1152},
    { 8, -448, -1048},
    { -728, 1576, 1984},
    { 0, -616, -1784},
    { -112, 72, -1144},
    { 40, -128, -1008},
    { 0, -48, -952},
    { -96, -64, -968},
    { -136, -16, -1032},
    { 256, -288, -968},
    { -104, -104, -992},
    { -136, -104, -1032},
    { -160, -112, -1008},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}



// ----------------------------------------------------------------
// Sample captured: 2015-09-22 13:27:44 local
AccelRawData *activity_sample_100_steps_heather_5(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME walk_100_heather_5
  //> TEST_EXPECTED 100
  //> TEST_EXPECTED_MIN 80
  //> TEST_EXPECTED_MAX 110
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { 128, 32, -1184},
    { 144, 192, -1264},
    { 168, 272, -1264},
    { 136, 264, -1136},
    { 72, 168, -928},
    { 16, 56, -784},
    { -32, 32, -784},
    { -72, -24, -808},
    { -8, -40, -896},
    { -72, 0, -1032},
    { -64, -16, -1064},
    { -96, -80, -1072},
    { -40, 8, -1160},
    { -136, -200, -1144},
    { -104, -168, -1136},
    { 0, 48, -1208},
    { -192, 32, -1176},
    { -32, 80, -1056},
    { -48, 104, -1032},
    { -80, -40, -896},
    { -152, -112, -832},
    { -176, -304, -936},
    { -48, -184, -808},
    { 112, 216, -1048},
    { 208, -648, -840},
    { 152, -400, -912},
    { 192, -320, -896},
    { 280, -424, -824},
    { 592, -608, -56},
    { 1160, 216, 48},
    { 1688, 696, -128},
    { 1912, 760, -16},
    { 1792, 720, 232},
    { 1864, 680, 384},
    { -1992, 728, 296},
    { -1624, 872, 392},
    { -1880, 992, 520},
    { 1872, 856, 320},
    { 1576, 856, -24},
    { 1576, 768, 32},
    { 1056, 880, 56},
    { 1096, 968, 168},
    { 608, 1056, 88},
    { 752, 944, -40},
    { 888, 760, 32},
    { 1264, 736, 64},
    { 1656, 632, 128},
    { 1808, 496, 80},
    { 1888, 480, 40},
    { 2000, 496, 72},
    { 1968, 504, 40},
    { 1760, 456, 16},
    { 1584, 352, -32},
    { 1456, 136, -32},
    { 672, -360, 120},
    { 760, -408, 16},
    { 1216, -144, -168},
    { 1472, -48, -152},
    { 1576, 72, -16},
    { 1608, 160, 64},
    { 1464, 272, -64},
    { 1448, 360, -104},
    { 1632, 520, -120},
    { 1744, 616, 56},
    { 1712, 688, 168},
    { 1360, 744, -24},
    { 1232, 1008, -280},
    { 1152, 1712, -192},
    { 896, 888, -160},
    { 1056, 976, -32},
    { 1064, 640, -248},
    { 1176, 592, -216},
    { 1496, 600, -160},
    { 1952, 528, -104},
    { 1968, 424, -96},
    { 1904, 352, -16},
    { 1840, 352, -40},
    { 1784, 408, -152},
    { 1552, 440, -168},
    { 1304, 264, -136},
    { 744, -280, -16},
    { 656, -416, 72},
    { 1080, -264, -64},
    { 1192, -136, -120},
    { 1352, 136, -232},
    { 1408, 184, -104},
    { 1784, 176, -48},
    { -2048, 408, -192},
    { 2024, 688, -216},
    { 1744, 976, 160},
    { 1408, 752, -216},
    { 1456, 264, -224},
    { 1232, 672, -136},
    { 1520, 1336, -96},
    { 848, 1040, 120},
    { 1016, 984, 0},
    { 960, 832, -56},
    { 1088, 688, -48},
    { 1344, 616, 0},
    { 1808, 760, 8},
    { 1880, 704, -16},
    { 1840, 256, 168},
    { 1728, 336, 48},
    { 1784, 400, -72},
    { 1672, 320, -128},
    { 1296, 184, -296},
    { 1224, -120, -208},
    { 880, -400, -160},
    { 1088, -296, -120},
    { 1144, -96, -56},
    { 1304, 200, -184},
    { 1368, 208, -80},
    { 1784, 312, -232},
    { 1784, 432, -376},
    { 1640, 560, -360},
    { 1552, 448, -240},
    { 1440, 576, -152},
    { 1384, 640, -304},
    { 1272, 776, -80},
    { 1232, 1184, -96},
    { 824, 1128, -32},
    { 912, 848, 0},
    { 896, 840, 80},
    { 1096, 776, 40},
    { 1488, 736, 56},
    { 1808, 752, 144},
    { 1968, 536, 144},
    { 1832, 328, 120},
    { 1712, 312, 80},
    { 1744, 384, -80},
    { 1680, 416, -264},
    { 1472, 232, -288},
    { 1064, -288, -56},
    { 912, -392, -360},
    { 992, -488, -304},
    { 1272, -320, -184},
    { 1568, 160, -96},
    { 1720, 368, -16},
    { 2024, 408, -168},
    { -2024, 592, -224},
    { 1832, 640, -120},
    { 1488, 856, -48},
    { 1448, 616, -272},
    { 1328, 400, -8},
    { 1096, 832, 64},
    { 1288, 1304, 192},
    { 824, 1000, 152},
    { 1016, 808, 152},
    { 968, 808, 144},
    { 1096, 776, -8},
    { 1328, 752, 136},
    { 1896, 736, 176},
    { 2000, 592, 152},
    { 1896, 392, 136},
    { 1840, 312, 64},
    { 1768, 304, -80},
    { 1616, 400, -152},
    { 1416, 304, -176},
    { 1112, 32, -104},
    { 784, -208, -112},
    { 912, -192, -120},
    { 1272, 72, -256},
    { 1248, 248, -392},
    { 1240, 184, -144},
    { 1512, 208, -104},
    { 1576, 280, -184},
    { 1640, 440, -168},
    { 1824, 680, -104},
    { 1704, 752, 88},
    { 1584, 664, -48},
    { 1464, 768, -208},
    { 1416, 2000, -152},
    { 624, 1568, -152},
    { 1200, 1352, -192},
    { 1272, 632, -296},
    { 1496, 400, -160},
    { 1696, 536, 32},
    { 1904, 552, -40},
    { 1864, 544, -176},
    { 1752, 432, -40},
    { 1696, 416, -64},
    { 1584, 416, -64},
    { 1456, 360, -224},
    { 1112, -80, -184},
    { 704, -512, -96},
    { 680, -272, -432},
    { 1112, -160, -168},
    { 1416, 200, -296},
    { 1576, 256, -280},
    { 1832, 312, -128},
    { -1984, 392, -128},
    { 1904, 560, -112},
    { 1696, 704, -240},
    { 1520, 784, -80},
    { 1608, 352, -160},
    { 1360, 872, -312},
    { 1224, 1456, -280},
    { 1080, 1040, -104},
    { 840, 816, -152},
    { 1056, 688, -48},
    { 1008, 648, -176},
    { 1216, 640, -48},
    { 1672, 696, 8},
    { 1848, 608, 48},
    { 1840, 432, 24},
    { 1768, 312, 72},
    { 1768, 320, -88},
    { 1680, 384, -216},
    { 1456, 312, -240},
    { 1080, -136, -112},
    { 928, -584, -96},
    { 880, -200, -392},
    { 1352, -216, -144},
    { 1592, 184, -272},
    { 1648, 144, -120},
    { 1992, 264, -72},
    { 2008, 488, -184},
    { 1664, 568, -208},
    { 1368, 728, 40},
    { 1344, 584, -184},
    { 1408, 456, -40},
    { 1200, 672, 48},
    { 1176, 1040, -16},
    { 912, 1280, 144},
    { 976, 648, -32},
    { 960, 712, 56},
    { 1000, 736, -96},
    { 1240, 712, 8},
    { 1624, 688, 56},
    { 1896, 616, 96},
    { 1800, 424, 88},
    { 1688, 304, 88},
    { 1648, 312, -80},
    { 1600, 368, -264},
    { 1424, 208, -200},
    { 1120, -120, -128},
    { 936, -200, -224},
    { 936, 16, -240},
    { 1136, 40, -144},
    { 1280, 184, -232},
    { 1264, 64, -160},
    { 1504, 112, -56},
    { 1464, 336, -128},
    { 1352, 456, -104},
    { 1512, 560, -88},
    { 1640, 656, -88},
    { 1576, 664, -32},
    { 1240, 1120, -160},
    { 1376, 1248, -408},
    { 904, 736, -96},
    { 1184, 1048, -120},
    { 1048, 784, -72},
    { 1136, 704, -120},
    { 1368, 648, -48},
    { 1640, 600, 8},
    { 1768, 504, 64},
    { 1648, 384, 48},
    { 1616, 328, -24},
    { 1648, 352, -168},
    { 1512, 352, -72},
    { 1240, 64, -88},
    { 1048, -304, -104},
    { 760, -408, -200},
    { 1112, -312, -280},
    { 1560, 96, -352},
    { 1728, 128, -192},
    { 1856, 208, -40},
    { 1872, 312, -96},
    { 1632, 496, -136},
    { 1472, 592, -104},
    { 1360, 616, 32},
    { 1448, 552, 0},
    { 1288, 584, -24},
    { 1080, 944, -104},
    { 1184, 1584, 72},
    { 776, 664, -32},
    { 1160, 752, 96},
    { 1088, 768, -104},
    { 1160, 688, -48},
    { 1432, 624, 32},
    { 1776, 528, 48},
    { 1800, 456, 0},
    { 1744, 400, 0},
    { 1928, 448, -120},
    { 1864, 440, -192},
    { 1424, 56, -192},
    { 1064, -368, 32},
    { 1208, -376, -144},
    { 920, -544, -192},
    { 1400, -224, -48},
    { 1608, 200, -176},
    { 1632, 360, -152},
    { 1992, 360, -136},
    { 1920, 544, -296},
    { 1544, 496, -120},
    { 1440, 480, -168},
    { 1304, 528, -152},
    { 1272, 552, -376},
    { 1016, 832, -344},
    { 1080, 1184, -376},
    { 1008, 800, -56},
    { 1152, 824, -112},
    { 1096, 664, -256},
    { 1040, 536, -224},
    { 1368, 600, -48},
    { 1768, 648, 32},
    { 2016, 488, -16},
    { 1856, 360, 40},
    { 1688, 272, 40},
    { 1608, 352, -80},
    { 1496, 384, -136},
    { 1208, 208, -184},
    { 1128, -256, -176},
    { 920, -640, -56},
    { 1128, -520, -112},
    { 1632, 8, -8},
    { 1648, 448, -168},
    { 1704, 400, -96},
    { 1848, 416, -152},
    { 1744, 384, -112},
    { 1688, 464, -152},
    { 1528, 744, 16},
    { 1368, 704, -216},
    { 1184, 736, -208},
    { 872, 960, -184},
    { 1200, 1104, -128},
    { 712, 776, -32},
    { 1224, 880, 56},
    { 1120, 808, -32},
    { 1320, 704, -24},
    { 1624, 664, 72},
    { 1944, 656, 144},
    { 1912, 504, 152},
    { 1808, 296, 96},
    { 1696, 240, 24},
    { 1600, 408, -88},
    { 1480, 304, -216},
    { 1144, -56, -192},
    { 760, -448, -48},
    { 752, -456, -240},
    { 1136, -184, -256},
    { 1456, 40, -96},
    { 1744, 400, -232},
    { 1872, 376, -128},
    { -2024, 336, -184},
    { 1832, 336, -192},
    { 1456, 512, -288},
    { 1312, 624, -288},
    { 1424, 432, -64},
    { 1248, 856, -256},
    { 1000, 1032, -128},
    { 1160, 984, -160},
    { 896, 648, -72},
    { 1104, 792, 128},
    { 1136, 664, 48},
    { 1184, 728, -56},
    { 1536, 680, -40},
    { 1880, 680, 48},
    { 1920, 440, 96},
    { 1736, 328, 80},
    { 1720, 328, -48},
    { 1688, 328, -136},
    { 1544, 352, -184},
    { 1304, 208, -216},
    { 944, -248, -40},
    { 656, -296, -200},
    { 760, -16, -432},
    { 1168, 8, -152},
    { 1344, 224, -168},
    { 1600, 224, -144},
    { 1896, 312, -120},
    { 1880, 456, -160},
    { 1592, 552, -152},
    { 1440, 688, -208},
    { 1440, 632, -72},
    { 1400, 504, -72},
    { 1168, 568, -88},
    { 944, 968, -136},
    { 1184, 1456, -152},
    { 848, 672, -32},
    { 1184, 872, 16},
    { 1208, 816, -16},
    { 1120, 800, 0},
    { 1432, 760, 80},
    { 1936, 640, 120},
    { 1888, 472, 176},
    { 1776, 352, 80},
    { 1712, 336, 48},
    { 1720, 344, -72},
    { 1504, 320, -112},
    { 1144, 88, -424},
    { 944, -176, -312},
    { 800, -576, -152},
    { 944, -256, -336},
    { 1104, -104, -184},
    { 1368, 144, -320},
    { 1480, 152, -216},
    { 1872, 200, -344},
    { 1816, 392, -264},
    { 1632, 544, -168},
    { 1520, 696, -160},
    { 1488, 720, -224},
    { 1336, 760, -344},
    { 984, 1208, -416},
    { 1208, 1248, -328},
    { 1032, 816, -96},
    { 1312, 920, -192},
    { 1096, 816, -144},
    { 1360, 760, -176},
    { 1672, 656, -48},
    { 1904, 568, 56},
    { 1744, 472, 104},
    { 1752, 392, 56},
    { 1688, 544, 64},
    { 1664, 272, -88},
    { 1472, 208, -112},
    { 1208, -48, -256},
    { 912, -328, -88},
    { 816, -184, -168},
    { 1080, 56, -16},
    { 1208, 64, -312},
    { 1192, 120, -424},
    { 1328, 48, -232},
    { 1560, 120, -272},
    { 1696, 336, -272},
    { 1824, 672, -480},
    { 1712, 856, -384},
    { 1448, 680, -256},
    { 1208, 504, -336},
    { 1360, 944, -720},
    { 1176, 952, -512},
    { 1128, 808, -408},
    { 976, 776, -400},
    { 976, 672, -400},
    { 1360, 648, -288},
    { 1704, 608, -120},
    { 1752, 520, -56},
    { 1584, 448, -16},
    { 1592, 376, -80},
    { 1576, 352, -184},
    { 1544, 296, -240},
    { 1448, 40, -152},
    { 1048, -280, -96},
    { 872, -424, -184},
    { 1008, -536, -240},
    { 1176, -296, -16},
    { 1712, 88, -184},
    { 1792, 248, -200},
    { 1760, 248, -360},
    { 1520, 240, -400},
    { 1416, 328, -344},
    { 1400, 448, -224},
    { 1472, 504, -240},
    { 1488, 592, -256},
    { 1296, 880, -424},
    { 1264, 1016, -384},
    { 984, 888, -280},
    { 1144, 912, -64},
    { 944, 792, -8},
    { 1040, 776, -72},
    { 1408, 632, 32},
    { 1776, 624, 56},
    { 1896, 528, 64},
    { 1848, 432, 64},
    { 1800, 408, 0},
    { 1728, 416, -152},
    { 1528, 264, -192},
    { 1296, 136, -208},
    { 1104, -208, -104},
    { 896, -416, -184},
    { 1016, -304, -232},
    { 1408, -104, -96},
    { 1632, 176, -224},
    { 1640, 200, -80},
    { 1720, 272, -144},
    { 1672, 400, -184},
    { 1624, 472, -120},
    { 1632, 624, 88},
    { 1624, 704, 88},
    { 1496, 600, -80},
    { 1192, 856, -560},
    { 1288, 1040, -392},
    { 928, 752, -216},
    { 1160, 840, -232},
    { 672, 936, -136},
    { 960, 784, -80},
    { 1424, 616, -40},
    { 1584, 504, 104},
    { 1592, 576, -56},
    { 1728, 480, -144},
    { 1824, 480, -88},
    { 1872, 280, -56},
    { 1720, 208, -168},
    { 1568, -152, -88},
    { 1280, -592, -136},
    { 1008, -496, -104},
    { 1304, -88, -168},
    { 1256, 96, -192},
    { 1440, 248, -224},
    { 1560, 128, -224},
    { 1624, 40, -88},
    { 1544, 512, -216},
    { 1456, 408, -24},
    { 1416, 584, 56},
    { 1368, 728, -80},
    { 1112, 744, -160},
    { 1240, 1048, -304},
    { 1072, 784, -168},
    { 1256, 896, -152},
    { 928, 784, -240},
    { 1128, 712, -152},
    { 1312, 640, -112},
    { 1584, 536, -32},
    { 1512, 456, 64},
    { 1544, 432, -88},
    { 1616, 368, 40},
    { 1744, 304, -104},
    { 1632, 176, -112},
    { 1440, -48, -128},
    { 1096, -432, 72},
    { 984, -160, -320},
    { 1096, -272, -24},
    { 1408, 88, -304},
    { 1432, 128, -392},
    { 1600, 88, -232},
    { 1576, 232, -312},
    { 1392, 320, -328},
    { 1400, 408, -192},
    { 1480, 536, -64},
    { 1392, 600, -152},
    { 1168, 648, -200},
    { 1280, 1000, -320},
    { 1000, 1000, -168},
    { 1104, 832, -136},
    { 984, 936, -48},
    { 872, 688, -88},
    { 1264, 584, -104},
    { 1584, 616, -24},
    { 1704, 536, 8},
    { 1592, 440, 24},
    { 1624, 400, -24},
    { 1680, 384, -128},
    { 1528, 272, -216},
    { 1456, 216, -264},
    { 1304, 64, -240},
    { 1032, -496, -168},
    { 1152, -368, -64},
    { 1272, -64, -184},
    { 1456, 104, -232},
    { 1480, 128, -216},
    { 1560, 224, -280},
    { 1416, 328, -272},
    { 1360, 392, -128},
    { 1424, 536, -32},
    { 1408, 560, -32},
    { 1360, 616, -64},
    { 1264, 808, -216},
    { 1424, 1176, -288},
    { 928, 800, -120},
    { 1168, 808, -104},
    { 952, 816, -240},
    { 1112, 648, -128},
    { 1384, 672, -104},
    { 1720, 616, -24},
    { 1712, 488, 56},
    { 1656, 448, 8},
    { 1664, 344, -16},
    { 1672, 312, -192},
    { 1496, 32, -168},
    { 1232, -128, -192},
    { 1128, -344, -56},
    { 880, -376, -192},
    { 1248, -464, 24},
    { 1728, -200, 24},
    { 1816, 232, -8},
    { -2032, 344, -112},
    { 1816, 488, -320},
    { 1512, 400, -216},
    { 1352, 560, -120},
    { 1240, 616, -24},
    { 1272, 680, -168},
    { 1064, 704, -24},
    { 1200, 856, -192},
    { 1048, 1000, 72},
    { 840, 848, -32},
    { 1088, 824, 136},
    { 1008, 776, -48},
    { 1328, 728, 8},
    { 1824, 680, -32},
    { 1864, 568, 72},
    { 1760, 400, 96},
    { 1768, 328, 32},
    { 1768, 344, -72},
    { 1656, 256, -184},
    { 1440, 88, -176},
    { 1128, -168, -144},
    { 944, -304, 8},
    { 1128, -120, -168},
    { 1296, -32, -48},
    { 1360, 192, -192},
    { 1432, 80, -160},
    { 1624, 168, -304},
    { 1504, 248, -328},
    { 1400, 336, -296},
    { 1448, 432, -168},
    { 1544, 616, 8},
    { 1376, 728, -48},
    { 1352, 1088, -392},
    { 1304, 976, -304},
    { 944, 864, -168},
    { 1152, 896, -80},
    { 928, 744, -200},
    { 1152, 816, -200},
    { 1616, 704, 0},
    { 1688, 592, 128},
    { 1648, 432, 56},
    { 1568, 352, 40},
    { 1648, 360, -64},
    { 1616, 288, -144},
    { 1488, 240, -128},
    { 1320, 40, -208},
    { 1000, -416, -40},
    { 744, -704, -96},
    { 1536, -136, -248},
    { 1792, 152, -16},
    { 2000, 408, -176},
    { 1752, 344, -232},
    { 1392, 256, -208},
    { 1256, 240, -56},
    { 1384, 432, -72},
    { 1408, 584, 32},
    { 1408, 632, -32},
    { 1216, 704, -40},
    { 1400, 1328, -88},
    { 752, 936, -176},
    { 920, 600, -104},
    { 960, 1160, -200},
    { 1152, 808, -40},
    { 1568, 728, -40},
    { 1984, 608, -32},
    { 2008, 544, 48},
    { 1712, 512, 272},
    { 1824, 312, -16},
    { 1776, 368, -16},
    { 1560, 304, -96},
    { 1416, 184, -40},
    { 1152, -152, 48},
    { 792, -376, 56},
    { 952, -232, -328},
    { 1160, -224, -88},
    { 1504, 168, -216},
    { 1608, 152, -112},
    { 1808, 280, -272},
    { 1760, 320, -256},
    { 1664, 448, -120},
    { 1640, 592, -56},
    { 1576, 704, -120},
    { 1336, 736, -32},
    { 1240, 1056, -272},
    { 1384, 1232, 32},
    { 888, 920, 64},
    { 1144, 984, 64},
    { 1000, 752, 40},
    { 1040, 736, -48},
    { 1400, 680, 64},
    { 1880, 560, 80},
    { 1752, 464, 24},
    { 1560, 392, 48},
    { 1592, 400, -88},
    { 1656, 408, -192},
    { 1488, 232, -176},
    { 1344, -24, -216},
    { 1000, -368, -176},
    { 712, -472, -232},
    { 1096, -184, -320},
    { 1384, 80, -376},
    { 1488, 168, -232},
    { 1720, 296, -280},
    { 1576, 376, -304},
    { 1216, 416, -184},
    { 1096, 464, -120},
    { 1216, 480, -48},
    { 1352, 496, -72},
    { 1248, 576, -136},
    { 1360, 904, -232},
    { 1312, 1688, 8},
    { 976, 608, -208},
    { 1144, 1080, 0},
    { 928, 888, -80},
    { 1072, 744, -64},
    { 1416, 664, 0},
    { 1736, 584, 64},
    { 1600, 536, 32},
    { 1576, 408, 112},
    { 1680, 408, 0},
    { 1752, 408, 40},
    { 1544, 288, 8},
    { 1424, 120, -96},
    { 1032, -208, -96},
    { 736, -424, -56},
    { 1048, -288, -192},
    { 1312, -80, -24},
    { 1552, 232, -224},
    { 1672, 232, -144},
    { 1816, 360, -224},
    { 1656, 456, -304},
    { 1424, 480, -200},
    { 1408, 504, 24},
    { 1336, 632, 48},
    { 1448, 544, -120},
    { 1216, 704, -88},
    { 1352, 1128, -312},
    { 856, 1032, -48},
    { 1048, 832, -24},
    { 912, 840, -136},
    { 1168, 616, -128},
    { 1488, 616, 24},
    { 1864, 600, 40},
    { 1848, 480, 0},
    { 1704, 376, 0},
    { 1656, 320, 24},
    { 1616, 384, -88},
    { 1584, 424, -248},
    { 1416, 128, -248},
    { 1000, -304, -72},
    { 808, -488, -176},
    { 1248, -200, -288},
    { 1408, 40, -264},
    { 1536, 248, -280},
    { 1656, 240, -160},
    { 1792, 320, -200},
    { 1616, 440, -224},
    { 1416, 464, -144},
    { 1368, 480, -48},
    { 1368, 480, -120},
    { 1328, 576, -224},
    { 1216, 1056, -328},
    { 1136, 1480, -144},
    { 768, 752, -120},
    { 1128, 952, -88},
    { 1080, 648, -152},
    { 1312, 648, -72},
    { 1648, 688, 8},
    { -2040, 672, 8},
    { 2000, 544, 64},
    { 1848, 304, 144},
    { 1744, 248, 48},
    { 1608, 304, -136},
    { 1424, 312, -200},
    { 1184, 24, -120},
    { 792, -320, -8},
    { 704, -304, -272},
    { 1080, -264, -184},
    { 1520, -80, -136},
    { 1824, 240, -304},
    { 1976, 360, -280},
    { 1576, 432, -200},
    { 1208, 408, -152},
    { 1312, 472, -264},
    { 1592, 496, -88},
    { 1600, 552, -56},
    { 1440, 544, 72},
    { 1304, 928, -56},
    { 1216, 1904, 176},
    { 952, 552, -80},
    { 920, 1080, 152},
    { 856, 880, 32},
    { 1120, 744, 0},
    { 1456, 584, 16},
    { 1592, 432, 152},
    { 1528, 520, -8},
    { 1544, 384, 0},
    { 1616, 344, -72},
    { 1632, 344, -128},
    { 1520, 416, -168},
    { 1192, 80, -232},
    { 1096, -376, -40},
    { 816, -392, -96},
    { 1344, -232, -72},
    { 1592, 224, -360},
    { 1520, 280, -224},
    { 1592, 288, -192},
    { 1504, 328, -272},
    { 1320, 336, -160},
    { 1304, 416, 8},
    { 1416, 536, 32},
    { 1416, 632, 32},
    { 1224, 1264, -200},
    { 1344, 1456, -328},
    { 936, 888, 40},
    { 1024, 960, 8},
    { 1152, 720, -8},
    { 1152, 728, -88},
    { 1376, 672, 8},
    { 1872, 632, 112},
    { 1840, 472, 120},
    { 1768, 320, 80},
    { 1656, 328, 24},
    { 1616, 368, -112},
    { 1440, 368, -208},
    { 904, 208, -200},
    { 944, -184, -120},
    { 768, -168, -568},
    { 944, -168, -368},
    { 1296, -72, -224},
    { 1400, 80, -288},
    { 1536, 152, -56},
    { 1728, 232, 8},
    { 1704, 448, -16},
    { 1632, 568, -56},
    { 1696, 688, -48},
    { 1792, 808, -16},
    { 1456, 672, -120},
    { 1064, 1072, -680},
    { 1256, 1032, -496},
    { 928, 528, -144},
    { 1088, 640, -128},
    { 960, 720, -160},
    { 1112, 864, -256},
    { 1432, 816, -184},
    { 1616, 432, 56},
    { 1488, 472, -40},
    { 1448, 504, -112},
    { 1584, 472, -128},
    { 1704, 408, -112},
    { 1664, 312, -224},
    { 1152, 24, -432},
    { 1008, -384, -312},
    { 744, -488, -304},
    { 1248, -232, -352},
    { 1472, -48, -288},
    { 1720, 256, -408},
    { 1808, 264, -336},
    { 1840, 320, -336},
    { 1592, 408, -224},
    { 1328, 440, -128},
    { 1272, 576, 64},
    { 1192, 608, -112},
    { 1144, 568, -168},
    { 1072, 728, -32},
    { 1320, 992, 120},
    { 800, 920, 192},
    { 992, 832, 152},
    { 1088, 816, 96},
    { 1088, 760, 8},
    { 1528, 800, 88},
    { -2000, 824, 176},
    { -1856, 576, 208},
    { -2048, 216, 168},
    { 1760, 144, 80},
    { 1608, 240, -96},
    { 1448, 344, -224},
    { 1200, 240, -144},
    { 864, -192, -48},
    { 768, -248, -272},
    { 744, -200, -408},
    { 1256, -80, -200},
    { 1608, 128, -256},
    { 1696, 168, -168},
    { 2040, 264, -160},
    { -2008, 432, -128},
    { 1904, 592, -48},
    { 1840, 688, -32},
    { 1664, 616, 8},
    { 1600, 512, 72},
    { 1216, 592, 56},
    { 1272, 1128, 16},
    { 752, 1208, 0},
    { 968, 824, 112},
    { 912, 896, 56},
    { 1008, 856, -72},
    { 1360, 776, 96},
    { 1976, 752, 200},
    { -1936, 512, 160},
    { 2008, 352, 160},
    { 1960, 240, 80},
    { 1960, 280, -40},
    { 1776, 376, -120},
    { 1480, 272, -200},
    { 896, -128, -200},
    { 944, -392, -280},
    { 952, -176, -496},
    { 1200, -72, -288},
    { 1336, 296, -216},
    { 1496, 352, -136},
    { 1688, 312, -96},
    { 1792, 312, -40},
    { 1792, 416, -56},
    { 1840, 600, -56},
    { 1712, 792, 128},
    { 1472, 616, 16},
    { 1152, 928, -304},
    { 1144, 1496, -288},
    { 976, 904, 16},
    { 872, 1016, -120},
    { 976, 904, -8},
    { 1080, 816, -144},
    { 1416, 688, -48},
    { 1840, 688, 96},
    { 1984, 576, 104},
    { 1936, 480, 104},
    { 1944, 384, 96},
    { 1992, 384, 0},
    { 1800, 336, 72},
    { 1520, 232, -200},
    { 1048, -184, -120},
    { 800, -448, -176},
    { 688, -440, -72},
    { 1112, -296, 32},
    { 1488, 0, -104},
    { 1704, -88, -144},
    { 1864, 104, -216},
    { 1664, 304, -144},
    { 1432, 408, -96},
    { 1536, 592, -328},
    { 1640, 616, -112},
    { 1520, 656, -32},
    { 1232, 896, -368},
    { 1616, 1088, -160},
    { 1008, 832, -96},
    { 1128, 904, -96},
    { 896, 880, -8},
    { 896, 784, -120},
    { 1312, 728, 0},
    { 1688, 616, 88},
    { 1688, 488, 16},
    { 1640, 392, 32},
    { 1680, 432, 32},
    { 1760, 368, -80},
    { 1584, 296, -160},
    { 1328, 104, -160},
    { 1088, -184, -112},
    { 888, -296, -272},
    { 1024, -232, -240},
    { 1312, -128, -128},
    { 1504, 168, -216},
    { 1616, 184, -104},
    { 1744, 312, -232},
    { 1520, 376, -232},
    { 1368, 400, -136},
    { 1384, 488, 88},
    { 1480, 592, 88},
    { 1280, 584, -24},
    { 1096, 944, -472},
    { 1560, 1224, -376},
    { 848, 800, -144},
    { 1304, 760, -64},
    { 960, 880, -248},
    { 1056, 704, -184},
    { 1408, 672, -40},
    { 1696, 512, 104},
    { 1504, 424, 112},
    { 1552, 464, -16},
    { 1704, 504, -64},
    { 1760, 472, -8},
    { 1624, 368, -104},
    { 1424, 200, -200},
    { 1304, -176, -152},
    { 984, -320, -224},
    { 1184, -216, -144},
    { 1200, -8, -160},
    { 1320, 192, -320},
    { 1376, 168, -200},
    { 1472, 264, -312},
    { 1336, 280, -216},
    { 1328, 360, -144},
    { 1392, 488, 24},
    { 1496, 616, 88},
    { 1520, 656, -48},
    { 1192, 792, -40},
    { 1448, 1200, -344},
    { 768, 960, -136},
    { 1304, 776, -120},
    { 952, 752, -216},
    { 984, 792, -200},
    { 1296, 680, -48},
    { 1704, 584, 8},
    { 1480, 424, 80},
    { 1488, 416, 16},
    { 1536, 368, 16},
    { 1640, 360, -72},
    { 1528, 344, -112},
    { 1368, 168, -56},
    { 1008, -104, -72},
    { 928, -208, -136},
    { 1144, -88, -216},
    { 1216, -8, -80},
    { 1384, 224, -184},
    { 1480, 280, -168},
    { 1584, 304, -280},
    { 1424, 344, -384},
    { 1400, -24, -320},
    { 1464, 168, 400},
    { 1264, 840, 104},
    { 1216, 768, 104},
    { 1008, 1072, -136},
    { 1392, 1352, -88},
    { 1048, 704, 112},
    { 1248, 936, -48},
    { 1040, 776, -152},
    { 1120, 664, -120},
    { 1312, 576, -16},
    { 1736, 584, 24},
    { 1632, 448, 24},
    { 1528, 328, 24},
    { 1544, 440, -104},
    { 1560, 344, -136},
    { 1504, 304, -248},
    { 1216, 0, -272},
    { 864, -288, -120},
    { 856, -280, -304},
    { 944, -232, -312},
    { 1496, -128, -96},
    { 1656, 168, -224},
    { 1600, 200, -152},
    { 1864, 400, -272},
    { 1712, 440, -184},
    { 1536, 512, -104},
    { 1456, 624, 64},
    { 1280, 632, 16},
    { 1144, 520, -96},
    { 976, 672, -200},
    { 1248, 1000, -120},
    { 704, 1184, 104},
    { 1304, 840, -96},
    { 1112, 704, -216},
    { 1264, 712, -216},
    { 1552, 696, -48},
    { 1888, 600, -8},
    { 1864, 592, -8},
    { 1808, 504, 80},
    { 1920, 536, 48},
    { 1816, 328, 168},
    { 1560, 200, 112},
    { 1256, 48, 144},
    { 896, -208, 48},
    { 632, 8, 224},
    { 1080, -320, 336},
    { 1224, -40, 248},
    { 1640, 56, 32},
    { 1720, -48, -96},
    { 1680, 56, -112},
    { 1560, 168, -88},
    { 1552, 232, -160},
    { 1648, 432, -128},
    { 1720, 576, -128},
    { 1688, 672, -88},
    { 1416, 960, -144},
    { 1232, 1200, -320},
    { 896, 792, -32},
    { 1016, 688, -72},
    { 864, 736, -152},
    { 1056, 784, -168},
    { 1432, 840, -80},
    { 1936, 824, 64},
    { -2008, 696, 152},
    { -1920, 808, 112},
    { -1744, 1048, 112},
    { -1760, 1336, 200},
    { -1920, 1480, 16},
    { 1816, 1368, -96},
    { 1320, 1176, -264},
    { 848, 840, -432},
    { 480, 8, -256},
    { -40, -104, -592},
    { -448, -224, -544},
    { -368, -248, -640},
    { -304, -360, -472},
    { -368, 88, -512},
    { -536, 240, -496},
    { -640, 0, -312},
    { -616, -136, -224},
    { -648, -144, -352},
    { -760, -184, -544},
    { -1000, -232, -480},
    { -1072, -336, -272},
    { -1264, -424, -304},
    { -1448, 56, -104},
    { -1368, 688, -48},
    { -1080, 360, -80},
    { -880, -320, -56},
    { -464, -264, -168},
    { -216, 8, -336},
    { -160, 224, -544},
    { -40, 160, -544},
    { 208, 160, -520},
    { 584, 528, -656},
    { 1272, 216, -528},
    { 1944, 456, -256},
    { -1792, 416, 336},
    { -1296, 1144, 400},
    { -1624, 1456, -248},
    { 2040, 832, -184},
    { 1776, 600, 88},
    { 1480, 624, 96},
    { 1384, 432, 168},
    { 1256, 424, 176},
    { 1160, 456, 128},
    { 1048, 624, -64},
    { 968, 672, -32},
    { 960, 680, 128},
    { 848, 832, 264},
    { 792, 896, 144},
    { 784, 520, -64},
    { 744, 616, 32},
    { 1184, 856, 176},
    { -1920, 776, 216},
    { -1824, 560, 240},
    { -1888, 568, 144},
    { -2008, 496, 144},
    { 1808, 368, 96},
    { 1592, 392, -8},
    { 1344, 240, 72},
    { 1376, 176, -16},
    { 1168, 120, -40},
    { 904, -160, 40},
    { 1096, -104, 152},
    { 1400, 80, -8},
    { 1416, 216, -80},
    { 1528, 264, 16},
    { 1832, 392, -144},
    { 1984, 472, -160},
    { -1952, 528, -128},
    { 1960, 648, -80},
    { 1608, 840, -88},
    { 1440, 512, -192},
    { 1312, 744, 56},
    { 864, 984, 384},
    { 880, 904, 160},
    { 696, 816, 200},
    { 952, 768, 24},
    { 1312, 704, 120},
    { 1736, 744, 184},
    { 1784, 696, 152},
    { 1968, 536, 240},
    { -2032, 400, 224},
    { 1888, 328, 0},
    { 1648, 376, -112},
    { 1512, 144, -160},
    { 1416, -40, -32},
    { 912, -168, 0},
    { 1048, -128, -88},
    { 1104, -80, 56},
    { 1576, 216, -88},
    { 1488, 184, -16},
    { 1536, 336, -152},
    { 1632, 296, -152},
    { 1840, 440, -112},
    { 1856, 640, -88},
    { 1640, 752, 32},
    { 1400, 784, -64},
    { 1304, 744, -248},
    { 1224, 736, -216},
    { 896, 624, 72},
    { 752, 648, 136},
    { 680, 832, 136},
    { 840, 560, 56},
    { 1088, 632, 96},
    { 1432, 760, 176},
    { 1744, 744, 152},
    { 1768, 568, 248},
    { 1856, 512, 272},
    { 1920, 448, 48},
    { 1712, 376, 0},
    { 1488, 280, -64},
    { 1304, 8, -64},
    { 1096, -80, -112},
    { 840, -128, -192},
    { 960, -64, -184},
    { 1264, -16, -72},
    { 1560, 168, -152},
    { 1472, 264, -72},
    { 1624, 344, -64},
    { 1720, 400, -16},
    { 1992, 528, 64},
    { -1984, 720, 120},
    { 1848, 832, 136},
    { 1256, 912, 112},
    { 1080, 480, -184},
    { 896, 504, 80},
    { 664, 768, 352},
    { 712, 752, 160},
    { 792, 760, 160},
    { 1016, 736, 8},
    { 1456, 704, 72},
    { 1960, 704, 168},
    { -2040, 680, 168},
    { 2016, 616, 160},
    { -1912, 480, 152},
    { 1952, 344, 104},
    { 1632, 320, 56},
    { 1304, 128, 16},
    { 888, -280, 112},
    { 832, -48, -64},
    { 744, 88, -296},
    { 1000, 96, -176},
    { 1304, 80, 152},
    { 1816, 272, 64},
    { 1896, 536, -72},
    { 1896, 600, -152},
    { 1752, 640, -256},
    { 1592, 560, -192},
    { 1384, 480, 72},
    { 1392, 432, 48},
    { 1256, 424, -120},
    { 1104, 568, -216},
    { 920, 664, -88},
    { 784, 784, 120},
    { 712, 904, 40},
    { 848, 728, -72},
    { 1000, 640, -104},
    { 1488, 696, -8},
    { 2032, 784, 128},
    { -1944, 680, 144},
    { -1992, 544, 128},
    { 1952, 352, 88},
    { 1696, 296, -136},
    { 1504, 280, -392},
    { 1304, -40, -72},
    { 736, -280, 8},
    { 896, 0, -304},
    { 816, 144, -432},
    { 888, 136, -48},
    { 1272, 200, -32},
    { 1608, 344, -56},
    { 2032, 584, -152},
    { 2032, 664, -224},
    { 1672, 488, -88},
    { 1384, 416, -64},
    { 1288, 376, -144},
    { 1312, 312, -224},
    { 1288, 424, -248},
    { 1192, 624, -200},
    { 1000, 768, -24},
    { 760, 1000, -88},
    { 704, 784, -208},
    { 1112, 440, -144},
    { 760, 616, 24},
    { 1144, 824, -24},
    { 1824, 848, 88},
    { -2040, 624, 192},
    { 2000, 504, 168},
    { 1952, 280, 160},
    { 1656, 232, 16},
    { 1456, 344, -40},
    { 1320, 336, -64},
    { 1248, 240, -32},
    { 1112, 80, -16},
    { 864, 64, -136},
    { 808, 32, -72},
    { 1200, 88, 56},
    { 1560, 336, -184},
    { 1528, 432, -280},
    { 1544, 368, -224},
    { 1504, 280, -144},
    { 1504, 288, -104},
    { 1528, 408, -208},
    { 1392, 528, -168},
    { 1392, 520, -56},
    { 1448, 520, -128},
    { 1336, 680, -144},
    { 816, 784, -16},
    { 632, 960, 144},
    { 1096, 752, -152},
    { 1144, 536, -136},
    { 1280, 664, -16},
    { 1808, 832, 88},
    { 1888, 712, 112},
    { 1840, 480, 96},
    { 1688, 288, 88},
    { 1480, 280, -16},
    { 1352, 320, -96},
    { 1248, 160, -32},
    { 936, -88, 40},
    { 1112, 32, -176},
    { 912, 80, -240},
    { 984, 80, -64},
    { 1192, 144, 16},
    { 1528, 344, -40},
    { 1736, 472, -88},
    { 1832, 560, -192},
    { 1656, 616, -192},
    { 1360, 496, -160},
    { 1232, 392, -48},
    { 1224, 320, -96},
    { 1248, 392, -168},
    { 1200, 592, -224},
    { 936, 688, -152},
    { 664, 928, 80},
    { 912, 912, -416},
    { 1144, 496, -208},
    { 1224, 592, -160},
    { 1552, 680, 24},
    { -1968, 672, 64},
    { 1944, 512, 32},
    { 1808, 416, 0},
    { 1680, 400, 16},
    { 1472, 472, -40},
    { 1496, 688, -216},
    { 1344, 712, -152},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}


// ----------------------------------------------------------------
// Sample captured: 2015-09-25 15:18:36 local
AccelRawData *activity_sample_100_steps_ron_1(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME walk_100_ron_1
  //> TEST_EXPECTED 100
  //> TEST_EXPECTED_MIN 90
  //> TEST_EXPECTED_MAX 120
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { 176, -144, -984},
    { 176, -120, -968},
    { 184, -128, -976},
    { 176, -136, -992},
    { 184, -136, -992},
    { 184, -136, -984},
    { 184, -128, -984},
    { 184, -128, -984},
    { 184, -128, -992},
    { 184, -128, -992},
    { 168, -136, -984},
    { 184, -128, -1000},
    { 184, -120, -992},
    { 184, -120, -992},
    { 184, -120, -992},
    { 176, -120, -992},
    { 184, -104, -984},
    { 160, -168, -984},
    { 144, -168, -976},
    { 152, -136, -976},
    { 160, -136, -976},
    { 144, -128, -952},
    { 152, -120, -952},
    { 232, -112, -960},
    { 256, -128, -936},
    { 200, -112, -896},
    { 248, -72, -920},
    { 208, -72, -896},
    { 288, -72, -928},
    { 200, -104, -864},
    { 280, -80, -840},
    { 312, -80, -840},
    { 344, 0, -864},
    { 376, 64, -904},
    { 424, 16, -968},
    { 472, 48, -992},
    { 496, 24, -992},
    { 464, 16, -952},
    { 416, -24, -928},
    { 432, 8, -912},
    { 480, 24, -912},
    { 496, -8, -920},
    { 512, 0, -864},
    { 512, -24, -864},
    { 536, -32, -848},
    { 528, -40, -824},
    { 528, -64, -824},
    { 528, -48, -824},
    { 568, -56, -856},
    { 584, -32, -872},
    { 544, -48, -848},
    { 504, -48, -824},
    { 456, -80, -792},
    { 456, -72, -808},
    { 480, -64, -784},
    { 512, -56, -792},
    { 528, -72, -800},
    { 520, -96, -784},
    { 544, -72, -808},
    { 584, -72, -824},
    { 560, -96, -736},
    { 648, -8, -712},
    { 872, 88, -704},
    { 912, 136, -536},
    { 832, 256, -520},
    { 848, 288, -464},
    { 888, 288, -424},
    { 880, 208, -360},
    { 848, 208, -312},
    { 864, 208, -264},
    { 872, 176, -120},
    { 888, 168, -104},
    { 880, 144, -56},
    { 896, 144, -40},
    { 912, 176, -8},
    { 952, 184, 0},
    { 1000, 184, 8},
    { 1056, 176, -48},
    { 1176, 216, 96},
    { 1328, 232, 144},
    { 1144, 208, 24},
    { 800, 224, -224},
    { 672, 216, -208},
    { 720, 96, -56},
    { 784, 8, 96},
    { 920, 24, 144},
    { 904, 136, 120},
    { 896, 216, 16},
    { 872, 168, -24},
    { 880, 136, -16},
    { 848, 120, -24},
    { 816, 104, -24},
    { 848, 112, -24},
    { 944, 120, 0},
    { 976, 160, 16},
    { 1016, 144, 88},
    { 1224, 112, 88},
    { 1288, 176, 96},
    { 1024, 168, 80},
    { 1112, 112, 56},
    { 1136, 80, 56},
    { 896, 112, 24},
    { 824, 136, -32},
    { 784, 152, -8},
    { 768, 160, 48},
    { 800, 144, 80},
    { 832, 96, 136},
    { 872, 112, 136},
    { 912, 104, 152},
    { 912, 120, 112},
    { 944, 112, 0},
    { 1152, 104, 16},
    { 1312, 128, 96},
    { 1016, 184, -72},
    { 944, 192, -200},
    { 792, 208, -144},
    { 808, 80, -8},
    { 848, 16, 64},
    { 888, 72, 48},
    { 864, 64, 56},
    { 848, 144, -24},
    { 864, 144, -48},
    { 848, 144, -64},
    { 832, 168, -56},
    { 832, 144, -104},
    { 856, 120, -96},
    { 1024, 136, -24},
    { 1016, 144, 24},
    { 1232, 144, 56},
    { 1360, 184, 8},
    { 1088, 184, 72},
    { 1056, 144, 104},
    { 1096, 104, 144},
    { 952, 136, 120},
    { 824, 176, 64},
    { 832, 192, -8},
    { 800, 128, 56},
    { 800, 128, 56},
    { 808, 96, 56},
    { 784, 104, 56},
    { 848, 136, 104},
    { 888, 184, 88},
    { 928, 184, 80},
    { 912, 144, -32},
    { 1240, 120, 152},
    { 1216, 200, 152},
    { 984, 216, -48},
    { 872, 176, -176},
    { 824, 200, -136},
    { 832, 96, 0},
    { 928, 64, 56},
    { 928, 120, 72},
    { 888, 144, 40},
    { 848, 152, -24},
    { 816, 160, -56},
    { 816, 176, -48},
    { 856, 160, -40},
    { 888, 136, -40},
    { 960, 176, -40},
    { 992, 200, 0},
    { 1000, 168, 64},
    { 1192, 160, 104},
    { 1200, 184, 104},
    { 1072, 184, 96},
    { 1064, 152, 104},
    { 1088, 112, 120},
    { 936, 120, 80},
    { 832, 112, 16},
    { 792, 136, 0},
    { 800, 120, 40},
    { 816, 96, 104},
    { 832, 96, 88},
    { 856, 120, 72},
    { 928, 160, 120},
    { 936, 168, 120},
    { 960, 160, 64},
    { 960, 168, -40},
    { 1296, 152, 104},
    { 1184, 184, 56},
    { 880, 200, -136},
    { 784, 192, -160},
    { 816, 144, -56},
    { 944, 80, 56},
    { 976, 72, 120},
    { 904, 88, 120},
    { 840, 136, 32},
    { 816, 112, 0},
    { 848, 152, -8},
    { 856, 192, -40},
    { 848, 208, -72},
    { 840, 184, -96},
    { 888, 168, -80},
    { 992, 176, -40},
    { 968, 144, 40},
    { 1200, 120, 112},
    { 1320, 152, 104},
    { 1024, 128, 128},
    { 984, 104, 88},
    { 1048, 96, 96},
    { 1024, 192, 48},
    { 936, 264, 0},
    { 864, 232, 8},
    { 824, 168, 24},
    { 808, 88, 88},
    { 816, 56, 144},
    { 848, 64, 160},
    { 896, 112, 168},
    { 896, 144, 136},
    { 944, 128, 88},
    { 904, 136, -64},
    { 1280, 136, 16},
    { 1248, 176, 16},
    { 1008, 200, -168},
    { 824, 184, -216},
    { 736, 128, -144},
    { 776, 40, 0},
    { 872, 32, 80},
    { 880, 48, 112},
    { 904, 128, 64},
    { 848, 160, -8},
    { 848, 136, -48},
    { 856, 200, -96},
    { 848, 184, -128},
    { 824, 152, -136},
    { 880, 128, -120},
    { 1008, 160, -56},
    { 1032, 176, -8},
    { 1144, 152, 56},
    { 1288, 136, 88},
    { 1120, 136, 88},
    { 976, 152, 56},
    { 1048, 128, 64},
    { 1080, 136, 96},
    { 952, 192, 64},
    { 888, 192, 24},
    { 824, 176, 8},
    { 776, 136, 32},
    { 784, 72, 64},
    { 808, 64, 80},
    { 840, 96, 72},
    { 904, 128, 96},
    { 936, 160, 104},
    { 936, 160, 40},
    { 944, 152, -32},
    { 1256, 152, 56},
    { 1104, 184, 8},
    { 1032, 176, -104},
    { 880, 168, -136},
    { 792, 144, -128},
    { 832, 48, -16},
    { 888, 40, 48},
    { 880, 64, 64},
    { 832, 112, 32},
    { 824, 152, 0},
    { 840, 176, -48},
    { 840, 200, -56},
    { 840, 208, -96},
    { 872, 168, -96},
    { 992, 152, -72},
    { 1064, 168, -32},
    { 1296, 176, 48},
    { 1352, 224, 48},
    { 1104, 120, 112},
    { 968, 64, 88},
    { 920, 88, 48},
    { 944, 112, 40},
    { 912, 160, 72},
    { 888, 232, 80},
    { 848, 160, 72},
    { 840, 168, 88},
    { 848, 104, 104},
    { 832, 80, 72},
    { 856, 88, 48},
    { 904, 96, 40},
    { 848, 104, 48},
    { 912, 128, 48},
    { 896, 152, -32},
    { 1184, 216, 56},
    { 1152, 208, 96},
    { 1000, 216, -48},
    { 912, 184, -144},
    { 848, 144, -120},
    { 864, 72, -16},
    { 928, 48, 48},
    { 920, 48, 72},
    { 880, 88, 16},
    { 824, 120, -24},
    { 800, 120, -56},
    { 808, 160, -80},
    { 784, 200, -96},
    { 840, 168, -96},
    { 976, 176, -32},
    { 1056, 216, 24},
    { 952, 192, 16},
    { 1224, 168, 40},
    { 1288, 200, 72},
    { 1072, 152, 96},
    { 1016, 96, 56},
    { 1032, 112, 96},
    { 960, 128, 104},
    { 864, 176, 64},
    { 824, 176, 40},
    { 816, 144, 72},
    { 824, 88, 112},
    { 808, 88, 104},
    { 816, 96, 80},
    { 896, 120, 88},
    { 880, 144, 96},
    { 936, 152, 72},
    { 912, 160, -72},
    { 1344, 160, 96},
    { 1248, 232, 104},
    { 904, 208, -152},
    { 824, 192, -184},
    { 880, 128, -40},
    { 920, 80, 64},
    { 904, 56, 120},
    { 872, 88, 72},
    { 816, 128, 16},
    { 800, 120, -8},
    { 824, 144, -40},
    { 792, 200, -72},
    { 792, 192, -120},
    { 904, 176, -80},
    { 1048, 184, -32},
    { 1000, 168, 16},
    { 1264, 160, 80},
    { 1408, 224, 80},
    { 1096, 168, 96},
    { 976, 80, 88},
    { 968, 96, 88},
    { 920, 120, 80},
    { 872, 200, 56},
    { 856, 176, 64},
    { 832, 152, 72},
    { 848, 104, 104},
    { 840, 72, 112},
    { 816, 80, 72},
    { 856, 136, 56},
    { 880, 152, 80},
    { 952, 136, 96},
    { 952, 136, 8},
    { 1304, 136, 120},
    { 1272, 208, 96},
    { 960, 208, -128},
    { 864, 192, -200},
    { 776, 120, -120},
    { 808, 56, 32},
    { 904, 32, 112},
    { 912, 80, 136},
    { 880, 160, 48},
    { 832, 176, -16},
    { 840, 168, -56},
    { 840, 192, -64},
    { 824, 232, -104},
    { 792, 160, -104},
    { 936, 144, -48},
    { 1096, 200, 32},
    { 992, 200, 16},
    { 1040, 160, 8},
    { 1176, 168, 80},
    { 1152, 232, 96},
    { 1064, 208, 64},
    { 1040, 160, 72},
    { 992, 152, 72},
    { 928, 168, 48},
    { 896, 152, 64},
    { 848, 160, 72},
    { 832, 144, 88},
    { 808, 88, 128},
    { 808, 80, 120},
    { 792, 80, 80},
    { 864, 96, 96},
    { 912, 144, 112},
    { 936, 168, 96},
    { 936, 176, -8},
    { 952, 168, -64},
    { 1296, 192, 96},
    { 1136, 232, 24},
    { 864, 224, -144},
    { 840, 216, -160},
    { 880, 136, -40},
    { 920, 56, 56},
    { 912, 32, 104},
    { 848, 72, 88},
    { 800, 88, 56},
    { 792, 104, 40},
    { 824, 144, -8},
    { 824, 176, -24},
    { 872, 200, -72},
    { 920, 176, -104},
    { 1032, 216, -80},
    { 1000, 200, 32},
    { 1200, 136, 136},
    { 1312, 184, 112},
    { 1112, 200, 128},
    { 1032, 120, 128},
    { 1024, 88, 96},
    { 936, 120, 72},
    { 864, 168, 24},
    { 848, 176, 40},
    { 824, 136, 64},
    { 784, 104, 112},
    { 784, 80, 128},
    { 792, 88, 104},
    { 824, 104, 104},
    { 888, 152, 112},
    { 936, 152, 88},
    { 936, 184, -32},
    { 1280, 176, 80},
    { 1304, 240, 88},
    { 968, 208, -152},
    { 880, 104, -168},
    { 864, 88, -16},
    { 872, 0, 104},
    { 904, 24, 112},
    { 880, 64, 120},
    { 832, 152, 40},
    { 840, 168, 16},
    { 856, 184, -24},
    { 880, 256, -72},
    { 856, 248, -88},
    { 824, 184, -104},
    { 880, 144, -56},
    { 1008, 168, -16},
    { 1016, 184, 24},
    { 992, 120, 88},
    { 1168, 96, 144},
    { 1328, 104, 168},
    { 960, 184, 120},
    { 912, 112, 56},
    { 1032, 96, 56},
    { 1024, 160, 16},
    { 920, 176, 16},
    { 856, 176, 8},
    { 824, 112, 24},
    { 792, 96, 96},
    { 808, 72, 112},
    { 824, 80, 88},
    { 872, 112, 72},
    { 944, 152, 104},
    { 936, 160, 64},
    { 912, 160, -48},
    { 928, 144, -112},
    { 1264, 120, 72},
    { 1192, 168, 0},
    { 904, 192, -168},
    { 808, 168, -120},
    { 864, 96, 16},
    { 928, 56, 88},
    { 912, 96, 64},
    { 856, 120, 32},
    { 808, 176, -24},
    { 808, 152, -48},
    { 848, 120, -8},
    { 840, 192, -40},
    { 832, 136, -24},
    { 880, 160, -40},
    { 1008, 160, -24},
    { 1008, 176, -16},
    { 1144, 136, 48},
    { 1288, 152, 88},
    { 1184, 200, 48},
    { 976, 152, 64},
    { 992, 104, 56},
    { 1000, 128, 32},
    { 920, 200, 8},
    { 896, 192, 32},
    { 848, 192, 48},
    { 816, 120, 80},
    { 784, 64, 112},
    { 776, 64, 96},
    { 792, 112, 64},
    { 880, 144, 80},
    { 952, 144, 112},
    { 1000, 176, 40},
    { 1008, 128, 16},
    { 1240, 136, 128},
    { 1136, 208, 48},
    { 992, 216, -120},
    { 816, 200, -144},
    { 800, 128, -88},
    { 880, 40, 24},
    { 880, 48, 40},
    { 848, 88, 32},
    { 840, 152, -16},
    { 832, 160, -16},
    { 840, 168, -48},
    { 864, 240, -72},
    { 856, 200, -80},
    { 864, 160, -72},
    { 960, 136, -40},
    { 1008, 136, 8},
    { 1040, 136, 56},
    { 1216, 128, 112},
    { 1264, 192, 104},
    { 1024, 224, 80},
    { 968, 128, 48},
    { 1016, 120, 56},
    { 960, 152, 16},
    { 912, 168, 32},
    { 872, 128, 48},
    { 816, 136, 72},
    { 800, 112, 80},
    { 800, 88, 88},
    { 800, 120, 72},
    { 848, 144, 80},
    { 888, 152, 96},
    { 944, 168, 96},
    { 944, 168, -8},
    { 1064, 168, -8},
    { 1232, 144, 112},
    { 1064, 232, -24},
    { 976, 208, -128},
    { 840, 200, -144},
    { 800, 128, -88},
    { 872, 40, 0},
    { 880, 56, 64},
    { 864, 80, 48},
    { 824, 112, 24},
    { 816, 152, -8},
    { 840, 168, -24},
    { 872, 168, -32},
    { 880, 240, -80},
    { 872, 192, -96},
    { 904, 152, -80},
    { 984, 136, -40},
    { 912, 112, 0},
    { 1168, 136, 48},
    { 1360, 160, 104},
    { 1072, 240, 96},
    { 1032, 152, 72},
    { 1128, 104, 112},
    { 1040, 176, 48},
    { 920, 208, -16},
    { 856, 176, -24},
    { 792, 80, 16},
    { 768, 96, 56},
    { 776, 80, 104},
    { 768, 96, 104},
    { 848, 120, 104},
    { 920, 136, 120},
    { 944, 136, 64},
    { 936, 152, -64},
    { 1360, 144, 56},
    { 1168, 208, 8},
    { 984, 240, -216},
    { 864, 208, -200},
    { 856, 128, -88},
    { 872, 24, 32},
    { 848, 24, 88},
    { 800, 64, 48},
    { 824, 112, 8},
    { 856, 136, -16},
    { 880, 176, -64},
    { 872, 192, -112},
    { 848, 224, -168},
    { 872, 168, -136},
    { 984, 160, -64},
    { 1032, 168, -16},
    { 1016, 168, 24},
    { 1216, 160, 80},
    { 1280, 240, 80},
    { 1072, 224, 64},
    { 1000, 120, 24},
    { 1040, 112, 48},
    { 984, 112, 48},
    { 904, 144, 32},
    { 848, 152, 24},
    { 848, 128, 40},
    { 840, 96, 88},
    { 824, 88, 88},
    { 800, 104, 40},
    { 864, 152, 56},
    { 848, 176, 72},
    { 904, 192, 64},
    { 896, 208, -32},
    { 976, 168, -56},
    { 1248, 168, 80},
    { 1096, 184, -40},
    { 968, 192, -200},
    { 824, 152, -152},
    { 824, 72, -32},
    { 896, 40, 72},
    { 896, 72, 112},
    { 864, 136, 88},
    { 840, 176, 16},
    { 840, 184, -16},
    { 856, 208, -56},
    { 856, 240, -96},
    { 824, 176, -112},
    { 832, 136, -128},
    { 992, 136, -64},
    { 1048, 160, 0},
    { 976, 168, 16},
    { 1272, 160, 88},
    { 1304, 224, 112},
    { 944, 192, 40},
    { 984, 128, 8},
    { 1096, 120, 104},
    { 1008, 160, 112},
    { 880, 208, 24},
    { 808, 192, 24},
    { 816, 160, 24},
    { 832, 80, 104},
    { 832, 80, 96},
    { 856, 96, 88},
    { 880, 136, 104},
    { 896, 160, 96},
    { 912, 144, 88},
    { 904, 168, 0},
    { 976, 168, -24},
    { 1224, 200, 80},
    { 1056, 208, -32},
    { 992, 184, -96},
    { 856, 192, -136},
    { 792, 128, -80},
    { 856, 56, 24},
    { 944, 64, 56},
    { 936, 112, 80},
    { 888, 144, 32},
    { 848, 184, -56},
    { 856, 176, -80},
    { 840, 200, -104},
    { 824, 168, -104},
    { 808, 144, -112},
    { 888, 152, -80},
    { 1048, 160, 8},
    { 992, 168, 56},
    { 1048, 160, 56},
    { 1192, 176, 88},
    { 1136, 264, 40},
    { 952, 184, 8},
    { 976, 96, 24},
    { 1056, 120, 56},
    { 968, 224, 32},
    { 952, 272, 32},
    { 888, 168, 88},
    { 824, 120, 104},
    { 808, 56, 120},
    { 832, 40, 136},
    { 800, 80, 88},
    { 856, 136, 72},
    { 904, 136, 64},
    { 944, 168, 16},
    { 1136, 168, 72},
    { 1264, 168, 104},
    { 952, 208, -128},
    { 1000, 192, -168},
    { 872, 208, -160},
    { 808, 88, -64},
    { 816, 72, -8},
    { 872, 64, 40},
    { 896, 72, 24},
    { 840, 128, 8},
    { 832, 192, -40},
    { 848, 176, -40},
    { 856, 152, -48},
    { 848, 192, -80},
    { 824, 168, -112},
    { 952, 160, -96},
    { 1000, 192, -48},
    { 1008, 168, 16},
    { 1176, 216, 40},
    { 1240, 280, 32},
    { 1104, 256, 72},
    { 992, 160, 32},
    { 968, 120, 64},
    { 976, 120, 88},
    { 928, 176, 96},
    { 880, 168, 96},
    { 824, 160, 88},
    { 792, 88, 80},
    { 800, 72, 64},
    { 808, 96, 40},
    { 872, 128, 56},
    { 912, 152, 72},
    { 920, 152, 96},
    { 920, 144, 64},
    { 880, 192, -56},
    { 1288, 176, 112},
    { 1232, 192, 104},
    { 960, 208, -64},
    { 880, 160, -88},
    { 800, 160, -88},
    { 864, 96, 16},
    { 904, 88, 72},
    { 896, 120, 80},
    { 840, 160, 32},
    { 816, 136, 16},
    { 848, 168, 16},
    { 888, 168, -8},
    { 864, 184, -32},
    { 840, 168, -72},
    { 888, 136, -40},
    { 984, 144, 16},
    { 944, 152, 72},
    { 1160, 128, 128},
    { 1344, 168, 144},
    { 1048, 224, 104},
    { 976, 144, 40},
    { 1088, 96, 72},
    { 1040, 136, 56},
    { 952, 192, 24},
    { 872, 168, 48},
    { 816, 160, 56},
    { 792, 96, 72},
    { 800, 72, 104},
    { 776, 96, 72},
    { 856, 128, 104},
    { 904, 168, 112},
    { 928, 184, 88},
    { 952, 208, -16},
    { 1072, 200, -16},
    { 1176, 160, 80},
    { 1000, 176, -56},
    { 1048, 136, -80},
    { 856, 160, -96},
    { 792, 160, -80},
    { 856, 64, 16},
    { 872, 80, 88},
    { 888, 112, 80},
    { 856, 144, 56},
    { 840, 232, -32},
    { 832, 200, -80},
    { 848, 216, -104},
    { 840, 160, -96},
    { 880, 128, -72},
    { 1000, 128, -16},
    { 1032, 160, 16},
    { 976, 168, 40},
    { 1184, 184, 72},
    { 1296, 240, 104},
    { 1048, 152, 72},
    { 952, 128, -16},
    { 992, 120, 32},
    { 952, 152, 32},
    { 928, 192, 80},
    { 888, 232, 96},
    { 856, 160, 104},
    { 840, 88, 136},
    { 832, 40, 128},
    { 800, 48, 64},
    { 824, 88, 40},
    { 872, 136, 56},
    { 936, 184, 72},
    { 920, 224, -16},
    { 1224, 208, 72},
    { 1200, 224, 120},
    { 952, 232, -80},
    { 856, 176, -160},
    { 840, 120, -72},
    { 888, 72, 48},
    { 928, 88, 112},
    { 912, 128, 120},
    { 848, 168, 88},
    { 816, 168, 40},
    { 848, 152, 0},
    { 872, 208, -24},
    { 872, 208, -80},
    { 872, 192, -120},
    { 952, 184, -96},
    { 1056, 192, -8},
    { 968, 152, 56},
    { 1120, 112, 88},
    { 1272, 168, 128},
    { 1112, 208, 136},
    { 1000, 192, 56},
    { 944, 160, 16},
    { 960, 160, 48},
    { 960, 184, 64},
    { 960, 160, 104},
    { 912, 192, 96},
    { 856, 120, 112},
    { 832, 72, 128},
    { 816, 56, 128},
    { 800, 72, 80},
    { 840, 88, 56},
    { 872, 128, 48},
    { 896, 152, 32},
    { 928, 168, -16},
    { 1008, 184, 0},
    { 1208, 208, 120},
    { 1104, 256, -40},
    { 848, 248, -224},
    { 768, 152, -136},
    { 888, 40, 40},
    { 968, 16, 136},
    { 968, 72, 120},
    { 896, 56, 160},
    { 832, 120, 48},
    { 832, 104, -8},
    { 856, 144, -48},
    { 832, 160, -72},
    { 832, 224, -96},
    { 880, 192, -80},
    { 1008, 208, -32},
    { 1016, 160, 16},
    { 1112, 120, 80},
    { 1256, 136, 112},
    { 1128, 208, 88},
    { 1008, 144, 80},
    { 984, 104, 64},
    { 992, 136, 64},
    { 936, 176, 48},
    { 888, 168, 64},
    { 872, 184, 48},
    { 856, 120, 96},
    { 848, 72, 120},
    { 840, 56, 120},
    { 824, 80, 96},
    { 856, 112, 88},
    { 880, 120, 104},
    { 960, 160, 88},
    { 944, 176, 0},
    { 1128, 184, 48},
    { 1200, 176, 112},
    { 952, 200, -32},
    { 904, 184, -120},
    { 800, 160, -104},
    { 864, 104, 0},
    { 960, 56, 104},
    { 952, 80, 112},
    { 896, 152, 56},
    { 832, 136, -16},
    { 824, 128, -40},
    { 824, 168, -56},
    { 840, 192, -72},
    { 856, 192, -80},
    { 920, 192, -64},
    { 1040, 192, -32},
    { 1000, 176, 16},
    { 1024, 112, 48},
    { 1160, 128, 112},
    { 1248, 184, 120},
    { 984, 176, 72},
    { 928, 112, 16},
    { 1024, 112, 48},
    { 1000, 184, 32},
    { 936, 224, 32},
    { 872, 224, 56},
    { 832, 152, 72},
    { 808, 72, 120},
    { 808, 48, 128},
    { 808, 80, 104},
    { 840, 112, 88},
    { 880, 128, 112},
    { 928, 136, 88},
    { 904, 144, -32},
    { 1072, 160, -8},
    { 1216, 184, 72},
    { 1024, 232, -40},
    { 976, 224, -120},
    { 800, 168, -112},
    { 808, 104, -48},
    { 896, 32, 56},
    { 936, 64, 104},
    { 904, 112, 80},
    { 848, 128, 32},
    { 832, 120, -16},
    { 840, 128, -48},
    { 856, 192, -88},
    { 864, 168, -88},
    { 872, 168, -88},
    { 976, 176, -48},
    { 1016, 192, -8},
    { 1008, 128, 64},
    { 1224, 128, 104},
    { 1392, 192, 152},
    { 992, 168, 80},
    { 1040, 64, 64},
    { 1032, 64, 40},
    { 888, 120, -16},
    { 856, 176, -8},
    { 832, 176, 24},
    { 832, 152, 80},
    { 832, 96, 128},
    { 816, 80, 104},
    { 792, 96, 56},
    { 864, 128, 64},
    { 920, 152, 72},
    { 920, 160, -8},
    { 1048, 120, -8},
    { 1232, 168, 144},
    { 1048, 200, -16},
    { 960, 216, -160},
    { 864, 208, -152},
    { 832, 96, -64},
    { 880, 16, 48},
    { 904, 40, 80},
    { 864, 96, 40},
    { 840, 144, 8},
    { 840, 176, -24},
    { 832, 184, -48},
    { 776, 160, -64},
    { 840, 168, -72},
    { 1016, 192, -24},
    { 1104, 208, 0},
    { 968, 176, -16},
    { 1216, 160, 0},
    { 1384, 216, 16},
    { 1064, 216, 40},
    { 960, 136, 24},
    { 1000, 96, 64},
    { 1000, 104, 88},
    { 920, 160, 88},
    { 880, 192, 72},
    { 856, 96, 120},
    { 848, 64, 160},
    { 840, 32, 120},
    { 800, 40, 72},
    { 808, 72, 40},
    { 880, 120, 40},
    { 912, 160, 40},
    { 944, 184, -24},
    { 920, 192, -56},
    { 1240, 208, 112},
    { 1176, 224, 96},
    { 896, 232, -80},
    { 752, 192, -128},
    { 864, 88, -24},
    { 968, 0, 72},
    { 992, 56, 96},
    { 936, 152, 40},
    { 864, 184, -16},
    { 824, 184, -48},
    { 832, 192, -72},
    { 832, 176, -80},
    { 832, 224, -104},
    { 888, 200, -72},
    { 984, 208, -48},
    { 976, 200, 8},
    { 1120, 160, 72},
    { 1240, 144, 128},
    { 1216, 216, 120},
    { 912, 168, 64},
    { 1032, 80, 40},
    { 1080, 96, 64},
    { 984, 168, 24},
    { 920, 192, 40},
    { 856, 160, 56},
    { 816, 152, 80},
    { 800, 80, 112},
    { 792, 72, 104},
    { 816, 88, 80},
    { 888, 128, 128},
    { 920, 176, 112},
    { 912, 184, 24},
    { 920, 192, -88},
    { 1256, 184, 56},
    { 1088, 152, -8},
    { 968, 208, -168},
    { 808, 176, -176},
    { 824, 152, -64},
    { 920, 80, 80},
    { 976, 80, 200},
    { 944, 168, 112},
    { 888, 176, 40},
    { 872, 152, -32},
    { 872, 160, -88},
    { 856, 152, -136},
    { 808, 136, -144},
    { 800, 168, -144},
    { 992, 176, -72},
    { 1112, 192, 32},
    { 1040, 152, 96},
    { 1144, 152, 72},
    { 1232, 176, 120},
    { 1064, 160, 112},
    { 1024, 80, 96},
    { 1072, 80, 120},
    { 984, 136, 88},
    { 920, 240, 48},
    { 848, 208, 40},
    { 832, 184, 56},
    { 832, 80, 88},
    { 824, 56, 96},
    { 824, 88, 72},
    { 856, 144, 88},
    { 888, 168, 120},
    { 952, 176, 120},
    { 952, 168, 56},
    { 1136, 176, 120},
    { 1104, 192, 48},
    { 1040, 208, -104},
    { 936, 216, -120},
    { 792, 168, -112},
    { 840, 32, 0},
    { 936, 40, 80},
    { 968, 64, 88},
    { 920, 96, 64},
    { 864, 128, 0},
    { 840, 184, -32},
    { 832, 192, -48},
    { 856, 184, -80},
    { 840, 216, -96},
    { 816, 192, -120},
    { 952, 160, -56},
    { 1048, 160, 48},
    { 936, 112, 80},
    { 1208, 112, 88},
    { 1360, 224, 120},
    { 1056, 256, 96},
    { 992, 152, 24},
    { 1016, 96, 72},
    { 1016, 120, 64},
    { 912, 152, 56},
    { 864, 168, 48},
    { 840, 144, 72},
    { 824, 56, 128},
    { 816, 72, 120},
    { 768, 88, 64},
    { 792, 112, 64},
    { 888, 144, 120},
    { 968, 176, 104},
    { 1096, 168, 56},
    { 1368, 176, 128},
    { 1080, 176, -48},
    { 944, 192, -232},
    { 792, 176, -152},
    { 816, 96, -16},
    { 856, 48, 88},
    { 888, 80, 104},
    { 856, 128, 56},
    { 808, 144, 16},
    { 808, 168, -32},
    { 832, 160, -40},
    { 872, 192, -48},
    { 880, 208, -80},
    { 920, 192, -80},
    { 1088, 168, -16},
    { 1040, 160, -8},
    { 1008, 120, 8},
    { 1208, 184, 40},
    { 1176, 272, 16},
    { 1088, 192, 48},
    { 968, 128, 64},
    { 976, 128, 80},
    { 952, 144, 96},
    { 928, 208, 104},
    { 928, 184, 112},
    { 856, 160, 120},
    { 808, 88, 112},
    { 800, 56, 88},
    { 792, 72, 64},
    { 824, 136, 40},
    { 872, 168, 64},
    { 904, 184, 80},
    { 952, 184, 24},
    { 1088, 168, 16},
    { 1264, 200, 144},
    { 1080, 256, -16},
    { 928, 208, -192},
    { 744, 120, -176},
    { 792, 56, -72},
    { 912, 0, 64},
    { 912, 32, 104},
    { 872, 136, 80},
    { 856, 184, 24},
    { 840, 176, -16},
    { 864, 208, -40},
    { 856, 232, -96},
    { 816, 168, -152},
    { 848, 112, -128},
    { 1032, 128, -32},
    { 1064, 152, 48},
    { 896, 112, 56},
    { 1152, 112, 80},
    { 1304, 160, 160},
    { 1072, 200, 152},
    { 952, 184, 40},
    { 968, 136, 40},
    { 1008, 152, 64},
    { 952, 168, 72},
    { 944, 216, 56},
    { 880, 152, 96},
    { 816, 104, 104},
    { 792, 64, 112},
    { 784, 64, 104},
    { 752, 80, 64},
    { 872, 112, 96},
    { 920, 152, 96},
    { 960, 200, 32},
    { 912, 208, -104},
    { 1256, 160, 64},
    { 1248, 160, 144},
    { 944, 192, -40},
    { 840, 184, -136},
    { 784, 144, -80},
    { 872, 64, 32},
    { 960, 48, 104},
    { 952, 112, 96},
    { 896, 160, 32},
    { 840, 176, -40},
    { 824, 120, -64},
    { 840, 184, -80},
    { 816, 144, -72},
    { 808, 136, -88},
    { 936, 152, -40},
    { 1064, 184, 8},
    { 1072, 168, 96},
    { 1304, 152, 144},
    { 1224, 200, 152},
    { 1040, 128, 88},
    { 984, 56, 0},
    { 1024, 88, 24},
    { 960, 184, 0},
    { 920, 256, 8},
    { 880, 232, 56},
    { 856, 200, 80},
    { 808, 72, 160},
    { 800, 16, 168},
    { 776, 64, 104},
    { 880, 88, 120},
    { 920, 152, 96},
    { 912, 176, -8},
    { 872, 168, -96},
    { 1192, 176, 40},
    { 1136, 128, 0},
    { 1008, 176, -72},
    { 976, 184, -80},
    { 808, 184, -136},
    { 808, 88, -48},
    { 904, 56, 16},
    { 960, 48, 80},
    { 904, 96, 24},
    { 856, 176, -56},
    { 840, 160, -96},
    { 832, 208, -120},
    { 816, 160, -112},
    { 840, 128, -72},
    { 936, 144, -24},
    { 1024, 168, 0},
    { 952, 168, 24},
    { 1104, 136, 32},
    { 1384, 168, 104},
    { 1128, 168, 160},
    { 936, 96, 56},
    { 1024, 56, 72},
    { 1032, 136, 72},
    { 912, 224, 24},
    { 864, 248, 32},
    { 824, 112, 72},
    { 816, 96, 104},
    { 816, 56, 112},
    { 824, 72, 96},
    { 840, 104, 88},
    { 864, 136, 96},
    { 888, 152, 96},
    { 864, 136, -8},
    { 1080, 152, 32},
    { 1336, 168, 168},
    { 976, 240, -40},
    { 968, 248, -184},
    { 840, 216, -136},
    { 840, 80, -72},
    { 912, -16, 32},
    { 928, 32, 80},
    { 864, 72, 16},
    { 840, 96, 24},
    { 856, 144, 0},
    { 856, 184, -48},
    { 872, 176, -88},
    { 848, 216, -104},
    { 832, 176, -120},
    { 928, 176, -104},
    { 984, 296, 40},
    { 1000, 144, 136},
    { 1288, 112, 152},
    { 1256, 192, 112},
    { 1080, 200, 56},
    { 1072, 104, 64},
    { 1064, 112, 64},
    { 912, 128, 16},
    { 840, 128, 16},
    { 816, 112, 16},
    { 816, 88, 64},
    { 816, 96, 104},
    { 808, 112, 96},
    { 784, 136, 64},
    { 872, 160, 96},
    { 896, 160, 104},
    { 944, 160, 72},
    { 912, 144, -72},
    { 1328, 112, 72},
    { 1216, 160, 56},
    { 944, 224, -120},
    { 824, 224, -176},
    { 824, 176, -88},
    { 920, 80, 40},
    { 960, 56, 136},
    { 920, 104, 112},
    { 864, 104, 40},
    { 824, 112, -8},
    { 824, 128, -40},
    { 840, 168, -72},
    { 824, 176, -80},
    { 832, 176, -112},
    { 944, 152, -56},
    { 1064, 152, 0},
    { 960, 136, 40},
    { 1120, 144, 56},
    { 1320, 176, 104},
    { 1120, 208, 128},
    { 912, 144, 16},
    { 944, 104, 0},
    { 1008, 136, 24},
    { 968, 200, 48},
    { 928, 232, 72},
    { 880, 168, 80},
    { 856, 136, 104},
    { 840, 72, 112},
    { 816, 32, 80},
    { 816, 56, 56},
    { 872, 104, 48},
    { 904, 152, 64},
    { 976, 184, 48},
    { 984, 192, -64},
    { 1120, 200, 24},
    { 1192, 176, 152},
    { 1032, 216, 24},
    { 784, 216, -176},
    { 720, 128, -88},
    { 880, 40, 56},
    { 968, 40, 128},
    { 928, 88, 136},
    { 888, 168, 72},
    { 840, 176, 8},
    { 824, 152, -32},
    { 832, 168, -64},
    { 792, 128, -80},
    { 848, 104, -64},
    { 984, 128, 0},
    { 1112, 176, 64},
    { 1096, 184, 72},
    { 1264, 160, 104},
    { 1264, 240, 80},
    { 1088, 184, 48},
    { 992, 104, 8},
    { 952, 88, 32},
    { 904, 128, 24},
    { 864, 184, 64},
    { 856, 224, 88},
    { 832, 160, 104},
    { 832, 112, 144},
    { 840, 64, 176},
    { 840, 56, 144},
    { 880, 88, 112},
    { 880, 120, 72},
    { 904, 152, 40},
    { 896, 176, -56},
    { 1096, 184, -32},
    { 1144, 192, 48},
    { 976, 184, -48},
    { 928, 144, -96},
    { 808, 128, -32},
    { 832, 64, 56},
    { 944, 32, 112},
    { 952, 40, 120},
    { 896, 128, 48},
    { 856, 128, -32},
    { 840, 168, -72},
    { 864, 192, -96},
    { 848, 160, -80},
    { 864, 128, -72},
    { 896, 136, -40},
    { 1016, 200, -24},
    { 1000, 160, 40},
    { 1184, 112, 112},
    { 1368, 152, 128},
    { 1120, 184, 120},
    { 984, 152, 72},
    { 984, 104, 40},
    { 992, 136, 32},
    { 904, 184, 40},
    { 880, 208, 48},
    { 856, 160, 96},
    { 856, 104, 128},
    { 840, 64, 136},
    { 800, 72, 80},
    { 816, 96, 56},
    { 880, 128, 80},
    { 896, 144, 88},
    { 912, 184, 8},
    { 1040, 200, 32},
    { 1216, 200, 136},
    { 984, 232, -56},
    { 944, 200, -152},
    { 840, 192, -144},
    { 864, 72, -24},
    { 920, 16, 88},
    { 896, 64, 88},
    { 856, 96, 104},
    { 856, 176, 40},
    { 872, 248, -32},
    { 872, 256, -96},
    { 808, 248, -136},
    { 824, 168, -104},
    { 928, 120, -40},
    { 1088, 152, 64},
    { 984, 168, 56},
    { 1152, 160, 64},
    { 1312, 176, 96},
    { 1096, 184, 112},
    { 1024, 136, 80},
    { 1016, 112, 72},
    { 984, 176, 40},
    { 912, 216, 24},
    { 904, 224, 48},
    { 856, 144, 80},
    { 816, 96, 120},
    { 816, 56, 152},
    { 816, 64, 144},
    { 808, 88, 120},
    { 872, 112, 112},
    { 896, 136, 88},
    { 944, 144, 32},
    { 904, 200, -80},
    { 1208, 160, 72},
    { 1256, 192, 88},
    { 944, 256, -80},
    { 800, 216, -144},
    { 808, 80, -32},
    { 928, 0, 80},
    { 976, 0, 128},
    { 944, 96, 88},
    { 888, 128, 40},
    { 848, 152, -48},
    { 848, 176, -80},
    { 848, 152, -80},
    { 816, 176, -80},
    { 840, 168, -72},
    { 936, 152, -40},
    { 1040, 168, 8},
    { 1008, 136, 88},
    { 1144, 128, 104},
    { 1312, 168, 96},
    { 1096, 176, 136},
    { 1000, 112, 56},
    { 1024, 72, 72},
    { 976, 112, 48},
    { 920, 168, 48},
    { 872, 160, 56},
    { 816, 112, 64},
    { 816, 128, 80},
    { 824, 64, 112},
    { 816, 64, 96},
    { 840, 96, 80},
    { 872, 120, 96},
    { 896, 128, 72},
    { 912, 136, 24},
    { 952, 136, -32},
    { 1272, 176, 128},
    { 1104, 208, 80},
    { 936, 232, -80},
    { 816, 184, -120},
    { 824, 120, -56},
    { 944, 40, 32},
    { 976, 56, 88},
    { 944, 120, 80},
    { 888, 128, 32},
    { 840, 136, -8},
    { 824, 144, -24},
    { 864, 136, -48},
    { 848, 168, -40},
    { 856, 192, -64},
    { 904, 176, -40},
    { 984, 176, 0},
    { 960, 152, 64},
    { 1200, 128, 128},
    { 1416, 160, 200},
    { 1048, 144, 128},
    { 912, 72, 24},
    { 1080, 56, 48},
    { 1016, 120, 16},
    { 944, 200, -16},
    { 872, 192, 40},
    { 832, 128, 88},
    { 832, 144, 112},
    { 824, 56, 176},
    { 800, 56, 128},
    { 832, 72, 104},
    { 904, 96, 120},
    { 888, 112, 96},
    { 904, 136, -16},
    { 1048, 128, -16},
    { 1224, 168, 112},
    { 1032, 208, 8},
    { 904, 208, -128},
    { 808, 192, -128},
    { 888, 104, 8},
    { 1016, 56, 120},
    { 976, 88, 112},
    { 888, 152, 16},
    { 816, 128, -40},
    { 816, 104, -56},
    { 816, 120, -64},
    { 816, 136, -88},
    { 856, 152, -88},
    { 976, 160, -48},
    { 1072, 200, -16},
    { 1056, 176, 16},
    { 1208, 176, 64},
    { 1264, 224, 128},
    { 1056, 136, 152},
    { 968, 80, 48},
    { 976, 64, 48},
    { 960, 112, 16},
    { 952, 136, 24},
    { 904, 192, 72},
    { 856, 160, 96},
    { 824, 72, 128},
    { 808, 56, 160},
    { 792, 56, 128},
    { 824, 72, 96},
    { 864, 112, 96},
    { 896, 120, 88},
    { 920, 128, 32},
    { 1136, 104, 16},
    { 1304, 144, 144},
    { 1032, 200, -16},
    { 944, 200, -120},
    { 824, 176, -144},
    { 816, 112, -64},
    { 904, 8, 64},
    { 968, 56, 120},
    { 920, 80, 96},
    { 856, 128, 32},
    { 832, 120, -16},
    { 856, 136, -56},
    { 888, 136, -64},
    { 912, 216, -72},
    { 880, 184, -80},
    { 872, 152, -64},
    { 944, 160, -24},
    { 1000, 144, 64},
    { 1216, 160, 168},
    { 1400, 224, 208},
    { 976, 144, 104},
    { 904, 32, 48},
    { 1064, 32, 24},
    { 1048, 96, -8},
    { 920, 160, 16},
    { 872, 256, 32},
    { 856, 152, 72},
    { 808, 152, 96},
    { 792, 72, 136},
    { 784, 40, 136},
    { 832, 56, 128},
    { 880, 104, 112},
    { 952, 128, 80},
    { 872, 136, -32},
    { 1312, 120, 88},
    { 1216, 176, 96},
    { 1056, 248, -56},
    { 896, 240, -168},
    { 792, 184, -184},
    { 792, 64, -80},
    { 856, 0, 16},
    { 888, 56, 64},
    { 912, 88, 56},
    { 896, 152, 8},
    { 896, 160, -48},
    { 896, 88, -64},
    { 880, 152, -104},
    { 856, 120, -88},
    { 896, 144, -80},
    { 984, 160, -32},
    { 952, 144, 32},
    { 1184, 136, 96},
    { 1456, 200, 144},
    { 1016, 208, 128},
    { 976, 88, 40},
    { 1120, 48, 80},
    { 984, 120, 40},
    { 904, 152, 8},
    { 848, 152, 32},
    { 832, 128, 56},
    { 808, 136, 88},
    { 792, 80, 128},
    { 784, 88, 80},
    { 824, 88, 80},
    { 880, 112, 72},
    { 952, 120, 88},
    { 952, 136, 8},
    { 1312, 136, 80},
    { 1192, 184, 80},
    { 968, 224, -120},
    { 864, 224, -200},
    { 816, 152, -176},
    { 856, 48, -48},
    { 920, 0, 72},
    { 920, 56, 128},
    { 880, 120, 56},
    { 824, 96, 32},
    { 840, 104, -16},
    { 840, 120, -56},
    { 864, 168, -96},
    { 864, 144, -104},
    { 936, 152, -88},
    // elapsed: 1 minutes
    { 1048, 152, -48},
    { 1000, 128, 32},
    { 1200, 120, 72},
    { 1336, 192, 112},
    { 1056, 232, 112},
    { 968, 136, 56},
    { 1024, 112, 80},
    { 976, 120, 72},
    { 880, 160, 48},
    { 904, 168, 16},
    { 848, 96, 80},
    { 840, 80, 88},
    { 832, 40, 104},
    { 800, 56, 104},
    { 824, 96, 96},
    { 864, 144, 96},
    { 936, 168, 80},
    { 960, 192, 24},
    { 1272, 144, 136},
    { 1280, 184, 88},
    { 944, 208, -104},
    { 888, 176, -168},
    { 800, 136, -136},
    { 832, 40, -16},
    { 912, 40, 56},
    { 896, 40, 104},
    { 856, 80, 72},
    { 848, 120, 32},
    { 832, 144, -8},
    { 824, 168, -64},
    { 824, 224, -80},
    { 856, 184, -80},
    { 928, 152, -48},
    { 1032, 160, -8},
    { 1016, 160, 32},
    { 1144, 128, 80},
    { 1264, 120, 112},
    { 1136, 160, 128},
    { 968, 160, 88},
    { 1000, 120, 56},
    { 1024, 160, 56},
    { 920, 176, 40},
    { 896, 208, 48},
    { 888, 184, 80},
    { 816, 104, 96},
    { 776, 64, 104},
    { 808, 40, 128},
    { 808, 56, 128},
    { 856, 88, 144},
    { 896, 112, 152},
    { 944, 144, 104},
    { 872, 152, -24},
    { 1336, 160, 96},
    { 1288, 216, 104},
    { 960, 216, -72},
    { 848, 176, -160},
    { 800, 152, -120},
    { 888, 72, 16},
    { 952, 32, 96},
    { 888, 112, 64},
    { 840, 112, 0},
    { 824, 136, -56},
    { 832, 176, -80},
    { 840, 208, -88},
    { 840, 184, -72},
    { 896, 152, -40},
    { 1040, 160, 16},
    { 1048, 152, 40},
    { 1168, 136, 56},
    { 1352, 136, 112},
    { 1160, 176, 160},
    { 1024, 104, 64},
    { 960, 72, 8},
    { 936, 112, 24},
    { 896, 152, 24},
    { 936, 216, 72},
    { 896, 208, 144},
    { 840, 208, 136},
    { 808, 96, 168},
    { 800, 56, 136},
    { 808, 72, 80},
    { 912, 112, 88},
    { 912, 168, 64},
    { 912, 168, 48},
    { 920, 192, -32},
    { 1008, 160, 0},
    { 1192, 160, 112},
    { 1056, 224, 8},
    { 904, 224, -144},
    { 752, 144, -104},
    { 808, 56, 16},
    { 944, 40, 80},
    { 976, 80, 120},
    { 928, 120, 80},
    { 864, 136, 16},
    { 840, 136, -16},
    { 840, 120, -64},
    { 808, 160, -104},
    { 776, 144, -120},
    { 904, 144, -56},
    { 1192, 224, 80},
    { 1040, 216, 128},
    { 1120, 104, 56},
    { 1232, 168, 88},
    { 1072, 152, 112},
    { 1040, 112, 80},
    { 1000, 72, 32},
    { 992, 88, 40},
    { 936, 192, 56},
    { 928, 216, 88},
    { 872, 272, 64},
    { 824, 168, 104},
    { 784, 88, 144},
    { 784, 48, 144},
    { 752, 48, 120},
    { 848, 48, 120},
    { 920, 80, 104},
    { 984, 112, 64},
    { 1112, 120, 40},
    { 1304, 152, 136},
    { 1040, 240, 32},
    { 888, 248, -120},
    { 752, 224, -144},
    { 824, 104, -32},
    { 912, 32, 72},
    { 952, 64, 136},
    { 912, 96, 96},
    { 872, 120, 16},
    { 848, 128, -16},
    { 840, 152, -56},
    { 848, 200, -80},
    { 856, 168, -72},
    { 904, 176, -64},
    { 976, 168, -24},
    { 1016, 160, 32},
    { 944, 120, 80},
    { 1176, 80, 112},
    { 1336, 112, 176},
    { 1104, 176, 160},
    { 872, 136, 32},
    { 1024, 88, 40},
    { 1096, 136, 40},
    { 984, 184, 40},
    { 920, 200, 40},
    { 848, 200, 48},
    { 776, 120, 96},
    { 768, 56, 112},
    { 784, 48, 112},
    { 792, 72, 88},
    { 888, 128, 112},
    { 944, 128, 128},
    { 888, 184, 8},
    { 1080, 160, 16},
    { 1272, 184, 136},
    { 1000, 224, -8},
    { 928, 216, -168},
    { 840, 168, -152},
    { 864, 80, -48},
    { 936, 16, 48},
    { 936, 56, 104},
    { 888, 144, 32},
    { 832, 136, -16},
    { 824, 144, -48},
    { 800, 128, -64},
    { 808, 160, -80},
    { 848, 152, -80},
    { 1024, 160, -48},
    { 1096, 184, 0},
    { 1104, 160, 24},
    { 1208, 160, 56},
    { 1240, 224, 120},
    { 1064, 184, 136},
    { 1016, 96, 48},
    { 1032, 104, 56},
    { 952, 152, 24},
    { 896, 160, 32},
    { 864, 168, 40},
    { 824, 120, 88},
    { 800, 80, 128},
    { 784, 64, 112},
    { 784, 80, 80},
    { 848, 96, 80},
    { 872, 136, 88},
    { 920, 144, 80},
    { 888, 168, -56},
    { 1400, 200, 104},
    { 1192, 224, 80},
    { 960, 240, -136},
    { 864, 184, -176},
    { 840, 120, -112},
    { 896, 32, -8},
    { 936, 48, 56},
    { 888, 120, 32},
    { 848, 160, -16},
    { 832, 168, -40},
    { 832, 168, -48},
    { 808, 152, -48},
    { 808, 168, -64},
    { 848, 144, -56},
    { 992, 144, -24},
    { 1080, 152, -8},
    { 1088, 152, 16},
    { 1168, 128, 40},
    { 1176, 160, 56},
    { 1088, 160, 88},
    { 1000, 152, 48},
    { 1016, 168, 64},
    { 984, 176, 32},
    { 944, 152, 48},
    { 880, 144, 88},
    { 824, 136, 88},
    { 824, 96, 96},
    { 840, 72, 120},
    { 840, 72, 96},
    { 848, 96, 56},
    { 856, 120, 32},
    { 872, 144, 24},
    { 872, 152, 32},
    { 864, 160, -32},
    { 1208, 152, 72},
    { 1360, 216, 168},
    { 1064, 280, -24},
    { 928, 176, -232},
    { 744, 136, -224},
    { 776, 16, -128},
    { 944, 24, 0},
    { 1016, 96, 64},
    { 952, 152, 32},
    { 896, 168, -16},
    { 904, 160, -40},
    { 912, 232, -72},
    { 912, 304, -104},
    { 960, 320, -56},
    { 976, 360, -96},
    { 968, 392, -96},
    { 976, 456, -160},
    { 984, 464, -168},
    { 928, 520, -232},
    { 888, 576, -336},
    { 848, 552, -392},
    { 784, 528, -480},
    { 704, 488, -576},
    { 608, 400, -632},
    { 520, 320, -680},
    { 440, 160, -728},
    { 352, 104, -760},
    { 360, 72, -792},
    { 280, -8, -800},
    { 256, -16, -800},
    { 216, -144, -800},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}




// ----------------------------------------------------------------
// Sample captured: 2015-09-25 15:20:22 local
AccelRawData *activity_sample_100_steps_ron_2(int *len) {
  // The unit tests parse the //> TEST_.* lines below for test values
  //> TEST_NAME walk_100_ron_2
  //> TEST_EXPECTED 100
  //> TEST_EXPECTED_MIN 95
  //> TEST_EXPECTED_MAX 120
  //> TEST_WEIGHT 1.0
  static AccelRawData samples[] = {
    // elapsed: 0 minutes
    { 16, -16, -1000},
    { 32, -24, -1032},
    { 64, -48, -1040},
    { 88, 0, -1048},
    { 56, -24, -1024},
    { 88, -56, -984},
    { 112, -96, -992},
    { 120, -88, -984},
    { 120, -96, -1000},
    { 120, -64, -984},
    { 152, -64, -976},
    { 176, -88, -960},
    { 224, -128, -968},
    { 240, -144, -984},
    { 232, -152, -976},
    { 200, -152, -976},
    { 160, -160, -1024},
    { 136, -144, -1048},
    { 152, -112, -1056},
    { 192, -120, -1024},
    { 216, -112, -1016},
    { 248, -56, -1024},
    { 168, -96, -976},
    { 128, -104, -968},
    { 96, -72, -968},
    { 112, -48, -984},
    { 104, -72, -1024},
    { 104, -96, -1016},
    { 104, -128, -1024},
    { 112, -128, -992},
    { 96, -120, -960},
    { 104, -136, -952},
    { 88, -168, -952},
    { 64, -176, -976},
    { 56, -152, -1000},
    { 120, -184, -992},
    { 80, -200, -960},
    { 0, -184, -1000},
    { 120, -144, -1008},
    { 120, -128, -1008},
    { 144, -104, -1008},
    { 128, -112, -1000},
    { 136, -104, -976},
    { 136, -88, -984},
    { 152, -88, -976},
    { 176, -80, -976},
    { 168, -48, -992},
    { 184, -72, -984},
    { 200, -64, -984},
    { 192, -64, -984},
    { 200, -72, -976},
    { 200, -72, -992},
    { 208, -80, -968},
    { 200, -48, -984},
    { 200, -40, -992},
    { 168, -16, -968},
    { 160, -24, -1000},
    { 200, -8, -1008},
    { 240, -8, -1000},
    { 232, -48, -1016},
    { 232, -48, -992},
    { 224, -40, -968},
    { 232, -56, -976},
    { 248, -32, -952},
    { 248, -24, -952},
    { 240, -40, -952},
    { 224, -32, -928},
    { 232, -56, -928},
    { 240, -40, -912},
    { 256, -48, -864},
    { 280, -88, -824},
    { 376, -64, -800},
    { 424, -64, -712},
    { 520, 72, -680},
    { 672, 168, -600},
    { 848, 272, -592},
    { 1008, 320, -552},
    { 960, 376, -512},
    { 968, 424, -496},
    { 952, 288, -344},
    { 944, 256, -240},
    { 912, 168, -232},
    { 856, 216, -216},
    { 840, 224, -128},
    { 824, 200, -144},
    { 808, 136, -104},
    { 832, 160, -104},
    { 792, 144, -120},
    { 840, 176, -144},
    { 1008, 200, -136},
    { 1064, 184, -104},
    { 1240, 208, -48},
    { 1336, 200, -40},
    { 1216, 176, 56},
    { 1048, 128, 48},
    { 1008, 96, 80},
    { 928, 120, 80},
    { 832, 160, 40},
    { 824, 184, 16},
    { 848, 176, 0},
    { 856, 104, 64},
    { 856, 144, 72},
    { 880, 128, 56},
    { 904, 128, 80},
    { 912, 144, 88},
    { 920, 160, 112},
    { 968, 176, 88},
    { 960, 168, 8},
    { 1160, 168, 104},
    { 1128, 184, 72},
    { 992, 144, -64},
    { 944, 120, -128},
    { 736, 144, -96},
    { 744, 104, -32},
    { 824, 48, 96},
    { 896, 128, 96},
    { 904, 168, 80},
    { 848, 240, 0},
    { 808, 200, -40},
    { 872, 176, -16},
    { 896, 120, 48},
    { 864, 112, 0},
    { 888, 136, -24},
    { 968, 152, -8},
    { 1016, 152, 72},
    { 1216, 144, 152},
    { 1304, 176, 160},
    { 1120, 184, 88},
    { 1000, 128, 8},
    { 968, 96, 16},
    { 968, 88, 56},
    { 880, 128, 72},
    { 856, 160, 72},
    { 880, 176, 80},
    { 824, 128, 136},
    { 816, 152, 120},
    { 856, 112, 136},
    { 864, 104, 128},
    { 864, 104, 112},
    { 904, 104, 96},
    { 1024, 104, 88},
    { 1008, 120, 32},
    { 1232, 144, 64},
    { 1144, 192, -8},
    { 976, 216, -136},
    { 832, 184, -128},
    { 840, 88, -16},
    { 856, 8, 104},
    { 840, 8, 120},
    { 824, 72, 88},
    { 800, 128, 16},
    { 824, 160, -8},
    { 880, 168, -16},
    { 904, 232, -40},
    { 888, 232, -96},
    { 848, 176, -120},
    { 992, 168, -48},
    { 1016, 184, -8},
    { 992, 176, 16},
    { 1200, 168, 32},
    { 1280, 200, 56},
    { 1104, 208, 80},
    { 1016, 144, 56},
    { 968, 120, 64},
    { 888, 152, 48},
    { 864, 168, 48},
    { 856, 168, 56},
    { 808, 192, 40},
    { 816, 144, 72},
    { 824, 88, 128},
    { 840, 72, 120},
    { 856, 96, 88},
    { 912, 112, 88},
    { 944, 136, 80},
    { 976, 160, 48},
    { 936, 168, -40},
    { 1336, 160, 120},
    { 1256, 200, 80},
    { 840, 256, -208},
    { 768, 184, -152},
    { 872, 64, 32},
    { 920, -8, 128},
    { 920, 48, 96},
    { 856, 80, 80},
    { 808, 152, 48},
    { 808, 152, -8},
    { 840, 208, 0},
    { 824, 312, -48},
    { 800, 232, -24},
    { 888, 192, -8},
    { 1072, 168, 16},
    { 1024, 176, 8},
    { 1096, 136, 72},
    { 1136, 160, 72},
    { 1112, 192, 96},
    { 976, 184, 64},
    { 992, 168, 56},
    { 1000, 216, 8},
    { 912, 208, -8},
    { 848, 192, 24},
    { 768, 168, 24},
    { 768, 120, 64},
    { 808, 72, 128},
    { 832, 88, 144},
    { 856, 88, 136},
    { 936, 112, 144},
    { 1064, 136, 104},
    { 1000, 160, -40},
    { 1304, 104, 32},
    { 1216, 128, -16},
    { 1008, 200, -152},
    { 856, 216, -184},
    { 808, 96, -112},
    { 816, 8, 0},
    { 832, -24, 64},
    { 872, 48, 40},
    { 824, 96, -8},
    { 792, 168, -48},
    { 792, 168, -96},
    { 816, 184, -104},
    { 808, 184, -104},
    { 824, 168, -104},
    { 920, 184, -64},
    { 1008, 224, -64},
    { 1032, 200, -24},
    { 1272, 216, 64},
    { 1352, 264, 80},
    { 1080, 208, 64},
    { 1016, 128, 24},
    { 1000, 136, -8},
    { 888, 144, -32},
    { 840, 160, -16},
    { 800, 152, 16},
    { 784, 144, 40},
    { 792, 112, 104},
    { 808, 120, 112},
    { 808, 112, 64},
    { 904, 120, 72},
    { 984, 144, 80},
    { 1040, 176, 64},
    { 1024, 192, -32},
    { 1248, 200, 72},
    { 1032, 144, -8},
    { 968, 152, -176},
    { 888, 192, -144},
    { 832, 152, -96},
    { 840, 48, 0},
    { 864, 40, 48},
    { 840, 88, 40},
    { 768, 144, 24},
    { 776, 240, -24},
    { 800, 248, -24},
    { 808, 288, -80},
    { 816, 208, -72},
    { 920, 160, -64},
    { 1064, 264, -48},
    { 1064, 288, -48},
    { 1224, 208, 40},
    { 1264, 264, 80},
    { 1096, 192, 88},
    { 936, 104, 80},
    { 920, 112, 48},
    { 936, 184, 16},
    { 888, 240, 40},
    { 864, 224, 64},
    { 848, 160, 88},
    { 816, 112, 128},
    { 792, 72, 144},
    { 800, 80, 112},
    { 808, 112, 96},
    { 856, 120, 96},
    { 952, 112, 96},
    { 976, 136, 0},
    { 1136, 128, 16},
    { 1248, 136, 104},
    { 1048, 232, -32},
    { 912, 224, -168},
    { 848, 152, -80},
    { 864, 56, 32},
    { 912, 16, 104},
    { 880, 32, 80},
    { 824, 104, 0},
    { 784, 144, -16},
    { 800, 168, -48},
    { 848, 184, -32},
    { 920, 288, -48},
    { 880, 240, -56},
    { 872, 152, -64},
    { 960, 192, -32},
    { 952, 184, 32},
    { 1056, 136, 80},
    { 1304, 96, 144},
    { 1216, 168, 176},
    { 984, 216, 80},
    { 1032, 128, 48},
    { 1072, 136, 72},
    { 912, 136, 48},
    { 840, 120, 40},
    { 824, 88, 56},
    { 808, 64, 112},
    { 792, 64, 144},
    { 792, 80, 128},
    { 832, 128, 96},
    { 880, 160, 152},
    { 952, 208, 128},
    { 952, 232, 24},
    { 1312, 192, 96},
    { 1208, 168, 40},
    { 952, 160, -176},
    { 912, 120, -168},
    { 800, 40, -8},
    { 792, -48, 136},
    { 896, 40, 88},
    { 920, 64, 144},
    { 872, 168, 88},
    { 840, 192, -8},
    { 832, 200, -56},
    { 840, 184, -72},
    { 816, 200, -88},
    { 808, 144, -88},
    { 888, 104, -48},
    { 1064, 192, 16},
    { 1024, 200, 56},
    { 1192, 192, 64},
    { 1328, 216, 80},
    { 1112, 208, 128},
    { 984, 144, 48},
    { 1000, 96, 48},
    { 992, 144, 64},
    { 888, 200, 48},
    { 872, 192, 56},
    { 808, 112, 104},
    { 784, 88, 104},
    { 824, 80, 128},
    { 824, 96, 112},
    { 872, 128, 96},
    { 896, 144, 88},
    { 968, 144, 48},
    { 928, 152, -48},
    { 1280, 120, 80},
    { 1224, 136, 88},
    { 968, 232, -72},
    { 888, 232, -120},
    { 784, 160, -64},
    { 800, 48, 16},
    { 856, 8, 64},
    { 880, 64, 80},
    { 848, 128, 40},
    { 848, 152, -8},
    { 872, 184, -40},
    { 880, 176, -56},
    { 888, 192, -64},
    { 864, 160, -72},
    { 896, 144, -48},
    { 968, 168, -16},
    { 1008, 200, 8},
    { 1104, 152, 112},
    { 1216, 120, 136},
    { 1224, 192, 96},
    { 912, 168, 56},
    { 1048, 88, 48},
    { 1072, 112, 24},
    { 920, 184, 16},
    { 880, 200, 0},
    { 856, 128, 64},
    { 816, 120, 96},
    { 800, 72, 96},
    { 784, 72, 80},
    { 792, 112, 56},
    { 904, 152, 104},
    { 960, 152, 104},
    { 952, 208, -16},
    { 1168, 184, 24},
    { 1216, 200, 56},
    { 1032, 208, -80},
    { 936, 192, -120},
    { 808, 168, -96},
    { 808, 104, -32},
    { 872, 64, 48},
    { 880, 96, 56},
    { 848, 136, 24},
    { 832, 176, -8},
    { 840, 184, -24},
    { 872, 200, -56},
    { 872, 224, -64},
    { 864, 208, -72},
    { 872, 176, -56},
    { 936, 176, -16},
    { 1008, 168, 8},
    { 1064, 104, 120},
    { 1256, 80, 136},
    { 1360, 144, 144},
    { 976, 216, 40},
    { 944, 128, -32},
    { 992, 112, -16},
    { 936, 160, 8},
    { 936, 184, 32},
    { 880, 192, 96},
    { 824, 168, 96},
    { 808, 120, 120},
    { 816, 80, 136},
    { 792, 96, 80},
    { 832, 104, 80},
    { 888, 112, 104},
    { 968, 152, 88},
    { 944, 160, -8},
    { 1240, 184, 64},
    { 1112, 208, -32},
    { 1072, 200, -120},
    { 896, 160, -112},
    { 800, 128, -80},
    { 824, 64, 0},
    { 848, 72, 64},
    { 864, 96, 48},
    { 880, 144, 24},
    { 856, 192, 0},
    { 848, 200, -56},
    { 856, 184, -72},
    { 832, 200, -80},
    { 848, 160, -80},
    { 936, 160, -40},
    { 1080, 160, -16},
    { 1000, 128, 24},
    { 1216, 120, 40},
    { 1368, 160, 72},
    { 1088, 224, 80},
    { 912, 168, 24},
    { 952, 136, 24},
    { 1008, 152, 64},
    { 952, 176, 80},
    { 920, 192, 80},
    { 880, 120, 88},
    { 840, 88, 120},
    { 792, 56, 96},
    { 776, 64, 72},
    { 784, 112, 32},
    { 856, 128, 72},
    { 904, 144, 80},
    { 992, 160, 48},
    { 1152, 176, 80},
    { 1272, 264, 112},
    { 1032, 304, -80},
    { 896, 264, -184},
    { 776, 192, -120},
    { 800, 80, -24},
    { 880, 16, 56},
    { 904, 56, 72},
    { 848, 88, 32},
    { 816, 128, 32},
    { 856, 200, 0},
    { 872, 240, -16},
    { 856, 232, -40},
    { 816, 288, -88},
    { 848, 160, -72},
    { 952, 176, -16},
    { 1048, 184, 16},
    { 1016, 160, 72},
    { 1192, 168, 96},
    { 1296, 216, 88},
    { 1016, 200, 80},
    { 944, 112, 40},
    { 1016, 112, 56},
    { 968, 152, 56},
    { 912, 176, 56},
    { 864, 176, 56},
    { 840, 136, 48},
    { 792, 72, 104},
    { 776, 56, 88},
    { 784, 80, 48},
    { 872, 136, 96},
    { 920, 176, 136},
    { 1000, 184, 88},
    { 968, 192, -16},
    { 1320, 160, 104},
    { 1176, 176, 40},
    { 936, 216, -136},
    { 800, 192, -144},
    { 768, 64, -56},
    { 848, 8, 24},
    { 912, 72, 64},
    { 896, 104, 96},
    { 856, 184, 0},
    { 816, 208, -40},
    { 832, 208, -64},
    { 840, 144, -48},
    { 864, 216, -80},
    { 840, 192, -120},
    { 896, 152, -96},
    { 1056, 136, 0},
    { 1016, 152, 24},
    { 1120, 168, 24},
    { 1264, 184, 72},
    { 1112, 216, 96},
    { 968, 152, 0},
    { 952, 96, 0},
    { 1000, 160, 24},
    { 960, 192, 32},
    { 936, 208, 56},
    { 848, 176, 88},
    { 792, 128, 96},
    { 784, 64, 120},
    { 776, 64, 112},
    { 784, 88, 72},
    { 880, 104, 80},
    { 960, 128, 80},
    { 1016, 184, 16},
    { 1128, 160, -8},
    { 1240, 216, 72},
    { 1064, 248, -40},
    { 952, 240, -128},
    { 792, 176, -112},
    { 800, 80, -40},
    { 880, 0, 64},
    { 896, 16, 96},
    { 864, 72, 48},
    { 840, 112, 8},
    { 832, 168, -32},
    { 856, 184, -48},
    { 872, 176, -72},
    { 880, 216, -80},
    { 920, 184, -72},
    { 1000, 168, -40},
    { 1008, 168, -8},
    { 1056, 120, 64},
    { 1232, 136, 96},
    { 1224, 232, 56},
    { 944, 216, 24},
    { 1000, 96, 24},
    { 1104, 112, 56},
    { 968, 160, 56},
    { 872, 184, 40},
    { 832, 144, 64},
    { 824, 136, 88},
    { 824, 64, 136},
    { 816, 64, 128},
    { 824, 80, 72},
    { 904, 120, 80},
    { 896, 144, 72},
    { 912, 184, 0},
    { 904, 192, -104},
    { 1288, 184, 64},
    { 1232, 176, 48},
    { 896, 224, -112},
    { 736, 144, -144},
    { 808, 40, 24},
    { 936, -8, 120},
    { 976, 40, 136},
    { 928, 168, 128},
    { 856, 232, 32},
    { 824, 200, -16},
    { 840, 216, -40},
    { 864, 272, -48},
    { 880, 208, -56},
    { 912, 176, -64},
    { 984, 176, -32},
    { 1040, 176, 16},
    { 992, 120, 72},
    { 1112, 80, 104},
    { 1232, 104, 144},
    { 1112, 184, 152},
    { 928, 192, 56},
    { 992, 160, 8},
    { 1072, 200, 40},
    { 968, 224, 24},
    { 888, 232, 24},
    { 824, 168, 64},
    { 768, 112, 104},
    { 776, 80, 144},
    { 816, 64, 160},
    { 808, 64, 136},
    { 888, 88, 144},
    { 976, 104, 128},
    { 968, 120, 16},
    { 1168, 128, 16},
    { 1232, 184, 56},
    { 1008, 200, -96},
    { 904, 208, -208},
    { 808, 192, -136},
    { 840, 88, -8},
    { 896, 8, 88},
    { 888, 32, 96},
    { 856, 72, 40},
    { 808, 120, 0},
    { 808, 152, -48},
    { 872, 184, -80},
    { 872, 208, -88},
    { 816, 256, -144},
    { 912, 216, -120},
    { 1072, 240, -8},
    { 984, 184, 48},
    { 1208, 184, 40},
    { 1288, 208, 24},
    { 1112, 152, 80},
    { 1016, 72, 56},
    { 1024, 96, 72},
    { 984, 160, 96},
    { 888, 216, 56},
    { 848, 200, 40},
    { 808, 152, 64},
    { 792, 120, 56},
    { 816, 80, 72},
    { 832, 88, 72},
    { 872, 136, 64},
    { 896, 144, 88},
    { 952, 128, 80},
    { 936, 152, 0},
    { 1200, 168, 56},
    { 1176, 184, 48},
    { 976, 208, -96},
    { 920, 200, -128},
    { 816, 168, -112},
    { 856, 88, -32},
    { 888, 64, 16},
    { 896, 96, 32},
    { 848, 120, 24},
    { 824, 160, -8},
    { 848, 152, 0},
    { 896, 176, 0},
    { 896, 256, -56},
    { 864, 216, -88},
    { 880, 152, -88},
    { 952, 136, -48},
    { 984, 144, 8},
    { 936, 112, 40},
    { 1160, 120, 56},
    { 1240, 168, 56},
    { 1048, 216, 80},
    { 944, 152, 48},
    { 1024, 128, 80},
    { 1080, 160, 120},
    { 960, 200, 56},
    { 864, 168, 24},
    { 816, 152, 24},
    { 800, 80, 56},
    { 800, 48, 80},
    { 808, 56, 56},
    { 824, 104, 56},
    { 880, 144, 96},
    { 960, 152, 104},
    { 976, 192, 48},
    { 992, 160, 8},
    { 1216, 176, 96},
    { 1064, 208, 24},
    { 976, 208, -88},
    { 864, 224, -128},
    { 832, 144, -64},
    { 904, 40, 40},
    { 928, 48, 96},
    { 912, 120, 80},
    { 856, 144, 24},
    { 824, 144, -32},
    { 856, 152, -64},
    { 856, 136, -72},
    { 848, 152, -64},
    { 856, 136, -64},
    { 928, 128, -32},
    { 1024, 152, 0},
    { 976, 136, 48},
    { 1176, 80, 104},
    { 1312, 112, 168},
    { 1080, 240, 96},
    { 928, 200, 0},
    { 1056, 128, 8},
    { 1064, 128, 48},
    { 960, 168, 24},
    { 840, 160, 40},
    { 816, 112, 56},
    { 792, 80, 112},
    { 800, 56, 120},
    { 808, 72, 80},
    { 856, 80, 80},
    { 920, 96, 112},
    { 1032, 144, 112},
    { 1016, 160, 24},
    { 1224, 176, 112},
    { 1072, 184, -8},
    { 952, 240, -144},
    { 840, 272, -168},
    { 832, 168, -80},
    { 872, 64, 0},
    { 856, 56, 48},
    { 856, 96, 24},
    { 816, 120, 0},
    { 808, 176, -24},
    { 848, 200, -24},
    { 864, 200, -48},
    { 872, 192, -72},
    { 880, 264, -88},
    { 976, 216, -64},
    { 1024, 224, -48},
    { 1248, 192, 64},
    { 1480, 208, 96},
    { 1168, 96, 144},
    { 1032, 56, 64},
    { 1008, 24, 24},
    { 888, 120, -24},
    { 840, 208, -16},
    { 856, 208, 24},
    { 800, 160, 88},
    { 792, 48, 152},
    { 824, 80, 152},
    { 808, 96, 80},
    { 840, 136, 80},
    { 864, 144, 80},
    { 960, 112, 72},
    { 984, 128, 8},
    { 1256, 128, 80},
    { 1152, 200, 24},
    { 1080, 224, -64},
    { 976, 240, -88},
    { 784, 192, -136},
    { 784, 56, -88},
    { 856, 24, 24},
    { 896, 64, 24},
    { 904, 80, 48},
    { 872, 176, 0},
    { 832, 208, -40},
    { 840, 192, -56},
    { 824, 160, -64},
    { 824, 200, -104},
    { 896, 184, -96},
    { 1064, 168, -24},
    { 1168, 136, 40},
    { 1280, 168, 64},
    { 1264, 184, 80},
    { 1152, 128, 120},
    { 960, 104, 24},
    { 912, 128, 16},
    { 904, 144, 32},
    { 872, 192, 72},
    { 912, 184, 88},
    { 864, 120, 144},
    { 840, 104, 128},
    { 832, 48, 112},
    { 816, 56, 72},
    { 808, 120, 16},
    { 872, 144, 24},
    { 880, 168, 48},
    { 944, 176, 40},
    { 936, 200, -32},
    { 1176, 184, 56},
    { 1152, 168, 120},
    { 992, 208, -24},
    { 944, 192, -136},
    { 784, 136, -88},
    { 816, 40, 0},
    { 912, 32, 72},
    { 920, 64, 96},
    { 896, 128, 72},
    { 840, 192, -8},
    { 832, 208, -56},
    { 864, 192, -96},
    { 848, 248, -104},
    { 816, 184, -104},
    { 896, 136, -64},
    { 1040, 128, 16},
    { 1032, 152, 40},
    { 1000, 152, 40},
    { 1184, 152, 88},
    { 1224, 232, 72},
    { 1080, 200, 96},
    { 968, 120, 16},
    { 976, 104, 24},
    { 976, 136, 8},
    { 904, 176, 24},
    { 856, 176, 56},
    { 840, 120, 88},
    { 840, 112, 128},
    { 816, 72, 128},
    { 784, 56, 88},
    { 816, 64, 80},
    { 880, 96, 104},
    { 984, 136, 96},
    { 960, 168, -24},
    { 1296, 136, 88},
    { 1216, 176, 64},
    { 976, 232, -96},
    { 848, 216, -144},
    { 824, 136, -56},
    { 872, 40, 24},
    { 912, 40, 72},
    { 896, 80, 88},
    { 840, 136, 16},
    { 800, 152, -32},
    { 816, 160, -40},
    { 856, 176, -48},
    { 872, 176, -56},
    { 880, 168, -64},
    { 968, 160, -48},
    { 1032, 168, -24},
    { 1088, 144, 72},
    { 1224, 152, 104},
    { 1224, 240, 80},
    { 1080, 184, 128},
    { 1016, 72, 80},
    { 1008, 80, 64},
    { 928, 120, 48},
    { 872, 144, 40},
    { 832, 136, 40},
    { 840, 104, 96},
    { 800, 56, 136},
    { 816, 96, 112},
    { 808, 120, 80},
    { 864, 128, 104},
    { 920, 128, 112},
    { 960, 136, 72},
    { 960, 144, 16},
    { 1232, 168, 120},
    { 1072, 216, 48},
    { 944, 224, -136},
    { 816, 160, -112},
    { 864, 64, 0},
    { 936, -16, 88},
    { 936, 64, 104},
    { 904, 144, 72},
    { 840, 200, 8},
    { 808, 184, -16},
    { 832, 200, -32},
    { 808, 152, -56},
    { 848, 184, -72},
    { 960, 160, -48},
    { 1120, 176, 8},
    { 1024, 176, 16},
    { 1152, 152, 40},
    { 1320, 160, 104},
    { 1136, 240, 128},
    { 1024, 184, 64},
    { 1008, 104, 72},
    { 968, 128, 80},
    { 920, 144, 56},
    { 896, 184, 64},
    { 856, 160, 80},
    { 840, 144, 104},
    { 832, 64, 144},
    { 808, 48, 120},
    { 800, 56, 80},
    { 864, 80, 80},
    { 904, 112, 96},
    { 944, 152, 48},
    { 968, 168, -48},
    { 1232, 192, 96},
    { 1096, 200, 32},
    { 936, 208, -112},
    { 824, 200, -136},
    { 840, 152, -80},
    { 904, 48, 16},
    { 944, 64, 72},
    { 936, 104, 48},
    { 856, 136, 0},
    { 832, 152, -40},
    { 848, 168, -64},
    { 856, 192, -72},
    { 864, 232, -104},
    { 888, 200, -104},
    { 1016, 192, -40},
    { 1072, 168, 8},
    { 944, 128, 24},
    { 1184, 136, 56},
    { 1344, 224, 56},
    { 1080, 256, 96},
    { 960, 136, 32},
    { 1000, 96, 72},
    { 992, 128, 88},
    { 936, 192, 64},
    { 920, 192, 56},
    { 880, 112, 88},
    { 856, 96, 104},
    { 824, 48, 88},
    { 784, 64, 40},
    { 832, 120, 48},
    { 832, 160, 64},
    { 896, 184, 48},
    { 920, 184, -32},
    { 1208, 192, 40},
    { 1208, 160, 72},
    { 1024, 184, -72},
    { 920, 184, -120},
    { 832, 144, -88},
    { 856, 48, 0},
    { 896, 32, 56},
    { 912, 88, 48},
    { 880, 152, 8},
    { 840, 240, -40},
    { 848, 232, -64},
    { 872, 216, -80},
    { 824, 272, -96},
    { 784, 176, -120},
    { 912, 136, -64},
    { 1160, 152, 40},
    { 1040, 144, 40},
    { 1152, 136, 8},
    { 1288, 184, 16},
    { 1192, 208, 80},
    { 1048, 184, 16},
    { 968, 136, 16},
    { 912, 152, 40},
    { 920, 168, 56},
    { 920, 176, 112},
    { 880, 176, 112},
    { 832, 136, 96},
    { 816, 88, 136},
    { 824, 56, 120},
    { 800, 56, 72},
    { 848, 80, 64},
    { 888, 120, 48},
    { 952, 160, 40},
    { 936, 176, -40},
    { 1256, 176, 64},
    { 1192, 192, 72},
    { 1008, 216, -80},
    { 864, 176, -144},
    { 784, 104, -104},
    { 864, 24, 8},
    { 944, 24, 88},
    { 944, 112, 72},
    { 896, 176, 32},
    { 856, 184, -24},
    { 840, 200, -72},
    { 864, 216, -104},
    { 856, 176, -96},
    { 856, 160, -80},
    { 928, 176, -48},
    { 1032, 176, 16},
    { 1016, 152, 56},
    { 1096, 96, 80},
    { 1224, 128, 112},
    { 1176, 216, 96},
    { 936, 224, 32},
    { 976, 144, 16},
    { 1032, 128, 48},
    { 968, 144, 24},
    { 912, 160, 40},
    { 848, 128, 64},
    { 816, 104, 112},
    { 816, 72, 160},
    { 816, 64, 168},
    { 816, 88, 104},
    { 872, 128, 80},
    { 936, 152, 72},
    { 880, 192, -96},
    { 1248, 168, -24},
    { 1200, 184, 0},
    { 1072, 224, -112},
    { 944, 208, -152},
    { 824, 128, -128},
    { 800, 16, -48},
    { 832, -24, 40},
    { 848, 16, 56},
    { 848, 72, 48},
    { 864, 168, 16},
    { 888, 248, -40},
    { 880, 240, -96},
    { 864, 256, -152},
    { 856, 200, -120},
    { 920, 176, -96},
    { 1016, 184, -56},
    { 1000, 184, -24},
    { 1232, 160, 32},
    { 1376, 184, 112},
    { 1144, 160, 112},
    { 888, 96, 56},
    { 1016, 64, 64},
    { 976, 136, 16},
    { 944, 232, -16},
    { 904, 208, 24},
    { 832, 128, 56},
    { 800, 128, 80},
    { 776, 48, 120},
    { 768, 56, 88},
    { 800, 104, 64},
    { 880, 128, 80},
    { 944, 152, 64},
    { 888, 144, -72},
    { 1256, 128, 64},
    { 1184, 168, 32},
    { 1056, 208, -96},
    { 944, 208, -136},
    { 872, 208, -176},
    { 832, 64, -88},
    { 832, 24, -24},
    { 848, 40, 8},
    { 864, 80, 8},
    { 864, 152, -24},
    { 872, 216, -56},
    { 872, 216, -96},
    { 864, 200, -160},
    { 848, 216, -144},
    { 904, 160, -104},
    { 1024, 160, -40},
    { 968, 144, -8},
    { 1224, 144, 56},
    { 1416, 208, 88},
    { 1144, 232, 112},
    { 1032, 88, 32},
    { 1032, 80, 24},
    { 928, 112, 8},
    { 848, 128, 8},
    { 832, 152, 8},
    { 832, 136, 64},
    { 824, 104, 88},
    { 816, 128, 64},
    { 768, 104, 16},
    { 864, 104, 64},
    { 904, 112, 96},
    { 936, 136, 64},
    { 944, 152, -32},
    { 1344, 184, 160},
    { 1080, 216, 48},
    { 936, 240, -208},
    { 800, 192, -208},
    { 856, 72, -72},
    { 920, -16, 64},
    { 912, 72, 112},
    { 888, 152, 96},
    { 856, 192, 16},
    { 848, 128, -8},
    { 888, 160, -64},
    { 872, 120, -104},
    { 840, 168, -136},
    { 840, 152, -128},
    { 960, 176, -48},
    { 1056, 208, 0},
    { 1120, 144, 88},
    { 1304, 160, 120},
    { 1208, 192, 136},
    { 952, 152, 48},
    { 992, 88, 16},
    { 1064, 160, 40},
    { 968, 216, 24},
    { 912, 200, 48},
    { 880, 176, 72},
    { 840, 144, 88},
    { 792, 48, 128},
    { 776, 32, 104},
    { 760, 56, 56},
    { 880, 104, 72},
    { 904, 152, 80},
    { 928, 168, 16},
    { 920, 136, -72},
    { 1344, 176, 136},
    { 1112, 200, 32},
    { 976, 200, -136},
    { 856, 192, -152},
    { 824, 160, -136},
    { 864, 64, -32},
    { 896, 72, 40},
    { 864, 120, 40},
    { 856, 152, 16},
    { 864, 168, -16},
    { 864, 160, -56},
    { 848, 200, -104},
    { 840, 168, -128},
    { 880, 144, -120},
    { 1048, 168, -64},
    { 1056, 184, -32},
    { 1192, 168, 32},
    { 1392, 200, 80},
    { 1232, 232, 120},
    { 1008, 160, 8},
    { 992, 80, 8},
    { 1000, 96, 32},
    { 888, 96, 72},
    { 856, 152, 72},
    { 880, 136, 96},
    { 864, 80, 144},
    { 840, 80, 144},
    { 776, 64, 56},
    { 840, 64, 56},
    { 880, 104, 48},
    { 920, 168, 40},
    { 888, 200, -80},
    { 1224, 192, 0},
    { 1152, 208, 64},
    { 976, 176, -80},
    { 880, 168, -192},
    { 784, 152, -128},
    { 840, 40, 0},
    { 928, 24, 88},
    { 960, 88, 104},
    { 936, 136, 48},
    { 880, 160, -32},
    { 856, 176, -56},
    { 880, 200, -96},
    { 864, 256, -120},
    { 808, 168, -112},
    { 880, 128, -96},
    { 1088, 144, 0},
    { 1168, 144, 80},
    { 1296, 168, 104},
    { 1200, 216, 72},
    { 1104, 128, 80},
    { 952, 96, 16},
    { 936, 112, 24},
    { 960, 168, 24},
    { 928, 184, 104},
    { 920, 192, 128},
    { 872, 192, 112},
    { 816, 96, 128},
    { 824, 40, 136},
    { 800, 56, 80},
    { 816, 80, 40},
    { 872, 136, 48},
    { 920, 168, 24},
    { 896, 176, -48},
    { 1024, 112, -8},
    { 1256, 160, 152},
    { 1008, 152, 24},
    { 936, 184, -104},
    { 840, 216, -120},
    { 824, 152, -72},
    { 872, 32, 24},
    { 928, 32, 80},
    { 904, 88, 48},
    { 888, 136, 16},
    { 864, 136, -32},
    { 872, 152, -72},
    { 888, 184, -104},
    { 888, 144, -96},
    { 904, 144, -64},
    { 952, 144, -40},
    { 1016, 152, 0},
    { 1088, 136, 104},
    { 1272, 160, 144},
    { 1248, 232, 104},
    { 1072, 152, 128},
    { 1040, 40, 88},
    { 1008, 48, 56},
    { 936, 120, 24},
    { 880, 168, 32},
    { 872, 176, 32},
    { 856, 112, 96},
    { 824, 96, 128},
    { 808, 80, 120},
    { 808, 104, 72},
    { 880, 120, 64},
    { 888, 152, 64},
    { 912, 160, 16},
    { 1120, 136, 40},
    { 1192, 168, 56},
    { 984, 192, -96},
    { 976, 224, -168},
    { 832, 200, -176},
    { 800, 64, -80},
    { 824, 16, 24},
    { 864, 48, 64},
    { 904, 48, 72},
    { 912, 144, 40},
    { 888, 208, -8},
    { 880, 240, -88},
    { 888, 200, -104},
    { 856, 216, -152},
    { 824, 152, -112},
    { 888, 144, -72},
    { 1024, 160, 0},
    { 1024, 152, 32},
    { 1144, 112, 64},
    { 1272, 136, 104},
    { 1144, 176, 112},
    { 992, 160, 72},
    { 960, 88, 40},
    { 1008, 128, 32},
    { 968, 176, 16},
    { 944, 200, 32},
    { 912, 152, 64},
    { 864, 88, 96},
    { 824, 112, 120},
    { 816, 64, 112},
    { 784, 88, 56},
    { 848, 112, 72},
    { 880, 136, 104},
    { 960, 184, 80},
    { 1000, 184, 40},
    { 1240, 184, 96},
    { 1096, 176, 8},
    { 1080, 184, -128},
    { 904, 160, -136},
    { 784, 120, -104},
    { 800, 8, 8},
    { 904, 16, 72},
    { 920, 64, 96},
    { 880, 104, 64},
    { 856, 168, 8},
    { 872, 200, -32},
    { 872, 208, -64},
    { 832, 248, -112},
    { 784, 184, -128},
    { 896, 136, -72},
    { 1072, 144, 8},
    { 1048, 184, 32},
    { 1152, 128, 64},
    { 1272, 184, 72},
    { 1176, 216, 56},
    { 928, 136, 0},
    { 920, 56, 0},
    { 1040, 96, 72},
    { 984, 200, 56},
    { 944, 248, 96},
    { 880, 184, 88},
    { 808, 56, 96},
    { 808, 80, 96},
    { 800, 56, 88},
    { 768, 80, 48},
    { 864, 120, 64},
    { 936, 136, 88},
    { 944, 152, 32},
    { 976, 128, -16},
    { 1200, 168, 64},
    { 1088, 160, 8},
    { 1072, 184, -56},
    { 896, 200, -104},
    { 784, 168, -120},
    { 800, 56, -40},
    { 872, 48, 32},
    { 904, 64, 48},
    { 864, 88, 32},
    { 856, 152, -24},
    { 872, 168, -56},
    { 864, 160, -72},
    { 872, 200, -128},
    { 864, 152, -120},
    { 896, 136, -80},
    { 1008, 176, -40},
    { 1024, 184, 24},
    { 1264, 184, 88},
    { 1424, 240, 80},
    { 1128, 192, 128},
    { 1008, 48, 40},
    { 992, 24, 64},
    { 936, 104, 16},
    { 880, 112, 64},
    { 856, 168, 64},
    { 848, 144, 88},
    { 832, 112, 128},
    { 816, 152, 96},
    { 808, 88, 72},
    { 872, 88, 64},
    { 872, 120, 80},
    { 960, 152, 80},
    { 904, 152, -24},
    { 1216, 168, 64},
    { 1112, 168, 40},
    { 1048, 200, -72},
    { 936, 200, -128},
    { 816, 168, -112},
    { 816, 40, -32},
    { 888, 16, 56},
    { 920, 56, 80},
    { 880, 80, 72},
    { 864, 176, 8},
    { 872, 208, -24},
    { 872, 224, -80},
    { 856, 168, -104},
    { 840, 192, -112},
    { 912, 136, -40},
    { 1056, 152, 24},
    { 1040, 168, 32},
    { 1080, 160, 48},
    { 1240, 144, 88},
    { 1216, 224, 88},
    { 1040, 176, 56},
    { 952, 80, 16},
    { 952, 72, 48},
    { 952, 88, 56},
    { 920, 168, 104},
    { 912, 224, 104},
    { 880, 160, 120},
    { 856, 168, 112},
    { 848, 88, 104},
    { 824, 56, 48},
    { 832, 80, 0},
    { 856, 104, 16},
    { 904, 144, 48},
    { 976, 176, 32},
    { 952, 200, -72},
    { 1200, 176, 80},
    { 1088, 128, 72},
    { 944, 152, -48},
    { 840, 200, -112},
    { 856, 184, -48},
    { 896, 112, 64},
    { 944, 88, 88},
    { 920, 80, 72},
    { 864, 136, 24},
    { 832, 128, -24},
    { 840, 176, -72},
    { 848, 176, -72},
    { 840, 192, -72},
    { 928, 176, -64},
    { 1024, 152, 0},
    { 1048, 144, 24},
    { 1072, 120, 40},
    { 1200, 128, 88},
    { 1288, 200, 120},
    { 1032, 168, 120},
    { 960, 72, 48},
    { 984, 80, 32},
    { 984, 136, 16},
    { 920, 208, 32},
    { 864, 176, 40},
    { 840, 168, 72},
    { 784, 88, 120},
    { 776, 72, 136},
    { 784, 80, 112},
    { 856, 104, 112},
    { 928, 120, 128},
    { 968, 120, 72},
    { 1120, 88, 72},
    { 1264, 136, 128},
    { 1048, 192, -48},
    { 872, 232, -232},
    { 824, 184, -160},
    { 848, 40, 0},
    { 896, 16, 80},
    { 896, 40, 104},
    { 888, 64, 72},
    { 856, 112, 24},
    { 832, 144, -40},
    { 848, 176, -80},
    { 856, 192, -104},
    { 840, 224, -144},
    { 888, 152, -88},
    { 1048, 224, -24},
    { 1008, 184, 48},
    { 1192, 152, 72},
    { 1384, 184, 72},
    { 1136, 240, 88},
    { 1008, 144, 72},
    { 1008, 56, 80},
    { 976, 80, 96},
    { 880, 112, 64},
    { 840, 128, 56},
    { 848, 112, 88},
    { 840, 88, 112},
    { 832, 80, 112},
    { 776, 128, 64},
    { 816, 112, 64},
    { 872, 136, 72},
    { 952, 152, 80},
    { 952, 168, -8},
    { 1288, 152, 72},
    { 1216, 160, 64},
    { 968, 200, -120},
    { 856, 192, -136},
    { 824, 144, -72},
    { 856, 64, 48},
    { 904, 56, 88},
    { 912, 96, 96},
    { 880, 144, 32},
    { 840, 160, -16},
    { 832, 200, -56},
    { 840, 208, -88},
    { 840, 288, -112},
    { 848, 232, -112},
    { 912, 168, -64},
    { 1048, 176, 0},
    { 976, 144, 24},
    { 1152, 128, 40},
    { 1416, 200, 96},
    { 1160, 192, 104},
    { 1008, 128, 32},
    { 952, 80, 24},
    { 952, 120, 48},
    { 904, 184, 40},
    { 888, 248, 64},
    { 856, 216, 80},
    { 848, 104, 144},
    { 848, 96, 168},
    { 832, 56, 128},
    { 848, 64, 80},
    { 912, 88, 80},
    { 888, 120, 72},
    { 936, 152, 48},
    { 952, 176, -32},
    { 1176, 144, 96},
    { 1112, 152, 32},
    { 1048, 184, -72},
    { 960, 232, -64},
    { 800, 176, -88},
    { 808, 56, -8},
    { 896, 56, 32},
    { 968, 64, 80},
    { 912, 128, 40},
    { 856, 152, -16},
    { 840, 160, -56},
    { 864, 152, -56},
    { 880, 232, -96},
    { 832, 200, -112},
    { 808, 152, -112},
    { 968, 128, -24},
    { 1080, 128, 64},
    { 1072, 120, 104},
    { 1136, 168, 48},
    { 1200, 224, 56},
    { 1160, 192, 104},
    { 952, 112, 24},
    { 896, 96, 40},
    { 920, 120, 56},
    { 960, 168, 112},
    { 928, 192, 144},
    { 872, 168, 120},
    { 824, 160, 120},
    { 816, 72, 120},
    { 832, 48, 96},
    { 856, 72, 72},
    { 888, 136, 48},
    { 904, 160, 40},
    { 944, 152, 16},
    { 904, 136, -56},
    { 872, 88, -72},
    { 1200, 104, 104},
    { 1080, 168, 96},
    { 960, 208, 0},
    { 848, 240, -72},
    { 840, 216, -40},
    { 952, 112, -8},
    { 968, 104, 16},
    { 928, 144, -8},
    { 864, 152, -72},
    { 800, 144, -104},
    { 776, 128, -96},
    { 776, 96, -40},
    { 848, 104, 8},
    { 992, 136, 16},
    { 1072, 192, 72},
    { 1208, 152, 120},
    { 1376, 96, 136},
    { 1224, 160, 96},
    { 1016, 152, 40},
    { 968, 104, -8},
    { 984, 128, 0},
    { 912, 168, 64},
    { 872, 160, 80},
    { 832, 168, 72},
    { 792, 112, 112},
    { 776, 104, 128},
    { 792, 104, 128},
    { 832, 96, 104},
    { 864, 88, 112},
    { 960, 96, 104},
    { 944, 112, 0},
    { 1176, 104, 40},
    { 1128, 144, 72},
    { 1032, 208, -48},
    { 1008, 248, -104},
    { 840, 232, -104},
    { 832, 80, -24},
    { 888, 16, 56},
    { 904, 48, 72},
    { 872, 64, 40},
    { 824, 120, -32},
    { 816, 152, -64},
    { 832, 168, -80},
    { 840, 192, -104},
    { 864, 240, -120},
    { 928, 168, -64},
    { 1072, 160, 8},
    { 1056, 136, 56},
    { 1160, 104, 64},
    { 1288, 120, 88},
    { 1136, 144, 104},
    { 944, 104, 16},
    { 944, 48, 16},
    { 984, 80, 56},
    { 944, 192, 48},
    { 952, 224, 72},
    { 880, 176, 48},
    { 808, 112, 24},
    { 808, 56, 72},
    { 800, 48, 72},
    { 816, 96, 40},
    { 880, 128, 72},
    { 888, 144, 72},
    { 968, 144, 56},
    { 1136, 152, 40},
    { 1272, 152, 112},
    { 1072, 184, -40},
    { 1064, 200, -152},
    { 840, 168, -152},
    { 752, 64, -96},
    { 792, -24, 16},
    { 896, 40, 88},
    { 896, 80, 104},
    { 864, 136, 48},
    { 832, 120, -8},
    { 832, 128, -56},
    { 840, 88, -96},
    { 832, 168, -128},
    { 816, 184, -120},
    { 920, 176, -72},
    { 1040, 184, -24},
    { 976, 144, 40},
    { 1168, 120, 72},
    { 1336, 152, 80},
    { 1088, 200, 96},
    { 984, 112, 48},
    { 1056, 72, 72},
    { 1048, 128, 56},
    { 928, 176, 48},
    { 856, 184, 40},
    { 816, 136, 56},
    // elapsed: 1 minutes
    { 808, 120, 64},
    { 800, 72, 88},
    { 792, 96, 32},
    { 856, 128, 56},
    { 880, 128, 88},
    { 952, 136, 104},
    { 936, 136, 24},
    { 1128, 96, 56},
    { 1192, 128, 136},
    { 1008, 184, -8},
    { 920, 208, -144},
    { 776, 232, -128},
    { 816, 176, -32},
    { 928, 112, 56},
    { 936, 136, 80},
    { 888, 168, 24},
    { 832, 168, -32},
    { 824, 168, -64},
    { 808, 128, -64},
    { 808, 168, -64},
    { 816, 168, -64},
    { 928, 176, -40},
    { 1056, 216, 0},
    { 1056, 200, 48},
    { 1304, 160, 96},
    { 1320, 152, 136},
    { 1088, 136, 72},
    { 1040, 56, 40},
    { 984, 104, 24},
    { 856, 168, -8},
    { 856, 208, 24},
    { 824, 192, 64},
    { 824, 120, 104},
    { 840, 144, 136},
    { 840, 104, 144},
    { 840, 96, 120},
    { 872, 112, 88},
    { 904, 96, 96},
    { 984, 112, 48},
    { 1056, 144, 8},
    { 1224, 168, 112},
    { 1056, 208, -16},
    { 1016, 208, -120},
    { 840, 168, -96},
    { 792, 80, -64},
    { 832, 8, 24},
    { 888, 32, 56},
    { 872, 88, 56},
    { 856, 160, 8},
    { 864, 168, -16},
    { 856, 208, -64},
    { 848, 184, -80},
    { 832, 176, -88},
    { 848, 168, -64},
    { 920, 184, -24},
    { 1040, 208, 24},
    { 944, 152, 64},
    { 1128, 112, 40},
    { 1320, 152, 72},
    { 1144, 208, 128},
    { 976, 168, 24},
    { 1048, 120, 48},
    { 1064, 136, 72},
    { 936, 160, 56},
    { 872, 168, 40},
    { 816, 104, 88},
    { 800, 64, 120},
    { 800, 56, 128},
    { 784, 120, 64},
    { 848, 128, 64},
    { 888, 168, 96},
    { 968, 152, 80},
    { 928, 152, -24},
    { 1280, 160, 80},
    { 1136, 160, 24},
    { 968, 216, -120},
    { 856, 224, -152},
    { 840, 168, -72},
    { 888, 64, 48},
    { 912, 40, 80},
    { 904, 104, 64},
    { 840, 152, -8},
    { 824, 168, -40},
    { 824, 176, -56},
    { 808, 168, -80},
    { 832, 200, -88},
    { 912, 144, -72},
    { 1096, 176, -16},
    { 1080, 176, -16},
    { 1144, 136, 8},
    { 1224, 160, 24},
    { 1176, 168, 96},
    { 1056, 168, 64},
    { 976, 144, 32},
    { 976, 152, 40},
    { 944, 168, 72},
    { 928, 176, 80},
    { 864, 136, 120},
    { 808, 112, 112},
    { 800, 64, 112},
    { 816, 48, 96},
    { 800, 72, 72},
    { 880, 104, 80},
    { 896, 128, 96},
    { 928, 168, 40},
    { 1000, 160, -8},
    { 1216, 208, 104},
    { 1080, 184, 48},
    { 1008, 184, -96},
    { 864, 160, -88},
    { 832, 80, -40},
    { 888, 0, 48},
    { 920, 40, 64},
    { 888, 88, 64},
    { 848, 136, 32},
    { 848, 176, 0},
    { 856, 192, -16},
    { 848, 264, -96},
    { 832, 200, -96},
    { 872, 160, -88},
    { 984, 160, -40},
    { 1040, 168, -8},
    { 1128, 120, 88},
    { 1432, 144, 136},
    { 1160, 224, 104},
    { 1000, 112, 96},
    { 1048, 32, 96},
    { 1000, 96, 80},
    { 920, 176, 32},
    { 888, 192, 56},
    { 840, 168, 64},
    { 816, 88, 88},
    { 800, 72, 120},
    { 768, 72, 96},
    { 800, 80, 88},
    { 872, 104, 120},
    { 936, 128, 128},
    { 936, 168, 32},
    { 1264, 136, 112},
    { 1200, 176, 56},
    { 1024, 184, -128},
    { 968, 192, -144},
    { 856, 128, -104},
    { 840, -8, -8},
    { 896, 16, 40},
    { 880, 56, 48},
    { 824, 144, 0},
    { 816, 184, -16},
    { 824, 208, -48},
    { 840, 216, -72},
    { 832, 296, -112},
    { 800, 184, -120},
    { 968, 168, -32},
    { 1128, 160, 32},
    { 1000, 136, 24},
    { 1232, 104, 0},
    { 1352, 192, 24},
    { 1144, 224, 64},
    { 1032, 160, -8},
    { 1008, 112, 48},
    { 952, 136, 56},
    { 904, 144, 88},
    { 856, 168, 104},
    { 808, 136, 96},
    { 784, 112, 120},
    { 800, 72, 120},
    { 808, 64, 80},
    { 840, 88, 40},
    { 888, 112, 48},
    { 944, 128, 72},
    { 952, 152, 16},
    { 1272, 136, 88},
    { 1264, 208, 104},
    { 976, 240, -80},
    { 880, 224, -192},
    { 816, 136, -96},
    { 840, 16, 8},
    { 872, -16, 88},
    { 880, 80, 88},
    { 832, 128, 32},
    { 800, 184, -24},
    { 808, 184, -40},
    { 824, 200, -48},
    { 832, 248, -96},
    { 880, 176, -88},
    { 1040, 184, -56},
    { 1120, 208, -32},
    { 1128, 160, 24},
    { 1312, 168, 72},
    { 1232, 176, 104},
    { 1040, 112, 72},
    { 944, 80, 16},
    { 968, 128, 40},
    { 912, 208, 40},
    { 904, 240, 72},
    { 840, 208, 88},
    { 816, 112, 104},
    { 808, 64, 136},
    { 808, 48, 120},
    { 824, 64, 80},
    { 872, 96, 80},
    { 896, 104, 72},
    { 952, 112, 72},
    { 944, 136, -24},
    { 1312, 168, 96},
    { 1144, 200, 8},
    { 1024, 216, -136},
    { 944, 160, -80},
    { 816, 120, -88},
    { 800, 24, -8},
    { 864, 40, 0},
    { 920, 80, 8},
    { 872, 104, 0},
    { 848, 192, -48},
    { 840, 216, -72},
    { 856, 176, -80},
    { 856, 272, -112},
    { 840, 184, -112},
    { 880, 144, -72},
    { 944, 168, -40},
    { 944, 160, 0},
    { 1176, 136, 64},
    { 1312, 176, 96},
    { 1112, 184, 112},
    { 1104, 96, 112},
    { 1056, 48, 184},
    { 952, 80, 152},
    { 896, 128, 96},
    { 904, 208, 88},
    { 944, 200, 96},
    { 960, 216, 128},
    { 968, 320, 80},
    { 968, 408, 72},
    { 904, 376, 64},
    { 880, 472, -48},
    { 848, 472, -80},
    { 840, 504, -184},
    { 832, 496, -272},
    { 784, 544, -320},
    { 728, 472, -392},
    { 688, 440, -496},
    { 600, 376, -592},
    { 544, 320, -664},
    { 512, 248, -688},
    { 504, 160, -768},
    { 456, 120, -768},
    { 424, 32, -752},
    { 424, -8, -848},
    { 392, -40, -864},
    { 384, -88, -912},
  };
  *len = ARRAY_LENGTH(samples);
  return samples;
}

